(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1485197,      27633]
NotebookOptionsPosition[   1373859,      25343]
NotebookOutlinePosition[   1455820,      27042]
CellTagsIndexPosition[   1455712,      27036]
WindowTitle->Introduction to Numerical Plane Curves
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Introduction to Numerical Plane Curves", "SectionInline",ExpressionUUID->
   "d538cb14-8055-4e27-8974-ea923b260689"],
  $Line = 0; Null]], "Section",
 Evaluatable->False,
 CellChangeTimes->{{3.647005965691028*^9, 3.64700596569107*^9}, {
  3.702918672313233*^9, 3.7029186723132563`*^9}, {3.703266985425777*^9, 
  3.7032670037839746`*^9}},
 CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:1",
 CellID->282314649,ExpressionUUID->"ebcbd362-cd7d-49ee-88c5-afa8c2e543b3"],

Cell["\<\
The current American mathematics curriculum provides beginning math students \
with few examples of plane algebraic curves other than lines and simple \
quadratics. Even advanced math students who are able to take a course in \
algebraic geometry get few actual examples of plane curves, even if one of \
the many available books on curves is used. Instead, the emphasis is on \
developing the big abstract theorem, and most texts have few, if any, \
illustrations. For this reason, I will start with a number of examples so the \
reader can have an idea of what this book is about. \
\>", "Text",
 CellChangeTimes->{{3.684924159703205*^9, 3.684924160334492*^9}, {
   3.684924205354662*^9, 3.684924212198593*^9}, {3.701008650995428*^9, 
   3.701008651018723*^9}, 3.701024205547908*^9, {3.708423462887551*^9, 
   3.708423505630311*^9}, {3.7084399410639715`*^9, 3.7084399434389715`*^9}, 
   3.716034624956717*^9},
 CellID->534820456,ExpressionUUID->"bfbf2b50-c4c7-4776-b98b-ff896557f378"],

Cell[TextData[{
 "First, however, we start with a definition. A ",
 StyleBox["real affine algebraic plane curve",
  FontSlant->"Italic"],
 " is a real solution set of a bivariate polynomial equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "\[VeryThinSpace]", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", "0"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"2e95343c-dab1-465c-888c-18cd3e8193b8"],
 "."
}], "Text",
 CellChangeTimes->{{3.684924333352167*^9, 3.684924337062307*^9}, {
   3.6849243890122*^9, 3.684924462390006*^9}, 3.701008651026741*^9, {
   3.701105538045536*^9, 3.7011055393007298`*^9}, {3.701447296213479*^9, 
   3.701447301275979*^9}, {3.7026532178393183`*^9, 3.7026532281466913`*^9}, {
   3.702653344373332*^9, 3.702653344384983*^9}, {3.702827332020697*^9, 
   3.702827332026787*^9}, {3.702838400405383*^9, 3.702838404972692*^9}, {
   3.7084235416183577`*^9, 3.708423542242337*^9}, {3.742574418224216*^9, 
   3.7425744219668217`*^9}},
 CellID->1508341297,ExpressionUUID->"d5f1fae6-2aaa-49c2-ba1f-8d694c7173e2"],

Cell[TextData[{
 "Historically, the word \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] \
appeared in mathematics about 100 years after the word \
\[OpenCurlyDoubleQuote]imaginary\[CloseCurlyDoubleQuote] was introduced by \
Cardano describing ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{"-", "1"}]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "7901798d-3e79-4ff5-92f6-2636374413e9"],
 ", \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] meaning \
\[OpenCurlyDoubleQuote]not imaginary.\[CloseCurlyDoubleQuote] Likewise the \
word \[OpenCurlyDoubleQuote]affine\[CloseCurlyDoubleQuote] has come to mean \
\[OpenCurlyDoubleQuote]not projective\[CloseCurlyDoubleQuote] or \
\[OpenCurlyDoubleQuote]not infinite.\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.68492449162521*^9, 3.684924535493755*^9}, {
   3.684924569389609*^9, 3.684924731222066*^9}, {3.684924762957936*^9, 
   3.684924765534061*^9}, 3.701008651036016*^9, {3.701008689474375*^9, 
   3.7010086894744263`*^9}, {3.701447328417095*^9, 3.701447354241905*^9}, {
   3.701447433877318*^9, 3.701447465436625*^9}, {3.7026532340236797`*^9, 
   3.702653236682716*^9}, {3.702653347869672*^9, 3.702653347874303*^9}, {
   3.702827570567778*^9, 3.7028275705732803`*^9}, 3.7084399632379713`*^9, {
   3.708440047569971*^9, 3.7084400536169715`*^9}, {3.708700714680429*^9, 
   3.708700717043665*^9}, {3.7087007753774977`*^9, 3.708700810190979*^9}},
 FontTracking->-0.1,
 CellID->1795209491,ExpressionUUID->"c09d921f-ff40-4539-b965-e6cd71c978b4"],

Cell["Some bivariate real polynomials are (input and display):", "CodeCaption",
 CellChangeTimes->{{3.684924775868072*^9, 3.684924809677184*^9}, 
   3.684924871852955*^9, {3.68492503344203*^9, 3.684925058073981*^9}, {
   3.684925164450196*^9, 3.684925170522141*^9}, {3.684925263713989*^9, 
   3.684925264199736*^9}, 3.7087008287478347`*^9},
 CellID->2088158534,ExpressionUUID->"02d499e1-0943-4cb9-9a58-fb7eee0d7f25"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", " ", 
  RowBox[{
   RowBox[{"3", 
    RowBox[{"x", "^", "3"}]}], "-", 
   RowBox[{"2", "x", " ", "y"}], "+", 
   RowBox[{"y", "^", "2"}], "-", 
   RowBox[{"3", "x"}], "+", "1"}]}]], "Input",
 CellChangeTimes->{{3.684925063859996*^9, 3.684925246122627*^9}, {
   3.7028283059686623`*^9, 3.702828307135028*^9}, 3.707488093065773*^9},
 CellLabel->"In[1]:=",
 CellID->1502721664,ExpressionUUID->"3aed2853-1640-4714-93b3-9c951a0903d7"],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"3", " ", "x"}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"2", " ", "x", " ", "y"}], "+", 
  SuperscriptBox["y", "2"]}]], "Output",
 CellChangeTimes->{3.711800553507648*^9, 3.73789117553286*^9, 
  3.7378924140078907`*^9, 3.737893519580757*^9, 3.737893961278808*^9, 
  3.742658533196569*^9},
 CellLabel->"Out[1]=",
 CellID->1456512468,ExpressionUUID->"9382f14b-f892-4504-868d-522fc0c65fbd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", "9"}], 
    RowBox[{"x", "^", "2"}]}], " ", "-", " ", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"y", "^", "2"}]}], " ", "-", " ", "1"}]}]], "Input",
 CellChangeTimes->{{3.684925063859996*^9, 3.684925246122627*^9}, {
  3.7028283059686623`*^9, 3.702828307135028*^9}, {3.707488093065773*^9, 
  3.70748809668876*^9}},
 CellLabel->"In[2]:=",
 CellID->738254982,ExpressionUUID->"c6a2a814-8a1f-42b9-a60f-5834dad6e2a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  FractionBox[
   SuperscriptBox["x", "2"], "9"], "-", 
  FractionBox[
   SuperscriptBox["y", "2"], "4"]}]], "Output",
 CellChangeTimes->{3.711800553524764*^9, 3.737891175585033*^9, 
  3.737892414023485*^9, 3.7378935196780977`*^9, 3.7378939613781357`*^9, 
  3.742658533243657*^9},
 CellLabel->"Out[2]=",
 CellID->438957523,ExpressionUUID->"5ba7c0de-ffdf-4140-bda0-c934bc6d0df4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", "=", " ", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "7", "]"}], "x"}], "-", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "/", "5"}], "]"}], "y"}], " ", "-", 
    RowBox[{"Sqrt", "[", "26", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.684925063859996*^9, 3.684925246122627*^9}, {
  3.7028283059686623`*^9, 3.702828307135028*^9}, {3.707488093065773*^9, 
  3.70748809668876*^9}},
 CellLabel->"In[3]:=",
 CellID->1838453755,ExpressionUUID->"6b8009dc-8d53-4f66-adf8-4b2827c3c734"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "5.0990195135927845`"}], "+", 
  RowBox[{"2.6457513110645907`", " ", "x"}], "-", 
  RowBox[{"0.4472135954999579`", " ", "y"}]}]], "Output",
 CellChangeTimes->{3.711800553559392*^9, 3.737891175604171*^9, 
  3.737892414042227*^9, 3.737893519697435*^9, 3.737893961399575*^9, 
  3.7426585332936373`*^9},
 CellLabel->"Out[3]=",
 CellID->952761616,ExpressionUUID->"20177444-00af-4e31-bbac-3533695f8058"]
}, Open  ]],

Cell[TextData[{
 "The first two are ",
 StyleBox["exact",
  FontSlant->"Italic"],
 " because the coefficients are integers or rational numbers; the third, \
although derived from a symbolic polynomial, is numerical because the \
symbolic square roots have been converted to machine numbers."
}], "Text",
 CellChangeTimes->{{3.684925298860187*^9, 3.684925481850241*^9}, 
   3.7010086510444202`*^9, {3.7074949113760357`*^9, 3.707494912378715*^9}, 
   3.708424001573*^9, {3.7084403773489714`*^9, 3.7084403776049714`*^9}},
 CellID->940222529,ExpressionUUID->"af8ba69f-d6f6-40fc-993b-d994bf1a7d26"],

Cell[TextData[{
 "Note that by putting the cursor on the output and again hitting ",
 Cell[BoxData[
  TemplateBox[{"enter"},
   "Key0"]],
  FontSize->16,ExpressionUUID->"ae51bf75-9ae6-4699-a631-56fd6812cdb3"],
 ", we get:"
}], "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{{3.684925298860187*^9, 3.684925481850241*^9}, 
   3.7010086510444202`*^9, 3.7074949113760357`*^9, 3.7087008488788476`*^9, {
   3.713717452667485*^9, 3.713717453449301*^9}, {3.7392045213265114`*^9, 
   3.739204530822511*^9}, {3.7392724345319767`*^9, 3.739272434643976*^9}, 
   3.740768877343354*^9, {3.740768990758469*^9, 3.74076901643095*^9}},
 CellID->1505406291,ExpressionUUID->"93c99296-6e76-408e-9b4f-d4414326557d"],

Cell[CellGroupData[{

Cell["\<\
-5.0990195135927845` + 2.6457513110645907` x - 0.4472135954999579` y\
\>", "Input",
 CellMargins->{{99, 10}, {4, 12}},
 CellChangeTimes->{{3.707586473885968*^9, 3.707586511390052*^9}},
 CellLabel->"In[4]:=",
 CellID->784418743,ExpressionUUID->"f6ce9a48-a129-401b-937c-7c772564baed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "5.0990195135927845`"}], "+", 
  RowBox[{"2.6457513110645907`", " ", "x"}], "-", 
  RowBox[{"0.4472135954999579`", " ", "y"}]}]], "Output",
 CellChangeTimes->{3.737891175625731*^9, 3.737892414058547*^9, 
  3.737893519717888*^9, 3.737893961429837*^9, 3.742658533343487*^9},
 CellLabel->"Out[4]=",
 CellID->1426408080,ExpressionUUID->"6bce6125-608c-479e-bb91-4fef9f987a7f"]
}, Open  ]],

Cell[TextData[{
 "Unlike the previous display, which only displays the first few digits, now \
we can see the full representation of the numbers in the software. We will \
discuss this fully in Chapter 2, along with what is actually meant when we \
have an equation of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "c59533eb-9bd7-4f0d-9af3-ca46069327de"],
 " where ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]], "InlineMath",ExpressionUUID->
  "34592722-798d-4f61-a50f-0ccb1047bc63"],
 " is this sort of a polynomial. This book will work mainly with this latter \
type of bivariate polynomial rather that the first two types seen in \
classical books on curve theory."
}], "Text",
 CellChangeTimes->{{3.684925504555155*^9, 3.684925579805387*^9}, {
   3.684925638177782*^9, 3.684925721834426*^9}, {3.684926149864427*^9, 
   3.684926177384377*^9}, {3.684926235392107*^9, 3.68492627024061*^9}, {
   3.701008651057845*^9, 3.7010086510685997`*^9}, {3.70100874747799*^9, 
   3.701008782284342*^9}, 3.701008812717884*^9, {3.702653255155274*^9, 
   3.702653280898473*^9}, {3.702653319412895*^9, 3.702653327426486*^9}, {
   3.702837702721472*^9, 3.702837711508696*^9}, 3.707502871845323*^9, 
   3.7084240329285984`*^9, {3.7084404106439714`*^9, 3.7084404108829713`*^9}, {
   3.711469887621195*^9, 3.7114698946831503`*^9}, 3.711470011788494*^9, 
   3.739204556445511*^9, {3.740768519192108*^9, 3.7407685243500032`*^9}},
 CellID->2061743155,ExpressionUUID->"04f5e587-55a3-4815-be68-67514575dacb"],

Cell[TextData[{
 "A polynomial may be multiplied by a constant without changing the solution \
set, but for technical reasons, we may wish to distinguish between ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]], "InlineMath",ExpressionUUID->
  "860d7c06-e09b-4aeb-a87d-386d90b687b3"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "f"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "deae7e41-f829-42de-af4e-ee0490f2f086"],
 " in some cases. "
}], "Text",
 CellChangeTimes->{{3.684926135822017*^9, 3.684926145416012*^9}, {
   3.684926274710907*^9, 3.684926327112029*^9}, {3.684926364024975*^9, 
   3.684926381386533*^9}, {3.7010090585943193`*^9, 3.7010090645071583`*^9}, 
   3.701024209130342*^9, {3.7026533751466217`*^9, 3.7026533830658607`*^9}, {
   3.702827378887204*^9, 3.702827387780685*^9}, {3.702837721121746*^9, 
   3.702837727467081*^9}, {3.7087013190761786`*^9, 3.708701335042178*^9}, 
   3.708701376030178*^9, {3.7087014515521784`*^9, 3.708701485681526*^9}, 
   3.708701606493606*^9, {3.709059582855159*^9, 3.7090595892209787`*^9}, {
   3.711386846412663*^9, 3.711386849116153*^9}, {3.71172132295193*^9, 
   3.711721326206752*^9}, 3.713717482770136*^9},
 CellID->2068561740,ExpressionUUID->"a3914152-26c7-4c54-9cc7-afa22ae61a79"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.1 Linear Curves", "Subsection",
 CellChangeTimes->{{3.684926411004012*^9, 3.684926426922592*^9}},
 CellID->704402897,ExpressionUUID->"1d25da2b-2436-4da6-b150-2aee7cef5d44"],

Cell[TextData[{
 "The easiest algebraic curves, straight lines, are a basic staple of \
beginning algebra. Children are taught that an equation of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    RowBox[{"b", "+", 
     RowBox[{"m", "\[InvisibleSpace]", "x"}]}]}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"0ae3c977-f054-439c-92c9-42e170bddee2"],
 " or ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"a", "\[InvisibleSpace]", "x"}], "+", 
     RowBox[{"b", "\[NegativeThinSpace]", "y"}]}], "=", "c"}], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "f097e237-10d3-41b7-85ab-a83a5dea7337"],
 " has as a solution set a straight line. For our purposes, we will prefer \
the more general formulation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "\[VeryThinSpace]", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "\[InvisibleSpace]", "x"}], "+", 
      RowBox[{"b", "\[NegativeThinSpace]", "y"}], "-", "c"}], "=", "0"}]}], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "a292ba2d-ce44-4a10-9e5b-e073c91bb489"],
 "."
}], "Text",
 CellChangeTimes->{{3.684927309243254*^9, 3.684927359526076*^9}, {
   3.684927439621767*^9, 3.684927471054059*^9}, {3.684927600215451*^9, 
   3.684927771154999*^9}, {3.701008651077499*^9, 3.70100865108912*^9}, {
   3.701008929654932*^9, 3.701008987585927*^9}, {3.7010090717937737`*^9, 
   3.701009083761174*^9}, {3.701009128873057*^9, 3.701009247781927*^9}, {
   3.70265341161054*^9, 3.7026534124498034`*^9}, {3.702837735983512*^9, 
   3.702837751427409*^9}, {3.702838412308902*^9, 3.702838415228791*^9}, {
   3.707494984167419*^9, 3.707494987713916*^9}, 3.7084242717316427`*^9, {
   3.7087023452766533`*^9, 3.708702364129141*^9}, {3.709059618853002*^9, 
   3.709059714967018*^9}, {3.709384357018813*^9, 3.709384412313555*^9}, {
   3.7392728450525045`*^9, 3.7392728479477944`*^9}, {3.740766921215309*^9, 
   3.74076695135608*^9}, {3.7407669907451553`*^9, 3.740766991105042*^9}, {
   3.7407698503329477`*^9, 3.7407698504988537`*^9}, {3.742574536169907*^9, 
   3.742574536169959*^9}},
 CellID->1969627615,ExpressionUUID->"e40101ec-309d-4faf-9a77-b501bb047a90"],

Cell["This equation defines an algebraic curve:", "CodeCaption",
 CellChangeTimes->{{3.684927309243254*^9, 3.684927359526076*^9}, {
  3.684927439621767*^9, 3.684927471054059*^9}, {3.684927600215451*^9, 
  3.684927771154999*^9}, {3.701008651077499*^9, 3.70100865108912*^9}, {
  3.701008929654932*^9, 3.701008987585927*^9}, {3.7010090717937737`*^9, 
  3.701009083761174*^9}, {3.701009128873057*^9, 3.701009247781927*^9}, {
  3.70265341161054*^9, 3.7026534124498034`*^9}, {3.702837735983512*^9, 
  3.702837751427409*^9}, {3.702838412308902*^9, 3.702838415228791*^9}, {
  3.707494984167419*^9, 3.707494984887288*^9}, {3.708702746864049*^9, 
  3.708702747581121*^9}},
 CellID->2073482407,ExpressionUUID->"d92d2bc9-fe56-466d-bd10-c6a695554e06"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "1"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.68492780043593*^9, 3.684927875855183*^9}, 
   3.6857091173405523`*^9, 3.707488110880584*^9},
 CellLabel->"In[5]:=",
 CellID->70906800,ExpressionUUID->"9396d4e4-3d95-4ce1-a61e-aad544ee03c8"],

Cell[BoxData[
 RowBox[{"0.8059223892769305`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.07010844731932853`", " ", "x"}], "-", 
  RowBox[{"0.7700727895764374`", " ", "y"}]}]], "Output",
 CellChangeTimes->{3.711800553624673*^9, 3.737891175651716*^9, 
  3.737892414075529*^9, 3.737893519738172*^9, 3.7378939614519033`*^9, 
  3.7426585333921137`*^9},
 CellLabel->"Out[5]=",
 CellID->1280649099,ExpressionUUID->"ba70bde2-89f1-4690-af98-9248c26e0315"]
}, Open  ]],

Cell[TextData[{
 "Then generate\[NonBreakingSpace]a contour plot of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]], "InlineMath",ExpressionUUID->
  "b6f57151-583c-4b35-80a2-3f8d405f6e68"],
 " as a function of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "280e67e6-284e-4f93-b71a-8fc886d0de3c"],
 " and ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "af9770bb-88c0-42d1-a264-3b9ac204e413"],
 ": ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"f", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]], "InlineCode",
  ExpressionUUID->"94d41a7d-8e11-44c9-b191-ca814cd5abe1"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.707501462808836*^9, 3.707501551527803*^9}, {
   3.7093068526162167`*^9, 3.7093068984883127`*^9}, {3.7093069855219383`*^9, 
   3.709307018278504*^9}, {3.739204899914511*^9, 3.7392049001215115`*^9}, {
   3.740767031680884*^9, 3.740767076320818*^9}, {3.7407671138922033`*^9, 
   3.740767116292048*^9}, 3.7425746623851957`*^9, 3.742648713674839*^9},
 CellID->1393475705,ExpressionUUID->"462f1cad-3cc3-4662-9fc1-6eb1a4403ea3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"f", " ", "\[Equal]", " ", "0"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.68492780043593*^9, 3.684927875855183*^9}, 
   3.6857091173405523`*^9, 3.707488110880584*^9},
 CellLabel->"In[6]:=",
 CellID->897547249,ExpressionUUID->"cb5ef45f-f56d-4246-b39f-0ebc7ab4d3dd"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxFlHs0FHgUxz1imkyHedBj0BiP1UuIar3uzxaawdZOLyqn8sruQUmlRE5J
D1Ga2hWzVrV6K5JUKvOTapFdoTCNVx5NwjAzDDNem5k63XN+5/5zz+9+7vc+
zAJ3cUK0NDQ0/L68Ka82C5Tah4KfrpkEuWbieXa6OWI57LA5qD0JSfmZfsTp
5uh8t46UyZsASxbXgsVlIoF27+Q2jwkIYxyJlk5johstfOKulnGI/Xzhdf0j
M0QPenVY4/o4sKfCLcyQ1dx0nrbzODS4JazL3MNAOqdMu4Ifj0GExVm3nF8Z
6ErTcb2WgjFoKYoQFkXMQ3ttf1p+3XYMyp5SgjocTJH1Rq+LT0pGIa1YGXoM
m6DApfF484VR+EHFY4ywZ18t22oUbtkSWIf/oKP8aoJlRqUSooblVm95cxFu
FvLW7lLCbuFUgjloZsDFSDFdCedyRm3mjMxGy1nl9/bXK+AXB9lH85hZyOSk
U4wnWwGPp3CERsg/euUMLlkBB2cP0Ar9jVDJ85Nu69tHwC6q/1o0h4Zi7TM4
LpYjoNaUhq6dEl91JIzA9pRO5c9PqGiVC+u1nXgYKHd7QssWk1Fj0/Bie41h
8FbpQ0ay7Ax3wZgcvDQEbd3GZFT1gOinr5RDkoH0YVW5AXqm4pBDwKfMVOI4
CXGWVHb26sjBWlU/CUHRquY46RB0vqv2taKQkOOJjURr4RAsepPoD5iABDeS
oyrJQ1Cs+kcXna7qP8D4NAg5a8r/fVmug7h2DzpNigZB+TDccl+iFtrO9J64
bjIIPio+TdTYnkl70SyDSu4RXuXEBPQLqZh6TgZcuN2+IVUJIp7e6aT5MvjG
aanwyN9ZJwXf43t4xPDv3lY/PraUOgCRhlWzghylUKaK/whR+hJvvQoJuIpS
I5ghDV/6WLN/0lMCyw45swrD6mHoTEoOcpeAfWjCm3NxNbBGxSUB9fw2upRY
/im6WzIAHM/4TVnxdfy46b52pr4DUMK+y/3Q9Z5PEC7hDJkNwG11Pj7twBnd
q2H9INamxw3fE/N1p6k82GQXB//oI+NXzjDZUq/og3vqevh5OZ2uvev6wL/A
2SqtVsGnDvN+L6johdzbFcHKlkl+4rb35Od5PeCp1gt71TjtWwo9ECBx8KJY
aWHGZ+O8iA+fwXBreEHzCl3sVphefiekGwrV/cBt42m5sQu64SzR51BTIAHb
NGeVWys+wfr2aHu3oySsmL4hIYMuAqa63zh2gaij1FAE2Cwo71o2Cbu8MW3v
MBBBjNeL0b32M/E3XRXGz6JWiA0wuyx79C/rLlitnjdM3eRKJ2p2AbvQ1b86
hIzvB1CWJdV0AuVm+emsFCr2K2IYbkYdMKkyKs5NPM9Z29sOv8W4ZyQk03Bk
QXXv7hPtsMDx7VWthUY49OZlG0O/D1Ck3hfskd99Kr2hDZKdPARL8mZha0Lq
31td22BlaSt/Z8VsLFrhkXaptQUi1PuInz5OOPosqRlujq+e01Y3F796eKEw
7aMQtvj2CKp20rH2PK8yI30hWKj3HYspiyTeWwVQgX3800ZMsNMOfWYYpwH2
CeQyO11TbKrDkqe4NYBQfU+weXjjtvf27+CVveYJbw4DO/ew52tH1sGg+w2f
S2cYOH9G8lkoqQWW+l7hdS+P/RdGrIHaEV3a4ctm+M6VjEdSp2pINL8VPsJg
Yt8wonLx+qqvPExMcg2MFfMroLWEdDl/gIk7I7NMWzP+AZpObsra++Z46ZOJ
t00Ly77OqwWO7C/epBdRCv8DYO6tEQ==
   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88}]},
      RowBox[{
        RowBox[{
          RowBox[{"0.8059223892769305`", "\[VeryThinSpace]"}], "+", 
          RowBox[{"0.07010844731932853`", " ", 
            TagBox["x", HoldForm]}], "-", 
          RowBox[{"0.7700727895764374`", " ", 
            TagBox["y", HoldForm]}]}], "\[Equal]", "0"}]],
     Annotation[#, 
      0.8059223892769305 + 0.07010844731932853 HoldForm[$CellContext`x] - 
       0.7700727895764374 HoldForm[$CellContext`y] == 0, "Tooltip"]& ]}],
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{175.06640625, Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
  PlotRange->{{-10, 10}, {-10, 10}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7118005536609097`*^9, 3.7378911765013638`*^9, 
  3.737892414786624*^9, 3.7378935198254423`*^9, 3.737893961544417*^9, 
  3.742658533440316*^9},
 CellLabel->"Out[6]=",
 CellID->1788296659,ExpressionUUID->"d2c317e2-a817-490b-9910-bc5230f153c6"]
}, Open  ]],

Cell[TextData[{
 "One thing almost everyone knows is that two points determine a straight \
line. As an example of the spirit of this book, we show how one should find \
the equation of a line through two points, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "=", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["p", "1"], ",", 
      SubscriptBox["p", "2"]}], "}"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"74c1e5dd-f01b-4f77-8a97-a38b2c59e237"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"q", "=", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["q", "1"], ",", 
      SubscriptBox["q", "2"]}], "}"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"af4c5d55-d4ac-441a-bac2-9cc2df3151e9"],
 "."
}], "Text",
 CellChangeTimes->{{3.684927928360791*^9, 3.684927942276195*^9}, {
   3.684928589180657*^9, 3.684928802056489*^9}, 3.701008651099271*^9, {
   3.701009353963326*^9, 3.701009444079862*^9}, {3.701024340645557*^9, 
   3.7010243418610992`*^9}, 3.702649710263631*^9, {3.702653430794426*^9, 
   3.7026534578255157`*^9}, {3.702837762337265*^9, 3.702837765910925*^9}, 
   3.702838995560713*^9, 3.7084242917151146`*^9, 3.7084413763399715`*^9},
 CellID->987453315,ExpressionUUID->"c8b84a2c-e1a1-45c9-abb8-2775557df0d1"],

Cell[TextData[{
 "We want an equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"a", "\[InvisibleSpace]", "x"}], "+", 
     StyleBox["by", "TI"], "+", "c"}], "=", "0"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"a7001918-1145-4b6b-b471-94da113550a8"],
 " with at least one of ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]], "InlineMath",ExpressionUUID->
  "ae9c1428-f4dc-4f5e-ab0b-f8b1fc6c16fd"],
 ", ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]], "InlineMath",ExpressionUUID->
  "e3523df3-68af-4275-ab0d-117ed3743b21"],
 ", ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineMath",ExpressionUUID->
  "172c240f-fe0a-4c90-b25e-e49e69fa364f"],
 " not zero. It will become clear why only ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "\[NotEqual]", "0"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"1a117131-f0d7-405f-a23d-c644ab8a2fe5"],
 " is acceptable. We need to satisfy the system:"
}], "Text",
 PageBreakAbove->True,
 CellChangeTimes->{{3.684928657530953*^9, 3.684928675748888*^9}, {
   3.684928840305943*^9, 3.684928884940534*^9}, {3.684928919558451*^9, 
   3.684928929837998*^9}, {3.684928969881066*^9, 3.684929003393798*^9}, {
   3.684929035804244*^9, 3.684929279638824*^9}, {3.684929516191547*^9, 
   3.684929564553418*^9}, {3.684929740387077*^9, 3.684929804506899*^9}, 
   3.684930620930739*^9, {3.701008651111094*^9, 3.701008651122387*^9}, {
   3.701009483253846*^9, 3.701009601471202*^9}, 3.70102421203216*^9, {
   3.701024355261012*^9, 3.7010243615249166`*^9}, {3.702653505466095*^9, 
   3.7026535060494537`*^9}, {3.702837771643731*^9, 3.702837784204018*^9}, 
   3.708430134651626*^9, 3.7087028837877407`*^9, 3.7087029719975605`*^9, {
   3.70905974005617*^9, 3.709059742046907*^9}, 3.7392731610501013`*^9, {
   3.74076994447707*^9, 3.740769944477117*^9}},
 CellID->374241189,ExpressionUUID->"dfeb4a09-6a1c-4b5f-b1c9-1b52e0ec1371"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"a", 
     SubscriptBox["p", 
      RowBox[{"1", " "}]]}], "+", 
    RowBox[{"b", " ", 
     SubscriptBox["p", 
      RowBox[{"2", " "}]]}], "+", "c"}], "=", "0"}], TraditionalForm], "\n", 
 FormBox[
  RowBox[{"a", 
   FormBox[
    RowBox[{
     RowBox[{
      SubscriptBox["q", 
       RowBox[{"1", " "}]], "+", 
      RowBox[{"b", " ", 
       SubscriptBox["q", 
        RowBox[{"2", " "}]]}], "+", "c"}], "=", "0"}],
    TraditionalForm]}], TraditionalForm]}], "DisplayFormula",
 CellChangeTimes->{{3.701011308888461*^9, 3.7010114285460873`*^9}, {
   3.701011728022867*^9, 3.701011734886795*^9}, {3.701024399831842*^9, 
   3.7010243998318863`*^9}, {3.701054428887748*^9, 3.701054453895719*^9}, {
   3.702649770695331*^9, 3.702649786305251*^9}, 3.7028395501448593`*^9},
 CellID->402679298,ExpressionUUID->"87977640-16d0-4e50-98fa-04c12edf286f"],

Cell[TextData[{
 "This is undetermined, so we need another equation. First, we add a dummy \
variable ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]], "InlineMath",ExpressionUUID->
  "84424a13-36ca-4e38-bcde-52de432641ca"],
 " for 1 multiplying ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineMath",ExpressionUUID->
  "d6ef2207-fa0f-40c9-8383-8875bb49ee54"],
 ", and then a third equation is created, giving us Equation 1:"
}], "Text",
 CellChangeTimes->{{3.684929414683105*^9, 3.684929437520118*^9}, {
   3.684929505775419*^9, 3.684929512231377*^9}, {3.684929686183278*^9, 
   3.68492970164743*^9}, {3.684929813202845*^9, 3.684929837779444*^9}, {
   3.684932315017744*^9, 3.684932316305941*^9}, 3.701008651132017*^9, {
   3.701009614831214*^9, 3.7010096623590803`*^9}, {3.702653517458027*^9, 
   3.702653517969305*^9}, {3.70283842743274*^9, 3.702838427435751*^9}, {
   3.702839005101019*^9, 3.702839005105769*^9}, 3.708424318562543*^9, {
   3.708702900967458*^9, 3.708702912708632*^9}, {3.7087039532896843`*^9, 
   3.7087039880721626`*^9}, {3.7087041069450483`*^9, 3.708704109812335*^9}, {
   3.709059752963893*^9, 3.709059754417679*^9}, {3.713724717563655*^9, 
   3.713724737842005*^9}, 3.7392050340105114`*^9, 3.7392732383568316`*^9, {
   3.739273339688964*^9, 3.73927333995199*^9}},
 CellID->2039545107,ExpressionUUID->"7b2d4d3b-ea05-4122-b288-bc85cc3fe9b3"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", 
     SubscriptBox["p", "1"]}], "+", 
    RowBox[{"b", " ", 
     SubscriptBox["p", "2"]}], "+", 
    RowBox[{"c", " ", "z"}]}], "=", "0"}], TraditionalForm], "\n", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"a", " ", 
      SubscriptBox["q", "1"]}], "+", 
     RowBox[{"b", " ", 
      SubscriptBox["q", "2"]}], "+", 
     RowBox[{"c", " ", "z"}]}], "=", "0"}], " "}], TraditionalForm], "\n", 
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", 
     SubscriptBox["r", "1"]}], "+", 
    RowBox[{"b", " ", 
     SubscriptBox["r", "2"]}], "+", 
    RowBox[{"c", " ", 
     SubscriptBox["r", "3"]}]}], "=", "1"}], 
  TraditionalForm]}], "DisplayFormula",
 CellChangeTimes->{{3.701054870708262*^9, 3.70105487105149*^9}, {
   3.7026497981600113`*^9, 3.7026498014872837`*^9}, 3.707488123072014*^9},
 CellID->451176329,ExpressionUUID->"de3bf2d5-0d51-4df2-8116-0f3ed23d50dd"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "1"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "892b07cb-0cb4-482b-a799-87414e684533"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "2"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "439dfaed-6b71-415e-bc2a-e8fe7d783103"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "3"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "eaa4d0ad-27ba-4405-9ccb-a967b3b057d4"],
 " are random real numbers, so the system will give a unique solution. This \
would be less likely if we used small integers or rational numbers."
}], "Text",
 CellChangeTimes->{{3.684931280123172*^9, 3.684931361018622*^9}, {
  3.684931564562138*^9, 3.684931606714382*^9}, {3.701009693080735*^9, 
  3.701009748974814*^9}, {3.702649862815051*^9, 3.702649867279127*^9}, {
  3.702649897320345*^9, 3.702649900486899*^9}, {3.702653524556963*^9, 
  3.702653566513311*^9}, {3.702837792462331*^9, 3.702837798135977*^9}, {
  3.708424379971525*^9, 3.708424384203525*^9}, {3.7084302056937885`*^9, 
  3.708430206916789*^9}},
 CellID->500639935,ExpressionUUID->"c6dec0ee-4d59-4cc4-ac71-7b17b73b56d2"],

Cell[TextData[{
 "Suppose we want to find the line through points ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"2", ",", "5"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"e4c973c7-30dd-4145-9126-84db29efd652"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"c91b5096-d437-469c-837f-1275285d2229"],
 ". We could do it in the Wolfram Language:"
}], "CodeCaption",
 CellChangeTimes->{{3.7010099412946663`*^9, 3.7010099415339317`*^9}, {
   3.702653596953602*^9, 3.702653597441059*^9}, {3.702837804221493*^9, 
   3.70283780720382*^9}, 3.702839738517189*^9, 3.707502876817753*^9, {
   3.7084244032265253`*^9, 3.7084244060425253`*^9}, {3.709307086491147*^9, 
   3.7093071086336813`*^9}, {3.740823920919689*^9, 3.740823924538509*^9}},
 CellID->414458599,ExpressionUUID->"66dcdc94-64bc-4c71-87e0-d65b5fbc6da8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"e3", "=", 
  RowBox[{
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.684931936790929*^9, 3.684931966969236*^9}, {
   3.684931997258203*^9, 3.684932049115657*^9}, {3.684932106149002*^9, 
   3.68493213851796*^9}, {3.684932258625747*^9, 3.684932290121877*^9}, {
   3.684933093476202*^9, 3.684933122972268*^9}, {3.684933407205774*^9, 
   3.684933412458498*^9}, 3.707488132488894*^9},
 CellLabel->"In[7]:=",
 CellID->1516206172,ExpressionUUID->"074ac557-0f8e-4b18-b1e8-03f95b1f0f4e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.3011290496599073`", " ", "a"}], "+", 
  RowBox[{"0.2640056965708597`", " ", "b"}], "-", 
  RowBox[{"0.3584749253624282`", " ", "c"}]}]], "Output",
 CellChangeTimes->{3.711800553686119*^9, 3.7378911765261*^9, 
  3.737892414802087*^9, 3.737893519844936*^9, 3.737893961572212*^9, 
  3.742658533460896*^9},
 CellLabel->"Out[7]=",
 CellID->1868308048,ExpressionUUID->"3945e821-ecfb-4b9a-8d88-f9481886ae84"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], "/.", 
   RowBox[{"NSolve", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"2", "a"}], "+", 
       RowBox[{"5", "b"}], "+", "c"}], ",", 
      RowBox[{
       RowBox[{"4", "a"}], "+", "b", "+", "c"}], ",", 
      RowBox[{"e3", "-", "1"}]}], "}"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.684931936790929*^9, 3.684931966969236*^9}, {
   3.684931997258203*^9, 3.684932049115657*^9}, {3.684932106149002*^9, 
   3.68493213851796*^9}, {3.684932258625747*^9, 3.684932290121877*^9}, {
   3.684933093476202*^9, 3.684933122972268*^9}, {3.684933407205774*^9, 
   3.684933412458498*^9}, 3.707488132488894*^9},
 CellLabel->"In[8]:=",
 CellID->1905770788,ExpressionUUID->"ee6143af-452e-48dd-91fb-b91adcc7f408"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"0.4886942868526496`", ",", "0.2443471434263248`", ",", 
    RowBox[{"-", "2.1991242908369233`"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.711800553705521*^9, 3.7378911766446247`*^9, 
  3.737892414817376*^9, 3.737893519865334*^9, 3.737893961595847*^9, 
  3.742658533508896*^9},
 CellLabel->"Out[8]=",
 CellID->147476302,ExpressionUUID->"3b6c8b12-0ec5-4e2b-a441-f1532559f8b8"]
}, Open  ]],

Cell[TextData[{
 "This returns the equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "71ef937a-6764-4724-9a17-ff2233001085"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.701009986750341*^9, 3.701010012629664*^9}, {
   3.70265360710568*^9, 3.702653607873032*^9}, 3.7028398177722397`*^9, {
   3.7087041608182845`*^9, 3.7087041672734604`*^9}, {3.7408239473573027`*^9, 
   3.740823947362199*^9}},
 CellID->232267465,ExpressionUUID->"01906240-f68d-43f6-bb65-edb6a3f16be7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l", "=", 
  RowBox[{
   RowBox[{"sol", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "1"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.684932152779533*^9, 3.684932195750653*^9}, {
  3.68493230697846*^9, 3.684932307489917*^9}},
 CellLabel->"In[9]:=",
 CellID->1741497656,ExpressionUUID->"9a892caa-5fdb-433a-9b48-f89aca6030c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2.1991242908369233`"}], "+", 
  RowBox[{"0.4886942868526496`", " ", "x"}], "+", 
  RowBox[{"0.2443471434263248`", " ", "y"}]}]], "Output",
 CellChangeTimes->{3.711800553741523*^9, 3.7378911767657537`*^9, 
  3.737892414832181*^9, 3.737893519885866*^9, 3.737893961619607*^9, 
  3.7426585335588923`*^9},
 CellLabel->"Out[9]=",
 CellID->438079076,ExpressionUUID->"25b614b3-5099-495b-97ad-12781f73afc0"]
}, Open  ]],

Cell["\<\
However, this is not what the answer section of your standard textbook would \
show. One may normalize it by:\
\>", "CodeCaption",
 CellChangeTimes->{
  3.701054465165731*^9, {3.7028397421965857`*^9, 3.70283974271646*^9}, 
   3.7084244410165253`*^9, {3.7088713177347364`*^9, 3.708871357231686*^9}, {
   3.7088713934113035`*^9, 3.7088713941563787`*^9}, {3.7392735592899213`*^9, 
   3.739273570418034*^9}},
 CellID->1560680741,ExpressionUUID->"b79745b9-e7de-4f62-8c9c-72bb1b73b360"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"l", "/", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"l", ",", "y"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.684932413090376*^9, 3.68493245409409*^9}},
 CellLabel->"In[10]:=",
 CellID->995949529,ExpressionUUID->"8ff687f1-7847-4628-a499-ec212306b1d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "9.`"}], "+", 
  RowBox[{"1.9999999999999998`", " ", "x"}], "+", 
  RowBox[{"0.9999999999999999`", " ", "y"}]}]], "Output",
 CellChangeTimes->{3.711800553773178*^9, 3.737891176783285*^9, 
  3.737892414847199*^9, 3.7378935199052267`*^9, 3.7378939616433783`*^9, 
  3.742658533608996*^9},
 CellLabel->"Out[10]=",
 CellID->1221088416,ExpressionUUID->"044a98c3-f21e-4990-bf70-89c96fe4237f"]
}, Open  ]],

Cell["\<\
This equation looks neater, but the Wolfram Language would be just as happy \
with the former in subsequent calculations.\
\>", "Text",
 CellChangeTimes->{{3.7010100711500607`*^9, 3.701010071525412*^9}, 
   3.707501663072763*^9, 3.7075028791348143`*^9, {3.7084420725176535`*^9, 
   3.7084420727496767`*^9}, {3.708871373811344*^9, 3.7088713757095337`*^9}},
 CellID->315440015,ExpressionUUID->"7240f084-e0f6-473f-8fae-3f8f39648acf"],

Cell[TextData[{
 "However, our method does give extra dividends. Suppose instead that we want \
the equation of the line through ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "169f8d7d-9dc1-4ce5-94ac-e034aaf3d0e3"],
 " with slope ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]], "InlineMath",ExpressionUUID->
  "aa64174e-ec80-4d7a-acfa-e1eab2a7f8e5"],
 "; instead of evaluating ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"a8da82f4-844b-4703-8717-ecf350f883b6"],
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["p", "1"], ",", 
     SubscriptBox["p", "2"], ",", "1"}], "}"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"9594295f-79ce-48ef-82c7-28cc0d834003"],
 ", we use ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"1", ",", "m", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"fd621067-3fc3-4a3e-b2b5-d5cd8e9b7037"],
 "."
}], "Text",
 CellChangeTimes->{{3.6849328013189*^9, 3.684932816066707*^9}, {
   3.684932895565181*^9, 3.68493297649441*^9}, {3.684933011785033*^9, 
   3.684933016977139*^9}, {3.68493321444723*^9, 3.684933294073417*^9}, 
   3.7010086511557426`*^9, {3.701010626732045*^9, 3.70101069686126*^9}, {
   3.701010729475712*^9, 3.701010739378831*^9}, {3.702653001933021*^9, 
   3.702653012885776*^9}, {3.702653104371208*^9, 3.702653202706674*^9}, {
   3.702653624220674*^9, 3.7026536404985323`*^9}, {3.7026536793337393`*^9, 
   3.702653684089326*^9}, {3.702653721434836*^9, 3.7026537214397507`*^9}, {
   3.7028378144708*^9, 3.7028378222611647`*^9}, {3.702838560742051*^9, 
   3.702838563597804*^9}, {3.708424482552525*^9, 3.7084244844557247`*^9}, {
   3.7084245473343096`*^9, 3.708424552638173*^9}, {3.7084302699537888`*^9, 
   3.7084302725617886`*^9}},
 CellID->1610691309,ExpressionUUID->"1d7db5e9-4067-4b7e-bf07-820351c5b706"],

Cell[TextData[{
 "In our example above, instead of the second point, we want slope ",
 Cell[BoxData[
  RowBox[{"m", "=", 
   RowBox[{"-", "2"}]}]], "InlineCode",ExpressionUUID->
  "9e11924f-18a9-4bd8-b3e2-a324c0295b09"],
 " so ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   RowBox[{"2", " ", "b"}]}]], "InlineCode",ExpressionUUID->
  "d33149ac-e3d4-46a2-b192-779b99bdd013"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.701010090434373*^9, 3.7010101174532127`*^9}, {
   3.70101076177325*^9, 3.701010774220933*^9}, 3.7010544685413847`*^9, {
   3.702839018806171*^9, 3.702839018809217*^9}, {3.702839829060234*^9, 
   3.7028398305402308`*^9}, {3.708424578487715*^9, 3.708424582512411*^9}, {
   3.709307135970887*^9, 3.709307140955166*^9}, {3.709308006465061*^9, 
   3.709308009177167*^9}, {3.7106741490816*^9, 3.710674174670947*^9}, {
   3.738386284474723*^9, 3.738386301160911*^9}, {3.740767639091408*^9, 
   3.740767642813251*^9}, {3.742574787269229*^9, 3.742574792087801*^9}, {
   3.742648215588521*^9, 3.742648216073358*^9}},
 CellID->1857459928,ExpressionUUID->"c3224869-7813-404a-8654-3a9cefd4702c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"e3", "=", 
  RowBox[{
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.684933579807346*^9, 3.684933628264417*^9}, 
   3.707488137944715*^9},
 CellLabel->"In[11]:=",
 CellID->359233457,ExpressionUUID->"98c18a1c-475c-4bd4-b537-9120a3608fd7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.15643122936402243`", " ", "a"}], "+", 
  RowBox[{"0.14380462187297294`", " ", "b"}], "+", 
  RowBox[{"0.9256622171773521`", " ", "c"}]}]], "Output",
 CellChangeTimes->{3.707586308946705*^9, 3.7378911767992983`*^9, 
  3.737892414862509*^9, 3.73789351992524*^9, 3.737893961667494*^9, 
  3.7426585336608467`*^9},
 CellLabel->"Out[11]=",
 CellID->1479276980,ExpressionUUID->"a905cbae-1fa7-439f-aa88-bf31abb5f150"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], "/.", 
   RowBox[{"NSolve", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"2", "a"}], "+", 
       RowBox[{"5", "b"}], "+", "c"}], ",", 
      RowBox[{"a", "-", 
       RowBox[{"2", "b"}]}], ",", 
      RowBox[{"e3", "-", "1"}]}], "}"}], "]"}]}]}]], "Input",
 PageBreakAbove->True,
 CellChangeTimes->{{3.684933579807346*^9, 3.684933628264417*^9}, 
   3.707488137944715*^9},
 CellLabel->"In[12]:=",
 CellID->571038911,ExpressionUUID->"d09c5eb3-1c74-4e73-9720-8162359acea4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "0.25399106078528005`"}], ",", 
    RowBox[{"-", "0.12699553039264003`"}], ",", "1.1429597735337602`"}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{3.707586308980072*^9, 3.737891176824339*^9, 
  3.7378924148788223`*^9, 3.737893519945207*^9, 3.7378939616909246`*^9, 
  3.742658533711076*^9},
 CellLabel->"Out[12]=",
 CellID->790021541,ExpressionUUID->"26932def-0ae9-4c1d-ad1d-b3f5beea396a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l", "=", 
  RowBox[{
   RowBox[{"sol", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "1"}], "}"}]}]}]], "Input",
 CellLabel->"In[13]:=",
 CellID->42349697,ExpressionUUID->"ecb38c96-c297-4c37-913e-a62814e2b07f"],

Cell[BoxData[
 RowBox[{"1.1429597735337602`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.25399106078528005`", " ", "x"}], "-", 
  RowBox[{"0.12699553039264003`", " ", "y"}]}]], "Output",
 CellChangeTimes->{3.707586309000176*^9, 3.737891176841778*^9, 
  3.737892414894618*^9, 3.737893519965444*^9, 3.7378939617145844`*^9, 
  3.742658533760644*^9},
 CellLabel->"Out[13]=",
 CellID->650186,ExpressionUUID->"65c65ed5-4e56-416a-92ae-ca4354f26f30"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"l", "/", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"l", ",", "y"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.684933653307325*^9, 3.684933666066111*^9}},
 CellLabel->"In[14]:=",
 CellID->1013426058,ExpressionUUID->"2bc04539-239a-4474-9dc2-51ebedf2246e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "9.`"}], "+", 
  RowBox[{"2.`", " ", "x"}], "+", 
  RowBox[{"1.`", " ", "y"}]}]], "Output",
 CellChangeTimes->{3.707586309030612*^9, 3.737891176859639*^9, 
  3.737892414910837*^9, 3.737893519985662*^9, 3.737893961738348*^9, 
  3.7426585338093348`*^9},
 CellLabel->"Out[14]=",
 CellID->190257867,ExpressionUUID->"237bbfcb-1596-4005-baa4-e0d7edbe2290"]
}, Open  ]],

Cell[TextData[{
 "Note that if we have a point far away on the line, say ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "1000"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"3df5a979-fcbf-4626-b2d7-81cb275a557f"],
 ", then ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    RowBox[{"-", "1991"}]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "a59c7948-4515-4cd9-be43-5021a7b8f8b7"],
 ", so the triple ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "1"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"eb1eb15e-5c73-4d19-92d2-4c5edfed693d"],
 " is approximately ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1000", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "2"}], ",", "0"}], "}"}]}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"4de87e89-8bff-415f-bb61-589de0bdde84"],
 "."
}], "Text",
 CellChangeTimes->{{3.701010818195239*^9, 3.70101091645809*^9}, {
   3.70283902559477*^9, 3.7028390367646713`*^9}, 3.707501680447209*^9, {
   3.708424617471115*^9, 3.708424628125642*^9}, 3.7084422024569683`*^9},
 CellID->249039608,ExpressionUUID->"06e1f160-500e-472e-80b9-60a16d31f5dc"],

Cell[TextData[{
 "This suggests that we think of the slope ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"1", ",", "m", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"78a9f209-8f47-456d-afae-1fd90be7b662"],
 " as being a point on the line but far away, which we call an ",
 StyleBox["infinite point",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.684933775578987*^9, 3.684933807852154*^9}, {
  3.684934266648499*^9, 3.684934272800846*^9}, {3.684934360163066*^9, 
  3.684934388300078*^9}, {3.701010934908766*^9, 3.701010945858089*^9}, {
  3.7026546814296217`*^9, 3.702654682900971*^9}, {3.702837833192568*^9, 
  3.702837836440297*^9}, {3.708424648888709*^9, 3.708424650292673*^9}, {
  3.710674201319758*^9, 3.710674203687463*^9}},
 CellID->163063653,ExpressionUUID->"da1a4eff-af71-44bf-b371-318882766756"],

Cell["\<\
A third way of thinking about a line is parametrically, that is\
\>", "Text",
 CellChangeTimes->{{3.68493450639023*^9, 3.68493452856791*^9}, 
   3.708881008421732*^9, {3.7408240531071987`*^9, 3.7408240532809973`*^9}},
 CellID->421682399,ExpressionUUID->"5fb16cc4-f111-44c4-ba06-53cc6d715544"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "y"}], "}"}], " ", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["p", "1"], ",", 
      SubscriptBox["p", "2"]}], "}"}], "+", 
    RowBox[{"t", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["v", "1"], ",", 
        SubscriptBox["v", "2"]}], "}"}], "."}]}]}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.701011308888461*^9, 3.7010114285460873`*^9}, {
   3.701011728022867*^9, 3.701011734886795*^9}, {3.7026499578392*^9, 
   3.70264996119144*^9}, 3.74082405770512*^9},
 CellID->877499497,ExpressionUUID->"fbfd7ee2-1065-4895-8979-099f251c9699"],

Cell[TextData[{
 "The vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{"v", "=", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["v", "1"], ",", 
      SubscriptBox["v", "2"]}], "}"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"5ae5b1e6-0376-4fbb-83f8-8988a0724e41"],
 " is called the direction vector or the ",
 StyleBox["tangent vector",
  FontSlant->"Italic"],
 ", but again, in Equation 1, just use ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["v", "1"], ",", 
     SubscriptBox["v", "2"], ",", "0"}], "}"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"6cf82b16-bd87-4dfb-bae4-ec97c5163b22"],
 " as the second point."
}], "Text",
 CellChangeTimes->{{3.684934875705668*^9, 3.684934968330963*^9}, {
   3.684935014603695*^9, 3.684935046244703*^9}, {3.684935117638901*^9, 
   3.684935180120967*^9}, {3.684935264501873*^9, 3.684935313334508*^9}, {
   3.684935464127921*^9, 3.684935697749407*^9}, {3.68493581186118*^9, 
   3.684935890409171*^9}, {3.684935964578716*^9, 3.684936039732506*^9}, {
   3.684936097254256*^9, 3.684936190737505*^9}, 3.684936230060262*^9, 
   3.7010086511923933`*^9, {3.701011583928048*^9, 3.701011636401433*^9}, {
   3.7026544012183027`*^9, 3.702654401221583*^9}, {3.7026544347370367`*^9, 
   3.7026544347416353`*^9}, {3.702654528037569*^9, 3.7026545420262957`*^9}, {
   3.702837845430545*^9, 3.7028378505700493`*^9}, {3.7084246773579793`*^9, 
   3.7084246989634256`*^9}, {3.708424729944231*^9, 3.7084247676016655`*^9}, {
   3.708881035551445*^9, 3.7088810372476144`*^9}, 3.739274035432806*^9, 
   3.7408240740017643`*^9},
 CellID->520044893,ExpressionUUID->"138bba24-2959-4a3c-9f3e-9f79c3bbee21"],

Cell[TextData[{
 "In our example above, we want the line through ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "e3dad05a-ead7-4ba3-b7fb-d6a9ef136545"],
 " with tangent vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"36009f44-8ce7-4dbe-95dd-55c67c399c37"],
 ", so we use ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"11f1d94d-9400-4107-a896-b7c3d8abc48b"],
 "."
}], "Text",
 CellChangeTimes->{
  3.701011678167262*^9, 3.7010544707095737`*^9, {3.7093071946271887`*^9, 
   3.709307209786262*^9}, {3.709307988546767*^9, 3.7093079885467997`*^9}, {
   3.713718092810781*^9, 3.713718104642462*^9}, 3.7392740513838058`*^9, {
   3.739274142106806*^9, 3.739274143218806*^9}, 3.7392742092478056`*^9, {
   3.7392742646438055`*^9, 3.739274267187806*^9}, 3.742574837437941*^9},
 CellID->136073361,ExpressionUUID->"f639a8a6-2a2f-4dee-8df3-a3c22ebe0c3a"],

Cell[TextData[{
 "Now the tangent vector also becomes an infinite point on our line, but any \
nonzero multiple of a tangent vector is also a tangent vector, so in the \
special case of infinite points, they are homogeneous. However, if we think \
of a finite point, or as we will call it, an affine point, in the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["p", "1"], ",", 
     SubscriptBox["p", "2"], ",", "1"}], "}"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"2f1a829a-f6b3-4249-bb10-8a31067c3217"],
 ", then for the purposes of Equation 1, a constant nonzero multiple by ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]], "InlineMath",ExpressionUUID->
  "985cda42-365b-4c2e-aa61-a86613880db4"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"k", " ", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["p", "1"], ",", 
       SubscriptBox["p", "2"], ",", "1"}], "}"}]}], "=", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["kp", "1"], ",", 
      SubscriptBox["kp", "2"], ",", "k"}], "}"}]}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"7164a855-ce57-47b7-8ff5-f24ffaed3319"],
 " works just as well. We will call any one of these equivalent forms the ",
 StyleBox["homogeneous form",
  FontSlant->"Italic"],
 " of the point. In Chapter 5, we will see that these homogeneous points, \
affine or infinite, make up the ",
 StyleBox["projective plane",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.684934875705668*^9, 3.684934968330963*^9}, {
   3.684935014603695*^9, 3.684935046244703*^9}, {3.684935117638901*^9, 
   3.684935180120967*^9}, {3.684935264501873*^9, 3.684935313334508*^9}, {
   3.684935464127921*^9, 3.684935697749407*^9}, {3.68493581186118*^9, 
   3.684935890409171*^9}, {3.684935964578716*^9, 3.684936039732506*^9}, {
   3.684936097254256*^9, 3.684936190737505*^9}, {3.701008651216806*^9, 
   3.701008651253792*^9}, 3.701011800207204*^9, {3.701012074486432*^9, 
   3.701012137141903*^9}, {3.701012195046145*^9, 3.7010121955330973`*^9}, {
   3.7026544649121923`*^9, 3.7026544711957417`*^9}, {3.702837857801161*^9, 
   3.702837865825732*^9}, {3.7084248101099286`*^9, 3.70842481145152*^9}, {
   3.7084248487070823`*^9, 3.708424851920662*^9}, 3.7084248927767997`*^9, 
   3.7084249299201612`*^9, {3.708442684645968*^9, 3.708442685672968*^9}, 
   3.7084427659709682`*^9, {3.708881075297419*^9, 3.708881080934983*^9}, 
   3.711721327376616*^9, {3.7391998822198334`*^9, 3.7391998865942707`*^9}},
 FontTracking->-0.15,
 CellID->2062377919,ExpressionUUID->"4a4221e1-d672-4c9c-a080-962b68a44e84"],

Cell[TextData[{
 "With the code for the ",
 Cell[BoxData[
 "line"], "InlineCode",ExpressionUUID->"71a884fc-f363-4444-9c39-26899401d77e"],
 " function, you can enter points as either pairs or triples (For a complete \
list of global functions, see Appendix 2):"
}], "CodeCaption",
 CellChangeTimes->{{3.685979833242631*^9, 3.6859799072898235`*^9}, {
   3.6859799842817125`*^9, 3.685980054962864*^9}, {3.70265470913348*^9, 
   3.702654709516651*^9}, {3.707501728896081*^9, 3.707501729952499*^9}, {
   3.7075018054164257`*^9, 3.707501819342798*^9}, {3.708430516491789*^9, 
   3.7084305169627886`*^9}, {3.708881186528541*^9, 3.7088811871656046`*^9}, {
   3.709301765052894*^9, 3.709301777747431*^9}, {3.711471087865707*^9, 
   3.711471088370665*^9}, 3.715332315634803*^9, {3.740824157620287*^9, 
   3.740824158445746*^9}},
 CellID->247148051,ExpressionUUID->"c9ae959d-9f05-4e70-93d8-3e06bf584b84"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"line", "[", 
    RowBox[{"p_", ",", "q_", ",", "x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"e1", ",", "e2", ",", "a", ",", "b", ",", "c", ",", "M"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"e1", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"Length", "[", "p", "]"}], ",", "2", ",", 
         RowBox[{"Append", "[", 
          RowBox[{"p", ",", "1"}], "]"}], ",", "3", ",", "p"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"e2", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"Length", "[", "q", "]"}], ",", "2", ",", 
         RowBox[{"Append", "[", 
          RowBox[{"q", ",", "1"}], "]"}], ",", "3", ",", "q"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"M", "=", 
       RowBox[{"{", 
        RowBox[{"e1", ",", "e2", ",", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}]}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"a", ",", "b", ",", "c"}], "}"}], "/.", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{"M", ".", 
              RowBox[{"{", 
               RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "\[Equal]", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ")"}]}], ")"}], ".", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "1"}], "}"}]}]}]}], "\[IndentingNewLine]",
     "]"}]}], ";"}]], "InputOnly",
 InitializationCell->True,
 CellLabel->"In[15]:=",
 CellID->136165244,ExpressionUUID->"9dad2e49-9d12-425a-9609-75dea1b94f3c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l", "=", 
  RowBox[{"line", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", "x", ",", "y"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.686143029619042*^9, 3.686143047493473*^9}, {
  3.686143182851768*^9, 3.686143254432967*^9}},
 CellLabel->"In[16]:=",
 CellID->1999622053,ExpressionUUID->"8fe69005-b542-4032-91b1-97f57686eaa1"],

Cell[BoxData[
 RowBox[{"1.1744603163534326`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.2609911814118739`", " ", "x"}], "-", 
  RowBox[{"0.13049559070593694`", " ", "y"}]}]], "Output",
 CellChangeTimes->{3.711800553924302*^9, 3.7378911768859797`*^9, 
  3.7378924149305973`*^9, 3.737893520010851*^9, 3.7378939617675953`*^9, 
  3.7426585338734913`*^9},
 CellLabel->"Out[16]=",
 CellID->60820286,ExpressionUUID->"c7975138-5d06-44cd-a74b-480264a66e96"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"l", "/", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"l", ",", "y"}], "]"}]}], "]"}]], "Input",
 PageBreakAbove->True,
 CellChangeTimes->{{3.686143267058553*^9, 3.686143284142976*^9}},
 CellLabel->"In[17]:=",
 CellID->2091471130,ExpressionUUID->"090a98b7-d5d6-4f94-b9bd-0b4bd5158a4c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "9.000000000000002`"}], "+", 
  RowBox[{"2.`", " ", "x"}], "+", 
  RowBox[{"1.`", " ", "y"}]}]], "Output",
 CellChangeTimes->{3.7118005539431133`*^9, 3.7378911769018297`*^9, 
  3.737892414947455*^9, 3.7378935200274754`*^9, 3.73789396178941*^9, 
  3.742658533900187*^9},
 CellLabel->"Out[17]=",
 CellID->4330830,ExpressionUUID->"4e037239-2e84-4cd8-af3a-61a23d0d29f4"]
}, Open  ]],

Cell["\<\
This all seems very complicated, but Equation 1 gives us a general way of \
constructing lines, and we will see later in Chapter 2 that we can also use \
it to construct higher-degree curves. In the process, we have discovered the \
projective plane, which will be important later. The one disadvantage is that \
even for a simple, exact case, we get the equation in a decimal form, but \
that is precisely what we are allowed and encouraged to do in this book.\
\>", "Text",
 CellChangeTimes->{{3.684936194517*^9, 3.68493620833362*^9}, {
   3.684936252143283*^9, 3.684936305040177*^9}, {3.684936336753695*^9, 
   3.684936493918012*^9}, {3.685617703647964*^9, 3.685617709761204*^9}, {
   3.701008651263439*^9, 3.7010086512861633`*^9}, 3.701054472446033*^9, {
   3.7084249525400167`*^9, 3.7084249849152102`*^9}, {3.7084250317305098`*^9, 
   3.7084250331189013`*^9}, {3.7084305464177885`*^9, 3.7084305737767887`*^9}, 
   3.708881214009289*^9, 3.709059824857532*^9, {3.710674246112852*^9, 
   3.710674246785111*^9}, 3.711721328298118*^9, {3.7392752097008038`*^9, 
   3.7392752099238043`*^9}, 3.739277014392801*^9},
 CellID->870779928,ExpressionUUID->"7016fbe4-f07a-4863-91a6-c4683025f9e6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2 Conics", "Subsection",
 CellChangeTimes->{{3.685188049041343*^9, 3.685188065781471*^9}},
 CellID->97195591,ExpressionUUID->"460e7d9f-3b4d-41e1-a0cc-e109d5757814"],

Cell["\<\
Besides lines, high-school algebra students learn about simple quadratic \
curves, the parabola, hyperbola, and ellipse.\
\>", "Text",
 CellChangeTimes->{{3.685188078246927*^9, 3.685188108872938*^9}, {
   3.685188526338635*^9, 3.685188534715131*^9}, {3.7084251270620956`*^9, 
   3.7084251272648945`*^9}, 3.7392770584548006`*^9},
 CellID->1478726217,ExpressionUUID->"b42816dd-b32a-4572-8106-da7000e32957"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"Axes", "\[RightArrow]", "True"}]], "InlineCode",ExpressionUUID->
  "178ba016-cfe7-4052-b523-00208bc6ba8e"],
 " simply turns the axes on:"
}], "CodeCaption",
 CellChangeTimes->{
  3.70750186303207*^9, {3.7088812375756454`*^9, 3.708881238151703*^9}, {
   3.740824225464149*^9, 3.7408242272872*^9}},
 CellID->642294212,ExpressionUUID->"1779bb41-e5d6-463e-9dae-feead3eaf820"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"y", "\[Equal]", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "4"}], 
         RowBox[{"x", "^", "2"}]}], "-", "2"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "4"}], ",", "8"}], "}"}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "^", "2"}], "-", 
        RowBox[{
         RowBox[{"1", "/", "4"}], 
         RowBox[{"x", "^", "2"}]}]}], "\[Equal]", "1"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", " ", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "^", "2"}], "+", 
        RowBox[{
         RowBox[{"1", "/", "4"}], 
         RowBox[{"x", "^", "2"}]}]}], "\[Equal]", "1"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", " ", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.685188115891287*^9, 3.685188172586753*^9}, {
  3.685188205283626*^9, 3.685188497994831*^9}, {3.7378924349519463`*^9, 
  3.73789248218721*^9}},
 CellLabel->"In[18]:=",
 CellID->123282388,ExpressionUUID->"062681c0-0400-48e6-8564-07ac992920a1"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJw9lglUVEcWhtmafW2abkBwQ1AzIAZx19RV0QMuyOIICIqKziBxBJGJZHJY
FTAiDIIGkNbgjA7R5LhORNShykgmBMcAGXAjKhAWlSDIvnX3NK/umz7V553u
917VrXvr/v83Y3ds0F49HR0dqv1OXvnHnvGrE5AX32qHgn2S53o4z3UKKMnD
0ZtKBbv1pybtcISSoQLXa/sULHBP7C/Oax1h2qV12qFgc9+80A4H8MufpR0K
5n//4dzETx0gZJbXF18bKpiv8L8DbJ6/x9a/Uc6yM02qo4vsoUed/51Tipwt
PlludvXvCjhZHXrFcb+cPRcWVMBes+1Jmt1yZlQX1tsUrABhGj85Sy8M7o03
VcDYeOlTt3d2zNAgcvYzGzlcjKjRDjsmhHvLDvw++1Ijz7BjLl4WTY/6ZKCK
LvLMS7Rjp+9e232qTgZ6v50oyXCzw/3LIOtSZEu9RsbOfem15nC+LbgKG9L+
FhaUgnJB7hd/zJSxKcs2TTf8vRR0gqHoapqM8bik0EY/0Q4ZCyzxCCrxkEJK
YNSaMhMZq4H7ki5HGxhYUdu/otaWCY/nW4N+XOzx09m27HrOxPnVVVagVK+f
t8Lfli1WnY5IVFrCm18Nr7s527IDwn4sIDVHMv7G1Ja9KNnd3hpiAbeFjUrZ
34T4zOEvr+13KLOkzNLzpzU/9JpCUc3yloidUozPFGKbWZq+kZTpmsrmBJQa
g0ezf0qVnpQ9Ojbgyk4YQ3Rl4rWAszasXJjXEBwa98XnfWrDHF8H7Dn4oSGs
FyayYV5lze2yewbwqyrJJ+GdNbv06k5b3zN98Mtp8M1psGa/CPXTh7BVFbsU
2dZsTFZofn+ZHoTc9k3cu9Oadd4sPx92TBciNAdUdwetMP86sPaJw1sXpRXr
cD9SXJCsJnx/lqxDu5oyfZw090yvMIq3ZGM5xT47hkdJsvVC7bBk/NyNkuV1
tHhqmgULCOm2HIgdIstCUlX3wILlBGoMMpMHiXJesHaYYz76SIs0zuS2gTk7
vt9n0cwp78kLIW4zdkI4X+/I5vCq0i5mynqbUs+fyX1DkqP2RbwKNcX8dJA4
oS4mbEniUolnWSv5c/1axfYEE9Y1uyps1KSFpFmvNp5x1Jh9/lVYg3vMY/I0
3UM7jNkpYf2fSesOyc0LTsYsz2PqmDqqnvCeNGb2wrWOLA3yrppWbsh6aU7w
qFs+6QivbA+vlLBc4f3vaOhX9TkDPhL2tYK4NR16RN2ERBiw1MHz1z/yfkyP
rOumAVX6zMI7RpMx8yV9MN9cO/TZSeH9Vjpr0/dq/QV6bMTqP9Fd6R2U11eX
/RQ6zbFrTRfdcHbo7R9ydZiuu29WUFk33aiaO1jWoKFqzeSnh2beCso89A8V
LdO0Xb63pI++FPI3Ti1zJgMYoBvKOla9GxulLju2OF+MHqTqhctjbPqGKdeT
IWqw64Lz76yH6KmM7qubw0bobCH+ARoyuXzUKL3xG1RGPntPR5L3GvWpxuhG
Ib731F57Nyl6nDZum1Ma1d9ND30eZiZJmKAtwsRddPLuN1YqusB7p59nylsq
d7x2oZCoqM6iyfU7KdcHFf1AWK+NNmb9e6wuVE0LJA3rrH5opUuE/lPTpA+3
sIpFzfRgpqSwZkhNO3ngtE7Ij4bGUfuZ3zg20pgttWdq/6qhd10N9H2f/JeW
k3qXw0oN7Reef0i9H08uoKE3mhUa85L7NPVJscXKtxp6xz1t0/iPN2hKysZT
fcMaytug+h72A9vG7xPx/lH+PhHff8DnJwtx/nN8fXIb1w/n8ZGPMb5aHj/5
GeM/xPdH4nF/R/j+yTLc/1SeH/IE8zPHVC7JTm8nfXdHtk/MU1ONUM9O8v98
8nwTBea7kdeDrMV6VPJ6kUSs1zpeT+KE9bzC603GsN5VwnntJ7xfx2jw5fI0
U4MB8iDjQE/7nVE6g58XEo7npccpImmDfIhkrLpoFRc5QmN6/jX88rNh4pvs
THMjh+mEcG6Hib6Q3mH6TOjHESKex1kuLVvDdcaI3nN/L+mBQfqUn2cixfN8
VtCPCcL9qZ8GZm4yr7isIodrX83XW9lH/ynMoybHJ9M17T3l+qYhYr+s5/0E
Euwn7ou68Bj7zYX3I6iwH7FfQezXdN7PYI/97ML7HZTY71u5HsCPqAeoFyDq
xWKuJ1BdyfWEx2UEdcK1lrRwPYJk1CPUKxD16hjXM2hGPUvgegctqHf7uR7C
dNTDJK6XIOqlP9dTeI16mnm0e/+MXWbA/a0b82oGiai/zVyfIQv1OTv6YMXM
beYg6jfPnwXoeU4a0iBZyvUeslHvV3I/gFD0A/QLEP3iFfcTGEI/+Zb7DTxH
v/HhfgSt6EfoVyD61VbuZ9CGfhbO/Q707LjfoR+C6Ifol1CGfsnjt4EP0E9X
VnxfEL7CBn1WAvbcf0GB/ls61+DM6lIbEP1ZKJvGBoRznWIM7tzPoQb9/CD3
ezBCv0ceAJEHkBfADHmB94EUipAnkDfgOfIG8giIPHKO8wp8hLyCPANXkGeQ
d0DkHeQhqEYeaue8BFuQlzSnCxcFp8lA5KkSzlvgiLzFz7sMipHHMjmvwVnk
NeQ5EHkOeQ8KkPfWcx4EN+RB5EUQeXGU8yRIkCeRN0HkTeRREHl010mv3oSP
5SDyKvIsiDyLvAsi7yIPg8jDyMsg8jLyNIg8jbwNIm8jj4PI48jrIPJ6Z228
2r1TAbwPp2Ae7EHk+/8BqpKqUQ==
     "], {{{}, {}, 
       TagBox[
        TooltipBox[{
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
            68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 
           84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
           100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 
           113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 
           126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 
           139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 
           152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
           165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
           178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 
           191}]}, 
         RowBox[{
           TagBox["y", HoldForm], "\[Equal]", 
           RowBox[{
             RowBox[{"-", "2"}], "+", 
             FractionBox[
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], "4"]}]}]], 
        Annotation[#, 
         HoldForm[$CellContext`y] == -2 + 
          Rational[1, 4] HoldForm[$CellContext`x]^2, "Tooltip"]& ]}}], {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0., 0.}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, AxesLabel -> {None, None}, 
     FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> Identity, 
     AspectRatio -> 1, Axes -> True, AxesLabel -> {None, None}, 
     DisplayFunction :> Identity, Frame -> True, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
     PlotRange -> {{-6, 6}, {-4, 8}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxdlwtUVNcVhofXMIC8QSSpbQhiokCtYWmsovsUgyAgUVMjrlDwQQzGB0oV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     "], {{{}, {}, 
       TagBox[
        TooltipBox[{
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
            68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 
           84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
           100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 
           113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125}], 
          
          LineBox[CompressedData["
1:eJwt0tciFgAAQOHfo3glj9AD6A0QspKRPRMyMsrem5K9yiZby977u3DxXZ3b
E/ziZUhoUCAQiCaMcCJ4RSRRz+01McQSRzwJvCGRtySRTAqpvCONdDLIJIts
csglj3wKKOQ9RXygmBJK+UgZ5VRQySeqqKaGWj7zhTrqaaCRJpppoZU22umg
ky666aGXPvoZYJAhvvKNYb4zwihjjDPBJFNMM8Msc/zgJ/MssMgSy6ywyhrr
/GKDTbbYZodd9tjnN3/4yz/+c8AhRxxzwilnnHPBJVdcc8Mtd9zzwCMBQwTx
BIg0Yvg=
           "]]}, 
         RowBox[{
           RowBox[{
             RowBox[{"-", 
               FractionBox[
                SuperscriptBox[
                 TagBox["x", HoldForm], "2"], "4"]}], "+", 
             SuperscriptBox[
              TagBox["y", HoldForm], "2"]}], "\[Equal]", "1"}]], 
        Annotation[#, 
         Rational[-1, 4] HoldForm[$CellContext`x]^2 + 
          HoldForm[$CellContext`y]^2 == 1, "Tooltip"]& ]}}], {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0., 0.}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, AxesLabel -> {None, None}, 
     FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> Identity, 
     AspectRatio -> 1, Axes -> True, AxesLabel -> {None, None}, 
     DisplayFunction :> Identity, Frame -> True, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
     PlotRange -> {{-6, 6}, {-4, 4}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxdlwtQVOcVx8EqdUTUQWKIIkKN2igpyGCboHJQ1EhgjC/EWpxmrJLoRFai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     "], {{{}, {}, 
       TagBox[
        TooltipBox[{
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
            68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 
           84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
           100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 
           113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 
           126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 
           139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 
           152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
           165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
           178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 
           191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 
           204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 
           217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 
           230, 231, 232, 233}]}, 
         RowBox[{
           RowBox[{
             FractionBox[
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], "4"], "+", 
             SuperscriptBox[
              TagBox["y", HoldForm], "2"]}], "\[Equal]", "1"}]], 
        Annotation[#, 
         Rational[1, 4] HoldForm[$CellContext`x]^2 + 
          HoldForm[$CellContext`y]^2 == 1, "Tooltip"]& ]}}], {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0., 0.}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, AxesLabel -> {None, None}, 
     FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> Identity, 
     AspectRatio -> 1, Axes -> True, AxesLabel -> {None, None}, 
     DisplayFunction :> Identity, Frame -> True, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
     PlotRange -> {{-3, 3}, {-3, 3}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.7378924838426647`*^9, 3.737893520262436*^9, 
  3.737893962031599*^9, 3.742658533998156*^9},
 CellLabel->"Out[18]=",
 CellID->1921299459,ExpressionUUID->"84595024-d48c-4b8f-8b88-32b9b84709df"]
}, Open  ]],

Cell[TextData[{
 "More generally, most curves of the form ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"b", " ", "x", " ", "y"}], "+", 
    RowBox[{"c", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"d", " ", "x"}], "+", 
    RowBox[{"e", " ", "y"}], "+", "k", "+", 
    SuperscriptBox["x", "2"]}], "=", "0"}]], "InlineCode",ExpressionUUID->
  "f25fc284-c9be-48d2-b864-d9e4acfbe23a"],
 " will be hyperbolas, parabolas, or ellipses: "
}], "CodeCaption",
 CellChangeTimes->{{3.685188555966585*^9, 3.685188711373132*^9}, {
   3.702654726228882*^9, 3.7026547571040907`*^9}, {3.702837875993774*^9, 
   3.702837876010379*^9}, 3.7084310191747885`*^9, {3.7093022034740667`*^9, 
   3.709302203474101*^9}, {3.7093022551195993`*^9, 3.709302289658231*^9}, {
   3.709307238779152*^9, 3.709307258632071*^9}, {3.709307302223525*^9, 
   3.709307346550808*^9}, {3.710674334604406*^9, 3.710674355236865*^9}, {
   3.738386449566656*^9, 3.73838644957036*^9}, {3.7392771080588007`*^9, 
   3.739277113386801*^9}},
 CellID->1832859408,ExpressionUUID->"bb105efa-8d84-4d54-830f-c6cd53b411e3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], "-", 
     RowBox[{"5", "x"}], "+", 
     RowBox[{"x", "^", "2"}], "+", 
     RowBox[{"4", "y"}], "-", 
     RowBox[{"2", "x", " ", "y"}], "+", 
     RowBox[{"3", 
      RowBox[{"y", "^", "2"}]}]}], "\[Equal]", "0"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.685188747960562*^9, 3.685188841155942*^9}},
 CellLabel->"In[19]:=",
 CellID->1362637688,ExpressionUUID->"6b81cf42-6435-489b-8812-40c51bb46a98"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdWGdUU1kXDUkYEQudhAiiyIgiIkXRQZx7hqKoKJbBkaY0ARsgSFMcVHCk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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl1FV4EAQUBeANGDBqxIiN2EZ3N0iIdKdISUuOEKSURkC6Q+luBEFppBuL
TqVUQLoR+Pfx8J/7el7OjWrdrV50YEBAQEYRc2MRmzgEEZd4xCeYBCQkEYlJ
QghJSUZyUhBKSlKRmjSEEU5a0pGeDEQQSVRMDzKRmSxkJRvZyUFOcpGbPOQl
H/kpQEEKUZgiFKUYxSlBSUpRmg8oQ1nKUZ4PqcBHVKQSlalCVapRnRrUpBa1
qUNd6lGfBjSkER/TmE9oQlOa0ZwWfEpLWtGaNrSlHe35jA50pBOd6UJXoulG
d3rQk8/pRW++oA996Ud/BvAlXzGQQQxmCEMZxnBG8DUjGcVovmEMYxnHeCYw
kUlMZgpTmcZ0ZjCTWczmW75jDnOZx3wWsJBFLGYJS1nGclawklWsZg1rWcd6
vmcDG/mBTWzmR35iC1vZxnZ2sJNd7OZn9rCXfeznAAc5xGGOcJRjHOcEJ/mF
X/mN3/mDU5zmDGc5x3kucJFLXOYKV/mTv7jGdW5wk1v8zT/8y23ucJf/uMd9
HvCQRzzmCU95xnNe8JJXvOZ/3vCWmPEHEovYxCGIuMQjPsEkICGJSEwSQkhK
MpKTglBSkorUpCGMcNKSjvRkIIJIogLf/6F3VNCDzQ==
        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"-", "4"}], "-", 
          RowBox[{"5", " ", 
            TagBox["x", HoldForm]}], "+", 
          SuperscriptBox[
           TagBox["x", HoldForm], "2"], "+", 
          RowBox[{"4", " ", 
            TagBox["y", HoldForm]}], "-", 
          RowBox[{"2", " ", 
            TagBox["x", HoldForm], " ", 
            TagBox["y", HoldForm]}], "+", 
          RowBox[{"3", " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "2"]}]}], "\[Equal]", "0"}]],
     Annotation[#, -4 - 5 HoldForm[$CellContext`x] + 
       HoldForm[$CellContext`x]^2 + 
       4 HoldForm[$CellContext`y] - (2 HoldForm[$CellContext`x]) 
       HoldForm[$CellContext`y] + 3 HoldForm[$CellContext`y]^2 == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{174.69921875, Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
  PlotRange->{{-3, 8}, {-4, 4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7118005540631037`*^9, 3.737891177234848*^9, 
  3.737892415402369*^9, 3.737893520379923*^9, 3.737893962150785*^9, 
  3.742658534071796*^9},
 CellLabel->"Out[19]=",
 CellID->1715891121,ExpressionUUID->"5a2465e4-9d41-4ee8-8a7e-015f5f8cb642"]
}, Open  ]],

Cell[TextData[{
 "In past years, more advanced students were expected to transform conics, \
like the one above, into the form of a simple conic. One can rid the equation \
of the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "3b35f3a2-350e-4026-bcb4-806739091e22"],
 ", ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "aa9cae58-8f7f-4d8d-a539-b8cd2ed6d097"],
 " terms by completing the square and then translating it to get the ",
 StyleBox["quadratic form",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"a", " ", "b", " ", "x", " ", "y"}], "+", 
    RowBox[{"c", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    SuperscriptBox["x", "2"]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"c5b0da35-6400-4362-9552-4bc4006bcd7a"],
 ". This can be rotated to a simple conic form using trigonometry or, better \
but more advanced, the ",
 StyleBox["principal axis theorem",
  FontSlant->"Italic"],
 " of linear algebra. In Chapter 7, we will learn some more pleasant ways to \
transform conics to simple conics or even to circles, depending on the group \
of transformations you want to allow."
}], "Text",
 PageBreakAbove->True,
 CellChangeTimes->{{3.685188870788898*^9, 3.685188952076857*^9}, {
   3.685189162347652*^9, 3.685189339865003*^9}, {3.685189377473292*^9, 
   3.685189467854067*^9}, {3.701008651296898*^9, 3.701008651326014*^9}, 
   3.701054475534225*^9, {3.7026549167333183`*^9, 3.702654917036051*^9}, {
   3.7026551183286867`*^9, 3.702655118336432*^9}, {3.702837881161099*^9, 
   3.7028378811678057`*^9}, 3.7084251587142925`*^9, {3.7084254910653706`*^9, 
   3.7084255253448505`*^9}, {3.708431065508789*^9, 3.7084310661417885`*^9}, {
   3.7084431719709682`*^9, 3.708443176594968*^9}, {3.708443258894968*^9, 
   3.708443259069968*^9}, {3.709059862866188*^9, 3.709059866741452*^9}, {
   3.740824453202379*^9, 3.740824456752049*^9}},
 CellID->1116772803,ExpressionUUID->"65341ccb-b814-46a3-ab0a-bced18c9dc2e"],

Cell["There are some exceptions. For example:", "CodeCaption",
 CellChangeTimes->{{3.685189953251307*^9, 3.685189978329908*^9}, 
   3.701008651337368*^9, 3.708882067624642*^9},
 CellID->593425241,ExpressionUUID->"2eb19713-d0c3-4513-9470-e31d00c2188c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "^", "2"}], "-", 
       RowBox[{"x", "^", "2"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "2"}], "-", 
       RowBox[{"2", "x", " ", "y"}], "+", 
       RowBox[{"y", "^", "2"}]}], "==", "1"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}], ",", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "2"}], "-", 
       RowBox[{"2", "x", " ", "y"}], "+", 
       RowBox[{"y", "^", "2"}]}], "\[Equal]", "0"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.685190081057518*^9, 3.685190121752183*^9}, {
  3.685190226819293*^9, 3.685190292173203*^9}},
 CellLabel->"In[20]:=",
 CellID->783968819,ExpressionUUID->"24c0f1df-7eae-483c-a5cd-424662751593"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx11jtrFFEYxvE1F+MV7BW8LSLodzjTKMYyvY1g5yr4ASzstBBdVNDCIqBW
plhkURN9DwpB2EaTsBpXzBJDMAR0CeKFKOqe9/kfYcBAeHgmmc15Z+b8JntP
nh07NVCpVOLf7376145IvmvWOs3a1pwP+9HZmPNadbReHR3IuZB+b93IG+n4
Ws4P6fhqzlvp+GLO1XS8k3M8HZ/J2Uj5LKev8+UUObu/f7xhY+nnjVD+OcfJ
c/45OS/438nZ8nXkvOTrzDnrc+S87HPmfO3XIecVv04F+cCvY843fp1z6j78
L+OZ/mnN7YUy1tSV8bS6MqbLU99WVD25rwX39626MpbWE6+mE7cUyni8/zHV
zYUyHlNXxqPqR9R/p6+RQslzVPA8NdWVsXR9NN+w5huOB9IcQ4UyVtWVcZ+6
MqbTaoOFkue24Pmtqytj6X7F9DHVDYUyas8USu2biu5PJf70QYPS/D79Ckp7
r+eC/dJRVxrPTVvdr+uPoLRH6UJ8DY89ramutIa60g6mhX8JSquqK22P+m71
63qO2b91daWVnncbSmP3glL7s6d92LPv6TJ8Dt88bVH7Bg866kpjX71S97lX
NP+KTaW5lsNTT82/rPmXbUL9vvqhNNdSOOyp+Zc0/5LtUt+pflP7HJ/q6krD
gYvqI2nObtjkqfm7mr9rvTT3QvjkaR/lCt511JWGOy/Un6doh2lPzdvWvG27
qz6u7nPNab45uy3X8LSurjTcO68uN3HU1tIfaoV1T623pfW2bFJ9Qt3XNa31
TdsdOYvfdXWl4fAJdXdpMrhHk3ZPbs946vyGzv/nPu+B0vssO4mbOImbOImb
OImbpfdhdhI3cRI3cRI3cRI3cRI3cRI3cRI3S+/f7CRu4iRu4iRu4iRu4iRu
4iRu4iRult732UncxEncxEncxEncxEncXJeTuImTuFn6/yI7iZs4iZs4iZs4
iZs4iZs4iZs4iZs4iZs4iZs4iZs4iZs4iZs4OVhyEjdxEjdxEjdxEjdxEjdx
Ejdx8knJSdzESdzESdzESdzESdzESdzESdzESdzESdzESdzESdzEyZWSk7iJ
k7jpc89r/vnsJo7iJo7iJo7iJo7iJo7iJo7iJo7iJo7iJo7iJo7iJo7iJG7i
JG7iJG525KQyO4mbOImb5f+X/wBGq89o
     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 23, 24, 25, 26}], 
         LineBox[{27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
          42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 
          59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 
          76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 
          93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 
          108, 109}], 
         LineBox[{110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 
          122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 
          135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 
          148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 
          161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 
          174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
          187, 188, 189, 190, 191, 192}]},
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"]}], "+", 
            SuperscriptBox[
             TagBox["y", HoldForm], "2"]}], "\[Equal]", "0"}]],
       Annotation[#, -HoldForm[$CellContext`x]^2 + HoldForm[$CellContext`y]^2 == 
        0, "Tooltip"]& ]}],
    AspectRatio->1,
    Axes->True,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-4, 4}, {-4, 4}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAlslFUUhafTToeUCJG4QImUUmopRDEiICRyfwXZLYLKIiIBQcpSIKwN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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
          35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
          52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
          69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
          86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
          102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 
          115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 
          128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 
          141, 142, 143, 144, 145}], LineBox[CompressedData["
1:eJwN0edaDQAAANB7k0oalEqh8UoewQPoUXyfNmmR0S4ttPegoa0pSUNShCh1
fpwnOBl3Mm/fDQYCgXvcJ4tscsglj3wKeMBDCnlEEcWUUEoZj3lCOU95xnNe
UEElVVRTQy111NPASxppopkWWnnFa97QRjsddNJFNz300kc/AwwyxDAjjPKW
d4wxzgSTvGeKaWaYZY55FvjAIksss8Iqa3xknU9s8JlNvrDFNjvs8pU9vrHP
dw445Ac/OeIXv/nDMX/5xwmn/OeMgMAgIVwglIuEEU4El4jkMlFEE0MsV7hK
HPFcI4FEkrhOMinc4Ca3SCWNdM4B7B9amw==
          "]]},
        RowBox[{
          RowBox[{
            SuperscriptBox[
             TagBox["x", HoldForm], "2"], "-", 
            RowBox[{"2", " ", 
              TagBox["x", HoldForm], " ", 
              TagBox["y", HoldForm]}], "+", 
            SuperscriptBox[
             TagBox["y", HoldForm], "2"]}], "\[Equal]", "1"}]],
       Annotation[#, 
        HoldForm[$CellContext`x]^2 - (2 HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y] + HoldForm[$CellContext`y]^2 == 1, 
        "Tooltip"]& ]}],
    AspectRatio->1,
    Axes->True,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-3, 3}, {-3, 3}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxF08tKw0AYxfEkbdWnEIo38A1c1ZVYceUjCN1Z9VG8PUotFQUFly7cKIjR
QkGoIAhW8YK2tTkn829I+MFkZs6XmUx5c2ejlkRRtDR6Mn1NXQSrB7OjexJF
dQIfmvW0WS/hnDoWcTvNXhSwlXVLE4yVM3ZNE8d4qJwIPW5wHnS/Pj6qjl/c
Ve4P+hu/8UjzfuK86v5A5/TQOW94ovZXbCv3BZ3zjAua9wnXNU8HOxqX4qL6
3WBX7Vf4Lk/R+9Y6C166vRK89jic9rx461xccV1Ydt34N8yuLt75u7HhdcFV
rxs6poczXnfc877gQDlfuOV9xXvvOzqnj8f+b3Df/9Vy0P1iVMxwrOtM0LkF
dN1FdB0lzM8N5ucK83OH/98/wbY=
     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
          35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
          52, 53, 54, 55, 56, 57}]},
        RowBox[{
          RowBox[{
            SuperscriptBox[
             TagBox["x", HoldForm], "2"], "-", 
            RowBox[{"2", " ", 
              TagBox["x", HoldForm], " ", 
              TagBox["y", HoldForm]}], "+", 
            SuperscriptBox[
             TagBox["y", HoldForm], "2"]}], "\[Equal]", "0"}]],
       Annotation[#, 
        HoldForm[$CellContext`x]^2 - (2 HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y] + HoldForm[$CellContext`y]^2 == 0, 
        "Tooltip"]& ]}],
    AspectRatio->1,
    Axes->True,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-3, 3}, {-3, 3}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{3.711800554146052*^9, 3.737891177478033*^9, 
  3.737892415652931*^9, 3.7378935206193933`*^9, 3.737893962391696*^9, 
  3.7426585341576567`*^9},
 CellLabel->"Out[20]=",
 CellID->424175084,ExpressionUUID->"0671bb6f-c03f-46f9-a1fa-8e8110bcc814"]
}, Open  ]],

Cell[TextData[{
 "In these cases, we get a pair of lines. In the right-hand plot, the lines \
are actually the same. In the middle plot, the lines are parallel, that is, \
they have the same slope ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "=", "1"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "7468c550-9f90-4de6-b6be-b7c50c3c63e9"],
 ", so by the previous section,",
 StyleBox[" ",
  FontSlant->"Italic"],
 "they meet at the infinite point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"abbf9c25-0773-4631-8f64-44852abd2957"],
 ". We call these curves ",
 StyleBox["singular",
  FontSlant->"Italic"],
 ", and in the left picture, the point where they meet is called a ",
 StyleBox["singularity",
  FontSlant->"Italic"],
 ". We will deal with this concept in Chapter 3."
}], "Text",
 CellChangeTimes->{{3.685190309744334*^9, 3.685190353549563*^9}, {
   3.685190389615234*^9, 3.685190555884358*^9}, {3.7010086513510323`*^9, 
   3.7010086513763227`*^9}, {3.701012464124711*^9, 3.701012510142693*^9}, {
   3.7026549841580133`*^9, 3.702654985342115*^9}, {3.702655140347925*^9, 
   3.702655140803216*^9}, {3.702837914890526*^9, 3.702837918447525*^9}, {
   3.7084255661695275`*^9, 3.7084256075401974`*^9}, {3.708425641485362*^9, 
   3.708425656601568*^9}, 3.7392828325384088`*^9},
 CellID->911542903,ExpressionUUID->"ff6acd5b-316d-4daa-a712-5bbee24adf11"],

Cell[TextData[{
 "Make numerical hyperbolas, and use ",
 Cell[BoxData[
  ButtonBox["ContourStyle",
   BaseStyle->"CodeLink"]], "InlineCode",ExpressionUUID->
  "5a78ffbe-f2eb-411b-a6cd-d633a1d2cfb2"],
 " to assign colors to certain lines:"
}], "CodeCaption",
 CellChangeTimes->{{3.707501965775124*^9, 3.707501974398226*^9}, {
  3.7084256765069127`*^9, 3.708425676850108*^9}, {3.7088820733802176`*^9, 
  3.7088820739242716`*^9}},
 CellID->1786011262,ExpressionUUID->"a5527fa5-0401-477d-a6c7-7890b13d8548"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{
   RowBox[{"-", "1.`"}], "-", 
   RowBox[{"0.43301270189221946`", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{"0.5`", " ", "x", " ", "y"}], "+", 
   RowBox[{"0.43301270189221946`", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Input",
 CellChangeTimes->{{3.685191181862449*^9, 3.68519124161855*^9}, {
   3.685191313835795*^9, 3.685191339476754*^9}, 3.7074881719845667`*^9},
 CellLabel->"In[21]:=",
 CellID->153233023,ExpressionUUID->"28770129-fcf8-4802-a369-8148641a0729"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1.`"}], "-", 
  RowBox[{"0.43301270189221946`", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"0.5`", " ", "x", " ", "y"}], "+", 
  RowBox[{"0.43301270189221946`", " ", 
   SuperscriptBox["y", "2"]}]}]], "Output",
 CellChangeTimes->{3.711800554190673*^9, 3.737891177505715*^9, 
  3.73789241567793*^9, 3.737893520656604*^9, 3.7378939624322777`*^9, 
  3.742658534223665*^9},
 CellLabel->"Out[21]=",
 CellID->1612412395,ExpressionUUID->"52034e76-934d-46b8-adfe-7763caa1569b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l1", "=", 
  RowBox[{"0.`", "\[VeryThinSpace]", "+", 
   RowBox[{"0.8583270645009377`", " ", "x"}], "-", 
   RowBox[{"1.4866660852270714`", " ", "y"}]}]}]], "Input",
 CellChangeTimes->{{3.685191181862449*^9, 3.68519124161855*^9}, {
  3.685191313835795*^9, 3.685191339476754*^9}, {3.7074881719845667`*^9, 
  3.707488175120425*^9}},
 CellLabel->"In[22]:=",
 CellID->346558734,ExpressionUUID->"8a4289d3-208c-441e-a96c-8dea06947ad0"],

Cell[BoxData[
 RowBox[{"0.`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.8583270645009377`", " ", "x"}], "-", 
  RowBox[{"1.4866660852270714`", " ", "y"}]}]], "Output",
 CellChangeTimes->{3.711800554224352*^9, 3.737891177524642*^9, 
  3.737892415693681*^9, 3.737893520674358*^9, 3.7378939624537497`*^9, 
  3.7426585342531443`*^9},
 CellLabel->"Out[22]=",
 CellID->718981272,ExpressionUUID->"5aebe583-03f4-44be-89a3-84768e677a47"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l2", "=", 
  RowBox[{"0.`", "\[VeryThinSpace]", "-", 
   RowBox[{"0.9830458468618561`", " ", "x"}], "-", 
   RowBox[{"0.5675617843114374`", " ", "y"}]}]}]], "Input",
 CellChangeTimes->{{3.685191181862449*^9, 3.68519124161855*^9}, {
  3.685191313835795*^9, 3.685191339476754*^9}, {3.7074881719845667`*^9, 
  3.707488175120425*^9}},
 CellLabel->"In[23]:=",
 CellID->636991674,ExpressionUUID->"eeef83b1-d2bf-4183-a6a3-538373e13dbc"],

Cell[BoxData[
 RowBox[{"0.`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.9830458468618561`", " ", "x"}], "-", 
  RowBox[{"0.5675617843114374`", " ", "y"}]}]], "Output",
 CellChangeTimes->{3.7118005542584457`*^9, 3.73789117754393*^9, 
  3.737892415708808*^9, 3.7378935206947193`*^9, 3.737893962477846*^9, 
  3.7426585342936373`*^9},
 CellLabel->"Out[23]=",
 CellID->27756835,ExpressionUUID->"c8826ab1-a849-4018-ad9a-53a0697cd968"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "\[Equal]", "0"}], ",", 
     RowBox[{"l1", "\[Equal]", "0"}], ",", 
     RowBox[{"l2", "\[Equal]", "0"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", " ", 
   RowBox[{"ContourStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", "Dashed", ",", "Dashed"}], "}"}]}]}], 
  "]"}]], "Input",
 PageBreakAbove->True,
 CellLabel->"In[24]:=",
 CellID->459516272,ExpressionUUID->"ec012bee-97fc-4b9c-90d1-91d8f9c0b050"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAlYjukax9tXpeVrGeEMhaNImjiWZp6bIWPfI8VYslYkRGKM9cRY4thC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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], AbsoluteThickness[1.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122}], 
       LineBox[{123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 
        135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
        149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 
        163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 
        177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 
        191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 
        205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 
        219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 
        233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 
        247, 248, 249, 250, 251}]},
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"-", "1.`"}], "-", 
              RowBox[{"0.43301270189221946`", " ", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "2"]}], "+", 
              RowBox[{"0.5`", " ", 
                TagBox["x", HoldForm], " ", 
                TagBox["y", HoldForm]}], "+", 
              RowBox[{"0.43301270189221946`", " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}]}], "\[Equal]", "0"}], ",", 
          RowBox[{
            RowBox[{
              RowBox[{"0.`", "\[VeryThinSpace]"}], "+", 
              RowBox[{"0.8583270645009377`", " ", 
                TagBox["x", HoldForm]}], "-", 
              RowBox[{"1.4866660852270714`", " ", 
                TagBox["y", HoldForm]}]}], "\[Equal]", "0"}], ",", 
          RowBox[{
            RowBox[{
              RowBox[{"0.`", "\[VeryThinSpace]"}], "-", 
              RowBox[{"0.9830458468618561`", " ", 
                TagBox["x", HoldForm]}], "-", 
              RowBox[{"0.5675617843114374`", " ", 
                TagBox["y", HoldForm]}]}], "\[Equal]", "0"}]}], "}"}]],
     Annotation[#, {-1. - 0.43301270189221946` 
        HoldForm[$CellContext`x]^2 + (0.5 HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y] + 
        0.43301270189221946` HoldForm[$CellContext`y]^2 == 0, 
       0. + 0.8583270645009377 HoldForm[$CellContext`x] - 1.4866660852270714` 
        HoldForm[$CellContext`y] == 0, 
       0. - 0.9830458468618561 HoldForm[$CellContext`x] - 0.5675617843114374 
        HoldForm[$CellContext`y] == 0}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwNycVSQgEAAMCHndid2IGo2N0dKDYqKuZF/f8Zgz3saSOZ7+RXKAiCT374
5Y9/AhEih1zyyKeAQooopoRSyignTAWVVFFNDbXUUU8DjTTRTAuttNFOB51E
6KKbHnrpo58BBhlimCgjxBhljHHiTDDJFNPMMMsc8yywyBLLrLDKGutssMkW
2+ywyx77HHDIEcckOOGUJGecc8ElV1xzQ4pb7rgnzQOPPJHhmRdeeeOdD7J5
bhvU
        "]]},
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"-", "1.`"}], "-", 
              RowBox[{"0.43301270189221946`", " ", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "2"]}], "+", 
              RowBox[{"0.5`", " ", 
                TagBox["x", HoldForm], " ", 
                TagBox["y", HoldForm]}], "+", 
              RowBox[{"0.43301270189221946`", " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}]}], "\[Equal]", "0"}], ",", 
          RowBox[{
            RowBox[{
              RowBox[{"0.`", "\[VeryThinSpace]"}], "+", 
              RowBox[{"0.8583270645009377`", " ", 
                TagBox["x", HoldForm]}], "-", 
              RowBox[{"1.4866660852270714`", " ", 
                TagBox["y", HoldForm]}]}], "\[Equal]", "0"}], ",", 
          RowBox[{
            RowBox[{
              RowBox[{"0.`", "\[VeryThinSpace]"}], "-", 
              RowBox[{"0.9830458468618561`", " ", 
                TagBox["x", HoldForm]}], "-", 
              RowBox[{"0.5675617843114374`", " ", 
                TagBox["y", HoldForm]}]}], "\[Equal]", "0"}]}], "}"}]],
     Annotation[#, {-1. - 0.43301270189221946` 
        HoldForm[$CellContext`x]^2 + (0.5 HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y] + 
        0.43301270189221946` HoldForm[$CellContext`y]^2 == 0, 
       0. + 0.8583270645009377 HoldForm[$CellContext`x] - 1.4866660852270714` 
        HoldForm[$CellContext`y] == 0, 
       0. - 0.9830458468618561 HoldForm[$CellContext`x] - 0.5675617843114374 
        HoldForm[$CellContext`y] == 0}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
       Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVyVVSQgEAQNHnUtySS/DPQAywGxW7uxURu7u7O/bj8ePM3JmbnhnOyEsL
giBElsgmh1xC/M8w+RRQSBERohRTQilllFNBJVVUU0MtddQTo4FGmojTTAut
tNFOB5100U0PvfTRzwCDDDHMCKOMMc4Ek0wxzQyzJJgjyTwpFlhkiWVWWGWN
dTbYZIttdthlj30OOOSIY0445YxzLrjkimtuuOWOex545IlnXnjljXc++OSL
b3745Q+sTUZB
        "]]},
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"-", "1.`"}], "-", 
              RowBox[{"0.43301270189221946`", " ", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "2"]}], "+", 
              RowBox[{"0.5`", " ", 
                TagBox["x", HoldForm], " ", 
                TagBox["y", HoldForm]}], "+", 
              RowBox[{"0.43301270189221946`", " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}]}], "\[Equal]", "0"}], ",", 
          RowBox[{
            RowBox[{
              RowBox[{"0.`", "\[VeryThinSpace]"}], "+", 
              RowBox[{"0.8583270645009377`", " ", 
                TagBox["x", HoldForm]}], "-", 
              RowBox[{"1.4866660852270714`", " ", 
                TagBox["y", HoldForm]}]}], "\[Equal]", "0"}], ",", 
          RowBox[{
            RowBox[{
              RowBox[{"0.`", "\[VeryThinSpace]"}], "-", 
              RowBox[{"0.9830458468618561`", " ", 
                TagBox["x", HoldForm]}], "-", 
              RowBox[{"0.5675617843114374`", " ", 
                TagBox["y", HoldForm]}]}], "\[Equal]", "0"}]}], "}"}]],
     Annotation[#, {-1. - 0.43301270189221946` 
        HoldForm[$CellContext`x]^2 + (0.5 HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y] + 
        0.43301270189221946` HoldForm[$CellContext`y]^2 == 0, 
       0. + 0.8583270645009377 HoldForm[$CellContext`x] - 1.4866660852270714` 
        HoldForm[$CellContext`y] == 0, 
       0. - 0.9830458468618561 HoldForm[$CellContext`x] - 0.5675617843114374 
        HoldForm[$CellContext`y] == 0}, "Tooltip"]& ]}],
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{175.3984375, Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
  PlotRange->{{-6, 6}, {-6, 6}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.711800554303625*^9, 3.737891177651822*^9, 
  3.737892415808136*^9, 3.737893520816041*^9, 3.7378939625969257`*^9, 
  3.742658534357292*^9},
 CellLabel->"Out[24]=",
 CellID->505174446,ExpressionUUID->"58302c4d-1084-4046-8e17-59791dedee3d"]
}, Open  ]],

Cell[TextData[{
 "In the plot, we have a numerical hyperbola and two lines that closely \
approximate the hyperbola when both ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "672cb508-6c34-4a35-a2e6-260363d90cc8"],
 ", ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "037a809a-de65-4a62-b028-6ccbcce02e03"],
 " are large. These are called asymptotes. We will see these again in the \
next section, but they will reappear in greater detail in Chapter 7."
}], "Text",
 CellChangeTimes->{{3.685191276936925*^9, 3.685191280977574*^9}, {
  3.685191359802143*^9, 3.68519143021312*^9}, {3.685191579945884*^9, 
  3.685191627843214*^9}, {3.685191674060986*^9, 3.68519168615854*^9}, {
  3.7010086513871593`*^9, 3.701008651403125*^9}, {3.701013875886834*^9, 
  3.701013888805827*^9}, {3.702837924905518*^9, 3.7028379273926287`*^9}, {
  3.708425713237844*^9, 3.708425739991501*^9}},
 CellID->74460890,ExpressionUUID->"abb9e7bb-c1e2-4da1-8c70-f31a02712087"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3 Cubics", "Subsection",
 CellChangeTimes->{{3.685191276936925*^9, 3.685191280977574*^9}, {
  3.685191359802143*^9, 3.68519143021312*^9}, {3.685191579945884*^9, 
  3.685191627843214*^9}, {3.685191674060986*^9, 3.685191692692875*^9}},
 CellID->1628695676,ExpressionUUID->"0a8656ad-9eca-496e-87e3-8be33e15d1f1"],

Cell[TextData[{
 "Many people who have gone further in mathematics, including PhD \
mathematicians, have never seen algebraic curves of a higher degree, other \
than function curves like ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    RowBox[{"f", "(", "x", ")"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"0c04e70a-0da0-4d78-8506-058ae5dbe3f9"],
 ", than cubics. Even the cubics they have seen are mostly of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["y", "2"], "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"b", " ", "x"}], "+", "c", "+", 
        SuperscriptBox["x", "3"]}], ")"}]}], "=", "0"}]}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"e9a1572e-9c12-4d59-a213-0906e8320408"],
 ". Nonsingular curves of this form are called ",
 StyleBox["elliptic curves",
  FontSlant->"Italic"],
 ". These form a major topic in mathematics, and especially ",
 StyleBox["number theory",
  FontSlant->"Italic"],
 ", so I recommend searching the ",
 ButtonBox["Wolfram Language & System Documentation Center",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com"], None},
  ButtonNote->"http://reference.wolfram.com"],
 ", ",
 ButtonBox["Wolfram|Alpha",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolframalpha.com"], None},
  ButtonNote->"http://wolframalpha.com"],
 ", ",
 Cell[BoxData[
  FormBox[
   ButtonBox[
    RowBox[{"Wolfram", ".", "com"}],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["http://www.wolfram.com"], None},
    ButtonNote->"http://www.wolfram.com"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"686df65b-b29a-450d-90b5-2671b7985676"],
 ", or Wikipedia for",
 StyleBox[" elliptic curves",
  FontSlant->"Italic"],
 " or the related ",
 StyleBox["elliptic integrals",
  FontSlant->"Italic"],
 ". Among other things, elliptic curves played an important role in ",
 ButtonBox["Andrew Wiles\[CloseCurlyQuote]s 1996 solution",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.wolframalpha.com/input/?i=fermat%27s+last+theorem"], 
    None},
  ButtonNote->"https://www.wolframalpha.com/input/?i=fermat%27s+last+theorem"],
 " of Fermat\[CloseCurlyQuote]s conjecture, known by many as Fermat\
\[CloseCurlyQuote]s last theorem."
}], "Text",
 CellChangeTimes->{{3.685191799531968*^9, 3.685192061785155*^9}, {
   3.685192112922809*^9, 3.685192121802123*^9}, {3.685192166467201*^9, 
   3.685192175897459*^9}, {3.685192637182939*^9, 3.685192655629943*^9}, {
   3.68519295731321*^9, 3.685193138222159*^9}, {3.685270607383278*^9, 
   3.685270681370571*^9}, {3.701008651416059*^9, 3.7010086514544477`*^9}, {
   3.701013928351426*^9, 3.701013982777388*^9}, {3.701014015751041*^9, 
   3.7010140540804377`*^9}, {3.7010141592385*^9, 3.7010141596054068`*^9}, {
   3.7010544787192287`*^9, 3.70105448085493*^9}, {3.702655164210823*^9, 
   3.702655164218527*^9}, {3.7028379334307404`*^9, 3.702837936285894*^9}, 
   3.707502881532281*^9, {3.7084257506773643`*^9, 3.708425863077733*^9}, 
   3.708426402904333*^9, {3.708882098949774*^9, 3.7088820989657755`*^9}, {
   3.708882439050781*^9, 3.708882458052681*^9}, {3.7088826098878627`*^9, 
   3.7088826098888626`*^9}, {3.70888265446532*^9, 3.7088826678106546`*^9}, {
   3.709059889340591*^9, 3.709059890866088*^9}, {3.7383866170112543`*^9, 
   3.7383866770418797`*^9}, {3.7383867076884727`*^9, 3.738386718617073*^9}, {
   3.739283524457594*^9, 3.739283526762824*^9}, {3.739284057312874*^9, 
   3.73928407087423*^9}, {3.7392841344535875`*^9, 3.739284134459588*^9}, {
   3.7392841806622076`*^9, 3.7392841807422156`*^9}, {3.7392845527404118`*^9, 
   3.7392845577279105`*^9}, {3.739285330031133*^9, 3.7392853605481844`*^9}, 
   3.740824620033218*^9, {3.740824659906848*^9, 3.7408246872139177`*^9}, {
   3.740824735569516*^9, 3.740824775816272*^9}, {3.740824901232779*^9, 
   3.7408249544156218`*^9}, {3.740824997511838*^9, 3.740825001422988*^9}},
 CellID->1661661870,ExpressionUUID->"cd97f1ed-21c1-40b2-8f90-9fa8f2884bdf"],

Cell["Here is the Wolfram|Alpha page for elliptic curves:", "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{
  3.7147415396060677`*^9, {3.740825132654142*^9, 3.740825135285561*^9}, {
   3.742574890852326*^9, 3.742574892683601*^9}},
 CellID->438824402,ExpressionUUID->"4b1c2d10-6c2a-498f-a1fc-73c667c23721"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzs3Q+sbdldH/YLprGhFDUtIURYJQ1VpLQlVdSWRhWCAlVFk5Q4UAdjjMEO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    "], {{0, 2493}, {1642, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> ColorProfileData[CompressedData["
1:eJydlndcFNcWx+/MbC+0XZYiZem9twVEehOQXkVh2V1gKQsuuxTFhogKRBQR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      "], "RGB", "XYZ"], Interleaving -> 
    True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->{545.6, Automatic},
  ImageSizeRaw->{1642, 2493},
  PlotRange->{{0, 1642}, {0, 2493}}]], "Picture",
 CellChangeTimes->{
  3.7095816977849607`*^9, {3.7095818654800253`*^9, 3.709581875192223*^9}, 
   3.709581948615986*^9},
 CellID->1359321250,ExpressionUUID->"bbf2424f-8351-4e32-ad74-9f4d327b338a"],

Cell["Typical examples of elliptic curves are:", "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{{3.685270103227367*^9, 3.685270142123806*^9}, 
   3.7088834757394533`*^9},
 CellID->1673703502,ExpressionUUID->"4a2bdcea-1c3d-4373-996e-6f4d0b679519"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "^", "2"}], "\[Equal]", 
      RowBox[{
       RowBox[{"x", "^", "3"}], "+", 
       RowBox[{"3", 
        RowBox[{"x", "^", "2"}]}], "-", 
       RowBox[{"3", "x"}], "+", "4"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}]}], "]"}], ",", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "^", "2"}], "==", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "12"}], " ", "x"}], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["x", "3"]}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "15"}], ",", "15"}], "}"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.685270147736631*^9, 3.685270168556867*^9}, {
  3.685270370672324*^9, 3.685270406626962*^9}, {3.685270452756033*^9, 
  3.685270486511134*^9}, {3.685270526908392*^9, 3.685270574926795*^9}},
 CellLabel->"In[25]:=",
 CellID->46466061,ExpressionUUID->"593a90e5-a460-41c9-8e3d-48f5ed49b3b4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdWXk8ldkbx+Ved7W1YGRKSZZC+yLnoSY00ljCLNr3MqVlNO1NSsq02Sra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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJwl1fOfEAYYBvC7bNuXbdvmZddlXrZt27btGmoIW8ZQW3Zbxlbf+/TD93n/
gud5g0JCg7sHBgQE7BFhNxzhiUBEIhGZKEQlGtGJQUxiEZs4xCUe8UlAQhKR
mCQkJRnJSUFKUpGaNASRlnSkJwMZyURmspCVbGQnBznJRW7ykJd85KcABSlE
YYpQlGIUpwQlKUVpylCWcpSnAhWpRGWqUJVqVKcGNalFbeoQTF3qUZ8GNKQR
jWlCU5rRnBa0pBWtCaENbWlHezrQkU50pgtd6UZ3QulBT3rRmz70pR/9GcBA
BjGYIQxlGMMZwUhGMZoxjGUc45nARCYxmSlMZRrTmcFMZjGbOcxlHvNZwEIW
sZglLGUZy1nBSlaxmjWsZR3r2cBGNrGZLWxlG9vZwU52sZs97GUf+znAQQ5x
mCMc5RjHOcE3fMt3fM9JTvEDP/ITP3OaM5zlHL/wK+e5wEUucZkrXOUa17nB
b/zOH/zJTW7xF39zmzvc5R73ecBDHvGYJzzlGc95wT/8y0te8Zo3vOUd7/nA
Rz7xH//zmbDyBxKO8EQgIpGITBSiEo3oxCAmsYhNHOISj/gkICGJSEwSkpKM
5KQgJalITRqCSEs60pOBjGQiM1nISjayk4Oc5CI3echLPvJTgIIUojBFKEox
ilOCkpSiNGUoSznKU4GKVKIyVahKNapTg5rUojZ1CKYu9ahPAxrSiMY0oSnN
aE4LWtKK1oTQhra0oz0d6EgnOtOFrnQjbLxD6UFPetGbPvSlH/0ZwEAGMZgh
DGUYwxnBSEYxmjGMZRzjmcBEJjGZKUxlGtOZwUxmMZs5zGUe81nAQhaxmCUs
ZRnLWcFKVrGaNaxlHevZwEY2sZktbGUb29nBTnaxO/DrP/sCNjrCQA==
          "]]},
        RowBox[{
          SuperscriptBox[
           TagBox["y", HoldForm], "2"], "\[Equal]", 
          RowBox[{"4", "-", 
            RowBox[{"3", " ", 
              TagBox["x", HoldForm]}], "+", 
            RowBox[{"3", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"]}], "+", 
            SuperscriptBox[
             TagBox["x", HoldForm], "3"]}]}]],
       Annotation[#, HoldForm[$CellContext`y]^2 == 
        4 - 3 HoldForm[$CellContext`x] + 3 HoldForm[$CellContext`x]^2 + 
         HoldForm[$CellContext`x]^3, "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-5, 5}, {-15, 15}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdV3lcTmn7f6qnep7Us7VL+yItTI0WxLleKYXMb0a2MEijUKIy2RIpOyWm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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
          35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
          52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
          69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
          86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
          102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 
          115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 
          128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140}], 
         LineBox[CompressedData["
1:eJwt0edaDQAAgOFzjEoRQrYc2aOMsqmshvU8LsEF6EoyMpKssjMyMrIlSjZJ
QjbZ2WS+P/x4L+B7vtDC7AWLgoFA4Cw5LGYJS1lGLstZwUpWkcdq8llDAWtZ
x3o2sJFCitjEZrawlW1sZwfF7GQXu9lDCXvZx34OUMpBDnGYI5RxlGMc5wQn
OcVpzlD+v62Cc5ynkiouUM1FLnGZK1zlGte5wU1quEUtt6njDvXc5R73aeAB
D3nEY57wlGc85wWNvOQVr3nDW97xniY+8JFPfOYLX/nGd37QzE9+8Zs//CVg
apAWtKQVrQkjnAjaEEkUbWlHNO3pQEdi6ERnuhBLV7rRnR70pBe96UMcfQnR
j3j6M4CBDGIwQxjKMIYzggQSGckoRjOGJJIZyzjGM4GJTGIyU5hKCqmkMY3p
zGAms0gng0yymM0c5jKP+fwDGHRoEQ==
          "]]},
        RowBox[{
          SuperscriptBox[
           TagBox["y", HoldForm], "2"], "\[Equal]", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "12"}], " ", 
              TagBox["x", HoldForm]}], "+", 
            SuperscriptBox[
             TagBox["x", HoldForm], "2"], "+", 
            SuperscriptBox[
             TagBox["x", HoldForm], "3"]}]}]],
       Annotation[#, 
        HoldForm[$CellContext`y]^2 == (-12) HoldForm[$CellContext`x] + 
         HoldForm[$CellContext`x]^2 + HoldForm[$CellContext`x]^3, 
        "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-5, 7}, {-15, 15}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{3.7118005543808193`*^9, 3.737891177855842*^9, 
  3.73789241598534*^9, 3.737893521018187*^9, 3.737893962796475*^9, 
  3.742658534438293*^9},
 CellLabel->"Out[25]=",
 CellID->1464057331,ExpressionUUID->"1eb17194-9130-4d39-8d5e-fe4434383fea"]
}, Open  ]],

Cell[TextData[{
 "Less well remembered are Issac Newton\[CloseCurlyQuote]s explorations with \
real cubics, see for example Struik (1986). Newton was largely interested in \
asymptotes, so he called his curves hyperbolas and numbered them from 1 to \
72. In honor of Newton, I have established a large catalog of curves with \
asymptotes using his ideas. I call these ",
 StyleBox["Newton Hyperbolas",
  FontSlant->"Italic"],
 ", and there are 960 cubics, numbered 64 through 1023, among these curves. \
There are over 268 million Newton hyperbolas, just 960 are of degree 3."
}], "Text",
 CellChangeTimes->{{3.685270598547055*^9, 3.685270600933424*^9}, {
   3.685270691398508*^9, 3.685271049206127*^9}, {3.685271159568992*^9, 
   3.685271199056504*^9}, {3.685271286002217*^9, 3.685271300404658*^9}, {
   3.685271350980676*^9, 3.685271400310271*^9}, {3.685271738299021*^9, 
   3.685271738648127*^9}, {3.70100865146493*^9, 3.701008651490633*^9}, {
   3.7010142220137377`*^9, 3.7010142223169394`*^9}, {3.7010544823099747`*^9, 
   3.7010544839818993`*^9}, 3.708425942606533*^9, 3.709035223183051*^9, {
   3.7090353968604174`*^9, 3.7090353984755783`*^9}, {3.7093035788516817`*^9, 
   3.709303578855001*^9}, {3.710674623442558*^9, 3.710674636641165*^9}, {
   3.710675658667422*^9, 3.710675664011252*^9}, 3.711801125338737*^9, {
   3.737892824666757*^9, 3.737892826432733*^9}, {3.73789287352838*^9, 
   3.73789288577553*^9}, {3.739290980768733*^9, 3.7392909894167333`*^9}, {
   3.740832772462104*^9, 3.740832772886389*^9}, {3.740832825838821*^9, 
   3.7408328268809433`*^9}, 3.742575085052479*^9},
 CellID->1906247015,ExpressionUUID->"972a55ea-2404-42a8-808a-a89b1390d0b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"newtonHyperbola", "[", 
   RowBox[{"n_", ",", "x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"v", ",", "c", ",", "k", ",", "n2dig", ",", "s"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", ">", 
          RowBox[{"2", "^", "28"}]}], ")"}], " ", "||", 
        RowBox[{"(", 
         RowBox[{"n", "<", "0"}], ")"}]}], ",", " ", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<n out of range\>\"", "]"}], ";", 
        RowBox[{"Return", "[", "Fail", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"v", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"5", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"6", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"5", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ";", "\n", 
     RowBox[{"c", "=", 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "1", ",", "1", ",", ".2", ",", "1", ",", ".2", ",", ".008", 
        ",", ".2", ",", ".2", ",", ".008", ",", ".000064", ",", 
        "\[IndentingNewLine]", ".008", ",", ".2", ",", ".008", ",", ".000064",
         ",", 
        RowBox[{".2", "^", "10"}], ",", 
        RowBox[{".2", "^", "6"}], ",", ".008", ",", ".008", ",", 
        RowBox[{".2", "^", "6"}], ",", 
        RowBox[{".2", "^", "10"}], ",", 
        RowBox[{".2", "^", "15"}], ",", 
        RowBox[{".2", "^", "10"}], ",", 
        RowBox[{".2", "^", "6"}], ",", 
        RowBox[{".2", "^", "3"}], ",", 
        RowBox[{".2", "^", "6"}], ",", 
        RowBox[{".2", "^", "10"}], ",", 
        RowBox[{".2", "^", "15"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"k", "=", 
      RowBox[{"Which", "[", " ", 
       RowBox[{
        RowBox[{"n", "<", "8"}], ",", "3", ",", 
        RowBox[{"n", "<", "64"}], ",", "6", ",", 
        RowBox[{"n", "<", "1024"}], " ", ",", "10", ",", 
        RowBox[{"n", "<", "32768"}], ",", "15", ",", 
        RowBox[{"n", "<", 
         RowBox[{"2", "^", "21"}]}], ",", "21", ",", "True", ",", "28"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"n2dig", "=", 
      RowBox[{"IntegerDigits", "[", 
       RowBox[{"n", ",", "2", ",", "k"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"s", "=", 
      RowBox[{"Reverse", "[", "n2dig", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Total", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "^", 
          RowBox[{"s", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], 
         RowBox[{"c", "[", 
          RowBox[{"[", "i", "]"}], "]"}], 
         RowBox[{"x", "^", 
          RowBox[{"v", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}]}], " ", 
         RowBox[{"y", "^", 
          RowBox[{"v", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input", "WebOnly",
 InitializationCell->True,
 CellChangeTimes->{{3.7378908928441153`*^9, 3.737890894247487*^9}},
 Background->None,
 CellLabel->"In[26]:=",
 CellID->157950131,ExpressionUUID->"d831976e-e309-427d-888c-5b80dfbc978c"],

Cell[TextData[{
 "If you are reading this in a Wolfram Notebook, the code for the global \
function ",
 Cell[BoxData[
 "newtonHyperbola"], "InlineCode",ExpressionUUID->
  "313fc802-195f-4942-a213-2af4e03fab70"],
 " is in the closed cell above, be sure to run it first. Once that is \
evaluated, the syntax for ",
 Cell[BoxData[
 "newtonHyperbola"], "InlineCode",ExpressionUUID->
  "6b20de15-c6f9-4d83-97eb-c2d273c92f4f"],
 " is:"
}], "CodeCaption",
 CellChangeTimes->{{3.685271565997032*^9, 3.685271595536971*^9}, {
   3.685272064277163*^9, 3.685272142783623*^9}, 3.707502883488802*^9, 
   3.7088824148473606`*^9, {3.7090355144161716`*^9, 3.7090355159673266`*^9}, 
   3.709299414500121*^9, {3.7092994551760187`*^9, 3.709299469203774*^9}, {
   3.7378908837431717`*^9, 3.7378908878726873`*^9}, {3.7408253906095667`*^9, 
   3.740825414470273*^9}},
 CellID->16348883,ExpressionUUID->"7aa565b3-670b-492f-8a12-02aa8e866b94"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"newtonHyperbola", "[", 
  RowBox[{"836", ",", "x", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.685271605835427*^9, 3.68527161555283*^9}, {
  3.685271845638727*^9, 3.685271848678681*^9}, {3.737891080940589*^9, 
  3.737891081554304*^9}},
 CellLabel->"In[27]:=",
 CellID->2045253412,ExpressionUUID->"acc956a8-37e8-4709-9bb4-2f27e01fc950"],

Cell[BoxData[
 RowBox[{"1", "+", "x", "+", 
  RowBox[{"0.2`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"0.008`", " ", 
   SuperscriptBox["x", "3"]}], "-", "y", "+", 
  RowBox[{"x", " ", "y"}], "+", 
  RowBox[{"0.2`", " ", 
   SuperscriptBox["x", "2"], " ", "y"}], "+", 
  RowBox[{"0.2`", " ", 
   SuperscriptBox["y", "2"]}], "-", 
  RowBox[{"0.2`", " ", "x", " ", 
   SuperscriptBox["y", "2"]}], "-", 
  RowBox[{"0.008`", " ", 
   SuperscriptBox["y", "3"]}]}]], "Output",
 CellChangeTimes->{3.7118005544241247`*^9, 3.7378911778903503`*^9, 
  3.737892416021536*^9, 3.737893521043873*^9, 3.7378939628376083`*^9, 
  3.7426585345045547`*^9},
 CellLabel->"Out[27]=",
 CellID->543934791,ExpressionUUID->"0b3ced75-9dcf-41a7-86f1-db578980eec8"]
}, Open  ]],

Cell["\<\
Some examples showing where the Newton hyperbola equation is positive are:\
\>", "CodeCaption",
 CellChangeTimes->{{3.685271857103496*^9, 3.685271864294886*^9}, {
   3.685273261373688*^9, 3.685273285165539*^9}, {3.7084259831153326`*^9, 
   3.708425987951333*^9}, 3.7090356244291716`*^9},
 CellID->14482418,ExpressionUUID->"e79b7bc1-6119-4570-b3c4-5c298f776f5b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"RegionPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"newtonHyperbola", "[", 
        RowBox[{"376", ",", "x", ",", "y"}], "]"}], ">", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "25"}], ",", "25"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "25"}], ",", "25"}], "}"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", " ", 
    RowBox[{"RegionPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"newtonHyperbola", "[", 
        RowBox[{"413", ",", "x", ",", "y"}], "]"}], ">", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "25"}], ",", "25"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "25"}], ",", "25"}], "}"}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
    RowBox[{"RegionPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"newtonHyperbola", "[", 
        RowBox[{"836", ",", "x", ",", "y"}], "]"}], ">", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "25"}], ",", "25"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "25"}], ",", "25"}], "}"}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.685272022428493*^9, 3.685272044375372*^9}, {
  3.685272160089897*^9, 3.685272244468839*^9}, {3.685272284757932*^9, 
  3.685272313734224*^9}, {3.685273288311982*^9, 3.685273314449764*^9}, {
  3.737890906363669*^9, 3.737890918967387*^9}, {3.737893529375514*^9, 
  3.737893585738254*^9}},
 CellLabel->"In[28]:=",
 CellID->740347215,ExpressionUUID->"bc4588d2-d29d-4021-8f0e-11bcd5eb74ca"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJyFmXlY00e3xxEQBQwqgguobAIBZEkggGj9jWIVqQtV0Ao2agWLolgRF3BD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     "], {{{
        EdgeForm[], 
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6], 
         Opacity[0.3]], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxVmXeYV9URhu9cQMrSixTBBRQBKdIRWLosIGJFELBQBGyoYFQUjYpi79FY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           "]], 
          PolygonBox[CompressedData["
1:eJw1lWesUEUUhM+u+ISnDw1S4wv4FHsiil1jAdRYEspDoj+sINEYKSYqYjdo
pIuIBQQEKQqCFEEQ0AghBrDEQhPsCioGRHqHbzLrj8mZ2bv37t6zZ87WdO1V
2zNHRD9QB1yN6JEiGsGXgZ3wHeA4+LfgffitzKkhvoZ+krgWfAZfD87m2Uj0
aPg0sBy+AsyFzwFz4Z2Z04w4Ev0RsQu6OfFN9AjiGejN8C1gHPoG9FHE/uif
ib+A9+BDwZfwL8A8+HzwCHwSmACfpT3Dd4Pv4APB9Xzruuy1FoDuPPs6md8P
noCvAUvh68A2+Pbkf68HnoZX8P6P2gt4Cr1ee4D/AN6G38TzusQB6M3ELVoD
fjTYCv83+Vsa2wT/B4yFjwETk3OmXG0DJ/GtAehX4FPA4/DVYAn8e9BbeQNv
6WxAc+YPQo+AT1WO4DWMbYBvBJ+jHwRV4TPpo9yARfDVoC98FfgUvlb/BO8F
vlKuwUNaC4yHzwQvw1vy/b/1L+BY+HPJZzMJNEW/iB4Ofxf8Ad+QXBujwGPw
leAT+BpQC9+nPYTPUPyW5LU11pDvNQa/a22wN/mMdbYrwQx4B54fT3wd3QD+
PHwYfDL4E/4XmB6u0TY874luDF8BZsM7MdaQ+Ab6HPio5LPRO+/ADybnZhdY
rNwk115T0JH5M/9fm9gePS15r1XFO9OJ14Q9dDp6DjFUB4Qb0eNLrVcQb0Y/
XP6vsnihvWow7AnVWkdiZbjmbkPPT85ty+Kte4m3hz12KnoW8bByoW+g62T/
uzyv3N3J89bhHNaiPyi5aKKzQH9YvFtdvNxVOQ97Wrm7m9gmnMO26HbZ3lCO
dzHWCv1f2JPiDzC2NTwmbz0jj4c9Vjfbc/LaT+FaG15ypZqrh34UPSj8jnrB
s+DXcE9QL3lVngv3lEr0AvSQ8Jxz0d8Ur2oP8vIx2WvJ0/LOS8m5koeuVW2B
3+CHwAnwKs0Jjw1kbnW29+TZF9AnZte+arAfun52LeqdwegW2mPYszrbj5O9
pTOWFy/i+e6wJy/WtxjbEx5TL7iEsb3hnjBFZ5vcu/aF5x5K7hV6Z4K8ndwb
Z4P+8GbZvUUeVW2ekt0rVKN3Jdd0g3Kmk4kHkr26A4xV7wAzwj2hQ3INV5Sa
VO/oAiaGe4hqeU+yV1XTS5I9JO9ozlR5IfsuOQA6FQ+o9nUH3VE8VVVqVGuP
BuPCe+gM35/cy+qDMck9Ur1Rc9T7liX/u3qgaue87F6rGmqUfcY6W/UY9cbz
0dvDPVJ3w2Xo/eE7Qr3rAvTOcA+7MLtHqDdo7NLsM9FZ6IxaZ+dQudM3r0Jf
qX4DPwguz86B/l1r6G69IvuZ7ljV7sLk3qoalpdPy+698vQ9xbNNiifVW87M
vkvVY7oVD1eXnnAyfEjyXa47NaFz9t2vPc0rPUW95D70Wdlj4vLUEXYfI7g=

           "]]}]}, {}, {}, {}, {}}, {{
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[{2, 1, 159, 332, 583, 411, 368, 413, 602, 412, 444, 414, 598, 
         415, 369, 445, 334, 584, 416, 370, 417, 585, 335, 446, 336, 586, 418,
          371, 465, 558, 362, 559, 502, 503, 466, 505, 363, 504, 372, 587, 
         337, 447, 557, 500, 501, 497, 499, 498, 556, 495, 496, 492, 494, 493,
          333, 5, 4, 3, 2}], 
        LineBox[CompressedData["
1:eJwl0jlPVGEUgOE7iKCY0NMBog7QsMkA4oLETpphNTEUFkYShIIACg6LW6dE
oyFa2DhuGE1ISDTaqBUq0rgAAiKoCPgPFJdnYvHkPd/57kxzb9aR9mhbKAiC
OLWGdM0gTIQDRGmmhQ5i9NHPAIOc5gxnOcd5biR+4z9/sMYq18lPCoJjusJ3
lrlGnv1R/cZXvjDMY5rcPdJcvao79IqGdUy362XN0Uu6TUd1qw5pll7UbH2g
jfpQl1jkApl2h/UzC3xikC32DfqUJ6Q5D+gEb5jkOS+4T437em1njnkO2dXp
T6IcdL6lnTzjJuO08ppXvCROgWe7dLP2a4r26SZNZdYcY6O5mv0kXmqVftRk
3cA+jjvv1RlN0hC72UMlu5h2dyrxUZhHtELLmTL38pd7lNlF+GDu4Q93KbXb
yXvzSX5zhxK7Yt6ZT7DObYrsCnlr7uZX6P+3+A/2ElOE
         "]], 
        LineBox[CompressedData["
1:eJwt0DtOQlEYhdGjteIDUFCUUDkDRoCWKiABIaiARiuYg2/RwsRAHIQJRKIJ
ta9Sh8QqLL6sf9/bnUyzU2hPhRBKympDPdV8TE+H8MA13nOdVabY5QrvuMp9
JnnLZd4wwQqjvOICL7nIMiO84AzPOct5zSmnuJYU07X/L9p21/mhA+3YAz5q
qF37kJ86Ut5+5ZNGKtgNfqmpov3Gvt61Z7f4rWOV7DGftene0q/7Tyf60anO
vNlYdeWV+3/PCVJQI28=
         "]]}}}], {
    DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {Automatic, Automatic}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, PlotRange -> {{-25, 25}, {-25, 25}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJyNmnlYU0fbxjERBNrUDVyiIiBKQPYQ4HU7o7jgUk2pdcHXVCtaNK36uoJL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     "], {{{
        EdgeForm[], 
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6], 
         Opacity[0.3]], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmgf4z9UXxz/3RmYqQmkZUVnZCuFnj5JdVkS07IzsHSJkr+wyIhTZkdHQ
oCJJg0pUSv9/e6j/ef3P+/t8ex7nOfdz1xn3nHPf9/tTqHOv5j1jkiTNL0oS
+5dcahSM6Ls88b5MRnmMMhtdbJRbfXznNcpilNXoMq1jzRWay1g+jWczmmqb
5zRewKilUYZRLaNrjXJJ/nXi7Hd14vMvMbpefehVSHqgV0mja7RHd9v/KuM3
GRXWOLoUEUffG8TRq6h4fhE6Zjfqafv0MPrK2gUlE3nFpTt63Zy4LL5LST66
lxZH31vE2eMp22+a0Wlrl1EfdpQVR98+Nt7b6Kx8U0bjtxrdKLtqqa+cUa/g
/ZWNaquvvFEF2Yl9VaQruteQfuh1m/ZjrKb6kFfNqIT8ers49rWSbOTU+Zec
u7SGuX1Nn0rGGxjdIRnIbyQdb5WOhXUmDROfz1hT7VHdqJ/t86jRN9ZuYlRV
MpppHDsaaz9ktJANGdKriOxvrrk1ta6U7G/9LzvGcN740uhe6cre/U1+feNt
jdrLJvQdaP0DjL61dgf1saaj1mF3N8lGr/uM7pQd7RLfk726yHfYfb849nUV
Z/1jmsf4A9qPvHlI54EdD4vfLTvaSOde4sjsYXSPxm4x3c8bP2fUWXqhR2/N
xdb+Rp2ke1/ZiW8elHxk99FcxgZoLvs9qrn4Y6D6sGGQ7Oiqc2ssv400esSo
u9EQ+Q5bh4ojc5g4dg8Xx+7B2o81I9THXuOlN7qMlv34ZpTk8D1WPsLuceLY
9Lg4618wX9Uwqm400b77yTczJQ/d6wbX7ymjybKZc3tSHLuniKPvY8HtnGo0
Sb5jTUZwm6cZPSE5jM2QzcibLl/wPUvysWm2OLbOESeu54pj6zxxbJ0vjq1X
m9xfpGN+a/9H8q+y9k+yKZ+1f0jcBwWs/bPs+006LTRqE1zeMs4xuN5PG11p
7R9l653B9V5s1Cy43kuMWgXXe6nRMaO3jN426hBc7+VGz0jvBUbXWf/v2n+T
tVcYLTO6zyiz0UVGf9vYs0arjQra9x/GVxg1DH5+i4yCtVcZX4dPrb2WMzda
r3VrtGaeZD+f+HzGXkx8PmtH2toRRpmMNqmPuZvF2W+MjY02ykIsGU0wymG0
zcY2Su52cfbeIc5+O8XZb7ytedn4a5yftccZZTPaY99bjLYa7U18X/YbG7x/
t9E+9bH3K5rLvP3qQ85fRn/K368nLou17+v7DeLD9nzV+GGjg4nLZr83xffq
DPdK5tvi+7V+t9ZMtn0mGV1iNCq4H9DpPdmHvHcTl8X3Ea1H5lFxZH4g/pbi
g7imBmzHv0ZPGp2Qvux3SmuItY/Vh8xPxLH1U3FkfiaOzK3B9/nI6KT62Au8
A8YAc4ChwDBgmkr2UcLo0uDYCCwBjgFD5dZ3Zq3jO2qc9eCnvP/al3uzkMbB
FeCMLxLHLuAW8MVUYSBwEzilgPQAn4CTsml+viSNtxjLqr680gM5BaVfQclL
YanCSRpLFUnSWIrv7xO/a6izX6ofeegE1gBzgFm4AypLJzBGCelRSt8pLFUq
SWOp0lp/m9ajVxmNoRPYoqz0AJuUT9IYi3ln1F9UepfXGjBXL2EXcF934Sr0
rSJ5XyeOFypoP7BQRpLGSdWka3V9o2sNfaNfTX2X0Nyq0ilDY5xTccksL1kp
TFdb8sBEfYVL0BXs0UB+bKTvRjbeOHhtpNbeqXqHTO75JtIJjNFUssEVKazU
XGPI455vKXuaan2G+lpIr9aaByYCM4ExuOO4TwZLP3BCO+nXQd/11ddWut+r
MbASWKJTksY3D0keeKCbbOiseejURd8pLNUlSWMpvrm/W8unzbUHY2CQjpLd
SnJSGOdByTsnHcBX4CbiG4xBjIMjiPPvEseDKYzVU2MpHNZTMsAjfZM0jhkm
G7jn+0vOCI11Ul8/yRupsQ7ao4/sBGMMTNKYaYh8MVD7pvDTUPlikNZ01fnw
DfaYqrXYM0rykA8WmCgbwBKjJZ/6Sp1N4aexOs/esrmX+sZIj0naq4f2GCXb
2HuC9J2seSkcNi5J4yfwRnuN9U7SGGuyznOI7AGPTZO93G3cQa8kaTw0R34k
J2Ykafw0S36nb3qSxlKzkzR+Yj35tEjrU1hqnvw1S/1lbc41wfERWGih9myo
vERGCh9wr4OFFms9OGqpZIN/lkku+AbcAaYB7/yTOD5JhHVWSQ/wynL5b4H0
AxMF4RtwynDdtey3XrqAwZbI3lXqA8ewBhwCLonB56/R2CaNXRzcFsaoa+Qn
eQw2GSu8slHnsTVJY51tSRrrbE/SWIfv0cIEYJeswfuRAW4aL/yxVWe7J/F5
8N3aa5/Onr326zt78DZ7DdOZgNvRD6wBxgBfcNdz9yMDbHA4SeObg0ka37yZ
pPEN3zmDt/dLl4PaD4wDZjok/d6QvNclJ4V33pO8FL45kqTxzVHJOKbvXMHb
yAPffGj8ncTxDhjluOaBdU4maXzzcZLGNJ9KHn0nJOOkxsArpyTvVmvnCX5/
XhYcc2RP0jiJfZcE/22De3568N9OuENzax137kbuBeG9mcF/5+Aee8Da3YLf
sbODv/u5H0oGr63U1TLWzhu8/lInqcupOkztpe5eHhxz5NcYc6ln1B3eNdSa
ysH3opbnkcwK2u+81vHW+W/idWmivmlTm37UftSdn9RHHfpZfRVtzyLKt0FG
vyZev4i13xRv16o2UBeGWXto8PcMucY6cos85s1CLr9ofcuNLiSem+Q7uQtG
/1NzH7HxUpJd3qiQ6gJ91AjWXRHcTu6yG4LnM7lcxfhNwfPjNrBP8JybG/xN
Q+7ypsqsGlI0eM6T7/ODv2nIv2eDz2NOMe2xWfb/Ij/dKDnk4MLgbxfyb1Hw
9xA5hy45latVjd+s78OKU7A3fbmUb8WDx+sxnTlxco9in/7PE49Z4oPY+FJx
SUyeURwQA9WC78W+NYP7626dG/X8KZ0/7+RUTPE2nqjz5808WbbyTsZezp83
9hTFC+9hYqZc8DggBrLL/9jLmRSVbzlb3q4rdOac6bOKh8JGKxUvRXS+xMv1
wWPmH50x5wse5M3M3ZNV54v/OcNiOqOc8jP+zCU/HJP/SsiH4GB+32osH5eU
n/FfaeVSDfkuhZfKKGextaziPlGMYhN2VJAt3NlgEe5yYq2i8ojfrCorZ6kT
4Lk6OvdKOnvwXXXJ5WxvD3629NVQfxHlCL6qFVwWWIE7m7uZe7mB8Xo66zrB
503T/NrBcRJ3BzgDfZlbV/MzNH+qxutp7RWy4ZziqIHmM15fc8Dt6LBIujTS
ed2hNv3zlfPEQ5PgWATccJb4sYfjS4njjaGKK2rKUO1DvZ0VvObSN0T99wbH
GcQMnG8wR1vj7YJjEfo6qn+e5oFJeIuwLzV8TvDaXS9xzjd1vL/6qee8T/kd
PEfi9wRvVd493PPUGurMjOD3RzFrd5I+6PZS8PWsPa292GOe1m5I3D70qZj4
e459uIPg7PuV8qOT9gRrtZWNxH7X4LHfmngJjofu0Tdz5moN2KyV+pnT3HgL
nUVqDBy1JfhviMTsc/ID/qCfO6+uzXlQbXKH/VpJ1oLgtZUzBR821/4t1UYu
uds5eE5TP+4PnsdfK0/IEXK9S/Aa0zR43LBPe9nOmc5Q3ExXXN2leENOs5DG
hbRnKTbaaO3S4Hf/lYnX8MXB63h39XNGYDZ+89pl7fXB6z4YbkPwNWCjHeLU
eO4AxsFEzwfHkfgBjAPWAduwFlx1IHFcQRt8BZ+sfrAG88FF7PG49kGHCdKn
j+VNs+h1qLDx3dHvsHLGZ0XHO68Y3xP998V3jV6OXltzaB/0LWR946PX7+uN
j41eg7cbHxO9ll9jfGf0e/xq4zui/9622Xi+6GfSRjnD2zGbbE/hZ3A72Jm4
ID6yyI8LNedptbFrsXx7QLmzOXi+jVVccV8/oTnoD77gjcH9wrlxruQZuUWO
ZdLeyEAvflubIp9fojZ+3qJ8Bpvz1uC30eesvTY4PhiuvRjbqFoEBqJeYc9o
6bZWc1iLbegNdl6nORsUG/NlE31j1M8c9EaPG8yvT0S/6/j9hL8tUR/W6Js2
nG/qGb9jkKucAb8FrVIsz1Z/PdXSNVpLbVkdvF7xLuP36JXy54tq99acXvLB
yuAx9kzwNSvlc2RdqX0YI364u6gh1IrC2vOC8pv+6op9coBzWC4dlulMNuqM
kLtW/hwuPcBpK9Wm/zrz04PR72P8t07+HGJ9ITreGUqMR8dBg/mxMjo+Jr6I
M+oz7w/y+bDq9EuKvZ3q3yrdt8iu41oDrmPONum8TXF2SLlMm3xO1YtDqgfM
O654W6sYe0D7d9P4TskdRn5Hx2KHjVeNjmWGG88UHceNMJ45Oo7bobWHdF9h
J7+tZrnI6ml0TDbKeM7o9+1IYi067htt/KrouIwaUEB1gPPaIDuoH9Sj8Yrh
dYpb7irij/sLDPVQcD2JpT6Kt1WKUWIGrPRwcIxDX0/1r9Ya5vNmIC7AhJV0
R/Lb4VnFaCXNn65YvaA4piagB3lwk3JnpvIF3Mcdxp1D7gxUjnyrb+rZ4OBv
oanSmVjvrj7G8BWYj98N+Q0HrMDe/Hb4jfKTPuY/pn0e03pwNXk5QHI3KQfI
qQrEbPA6dsH4H8H3W2D986LnVi3jJ3VePxnfH/zNmcfaG6PjgIXGXw3+JqQe
U3eoOYt0jgdUk+nnflmoM90lf6+Qz6n916r+X278+ei4Ib/xLdExVl/jj0Z/
r/Q3PiD6e+UX5CsuWkS/Y6gPeY1vio7VfseXwc/zlPXViY43s1usNo6OfS41
/lz0Oz6L8RXRcW024yuj49EjRnujv0PAmGAC8ECj6Huxz9no8U1sNzB+Jvob
ox76Rsf7OYyfjv7W+Th6jpFfX0XPGfLlo+g5ST7WMH4i+juqpvFPor+jZhr/
Pvj7LMPan0V/U3FuI3V2n0bPW3K2q/HPo783akf3BX54w/jB6DjvLe7z6PXn
XePvRc+xc8a/i55Lx4Jja870M/Ih+luolPE20e//4sbviX4n3mH86+hvtj+p
GdHfQtWMH43+Vvwgej2lllYxzn/A4X3wjvH50mey8Q+C47vq1j4e/d34YfT6
S+09Er3+Ununo3PwtzK+ryv/HzU6E7yG7zF+SnWgZHS90flm4zdGv3u5Jyfp
rtxr9EXwO65VdGzEndXReKfoeQ/GGac4HGh8d/C318ucjerPLdH9ha8mRo8t
4upXax82zlsQ3DQhOnYqZrxIdIywD3uU11ujxx+xty26r/HzIuO3R3+TN4we
i/9/60b3Oz5fGj2eiKVl0WOI+FkSPeaIt8XRfY2fyxovE/0+3WX8UPC79wXO
KvqboJ/xXcF/U2BuW80nRtopTt4jX4PfrY9Hx47gRs68l879ruh3CfcIdhyT
LZzVzzqvtdZ3WXT8zp3TIfr8Z4xnjf5OnWN8bvR3L3H9jmJpELkQ/Dc86kfF
6DWE+6q+cnC18VzR35onyAHVtPXWlzv6m6NJdPxK7frbvm+LXuOpqZWj19X3
jbeP/rvAaWpH9Lujt/Eu0d/AxNRviqsfgtc46hvn/JfOGr/Oju5b6nHn6DX5
C+PZo7+fia/y0WMMf3eXz6l/laLXwPOqp9TS49b+JnhNnobuwX/3Om/t76P/
fsZd8VPw+4Jzaxn97N40/nZ0TIFvSkf3D7lVNHp+EbOtFbePGO8R/TcTcutu
5Ve36DWxnHQpEV0f4ot3CDH2TXQcBgbbZ3x/9Ddeweg5Q768Zvz16O+9f4Lf
W/hnivGvg/+Gd8Dar0Z/+/0PI7e0oA==
           "]], 
          PolygonBox[CompressedData["
1:eJwtlnnQT1UYx+953hcvRdailYookezU1FgrRSGkQihRQ02mbaaZZppMJoUk
yfKipNKiTdvYkyUkZd9miFCSNWTp8+17//jM+T733N+99zznPN/nV6PvkM6D
I8uyqVAIZQjehXYpy26Bv9C94Fr0I1AO/R7chr4dmqF/hAHoh+EP2AS1oQX8
xFwLqIy+GZ5GPwPN0L/zvvPRn0NP4vtgAfQmrsdYCSqiP4LO6K7QHn0MnkOf
4Pdl0bfCpcQdYJe+HS5BXw878mfqWf+/k7nd4d/qN+XRH0BH9J1wDbqwIMsm
oedwT2XiWdCNuAcchbPEYxhrMd8QXZL7pxJXJd7GOIhrTRivhq3QgLgs4yrm
+6EXo5tCfVhL/Cv8rVwoB+izjPuJ6zIOIX4sfK9y2Bd9RnnOfE9z4sPwVH7t
ZfQIqEVcEtqiH4QGyTlZDQOIGzJm8AsMJG7MWELPQB8I7/UVcATOEI9WbvnJ
evQ6OIi+gGsb0Rv0DcRVdQa0VzCDuJHOT3JOlIsb4EXmhsGVyiP3vIQeDjWJ
I8/ddu1Dcg7rEZcgv8XoxVoz4xaoAy1hL2yAq6A5jOb+18Jz58IY9Ovhd5eD
J9BDoQJ6J8/bjt6mM4W+iGuPau2wI/M3PKncQkX0b1w7rrzxPWMZGyM3M7cJ
jqCrce0UJObHMbbLvNf9mb8u3/Ot6C1wlLkLid/Q3ufP1jetgi/DtTCNa401
D4OJdxPPRC9HT0Z3Sq6NCtAluUY+Vj0yFme+9jZxKWiNbgUr0SugbeaafTNc
k6rFG4m/Q38L/xKfgtKs5W7iAuZmwDwYF75XOXkHvYRxZOZ3jNdv81q/Kbm2
zgt/q2pM3lIa2id7zCH0wjyXQ/Oz+CcMSj6TJ9BrGWcx/0LyWV+U51Zn/ihx
K/iH+Fni4+g1jDOJn9c3Ey9lHJX5nX3CniWvksfIS5YxTszsKfI2eYq8RB63
F70HTjJfXTWEngOXo09rD9HfhOeUM3lZFbg32dN0VpepBvMzm9CTwrWuGtLZ
XUzcLz/D62ARcd/kGg705HCtqca+R78CRcn3yJsqQfdkj/oBPRLKJD9zebgG
dPb1DW+hJ4T3RmdgabhmVCv9oQBdHK5lnekv0CuT+4PW1EFz0Ad9GVRDfx3W
ylGGngiHMntaSfS0cG1pj74Kn3Gd7d6MJYinhmtBNViInhKuJdXIbK09fG+v
5N6yJPyt6jEH0fOTvfjx5FqZm+zFqpmTxOsZZxMPS87dq2GvUA7nhz1Q3vdA
cq+rHvZG9bzaOvvUwIT8GTWJg3h8fibvJ96lc42ukeytncJaHnsHumP4rOge
5fKzcC9RTruFz6zOaiF0DdfcjPwML5RXhr1cHtkjvCatpTSMRR9I9rLyjE3C
OVEu9nCtabjGVFv7Mu+dcqpcag97ok/BiOQepbMzKty7dYbmoReEcyMP6B6u
SdViKbhH9Q7D0efAXK097OXyePWCItYzPbknrGD8JNzLp2T2qg/DvVeetT/c
g9R75AHKfZ3wu7QH8tbT+VrksXp2l3Av0TvUixuFe5V6snp53XCu1NP1rRuT
e7u+WWvfnNxblAP1mvrhtajnaK9rhfdGe65eeFhrzdwT1QtO5LlWT9B/g2PJ
Xq3/CPKe6Vxrk+xB8kp5lrxKnikvfz/8X0qeLi96KPzfRZ5UFPZwebeesQPd
Gi5O7unqLT/DwOQecxd6X7j3yqNa6nyH/0tUgTXo1WGt37RB7wz/19MzPw3v
kfZGnvIf1v89ww==
           "]]}]}, {}, {}, {}, {}}, {{
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwl08VXlUEYB+BLN3bixq3ubMHuwI1rzwExluAR7NaF/gMmtmK3Yh67uzsJ
ayUCNoLPyOI5v3dmvrn3u/PO7ZhXMDY/KhKJ1BBNqNPpQGeyGEMuRSyjmise
XBvduGk2j3hMH9YRxRye8JS+rCeauTzjOf3YQAzzeMFL+rORWObzitcMYBNx
LOANbxnIZuJZyDsG8Y2r3nWrTGALiZRwzfx2mcQ2kqlgCGUMppxJDKWSYbwn
hclc9xnf5XBSWcQHPjKCkaSxg3R2csOe3bIJu2jKHm6a3yebsZfm7OeW+YOy
BQdoySFumz8iW3GY1pRyx/wx2YajtGV0+H0xkcgoeZx2LOYTn8nmBO1ZwklO
kUGdNpdQzFIKySGbTDqRQRqplPr+lHCnZL39tfIr3UJ/vEPX0B/jM1Spu1Md
zpGG0DNZxrmwz7gHP9S/wuW0/6es4ALV1nryW/2XKOt1spKL1FjrTb06T16S
tbJBjpMPyeIeD7jPRC5bnyCnUEA+mdzlj7XVspg14bwZH/oUehL6SC9yyeG8
58uZpZ7JKlZy1twMOZ1pVBmvkKdlkSxkKl+Ml8su4a6okx1DEokkEE8csY3H
8/9//A9hLYGw
         "]], 
        LineBox[CompressedData["
1:eJwl0sdOVAEYBeDLIEHeAelNkfYgFOloZOFGEcHwDvRq4XFoSneBVKUMA5LQ
hBmW9IRvwuLLOfnPzM2dZDLffa5uTwiCYIBdZUlussU2O4TjGxH22OcfB7SF
gqCVT7zhnj3P+SgjMsao/p1fLBJ2i/JN/8oC82y7nfFFH2GOWTbdThnWh5hh
mj9ug3KAfnL4ybp7n+ylh0wmWHHvll10kk4NTxODoFp+II3/vKKD374zLp8x
RioVlHNoeyurSPaMSvmeZfdLmUEzMS44I8o5Laz53JT8wSRZ1JHiWbXyyL7K
lV5PNnmE7Lny2LbBtd5APs9JtBfIE9tfbvRGXvCSJ/bC+O+0bXGrN1FECUn2
4vh72na4019TSlno8X/yAGiKU0U=
         "]]}}}], {
    DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {Automatic, Automatic}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, PlotRange -> {{-25, 25}, {-25, 25}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJydmndUVMfbx4lSFAOCQtRFke4C0lkgRnPHkGA3xFii0Y3kB4mKLQTLauxK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     "], {{{
        EdgeForm[], 
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6], 
         Opacity[0.3]], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmgnYT9UTx+85F0kkSYuUtZBCSqlXlmwpStpoU7RvtKi0SQtt2kRRZImK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           "]], 
          PolygonBox[CompressedData["
1:eJwllmeMFlUYhb/7Dipl6UVAKSvrUhdYQFqQzu7C0hdUJAhZFUVEBA0gXTou
CIqAIoomxBYsiGIhKCJIMPgDu7HEhjX23n1Ozo+TPGfuzNw7975l8itnj78m
crncblQN3Y0Zgc5Mudz5qC88PMvlTsDV0CD8EXQZfD1aBPdjfA98DqoDT+Ja
W3g4+hn+HS2Bm6EZcA/u2QmfhvbiL0KFcBlqx9jC8Nw3oIPwc+gSuDpaojHu
eQQ+F9WFJ3OtPTxCc8LfonnwAnQPfEF4bW3QH/A/aBncHH0H/4QWwU3R7fAO
1AeezH7shzswx634EpSPP4augOcz3gEezPgB/BF8W/xA/H784/ht+Af1jfix
6AH4fq0JvlBrgg+gKXAV9xfA/Xl+L34Xvgg/FH8I/wZ+E34zOgPfE18MlzF+
XHuNX49vjF+L34p64ZugSfBo1AUuYfwofIr7N+A3hve+AK2GGzC+Ev6U8X74
7mhU8pwD4RdRJXyd1qi9RRfDE9Ee+OHw2etM18DlvO8k3BFl8CiunQ0PRi/B
R9H05D2twfg4fEt4KHpU69Wa9C3odMbH4FvAQ1AevgLfCh6G/oabo0HJZ9ye
8Yn4Ccln+FA4JhQLWrPOZisak3xGpfBjqGHynMqFuxTjyTnRAN6Oxmn/k/d2
J6pI3uPG8J1ofHIMfQE/j2rCc1APuA7qlhzTGjuEpibfM1Znm/nb9Y3d4SvD
ubcjOXdq4ItyzqE34bfQTK2Fa+/Ab6P8nK+dhF9FM+BaXPsQ/gjNxnfCvwu/
h2YlP/MB/H54TNfOY76rwrm6S9+Mz8P3YvxenQn+anwNeDfqja+LH8D4ffiu
+M5oJLxNewKr4NTS3uvMNB6O7cP4hpljWLG7Cn0CfxyOda25HuNTwrFUnpw7
i9FtyTmk3OqSeS7lWCf4aa6VwluSY6FjZlZMFGXOAcW+3vE6/Fp4L7VnJ+BX
wnOpxjwVrgmqBZMVs6qVvKMK3qiYDOeIcqOeYgb+Hi2E+6P68Jdors4W/Rqu
kaqNi9FX8AsoL/ke5UZ5uBYqR4bB34RzoX5yLH0eji3F1A/hmqZapjlVC8vQ
/OSaqNxfp/hJrgEj4ZQ5F89Kzp3/0PLkHHoGfjac29rDJ+Anw7VMOaLYbx3e
C+XAcfjlcC1WDxit2M2cq8r5z8I1XbX8WvRXuCarFi9VjMKnwmPFKMez/4bX
pjU1hX8J79UA1Az+M/zsQDQzHKOKTcVkKdw1XOuOJfeyPqpZOfe0m8L3aKyz
4j18Rjob5aRyWWeos1NOV8KNuH9Nco1dG45hxa72dKqex69IrqHVwzms3FXO
Khe6oe3JObGS8SH4g4pV9GP4G/Vt6kn1wjmjXCnh+TvCPUq9qbdiFt4SHuuB
X6ZnuX8f3A7NCuekclE5p9g6jKYlx9iN8CDlCNwB1Q7ntHJZOfxbeI+1t+rh
cxXb4dirYHyfakl4btXQnuEaqdqoOebAX4f/FTYl185G4bWrhqq36Mx11uox
NcM1R7VGNaZ15jk11+bk3ro8/G3qseq9K8JrVw/W3k8L1w6dgfaiMNxLtSc6
u0vx65LPUL12afhfQj1X/zLq8ert+qdR710VPhv1YJ1Vp3Cv15lp79qHe732
UP8m6unq5fpHUW+uCseWenQT/OX49clrmADX5lrr5B6mf6tWmb9V/1gtM++h
9u7m5N7bIjOrBzdVPIV7/wbFKFwzcy9UD12AL8z8L6QeVqDvQ33hW5Jr1/Tw
s6phxZlrmmqZYnSeciXzv4OeUS1pk/lZ1RT1dv0z6F9BPf5/oJ8M3g==
           
           "]]}]}, {}, {}, {}, {}}, {{
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwl1FdYV2UcwPE/S5Ac5AgVQjPNFYh7kJZYZqLl6HnUtCw1t2iOOystR+Qu
SLOrhutRK9eF5ijzwsSGlZPKkeV+3CEo4OfNiw/f83ufP+fwf885PDJ8Uv/c
qEgkkuNHtIbjKiTTkE4Wn4uJRDprR8bQxpygi6hMW/NYzWIc7cyJupQqtDeP
165MoIO5qn5A9XBe80R9klw6mZP0Q/KZzCYmsZkC1vIRW9nC1zzLl/TgK2py
mWe4xNNMZQoNXKM+ex134yJvkGbtYb53/BTd6WXO1iSb08+eDCWXWRSwhu0U
UsQFblNCKXe4SxnlVETub3QUebzu3A+5xgitpcO1tuaF76Cv6oM6TGvoHM3R
ufozP/Fy+PustdAfOUAhQ8IeW2+q+/mBfQymmvXGuoH1rGMQG9nBQhaQ7nMz
9BsepYv5TR3IW+G+mhvppzwW7qP5bX2JmWEfzU30M5qF/TbP0qG8Q7a5uX7O
42HPze/qK8wO982crl+QEe6neZ6+xnvhfptb6koyw3Ngfl9HMp+e5la6itbU
MY/SZB2trbQ1GWSGc7Ha+prwHd2fzPBuEEOxW3ee4+xnG6vJZyYTaeBz9f1u
Ved5UR/QAeFd0DRN1P6aoP3COxSeOY3XvhqnL2glTdVYfV6jtY/GaIpGaW8t
J+K4QutxlzJKuEMpdSnmNjf5j1thL7jODa5wjathb/gkPIdkOfd0XcFyPmYa
na3X0mXhuaQ9e/iOC5wPzy3t+JbdnONsePZoyy528i//hL2iDU9wJjxrLGEx
qa53Wv/mBKc4SYr1P/UvjvMHRWEvrB/VYxziCIfDXlj/TX/nF37lYNj/cH1b
mUhlEoinEnHE3t/m//9P3gPOTZNC
         "]], 
        LineBox[{670, 586, 669, 631, 805, 632, 806, 585, 750, 584, 803, 804, 
         801, 630, 802, 567, 534, 668, 544, 695, 694, 810, 809, 597, 811, 812,
          696, 697, 698, 671, 546, 682, 672, 598, 635, 828, 545, 711, 710, 
         709, 587, 808, 634, 807, 633, 670}]}}}], {
    DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {Automatic, Automatic}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, PlotRange -> {{-25, 25}, {-25, 25}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.7118005552297983`*^9, 3.737891178953603*^9, 
  3.737892417082244*^9, 3.73789352207054*^9, 3.737893588057846*^9, 
  3.737893963867876*^9, 3.742658535370492*^9},
 CellLabel->"Out[28]=",
 CellID->74147058,ExpressionUUID->"15bb5dc6-a1cb-4fcf-81a7-ed0c4ec8b793"]
}, Open  ]],

Cell["\<\
We will connect these Newton hyperbolas to the twentieth-century work by Oleg \
Viro in Chapter 9 (2006). In particular, we can represent these curves by \
Gauss diagrams, which represent the topology of both the curve and positive \
region of the equation (brown dots).\
\>", "Text",
 PageBreakAbove->True,
 CellChangeTimes->{{3.685272464267123*^9, 3.685272535252061*^9}, {
   3.685272943165341*^9, 3.685272961071129*^9}, {3.68527316096366*^9, 
   3.685273203941499*^9}, {3.685273336615731*^9, 3.685273388065773*^9}, {
   3.685274732365861*^9, 3.6852747330298*^9}, 3.701008651501519*^9, {
   3.701054486549593*^9, 3.7010544881815367`*^9}, {3.708426001866533*^9, 
   3.7084260330041327`*^9}, {3.708431239482789*^9, 3.708431242449789*^9}, 
   3.7090357302457523`*^9, {3.710675761155305*^9, 3.710675763012314*^9}, 
   3.7117213292433147`*^9, {3.73789111006044*^9, 3.737891110935701*^9}, 
   3.7392900709871016`*^9, {3.7408329943034983`*^9, 3.740832997237487*^9}},
 CellID->495391787,ExpressionUUID->"1a34eac0-3243-491b-8f6f-c09f986766c1"],

Cell["Gauss curves represented as Newton hyperbolas:", "CodeCaption",
 CellChangeTimes->{
  3.740833017704131*^9, {3.742580340277495*^9, 3.742580340372953*^9}},
 CellID->381695321,ExpressionUUID->"13eb2eed-2713-435e-81c5-ba05ad5c4c3d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{{{
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{1, 1}, 0.5, 
          NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
           4.71238898038469}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, 0}, {1, 0}, {1, 1}, {0, 1}, {0, 0}}]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{1, 0}, {2, 0}, {2, 1}, {1, 1}, {1, 0}}]}, 
        {RGBColor[0, 1, 1], Thickness[Large], Dashing[{Small, Small}], 
         CircleBox[{2, 1}, 0.5, 
          NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
           4.71238898038469}]], 
         CircleBox[{1, 0}, 0.5, 
          NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], 
         {RGBColor[1, 0, 1], 
          CircleBox[{2, 0}, 0.5, 
           NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
            3.141592653589793}]], 
          CircleBox[{1, 1}, 0.5, 
           NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
            6.283185307179586}]]}}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{0, 1}, 0.5, 
          NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, 1}, {1, 1}, {1, 2}, {0, 2}, {0, 1}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{-1, 0}, 0.5, 
          NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-1, 0}, {0, 0}, {0, 1}, {-1, 1}, {-1, 0}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{0, -1}, 0.5, 
          NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, -1}, {1, -1}, {1, 0}, {0, 0}, {0, -1}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{0, 2}, 0.5, 
          NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
           4.71238898038469}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-1, 1}, {0, 1}, {0, 2}, {-1, 2}, {-1, 1}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{-2, 0.5}, {-1, 0.5}}]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-2, 0}, {-1, 0}, {-1, 1}, {-2, 1}, {-2, 0}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{1, -1}, 0.5, 
          NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
           4.71238898038469}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, -2}, {1, -2}, {1, -1}, {0, -1}, {0, -2}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{0, 0}, 0.5, 
          NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
           4.71238898038469}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-1, -1}, {0, -1}, {0, 0}, {-1, 0}, {-1, -1}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], LineBox[{{1.5, -1}, {1.5, 0}}]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{1, -1}, {2, -1}, {2, 0}, {1, 0}, {1, -1}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{-1, -2}, 0.5, 
          NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-1, -2}, {0, -2}, {0, -1}, {-1, -1}, {-1, -2}}]}}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-2, -1}, {-1, -1}, {-1, 0}, {-2, 0}, {-2, -1}}]}}, {{
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{2, 0}, {3, 0}, {2, 1}, {2, 0}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{2, 0.5}, {2.5, 0.5}}]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{1, 1}, {2, 1}, {1, 2}, {1, 1}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{1.5, 1}, {1.5, 1.5}}]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, 2}, {1, 2}, {0, 3}, {0, 2}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{0, 2.5}, {0.5, 2.5}}]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, 2}, {-1, 2}, {0, 3}, {0, 2}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{0, 2}, 0.5, 
          NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
           3.141592653589793}]]}}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-1, 1}, {-2, 1}, {-1, 2}, {-1, 1}}]}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-2, 0}, {-3, 0}, {-2, 1}, {-2, 0}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{-2, 0}, 0.5, 
          NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
           3.141592653589793}]]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-2, 0}, {-3, 0}, {-2, -1}, {-2, 0}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{-2.5, 0}, {-2.5, -0.5}}]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, -2}, {-1, -2}, {0, -3}, {0, -2}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{-0.5, -2}, {-0.5, -2.5}}]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-1, -1}, {-2, -1}, {-1, -2}, {-1, -1}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{-1, -1.5}, {-1.5, -1.5}}]}}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{2, 0}, {3, 0}, {2, -1}, {2, 0}}]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{0, -2}, {1, -2}, {0, -3}, {0, -2}}]}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{1, -1}, {2, -1}, {1, -2}, {1, -1}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{1, -1}, 0.5, 
          NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
           6.283185307179586}]]}}}, {{}, {{}, {}, 
        {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
         1.6], LineBox[{{-3., 0.}, {3., 0.}}]}, 
        {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
         1.6], LineBox[{{0., -3.}, {0., 3.}, {3., 0.}, {0., -3.}, {-3., 0.}, {
          0., 3.}}]}}, {}, {}, {{}, {}}}, {{}, {
        {RGBColor[0.6, 0.4, 0.2], AbsolutePointSize[6], AbsoluteThickness[
         1.6], GeometricTransformationBox[
          InsetBox["\[FilledCircle]", {0., 0.}], {{{0., 0.}}, {{1., 0.}}, {{
          0., 1.}}, {{-1., 1.}}, {{1., -1.}}, {{2., 1.}}, {{0., 3.}}, {{-1., 
          2.}}, {{-2., 1.}}, {{-3., 0.}}, {{-1., -2.}}}]}, 
        {RGBColor[1, 0.5, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
         GeometricTransformationBox[
          InsetBox["\[FilledCircle]", {0., 0.}], {{{-1., 0.}}, {{0., -1.}}, {{
          2., 0.}}, {{1., 1.}}, {{0., 2.}}, {{-2., 0.}}, {{
          0., -2.}}, {{-1., -1.}}, {{3., 0.}}, {{1., 2.}}, {{
          0., -3.}}, {{-2., -1.}}, {{1., -2.}}, {{
          2., -1.}}}]}, {}}, {}, {}, {{}, {}}}}, {
      {GrayLevel[1], RectangleBox[{1.1, 0.1}, {1.9, 0.9}]}, 
      {RGBColor[0, 0, 1], Thickness[Large], 
       CircleBox[{2, 1}, 0.5, 
        NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
         4.71238898038469}]], 
       CircleBox[{1, 0}, 0.5, 
        NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}}},
    AspectRatio->0.9935828574659354,
    ImageSize->{175, Automatic},
    PlotRange->{{-3.8743489583333313`, 
     3.802300347222223}, {-3.785807291666665, 3.8415798611111107`}},
    PlotRangePadding->None], ",", 
   GraphicsBox[{{{
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{1, 0}, 0.5, 
         NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
          3.141592653589793}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{0, 0}, {1, 0}, {1, 1}, {0, 1}, {0, 0}}]}}, {
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{1, 0}, 0.5, 
         NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{1, 0}, {2, 0}, {2, 1}, {1, 1}, {1, 0}}]}}, {
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{0, 2}, 0.5, 
         NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
          6.283185307179586}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{0, 1}, {1, 1}, {1, 2}, {0, 2}, {0, 1}}]}}, {
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{-1, 1}, 0.5, 
         NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
          6.283185307179586}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-1, 0}, {0, 0}, {0, 1}, {-1, 1}, {-1, 0}}]}}, {
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{0, 0}, 0.5, 
         NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
          6.283185307179586}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{0, -1}, {1, -1}, {1, 0}, {0, 0}, {0, -1}}]}}, {
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{0, 1}, 0.5, 
         NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
          3.141592653589793}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-1, 1}, {0, 1}, {0, 2}, {-1, 2}, {-1, 1}}]}}, {
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{-1, 1}, 0.5, 
         NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
          4.71238898038469}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-2, 0}, {-1, 0}, {-1, 1}, {-2, 1}, {-2, 0}}]}}, {
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{1, -2}, 0.5, 
         NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
          3.141592653589793}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{0, -2}, {1, -2}, {1, -1}, {0, -1}, {0, -2}}]}}, {
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{0, -1}, 0.5, 
         NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
          3.141592653589793}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-1, -1}, {0, -1}, {0, 0}, {-1, 0}, {-1, -1}}]}}, {
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{2, 0}, 0.5, 
         NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
          4.71238898038469}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{1, -1}, {2, -1}, {2, 0}, {1, 0}, {1, -1}}]}}, {
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{-1, -1}, 0.5, 
         NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
          6.283185307179586}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-1, -2}, {0, -2}, {0, -1}, {-1, -1}, {-1, -2}}]}}, {
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{-2, -1}, 0.5, 
         NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-2, -1}, {-1, -1}, {-1, 0}, {-2, 0}, {-2, -1}}]}}}, {{
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{2, 0}, {3, 0}, {2, 1}, {2, 0}}]}, 
       {RGBColor[0, 0, 1], Thickness[Large], 
        LineBox[{{2.5, 0}, {2.5, 0.5}}]}}, 
      {GrayLevel[0.5], Thickness[Tiny], 
       LineBox[{{1, 1}, {2, 1}, {1, 2}, {1, 1}}]}, {
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{0, 2}, {1, 2}, {0, 3}, {0, 2}}]}, 
       {RGBColor[0, 0, 1], Thickness[Large], 
        LineBox[{{0.5, 2}, {0.5, 2.5}}]}}, 
      {GrayLevel[0.5], Thickness[Tiny], 
       LineBox[{{0, 2}, {-1, 2}, {0, 3}, {0, 2}}]}, {
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-1, 1}, {-2, 1}, {-1, 2}, {-1, 1}}]}, 
       {RGBColor[0, 0, 1], Thickness[Large], 
        LineBox[{{-1.5, 1}, {-1.5, 1.5}}]}}, 
      {GrayLevel[0.5], Thickness[Tiny], 
       LineBox[{{-2, 0}, {-3, 0}, {-2, 1}, {-2, 0}}]}, {
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-2, 0}, {-3, 0}, {-2, -1}, {-2, 0}}]}, 
       {RGBColor[0, 0, 1], Thickness[Large], 
        LineBox[{{-2, -0.5}, {-2.5, -0.5}}]}}, {
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{0, -2}, {-1, -2}, {0, -3}, {0, -2}}]}, 
       {RGBColor[0, 0, 1], Thickness[Large], 
        LineBox[{{0, -2.5}, {-0.5, -2.5}}]}}, {
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-1, -1}, {-2, -1}, {-1, -2}, {-1, -1}}]}, 
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{-1, -1}, 0.5, 
         NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
          4.71238898038469}]]}}, {
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{2, 0}, {3, 0}, {2, -1}, {2, 0}}]}, 
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{2, 0}, 0.5, 
         NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
          6.283185307179586}]]}}, {
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{0, -2}, {1, -2}, {0, -3}, {0, -2}}]}, 
       {RGBColor[0, 0, 1], Thickness[Large], 
        CircleBox[{0, -2}, 0.5, 
         NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
          6.283185307179586}]]}}, {
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{1, -1}, {2, -1}, {1, -2}, {1, -1}}]}, 
       {RGBColor[0, 0, 1], Thickness[Large], 
        LineBox[{{1, -1.5}, {1.5, -1.5}}]}}}, {{}, {{}, {}, 
       {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
        1.6], LineBox[{{-3., 0.}, {3., 0.}}]}, 
       {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
        1.6], LineBox[{{0., -3.}, {0., 3.}, {3., 0.}, {0., -3.}, {-3., 0.}, {
         0., 3.}}]}}, {}, {}, {{}, {}}}, {{}, {
       {RGBColor[0.6, 0.4, 0.2], AbsolutePointSize[6], AbsoluteThickness[1.6],
         GeometricTransformationBox[InsetBox["\[FilledCircle]", {0., 0.}], {{{
         1., 0.}}, {{0., -1.}}, {{0., 2.}}, {{-1., 1.}}, {{0., -2.}}, {{
         1., -1.}}, {{3., 0.}}, {{0., 3.}}, {{-1., 
         2.}}, {{-1., -2.}}, {{-2., -1.}}, {{2., -1.}}}]}, 
       {RGBColor[1, 0.5, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
        GeometricTransformationBox[InsetBox["\[FilledCircle]", {0., 0.}], {{{
         0., 0.}}, {{0., 1.}}, {{-1., 0.}}, {{2., 0.}}, {{1., 1.}}, {{-2., 
         0.}}, {{-1., -1.}}, {{2., 1.}}, {{1., 2.}}, {{-2., 1.}}, {{-3., 
         0.}}, {{0., -3.}}, {{1., -2.}}}]}, {}}, {}, {}, {{}, {}}}},
    AspectRatio->1.0663183863009722`,
    ImageSize->{175, Automatic},
    PlotRange->{{-3.7610677083333286`, 
     3.716145833333334}, {-4.022569444444443, 3.950520833333332}},
    PlotRangePadding->None], ",", 
   GraphicsBox[{{{{
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{0, 1}, 0.5, 
          NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
           6.283185307179586}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, 0}, {1, 0}, {1, 1}, {0, 1}, {0, 0}}]}}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{1, 0}, {2, 0}, {2, 1}, {1, 1}, {1, 0}}]}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, 1}, {1, 1}, {1, 2}, {0, 2}, {0, 1}}]}, 
        {RGBColor[0, 1, 1], Thickness[Large], Dashing[{Small, Small}], 
         CircleBox[{1, 2}, 0.5, 
          NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
           4.71238898038469}]], 
         CircleBox[{0, 1}, 0.5, 
          NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], 
         {RGBColor[1, 0, 1], 
          CircleBox[{1, 1}, 0.5, 
           NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
            3.141592653589793}]], 
          CircleBox[{0, 2}, 0.5, 
           NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
            6.283185307179586}]]}}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{0, 0}, 0.5, 
          NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
           3.141592653589793}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-1, 0}, {0, 0}, {0, 1}, {-1, 1}, {-1, 0}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{1, -1}, 0.5, 
          NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
           3.141592653589793}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, -1}, {1, -1}, {1, 0}, {0, 0}, {0, -1}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], LineBox[{{-1, 1.5}, {0, 1.5}}]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-1, 1}, {0, 1}, {0, 2}, {-1, 2}, {-1, 1}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{-1.5, 0}, {-1.5, 1}}]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-2, 0}, {-1, 0}, {-1, 1}, {-2, 1}, {-2, 0}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{0.5, -2}, {0.5, -1}}]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, -2}, {1, -2}, {1, -1}, {0, -1}, {0, -2}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{-1, 0}, 0.5, 
          NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
           6.283185307179586}]]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-1, -1}, {0, -1}, {0, 0}, {-1, 0}, {-1, -1}}]}}, {
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{1, -0.5}, {2, -0.5}}]}, 
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{1, -1}, {2, -1}, {2, 0}, {1, 0}, {1, -1}}]}}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-1, -2}, {0, -2}, {0, -1}, {-1, -1}, {-1, -2}}]}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-2, -1}, {-1, -1}, {-1, 0}, {-2, 0}, {-2, -1}}]}, 
        {RGBColor[0, 1, 1], Thickness[Large], Dashing[{Small, Small}], 
         CircleBox[{-1, 0}, 0.5, 
          NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
           4.71238898038469}]], 
         CircleBox[{-2, -1}, 0.5, 
          NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], 
         {RGBColor[1, 0, 1], 
          CircleBox[{-1, -1}, 0.5, 
           NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
            3.141592653589793}]], 
          CircleBox[{-2, 0}, 0.5, 
           NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
            6.283185307179586}]]}}}}, {{
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{2, 0}, {3, 0}, {2, 1}, {2, 0}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{2.5, 0}, {2.5, 0.5}}]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{1, 1}, {2, 1}, {1, 2}, {1, 1}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{1, 1.5}, {1.5, 1.5}}]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, 2}, {1, 2}, {0, 3}, {0, 2}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{0, 2}, 0.5, 
          NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, 2}, {-1, 2}, {0, 3}, {0, 2}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{0, 2.5}, {-0.5, 2.5}}]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-1, 1}, {-2, 1}, {-1, 2}, {-1, 1}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{-1, 1}, 0.5, 
          NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
           3.141592653589793}]]}}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{-2, 0}, {-3, 0}, {-2, 1}, {-2, 0}}]}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-2, 0}, {-3, 0}, {-2, -1}, {-2, 0}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{-2, -0.5}, {-2.5, -0.5}}]}}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{0, -2}, {-1, -2}, {0, -3}, {0, -2}}]}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{-1, -1}, {-2, -1}, {-1, -2}, {-1, -1}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{-1.5, -1}, {-1.5, -1.5}}]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{2, 0}, {3, 0}, {2, -1}, {2, 0}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         CircleBox[{2, 0}, 0.5, 
          NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
           6.283185307179586}]]}}, {
        {GrayLevel[0.5], Thickness[Tiny], 
         LineBox[{{0, -2}, {1, -2}, {0, -3}, {0, -2}}]}, 
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{0.5, -2}, {0.5, -2.5}}]}}, 
       {GrayLevel[0.5], Thickness[Tiny], 
        LineBox[{{1, -1}, {2, -1}, {1, -2}, {1, -1}}]}}, {{}, {{}, {}, 
        {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
         1.6], LineBox[{{-3., 0.}, {3., 0.}}]}, 
        {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
         1.6], LineBox[{{0., -3.}, {0., 3.}, {3., 0.}, {0., -3.}, {-3., 0.}, {
          0., 3.}}]}}, {}, {}, {{}, {}}}, {{}, {
        {RGBColor[0.6, 0.4, 0.2], AbsolutePointSize[6], AbsoluteThickness[
         1.6], GeometricTransformationBox[
          InsetBox["\[FilledCircle]", {0., 0.}], {{{0., 0.}}, {{1., 0.}}, {{
          0., -1.}}, {{2., 0.}}, {{1., 1.}}, {{0., 2.}}, {{-2., 0.}}, {{
          0., -2.}}, {{-1., -1.}}, {{2., 1.}}, {{-1., 2.}}, {{-2., 
          1.}}, {{-3., 0.}}, {{0., -3.}}, {{-1., -2.}}}]}, 
        {RGBColor[1, 0.5, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
         GeometricTransformationBox[InsetBox["\[FilledCircle]", {0., 0.}], {{{
          0., 1.}}, {{-1., 0.}}, {{-1., 1.}}, {{1., -1.}}, {{3., 0.}}, {{1., 
          2.}}, {{0., 3.}}, {{-2., -1.}}, {{1., -2.}}, {{
          2., -1.}}}]}, {}}, {}, {}, {{}, {}}}}, {
      {GrayLevel[1], RectangleBox[{0.1, 1.1}, {0.9, 1.9}]}, 
      {RGBColor[0, 0, 1], Thickness[Large], 
       CircleBox[{1, 2}, 0.5, 
        NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
         4.71238898038469}]], 
       CircleBox[{0, 1}, 0.5, 
        NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}}, {
      {GrayLevel[1], 
       RectangleBox[{-1.9, -0.9}, {-1.1, -0.09999999999999998}]}, 
      {RGBColor[0, 0, 1], Thickness[Large], 
       CircleBox[{-1, 0}, 0.5, 
        NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
         4.71238898038469}]], 
       CircleBox[{-2, -1}, 0.5, 
        NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}}},
    AspectRatio->1.0108594765175423`,
    ImageSize->{175, Automatic},
    PlotRange->{{-3.780824438719163, 3.654306220095691}, {-3.758971291866028, 
     3.7569009937430984`}},
    PlotRangePadding->None]}], "}"}]], "Picture",
 CellChangeTimes->{{3.68527343462638*^9, 3.685273466783205*^9}, 
   3.742650626128518*^9},
 CellID->338274239,ExpressionUUID->"d2366454-fff6-4ac3-b43a-e0f8d8597aa8"],

Cell[TextData[{
 "There are also singular cubics. The equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["y", "2"], "=", 
    RowBox[{"f", "[", "x", "]"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"9942f57b-8e76-450b-918f-32b694f7cd32"],
 ", where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "[", "x", "]"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"b2cfc845-65fe-40af-82e8-ac7a0adf70de"],
 " is a polynomial of one variable, is called, in general, ",
 StyleBox["hyperelliptic",
  FontSlant->"Italic"],
 ". If the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "[", "x", "]"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"5750d8bf-6e82-4a6f-ba76-f14af3973067"],
 " is a cubic with a multiple real zero at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "r"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "acb21a21-faba-45ee-92a4-863ccc33c08c"],
 ", then the resulting curve will have a singularity at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"r", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"4fc8a78a-f590-4b94-8440-265e261c4bfd"],
 "."
}], "Text",
 CellChangeTimes->{{3.685273538943426*^9, 3.685273541728573*^9}, {
   3.685274041635037*^9, 3.685274077215751*^9}, {3.68527427699194*^9, 
   3.685274436396851*^9}, {3.685274470662464*^9, 3.685274573049722*^9}, {
   3.685274629914883*^9, 3.685274705958287*^9}, 3.685274891147706*^9, {
   3.701008651519082*^9, 3.701008651532198*^9}, {3.70101435716497*^9, 
   3.701014391387965*^9}, {3.701014435380679*^9, 3.7010144391640663`*^9}, {
   3.7026551932089367`*^9, 3.702655193213531*^9}, {3.702837964056205*^9, 
   3.7028379790621634`*^9}, {3.702838677573393*^9, 3.702838705067462*^9}, {
   3.708426081941333*^9, 3.708426115450133*^9}, {3.708431259720789*^9, 
   3.708431260688789*^9}},
 CellID->255664690,ExpressionUUID->"7ed3a781-cc71-4633-ad03-fcb3dc6d6ab1"],

Cell["Here is a look at three singular cubics:", "CodeCaption",
 CellChangeTimes->{{3.709036620627777*^9, 3.7090366232630405`*^9}},
 CellID->433701136,ExpressionUUID->"a81d5aea-f795-4f95-bb7c-5aa05bd1798f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "^", "2"}], "==", 
       RowBox[{
        RowBox[{"x", "^", "3"}], "+", 
        RowBox[{"2", 
         RowBox[{"x", "^", "2"}]}]}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "^", "2"}], "\[Equal]", 
       RowBox[{"x", "^", "3"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "^", "3"}], "+", 
        RowBox[{"y", "^", "3"}]}], " ", "\[Equal]", " ", 
       RowBox[{"3", " ", "x", " ", "y"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.685274712613723*^9, 3.685274716444789*^9}, {
  3.685274750934489*^9, 3.685274871522734*^9}, {3.68527490413795*^9, 
  3.685274963148737*^9}, {3.685275019287715*^9, 3.685275064383332*^9}, {
  3.685275109425784*^9, 3.685275109912043*^9}, {3.685275151218867*^9, 
  3.685275174514919*^9}, {3.737893596896797*^9, 3.737893641932248*^9}},
 CellLabel->"In[29]:=",
 CellID->1989150830,ExpressionUUID->"77141080-b3f4-4f43-a932-55a5b9d2669c"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxdmAk0VfsXxy9Kip6hRF6UStNrHiSpfaKUJsmQodIrqRQa9N7fo0EzDa9X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     "], {{{}, {}, 
       TagBox[
        TooltipBox[{
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
            68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 
           84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
           100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 
           113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 
           126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 
           139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 
           152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
           165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
           178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 
           191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 
           204, 205}], 
          LineBox[CompressedData["
1:eJwt0vVzDwAAxuHvtGmmc2q6m+lumzETYzqnc7pzYowxppmJv0R3d3c3jzs/
PL9+7t67NzQuPmJSUCAQeMBpznCWc5znAhe5xGWucJVrXOcGN7nFbe5wl3vc
/999yCMe84SnPOM5L3jJK17zhre84z0f+MgnPvOFr3zjOz/4yS9+84eAQUFk
IjNZyEo2spODnASTi9zkIS/5yE8BClKIEApThKIUozglKEkpSlOGspQjlPJU
oCKVqEwYVahKNapTg5rUojZ1qEs96tOAhjSiMU1oSjOa04JwWtKK1rShLe1o
Twc60onOdKEr3ehOD3rSi970IYJI+hJFP/oTzQBiGMggBjOEWIYyjDiGM4KR
jGI0YxjLOMYzgYn8O2I8k5nCVKYxnRnMZBazmcNc5pHAfBawkEUsZglLWcZy
VrCSVaxmDWtZx3o2kMhGNrGZLSSxlW0ks50dpLCTXaSymz2ksZd97OcABznE
YY5wlHSOkcFxTnCSU/wFflRtJQ==
           "]]}, 
         RowBox[{
           SuperscriptBox[
            TagBox["y", HoldForm], "2"], "\[Equal]", 
           RowBox[{
             RowBox[{"2", " ", 
               SuperscriptBox[
                TagBox["x", HoldForm], "2"]}], "+", 
             SuperscriptBox[
              TagBox["x", HoldForm], "3"]}]}]], 
        Annotation[#, HoldForm[$CellContext`y]^2 == 
         2 HoldForm[$CellContext`x]^2 + HoldForm[$CellContext`x]^3, 
         "Tooltip"]& ]}}], {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0., 0.}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, AxesLabel -> {None, None}, 
     FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> Identity, 
     AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> Identity,
      Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
     PlotRange -> {{-3, 3}, {-5, 5}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxdmHs81fcfxzluUyq3qNlPchvdZlu6bPT+VK6lpJtLpXVbk6wY2yqbFLWs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     "], {{{}, {}, 
       TagBox[
        TooltipBox[{
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1GOjEAYABdD3amlZy+bism1ry3xh8WXbtm1uy9bici27Ldt2p/pw7v0F
9yYJal05ODAgICCE+NaE5AdCEZowhCUcPxKeCEQkEpGJQlSiEZ0YxOQnYhGb
OMQlHvFJQEISkZgkJCUZyUlBSlKRmp9JQ1rSkZ4MZOQXMpGZLGQlG9nJQU5y
kZs85CUf+SlAQQpRmCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkq/MpvVKUa1alB
TWpRmzrUpR71aUAQDWlEY5rwO01pRnNa0JJWBNOaNrSlHe3pQEc60ZkudKUb
3elBT3rRmz70pR/9GcBABjGYIQxlGMMZwUhGMZoxjGUc45nARCYxmSlMZRrT
mcFMZjGbOcxlHvNZwEIWsZglLGUZf/Anf7GcFaxkFatZw1rWsZ4NbGQTm9nC
Vraxnb/ZwU52sZs97OUf9rGfAxzkEIc5wlGO8S/HOcFJTnGaM5zlHOe5wEUu
cZkr/Mf/XOUa17nBTW5xmzvc5R73ecBDHvGYJzzlGc95wUte8Zo3vOUd7/nA
Rz7xma/jDwz8/gNfAKrSgT0=
           "]]}, 
         RowBox[{
           SuperscriptBox[
            TagBox["y", HoldForm], "2"], "\[Equal]", 
           SuperscriptBox[
            TagBox["x", HoldForm], "3"]}]], 
        Annotation[#, HoldForm[$CellContext`y]^2 == 
         HoldForm[$CellContext`x]^3, "Tooltip"]& ]}}], {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0., 0.}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, AxesLabel -> {None, None}, 
     FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> Identity, 
     AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> Identity,
      Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
     PlotRange -> {{-1, 3}, {-5, 5}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxdmQlUzdsXxyulTCn0TIVkHlNRRDsRFWVMEor+QqVkLDNPIWTIkDwSZXhk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     "], {{{}, {}, 
       TagBox[
        TooltipBox[{
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1fN/EAgYBvCtZdu1lm3b5rJrmctatdqybdu2dQh34XzxLhzDXThffffp
h+/z/gXP84aEhYcODAwICLggYm4sgohNHOISj/gkICGJSEwSkpKM5KQgJalI
TRrSko70ZCAjmchMFrISTDZCyE4OcpKL3OQhL/nITwEKUojCFKEoxShOCUpS
itKUoSzlKE8FKlKJylShKtWoTg1qUova1KEu9ahPAxrSiMY0oSnNCKU5LWhJ
K1rThra0oz0d6EgnOtOFroTRje70oCe96E0f+tKP/gxgIOEMYjBDGMowhjOC
kYxiNGOIYCzjGE8kE5hIFNFMYjJTmMo0pjODmcxiNnOYyzzms4CFLGIxS1jK
MpazgpWsYjVrWMs61rOBjWxiM1vYyja2s4Od7GI3e9jLPvZzgIMc4jBHOMox
jnOCk5ziNGc4yznOc4GLXOIDPuQjPuYyV7jKNT7hU65zg5vc4jM+5wu+5Cu+
5hu+5TZ3uMs97vOA7/iehzziMU/4gR/5iZ/5hV95yjOe84Lf+J2XvOI1b/iD
P/mLv/mHf/mP/3lLTPkDiUUQsYlDXOIRnwQkJBGJSUJSkpGcFKQkFalJQ1rS
kZ4MZCQTmclCVoLJRgjZyUFOcpGbPOQlH/kpQEEKUZgiFKUYxSlBSUpRmjKU
pRzlqUBFKlGZKlSlGtWpQU1qUZs61KUe9WlAQxrRmCY0pRmhNKcFLWlFa9rQ
lna0pwMd6URnutCVMLrRnR70pBe96UNf+tGfAcSMdziDGMwQhjKM4YxgJKMY
zRgiGMs4xhPJBCYSRTSTmMwUpjKN6cxgJrOYzRzmMo/5LGAhi1jMEpayjOWs
YCWrWM0a1rKO9WxgI5vYzBa2so3t7GAnu9jNHvayj/0c4CCHOMwRjnKM45zg
JKc4zRnOco7zge//4DtLHMyd
           "]]}, 
         RowBox[{
           RowBox[{
             SuperscriptBox[
              TagBox["x", HoldForm], "3"], "+", 
             SuperscriptBox[
              TagBox["y", HoldForm], "3"]}], "\[Equal]", 
           RowBox[{"3", " ", 
             TagBox["x", HoldForm], " ", 
             TagBox["y", HoldForm]}]}]], 
        Annotation[#, 
         HoldForm[$CellContext`x]^3 + 
          HoldForm[$CellContext`y]^3 == (3 HoldForm[$CellContext`x]) 
          HoldForm[$CellContext`y], "Tooltip"]& ]}}], {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0., 0.}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, AxesLabel -> {None, None}, 
     FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> Identity, 
     AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> Identity,
      Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
     PlotRange -> {{-2, 2}, {-2, 2}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.7118005553514757`*^9, 3.737891179223248*^9, 3.737892417348186*^9, 
   3.7378935223009*^9, {3.737893629752529*^9, 3.737893643036973*^9}, 
   3.737893964159169*^9, 3.742658535516573*^9},
 CellLabel->"Out[29]=",
 CellID->649088546,ExpressionUUID->"bb26fb3a-d21d-48ec-bfe5-87fb961f82b1"]
}, Open  ]],

Cell[TextData[{
 "The left-hand singularity is called a ",
 StyleBox["node",
  FontSlant->"Italic"],
 "; the middle singularity is called a ",
 StyleBox["cusp",
  FontSlant->"Italic"],
 ". Other cubics may also be singular, such as the folium of Descartes on the \
right, which also has a node. We will explain in Chapter 5 why an irreducible \
cubic can have only one singularity."
}], "Text",
 CellChangeTimes->{{3.685274896567846*^9, 3.685274900189033*^9}, {
   3.685275196826563*^9, 3.685275258548753*^9}, {3.685275320318337*^9, 
   3.685275439050102*^9}, {3.701008651543149*^9, 3.7010086515582743`*^9}, {
   3.708426129474533*^9, 3.708426189153733*^9}, 3.739290214049406*^9, 
   3.74083304343925*^9},
 CellID->1780066961,ExpressionUUID->"59fa22c2-2a0e-4cf7-934f-74381ac1f6ff"],

Cell["\<\
Here is a look at reducible cubics, which are cubics where the equation \
factors can have two or three singularities:\
\>", "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{{3.709036694017115*^9, 3.709036712715985*^9}},
 CellID->836131144,ExpressionUUID->"b925b931-8f86-4302-b2ce-b6575adf95ab"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", "y", "-", "1"}], ")"}]}], " ", "\[Equal]", "0"}], 
     ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}], ",", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}], "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.685275444471519*^9, 3.685275555981604*^9}},
 CellLabel->"In[30]:=",
 CellID->990727170,ExpressionUUID->"3f99b59f-9d7b-4486-9f63-1a1edd884b3d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1mAtwVNUdxlcMlBFrQREpCkZJEcWp0el0fJzp2SgoAR3xPVWBYEERCAko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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJwl1GecCAQYBvA7t5fj9p1zw7m93HaHrEoZjVMiEpKGumtqEWW2NWwNGoiQ
klEho0KlRZq0J6I9VP/79eH/vJ+fD8+bPaq5sSkwICCgm2i5rQgimBBCCSOc
CCKJIpoYWhNLG9oSRzwJJJJEMimkkkY70mlPBplkkU0HcuhILnnkU0AhRRRT
QilllNOJCiqpopoaaqmjM/U00IWuLZ05ge70oCe96M2JnMTJ9OEUTqUv/ejP
AE7jdM7gTBoZyFmczSDOYTBDOJehDOM8hnM+IxjJKC5gNBcyhou4mEu4lLFc
xuU00cwVXMlVXM01XMs4ruN6buBGbmI8E7iZiUziFm5lMlOYyjSmM4PbuJ07
uJO7uJt7mMm93Mf9PMAsZjOHucxjPgtYyIM8xMM8wiIW8yiP8ThPsISlLONJ
lrOCp1jJKlbzNGt4hmdZy3OsYz0b2MjzvMCLbGIzW3iJrWxjOzt4mVd4lZ3s
Yjev8TpvsIc3eYu3eYd32cs+3mM/7/MBH/IRH/MJBzjIp3zG53zBl3zF13zD
t3zH9/zAIQ5zhB85yjF+4md+4Vd+43f+4E/+4m+O8w//0jL+QFoRRDAhhBJG
OBFEEkU0MbQmlja0JY54EkgkiWRSSCWNdqTTngwyySKbDuTQkVzyyKeAQooo
poRSyiinExVUUkU1NdRSR2fqaaALXQP//3n/AYCAiRM=
          "]], 
         LineBox[CompressedData["
1:eJwVz0VWFQAAQNHPUtgIjYBIN4p0SnephEh3l4B0NwISW+MyuOe86Qsuqkut
DQoEAn2EiFDCCCeCSKKI5gMxxBLHR+L5RAKJJJFMCqmkkU4GmWSRTQ65fOYL
eXwlnwIKKaKYEkopo5wKKqniG9XU8D5SRz0NNNJEMy200kY7HXTSRTff+cFP
euilj35+McBvBhlimBFGGWOcCSaZYpoZZpljngUWWWKZFVZZY50/bLDJFn/Z
Zodd9tjngEOOOOaEU84454JLrrjmhlvu+Mc9DzzynyeeeeGVN6vUQvU=
          "]], 
         LineBox[CompressedData["
1:eJwV0Nc61wEAgOHfnxJRRlSUQkZIJSuysopDl+ACuBA3ZY9o2yuUWWYRyngd
vM/zHX/pbR2t7aEgCDrpEt300Esf/QwwyBDDvGOEUd7zgY984jNf+MoY40ww
yRTTzDDLHPMs8I1FlljmOz9YYZU11tlgk5/8Yottdthlj31+84cDDvnLEcec
8I//nHLG+eWEsCAIEUY4V7hKBNeIJIrrRBPDDW4SSxzxJHCLRJK4zR3ukkwK
97hPKg94SBrpZPCITLLIJofH5JJHPk8o4CnPeE4hLyiimBJKKeMl5VTwikqq
qKaGWl5TRz0NNNLEG97STAsXjlVFzA==
          "]]},
        RowBox[{
          RowBox[{
            TagBox["x", HoldForm], " ", 
            TagBox["y", HoldForm], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                TagBox["x", HoldForm], "+", 
                TagBox["y", HoldForm]}], ")"}]}], "\[Equal]", "0"}]],
       Annotation[#, (HoldForm[$CellContext`x] HoldForm[$CellContext`y]) (-1 + 
          HoldForm[$CellContext`x] + HoldForm[$CellContext`y]) == 0, 
        "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-2, 2}, {-2, 2}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx9mAlUVeUWx1HQp6KlpZmhkTmbmFnmI8WNFY74CkzLIVOUVMIgHDBxKtcS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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
          35, 36, 37, 38, 39, 40}], 
         LineBox[{41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 
          56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 
          73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 
          90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 
          105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 
          118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
          131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 
          144, 145, 146, 147}], 
         LineBox[{148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 
          160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
          173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 
          186, 187}], LineBox[CompressedData["
1:eJwN0EVCAgEAAMDFxBa7EMEf+QROnPSDit2NKAZ2dzfGHOYDE08O9PWHgiBI
McgQaYYZYZQxxplgkimmmWGWOeZZYJEllllhlQxrZFlngxybbLHNDnl22WOf
Aw454pgTTjnjnAsuueKaG265454HHnnimRdeeeOdDz754psCP/zyRyAmRBHF
lFBKGeWEqaCSKqqpoZY66onQQCNNNNNCK22000EnXUTpJkYPcRL08g8/Uj+M

          "]], 
         LineBox[{292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 
          304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 
          317, 318, 319, 320, 321}], 
         LineBox[{322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 
          334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 
          347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 
          360, 361, 362, 363, 364, 365, 366, 367, 368}], 
         LineBox[{369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380, 
          381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392, 393, 
          394, 395, 396, 397, 398, 399, 400, 401}], LineBox[{402, 403, 404}], 
         LineBox[{405, 406, 407, 408, 409}], LineBox[{410, 411, 412}], 
         LineBox[{413, 414}]},
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                TagBox["x", HoldForm], "-", 
                TagBox["y", HoldForm]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "2"], "+", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}], ")"}]}], "\[Equal]", "0"}]],
       Annotation[#, (HoldForm[$CellContext`x] - 
          HoldForm[$CellContext`y]) (-1 + HoldForm[$CellContext`x]^2 + 
          HoldForm[$CellContext`y]^2) == 0, "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-2, 2}, {-2, 2}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{3.7118005554545517`*^9, 3.737891179406468*^9, 
  3.737892417529585*^9, 3.737893522518909*^9, 3.737893964403517*^9, 
  3.742658535622406*^9},
 CellLabel->"Out[30]=",
 CellID->14265862,ExpressionUUID->"27a9564e-1b13-4591-9738-f633ced05867"]
}, Open  ]],

Cell["\<\
In Chapter 7, I show that each irreducible cubic can be reduced to an \
equivalent hyperelliptic form. This is well known for nonsingular cubics in \
theory, but using my method, it actually can be done for almost any cubic, \
including those with numerical coefficients.\
\>", "Text",
 CellChangeTimes->{{3.685275285109362*^9, 3.685275310141706*^9}, {
   3.685275594189901*^9, 3.685275655384371*^9}, {3.685275759875628*^9, 
   3.68527577049915*^9}, {3.68527580622899*^9, 3.685275864445479*^9}, 
   3.7010086515710793`*^9, 3.7010544960854597`*^9, {3.7084262053309326`*^9, 
   3.708426261381333*^9}},
 CellID->1278050510,ExpressionUUID->"45b0b80c-6733-4074-a534-0252a6b446d5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4 Higher Degree", "Subsection",
 CellChangeTimes->{{3.685276040292815*^9, 3.685276067026937*^9}},
 CellID->1063484276,ExpressionUUID->"815521f1-7a0f-49cf-9593-f4603e03a7b8"],

Cell[TextData[{
 "Linear curves are of degree 1, conics are of degree 2, and cubics are of \
degree 3. Some people call curves of degree 4 biquadratics; others call them ",
 StyleBox["quartics",
  FontSlant->"Italic"],
 ". Otherwise, we simply say that the curve has degree ",
 StyleBox["d",
  FontSlant->"Italic"],
 ". Specifically, the ",
 StyleBox["total degree",
  FontSlant->"Italic"],
 " of a monomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "i"], " ", 
    SuperscriptBox["y", "j"]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"efd01587-7762-4bea-86cb-9cf9c4b60df3"],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"i", "+", "j"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "d2798eac-55fe-405e-83f8-0a206f31d096"],
 ". The total degree of a polynomial is the highest total degree of a \
monomial with a nonzero coefficient. "
}], "Text",
 CellChangeTimes->{{3.685275901107085*^9, 3.685275906867692*^9}, {
   3.68527594535306*^9, 3.685276034483819*^9}, {3.685276069835461*^9, 
   3.685276217479927*^9}, {3.685276269185524*^9, 3.685276314467169*^9}, {
   3.685276463486707*^9, 3.685276463711405*^9}, {3.701008651589744*^9, 
   3.701008651631044*^9}, {3.7010144991084557`*^9, 3.701014525578022*^9}, {
   3.701014562994493*^9, 3.701014588683546*^9}, {3.701054497621688*^9, 
   3.701054499189773*^9}, {3.702655214203158*^9, 3.7026552266909027`*^9}, {
   3.70283798934774*^9, 3.702837993535529*^9}, {3.7084263059191327`*^9, 
   3.708426380471533*^9}, {3.7084454378859596`*^9, 3.7084454597409596`*^9}, {
   3.709036836321344*^9, 3.709036853145026*^9}, 3.7391998900506163`*^9, {
   3.739290627853733*^9, 3.739290630701733*^9}},
 CellID->473832751,ExpressionUUID->"b9a040e7-3435-432a-808f-842fc8cb17a3"],

Cell["\<\
As you have seen, quite a bit is known about algebraic curves of degree 3 or \
lower. There is still a lot to discover about higher-degree curves. We will \
give some well-known examples in this section. Much of the rest of this book \
will be concerned with methods to represent higher-degree curves, especially \
when a contour plot is not sufficient.\
\>", "Text",
 CellChangeTimes->{{3.685276552188534*^9, 3.685276697181512*^9}, {
  3.701008651640914*^9, 3.7010086516628437`*^9}, {3.708426424041133*^9, 
  3.708426436365133*^9}, {3.739275220810804*^9, 3.739275221770804*^9}, {
  3.739275266999804*^9, 3.739275268071804*^9}},
 CellID->837682981,ExpressionUUID->"62e367be-97bf-4c1d-acf1-ae355467ec33"],

Cell["We start with a few named biquadratics:", "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{{3.685277410084571*^9, 3.685277456164692*^9}, {
   3.685277581542391*^9, 3.685277663064474*^9}, {3.685278222405197*^9, 
   3.685278224605568*^9}, {3.702839885484613*^9, 3.7028399033005943`*^9}, 
   3.7090375675064554`*^9},
 CellID->35071935,ExpressionUUID->"baf9cef9-1e2b-4aa9-bb0d-642119ce7bb3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Row", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"ContourPlot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"x", "^", "4"}], "+", 
           RowBox[{"4", "x", " ", "y"}], "+", 
           RowBox[{"y", "^", "4"}]}], " ", "==", ".25"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
       "\"\<Peanut Curve\>\""}], "]"}], ",", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"ContourPlot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"x", "^", "4"}], "+", 
           RowBox[{"y", "^", "4"}]}], "\[Equal]", "1"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
       "\"\<Fermat Curve\>\""}], "]"}], ",", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"ContourPlot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"x", "^", "2"}], "+", 
             RowBox[{
              RowBox[{"y", "^", "2"}], "/", "4"}], "-", "1"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "^", "2"}], "/", "4"}], "+", 
             RowBox[{"y", "^", "2"}], "-", "1"}], ")"}]}], "\[Equal]", 
          RowBox[{"-", ".04"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
       "\"\<Klein Curve\>\""}], "]"}]}], "}"}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.685278227459919*^9, 3.685278682616268*^9}, {
  3.685278748060698*^9, 3.68527875948437*^9}, {3.7378911977121687`*^9, 
  3.7378913011766376`*^9}},
 CellLabel->"In[31]:=",
 CellID->1043492267,ExpressionUUID->"2d1a5a71-8117-4590-931c-398555ca9d14"],

Cell[BoxData[
 TemplateBox[{TemplateBox[{
     GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJxdmXlczXnbx5PINs2MnQxG2aWxb2OuMVG2Gg/GGGOGMZn7sRSTdYxElnKb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       "], {{{}, {}, 
         TagBox[
          TooltipBox[{
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[1.6]], 
            LineBox[CompressedData["
1:eJwl1dO2GAgQBMDc2LZt27Zt27Zt27Zt27ZtO+vK2Yfq+YLuSdS4Q+X2AYEC
Bfolft/ABCEowQhOCEISitCEISzhCE8EIhKJyEQhKtGITgxiEovYxCEu8YhP
AhKSiMQkISnJSE4KUpKK1KQhLelITwYykonMZCEr2chODnKSi9zkIS/5yE8B
ClKIwhShKMUoTglKUorSlKEs5ShPBSpSicpUoSrVqE4NalKL2tShLvWoTwMa
0ojGNKEpzWhOC1rSita0oS3taE8HOtKJznShK93oTg960ove9KEv/ejPAAYy
iMEMYSjDGM4IRjKK0YxhLOMYzwQmMonJTGEq05jODGYyi9nMYS7zmM8CFrKI
xSxhKctYzgpWsorVrGEt61jPBjayic1sYSvb2M4OdrKL3exhL/vYzwEOcojD
HOEoxzjOCU5yitOc4SznOM8FLnKJy1zhKte4zg1ucovb3OEu97jPAx7yiMc8
4SnPeM4LXvKK17zhLe94zwc+8onPfOEr3/jOD37yiz/4k7/4m3/4l9/lDyAw
QQhKMIITgpCEIjRhCEs4whOBiEQiMlGISjSiE4OYxCI2cYhLPOKTgIQkIjFJ
SEoykpOClKQiNWlISzrSk4GMZCIzWchKNrKTg5zkIjd5yEs+8lOAghSiMEUo
SjGKU4KSlKI0ZShLOcpTgYpUojJVqEo1qlODmtSiNnWoSz3q04CGNKIxTWhK
M5rTgpa0ojVtaEs7fo93BzrSic50oSvd6E4PetKL3vShL/3ozwAGMojBDGEo
wxjOCEYyitGMYSzjGM8EJjKJyUxhKtOYzgxmMovZzGEu85jPAhayiMUsYSnL
WM4KVrKK1axhLetYzwY2sonNbGEr29jODnayi93sYS/72M8BDnKIwxzhKMc4
zglOcorTnOEs5zjPBS5yictc4SrXuM4NbnKL29zhLve4zwMe8ojHPOEpz3jO
C17yite84S3veM8HPvKJz3zhK9/4zg9+Bvz/4/8D/ZT8vQ==
             "]]}, 
           RowBox[{
             RowBox[{
               SuperscriptBox[
                TagBox["x", HoldForm], "4"], "+", 
               RowBox[{"4", " ", 
                 TagBox["x", HoldForm], " ", 
                 TagBox["y", HoldForm]}], "+", 
               SuperscriptBox[
                TagBox["y", HoldForm], "4"]}], "\[Equal]", "0.25`"}]], 
          Annotation[#, 
           HoldForm[$CellContext`x]^4 + (4 HoldForm[$CellContext`x]) 
             HoldForm[$CellContext`y] + HoldForm[$CellContext`y]^4 == 0.25, 
           "Tooltip"]& ]}}], {
      DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
       AxesOrigin -> {0., 0.}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, AxesLabel -> {None, None}, 
       FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> 
       Identity, AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> 
       Identity, Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> Small, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
       PlotRange -> {{-2, 2}, {-2, 2}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
     "\"Peanut Curve\""}, "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )],TemplateBox[{
     GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJx9VwtMlWUYPoVNTWSpqaTZrDQV8x6bm9RbU4MzVAIlp2heIHamkmjrApqh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       "], {{{}, {}, 
         TagBox[
          TooltipBox[{
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[1.6]], 
            
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
             188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 
             201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 
             214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 
             227, 228, 229, 230, 231, 232, 233, 234, 235, 236}]}, 
           RowBox[{
             RowBox[{
               SuperscriptBox[
                TagBox["x", HoldForm], "4"], "+", 
               SuperscriptBox[
                TagBox["y", HoldForm], "4"]}], "\[Equal]", "1"}]], 
          Annotation[#, 
           HoldForm[$CellContext`x]^4 + HoldForm[$CellContext`y]^4 == 1, 
           "Tooltip"]& ]}}], {
      DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
       AxesOrigin -> {0., 0.}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, AxesLabel -> {None, None}, 
       FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> 
       Identity, AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> 
       Identity, Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> Small, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
       PlotRange -> {{-2, 2}, {-2, 2}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
     "\"Fermat Curve\""}, "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )],TemplateBox[{
     GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJxdmndYlVfWxVXsREXsxIaKBhMD9opbo4BY0WCdjMaCXbHERnSUWBLF8KEY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       "], {{{}, {}, 
         TagBox[
          TooltipBox[{
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[1.6]], 
            
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184}], 
            LineBox[CompressedData["
1:eJwt0ldXDwAAxuF/CskmlKyWUbJXVgotWVHKlplRZIYvRmVllJEtI0J2Ilv2
0zkunrvf1Xve6KLS3JKgQCBwlmMcp4JKqjjBSU5xmjNU/+/PcZ4L1FDLRS5x
mSvUcZVrXOcGN7nFbe5Qz13ucZ8HNPCQRzTymCc8pYlnPOcFL3nFa97QzFta
eMd7WvnARz7xmS985RvfaeMHP/nFb/7wl4CRguhAMCF0pBOdCaULYXSlG93p
QU960Zs+9CWcfvRnABFEMpAoBjGYIQxlGNHEEEsc8QxnBCMZRQKJjCaJMYxl
HOOZwEQmMZkpTGUayUxnBjOZxWxSmEMqacxlHvNJJ4NMsshmATksZBGLWcJS
clnGcvLIZwUFFLKSVaxmDWtZx3o2UMRGNrGZLWxlG8VsZwc72UX7uUvZzR7K
2Ms+9nOAgxyinMMc4Sj/ALPdXj8=
             "]], 
            LineBox[CompressedData["
1:eJwNxudajgEAAND3+2SLsjOiZFNWiLgIl+ACuAJ775HsXUYphawQSmRvSmQW
kYrs2flxnufETZ85bUYoCIJiZsls5jCXecxnAQtZxGKWsJRlLGcFK1nFataw
lnWsJ40NpLORTWxmC1vZxnZ2sJNd7GYPe8kgk33s5wAHySKbQ+SQy2HyyOcI
RzlGAcc5wUlOcZpCznCWcxRxngtcpJgSLlHKZa5QxlWucZ0b3OQWt7nDXe5x
nwc85BGPKaeCJ1TylGdU8ZwXvOQVr3lDNTW85R21vOcDdXykngYa+cRnmvjC
V77xnR/85Be/+cNf/vGfIBwEIcK0IIKWtKI1bWhLO9rTgUg60okooulMF7rS
je70oCcx9KI3fehLLP3oTxzxDCCBgQxiMEMYyjCGM4KRJJLEKEYzhrGMI5nx
TGAiKUxiMqlMYSrN8UFsUg==
             "]], 
            LineBox[CompressedData["
1:eJwNw4dajQEAANAfT9KTWImMcMlIihQKZZNZSWWWzOyRmT2i7EtJZM/MjMje
I/Oc7zsRSRmh9BZBEIRt3TII2tjWdrY30g5G2dFORtvZLna1mzF2t4c9DdnL
3sbax772s79xDjDegSaY6CAHm+QQk01xqMMcbqppjnCko0w3w9GOcazjHO8E
JzrJyWY6xalOc7oznGmW2eY4y1xnm2e+Bc5xrvOc7wIXWmiRiyx2sUtc6jKX
u8ISV7rK1a5xretc7wY3uslSN7vFrW5zuzssc6e73O0e97rP/R7woIcs97BH
rLDSox7zuCc86SlPG/aMZ62y2nPWeN5aL3jROi952Ste9ZrXveFNb3nbO961
3nve94EPfeRjG3ziU5/53EZf+NImX/naN771ne/94Ec/+dkvfvWb3/3hT5v9
5W//+Nd/Bq2C4D/enHva
             "]]}, 
           RowBox[{
             RowBox[{
               RowBox[{"(", 
                 RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SuperscriptBox[
                    TagBox["x", HoldForm], "2"], "+", 
                   FractionBox[
                    SuperscriptBox[
                    TagBox["y", HoldForm], "2"], "4"]}], ")"}], " ", 
               RowBox[{"(", 
                 RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   FractionBox[
                    SuperscriptBox[
                    TagBox["x", HoldForm], "2"], "4"], "+", 
                   SuperscriptBox[
                    TagBox["y", HoldForm], "2"]}], ")"}]}], "\[Equal]", 
             RowBox[{"-", "0.04`"}]}]], 
          Annotation[#, (-1 + HoldForm[$CellContext`x]^2 + 
             Rational[1, 4] HoldForm[$CellContext`y]^2) (-1 + 
             Rational[1, 4] HoldForm[$CellContext`x]^2 + 
             HoldForm[$CellContext`y]^2) == -0.04, "Tooltip"]& ]}}], {
      DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
       AxesOrigin -> {0., 0.}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, AxesLabel -> {None, None}, 
       FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> 
       Identity, AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> 
       Identity, Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> Small, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
       PlotRange -> {{-3, 3}, {-3, 3}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
     "\"Klein Curve\""}, "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.711800555587922*^9, 3.713807558450289*^9, {3.737891179686167*^9, 
   3.737891214169039*^9}, {3.7378912715372972`*^9, 3.737891303060198*^9}, 
   3.737892417806988*^9, 3.737893522789465*^9, 3.73789396472532*^9, 
   3.7426585357657013`*^9},
 CellLabel->"Out[31]=",
 CellID->1395657817,ExpressionUUID->"8eaeca8c-4425-4c42-8ac4-f68a2a92e8b0"]
}, Open  ]],

Cell[TextData[{
 "Actually, \[OpenCurlyDoubleQuote]peanut curve\[CloseCurlyDoubleQuote] is my \
own name; this curve is similar to certain ",
 StyleBox["Cassini ovals",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.685278767463726*^9, 3.685278803507096*^9}, {
  3.685278840820756*^9, 3.68527886726956*^9}, {3.701014603627956*^9, 
  3.701014610403378*^9}, {3.7084264561147327`*^9, 3.7084264717927327`*^9}},
 CellID->1623070067,ExpressionUUID->"cecccaf0-17c8-4a60-91bc-67547cd286d3"],

Cell["Some singular curves are:", "CodeCaption",
 CellChangeTimes->{{3.685288856756733*^9, 3.685288879656627*^9}, 
   3.709038756690362*^9},
 CellID->1601331875,ExpressionUUID->"50aedd4b-7795-425a-973b-9cd17852db0d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"ContourPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"x", "^", "2"}], "-", "4"}], ")"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "2"}], ")"}], "^", "2"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"y", "^", "2"}], "-", "4"}], ")"}], "^", "2"}]}], 
         "\[Equal]", "0"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
      "\"\<Bicuspid Curve\>\""}], "]"}], ",", 
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"ContourPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"x", "^", "4"}], "+", 
          RowBox[{"4", "x", " ", "y"}], "+", 
          RowBox[{"y", "^", "4"}]}], "\[Equal]", "0"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
      "\"\<Lemniscate\>\""}], "]"}], ",", 
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"ContourPlot", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"3", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"x", "^", "2"}], "+", 
              RowBox[{"y", "^", "2"}]}], ")"}], "^", "2"}]}], "+", 
          RowBox[{"8", "x", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", 
              RowBox[{"y", "^", "2"}]}], "-", 
             RowBox[{"x", "^", "2"}]}], ")"}]}], "+", 
          RowBox[{"6", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"x", "^", "2"}], "+", 
             RowBox[{"y", "^", "2"}]}], ")"}]}]}], "\[Equal]", "1"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
      "\"\<Hypocycloid\>\""}], "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.685288895512027*^9, 3.685289116735419*^9}, {
   3.685289146929495*^9, 3.685289195687876*^9}, {3.685289381976491*^9, 
   3.68528938246314*^9}, {3.709304066836384*^9, 3.7093040707394943`*^9}, {
   3.737891355205984*^9, 3.73789139350049*^9}, 3.744641610745433*^9},
 CellLabel->"In[32]:=",
 CellID->1319758921,ExpressionUUID->"434294b5-6921-4d5c-aa11-a74fbc5181bc"],

Cell[BoxData[
 TemplateBox[{TemplateBox[{
     GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJxdWnlcjNsbn62ZsdW1pqvs2w0X4brWcyw3O0UREVqkfpZEtisUlS0tpCSV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       "], {{{}, {}, 
         TagBox[
          TooltipBox[{
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[1.6]], 
            LineBox[CompressedData["
1:eJwl1kO0GAYQBdAf27Ztm03S2LZt22rc2GqDNrZt27Zt9/7TxT1vPYs3M0ka
d6jcPkhAQED2oAEBgSkCghGcEIQkFKEJQ1jCEZ4IRCQSkYlCVKIRnRjEJBax
iUNc4hGfBCQkEYlJQlKSkZwUpCQVqUlDWtKRngxkJBOZyUJWsgXOQw5ykovc
5CEv+chPAQpSiMIUoSi/UYzilOB3SlKK0pShLOUoTwUqUonKVKEq1ahODWpS
i9rUoS71qE8DGtKIxjShKc1oTgta0orWtKEt7WhPBzrSic50oSvd6E4PetKL
3vShL/3ozwAGMojBDGEowxjOCEbyB6MYzRjGMo7xTOBPJjKJyUxhKtOYzgxm
MovZzGEu85jPAhbyF3+ziMUsYSn/8C/LWM4KVrKK1axhLetYzwY2sonNbGEr
29jODnayi93sYS/72M8BDnKIwxzhKMc4zglOcorTnOEs5zjPBS5yictc4SrX
uM4NbnKL29zhLve4zwMe8ojHPOEpz3jOC17yite84S3veM8HPvKJz3zhK9/4
zg9+8ovA8gchKMEITghCEorQhCEs4QhPBCISichEISrRiE4MYhKL2MQhLvGI
TwISkojEJCEpyUhOClKSitSkIS3pSE8GMpKJzGQhK9nITg5ykovc5CEv+chP
AQpSiMIUoSi/UYzilOB3SlKK0pShLOUoTwUqUonKVKEq1ahODWpSi9rUoS71
qE8DGtKIxjShKc1oTgta0orWtKEt7Qhc3h3oSCc604WudKM7PehJL3rTh770
oz8DGMggBjOEoQxjOCMYyR+MYjRjGMs4xjOBP5nIJCYzhalMYzozmMksZjOH
ucxjPgtYyF/8zSIWs4Sl/MO/LGM5K1jJKlazhrWsYz0b2MgmNrOFrWxjOzvY
yS52s4e97GM/BzjIIQ5zhKMc4zgnOMkpTnOGs5zjPBe4yCUuc4WrXOM6N7jJ
LW5zh7vc4z4PeMgjHvOEpzzjOS94ySte84a3vOM9H/jIJz7zha984zs/+Mkv
Ag9/EIISjOCEICShCE0YwhKO8EQgIpGITBSiEo3oxCAmsYhNHOISj/gkICGJ
SEwSkpKM5KQgJalITRrSko70ZCAjmchMFrKSLej//8x/NYkHxQ==
             "]]}, 
           RowBox[{
             RowBox[{
               RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    TagBox["x", HoldForm]}], ")"}], "2"], " ", 
                 RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox[
                    TagBox["x", HoldForm], "2"]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox[
                    TagBox["y", HoldForm], "2"]}], ")"}], "2"]}], "\[Equal]", 
             "0"}]], Annotation[#, (-2 + HoldForm[$CellContext`x])^2 (-4 + 
              HoldForm[$CellContext`x]^2) + (-4 + 
              HoldForm[$CellContext`y]^2)^2 == 0, "Tooltip"]& ]}}], {
      DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
       AxesOrigin -> {0., 0.}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, AxesLabel -> {None, None}, 
       FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> 
       Identity, AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> 
       Identity, Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> Small, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
       PlotRange -> {{-4, 4}, {-4, 4}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
     "\"Bicuspid Curve\""}, "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )],TemplateBox[{
     GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJxdmXdUVFcXxQc1scagiUEidoMliF0+GwexgAV77LFHLNiwYqLBLmAFVFQS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       "], {{{}, {}, 
         TagBox[
          TooltipBox[{
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[1.6]], 
            LineBox[CompressedData["
1:eJwl1FV4EAQUBeANNjZ6GzEYOTqkGwHpkG6RLukuJSWUUBoEg+4GQeluFEFp
lO5OKQH59/Hwn/t4ns6NbtWtTtfAgICA9CLmxiI2QQQThxBCiUs84pOAhCQi
MWGEE0ESkpKM5ESSgpREkYrUpCEt6WL6iSYDGclEZrKQlWxkJwc5+YBc5CYP
eclHfgpQkEIUpghFKUZxPqQEJSnFR5SmDGUpR3kqUJFKVKYKH1OValSnBjWp
RW3qUJd61KcBDfmERnxKY5rQlGY0pwUtaUVr2tCWz2hHezrQkU50pgtd6UZ3
etCTXvSmD33px+d8QX8GMJBBDGYIXzKUYQxnBF/xNSMZxWjG8A3fMpZxjGcC
E5nEZKYwle+YxnS+5wd+5CdmMJNZzGYOc5nHfBawkEUsZglLWcZyVrCSVaxm
DT+zlnX8wq+sZwMb2cRmtrCVbWxnBzvZxW72sJd97OcABznEb/zOYf7gCEf5
k784xnFOcJJTnOYMZ/mbfzjHeS5wkUtc5gpXucZ1bnCTW9zmDne5x30e8JBH
POYJT/mXZzznBS95xX+85g1v+Z+Y8QcSi9gEEUwcQgglLvGITwISkojEhBFO
BElISjKSE0kKUhJFKlKThrSkC3z/f94BLbKDhg==
             "]], 
            LineBox[CompressedData["
1:eJwV0OeDDwQAgOGfnU2n7HHctO7svfdIHCIlkr333ntTtorMsiojRTYhm7L3
3ntvjw/P+we8wU06xLSPFQgEgiSYrGQjhFDCCCeCSLKTg5zkIjdRRJOHvOQj
PwUoSCEKU4SiFKM4JShJKUpThrKUozwVqEglKlOFqlSjOp9Qg0+pSS1iqE0d
6vIZ9ajP5zTgC76kIV/RiMZ8TRO+oSnNaE4LWtKK1rShLe14P68DHelEZ7rQ
lW50pwc96UVv+tCXfvRnAAMZxGCGMJRhDGcEIxnFaMYwlnGMZwIT+ZbvmMRk
pjCVaUxnBjP5nh/4kVnM5ifmMJd5zGcBC/mZX1jEYpawlGX8ym/8znJWsJJV
/MFq/uQv1rCWv1nHejawkU1sZgtb2cY/bGcHO/mXXexmD3vZx34OcJBD/Mf/
HOYIRznGcU5wklOc5gxnOcd5LnCRS1zmCle5xnVucJNb3OYOd7nHfR7wkEc8
5glPecZzXvCSV7zmDW8JxA4EYhGbOMQlHvFJwAckJBGJSUJSkpGcFKTkQ4JI
xUd8TGrSkJZ0pCcDGclEZrIQTFayEUIoYYQTQSTZyUFOcpGbKKLJQ17y8Q6l
DYWt
             "]]}, 
           RowBox[{
             RowBox[{
               SuperscriptBox[
                TagBox["x", HoldForm], "4"], "+", 
               RowBox[{"4", " ", 
                 TagBox["x", HoldForm], " ", 
                 TagBox["y", HoldForm]}], "+", 
               SuperscriptBox[
                TagBox["y", HoldForm], "4"]}], "\[Equal]", "0"}]], 
          Annotation[#, 
           HoldForm[$CellContext`x]^4 + (4 HoldForm[$CellContext`x]) 
             HoldForm[$CellContext`y] + HoldForm[$CellContext`y]^4 == 0, 
           "Tooltip"]& ]}}], {
      DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
       AxesOrigin -> {0., 0.}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, AxesLabel -> {None, None}, 
       FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> 
       Identity, AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> 
       Identity, Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> Small, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
       PlotRange -> {{-2, 2}, {-2, 2}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
     "\"Lemniscate\""}, "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )],TemplateBox[{
     GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJxdWHk8lWn7lxnpV5RMNC0mrVpkQqlULvESyVhqMkQzNdFEqSGnRrSvUiGj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       "], {{{}, {}, 
         TagBox[
          TooltipBox[{
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[1.6]], 
            LineBox[CompressedData["
1:eJwl1FV0EAQYBeCNGqNrdI3a2OjuEaM7JaRbUiSku9ugu0uRRqWUTgVFpZQS
kEal89vh4bv/+z3n/qHtejXoGRgQEFBPxNxYxCYOcYlHEPEJJgEJSURikpCU
ZCQnBSlJRQipSUNa0pGeDGQkE5nJQlZCyUZ2cpCTXIQRTm4iiCQPeclHfgpQ
kEIUpghFKUZxSlCSUpSmDGUpRxTlqUBFKhFNZapQlWpUpwY1qUVt6lA3pj/q
04CGNKIxTfiApjSjOS34kJa0ojVtaEs72tOBjnSiM13oykd0ozs96EkvevMx
ffiEvvSjPwP4lIEMYjBDGMowhjOCkYxiNGMYyzjGM4GJTGIyU5jKNKYzg5l8
xud8wZfMYjZzmMs85rOAhSxiMUtYyjKWs4KVrGI1a1jLOtazga/4mo18wyY2
s4WtbGM7O9jJt3zH9+xiN3vYyz5+4Ef2c4CDHOIwRzjKMY5zgpOc4id+5jRn
+IVfOctv/M4fnOM8F7jIJf7kLy5zhatc4zp/c4Ob3OIfbnOHu9zjPg94yCP+
5T/+5zFPeMoznvOCl7ziNW94S8z4A4lFbOIQl3gEEZ9gEpCQRCQmCUlJRnJS
kJJUhJCaNKQlHenJQEYykZksZCWUbGQnBznJRRjh5CaCSPKQl3zkpwAFKURh
ilCUYhSnBCUpRWnKUJZyRFGeClSkEtFUpgpVqUZ1alCTWtSmDnUD3//Pd2Vr
jn4=
             "]]}, 
           RowBox[{
             RowBox[{
               RowBox[{"6", " ", 
                 RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox[
                    TagBox["x", HoldForm], "2"], "+", 
                    SuperscriptBox[
                    TagBox["y", HoldForm], "2"]}], ")"}]}], "+", 
               RowBox[{"3", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    TagBox["x", HoldForm], "2"], "+", 
                    SuperscriptBox[
                    TagBox["y", HoldForm], "2"]}], ")"}], "2"]}], "+", 
               RowBox[{"8", " ", 
                 TagBox["x", HoldForm], " ", 
                 RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox[
                    TagBox["x", HoldForm], "2"]}], "+", 
                    RowBox[{"3", " ", 
                    SuperscriptBox[
                    TagBox["y", HoldForm], "2"]}]}], ")"}]}]}], "\[Equal]", 
             "1"}]], Annotation[#, 
           6 (HoldForm[$CellContext`x]^2 + HoldForm[$CellContext`y]^2) + 
            3 (HoldForm[$CellContext`x]^2 + HoldForm[$CellContext`y]^2)^2 + (
              8 HoldForm[$CellContext`x]) (-HoldForm[$CellContext`x]^2 + 
              3 HoldForm[$CellContext`y]^2) == 1, "Tooltip"]& ]}}], {
      DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
       AxesOrigin -> {0., 0.}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, AxesLabel -> {None, None}, 
       FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> 
       Identity, AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> 
       Identity, Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> Small, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
       PlotRange -> {{-2, 2}, {-2, 2}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
     "\"Hypocycloid\""}, "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.711800555736668*^9, 3.713807714961342*^9, 
  3.73789117997683*^9, 3.7378913947001963`*^9, 3.737892418096725*^9, 
  3.737893523100758*^9, 3.737893965083294*^9, 3.742658535926667*^9},
 CellLabel->"Out[32]=",
 CellID->2004537785,ExpressionUUID->"1b6d541f-22b4-4202-8752-f417c36adaca"]
}, Open  ]],

Cell[TextData[{
 "Three more singular curves are plotted below. The first two curves do not \
look singular but, in fact, are at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"76da8731-01d7-4009-8994-f3f42e2a9d2e"],
 ". The more interesting part of these singularities is hidden in the complex \
plane. The third curve has an isolated, hence singular, point at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"0062d272-c6e5-43a0-a30e-50be187c895d"],
 ". In fact, for technical reasons such as not allowing reducible curves to \
be nonsingular, a curve will be called ",
 StyleBox["nonsingular",
  FontSlant->"Italic"],
 " only if there are no infinite or complex singular points as well as no \
affine real singular points. We will go into more detail in Chapters 3, 5, 6, \
and 8."
}], "Text",
 CellChangeTimes->{{3.685289480835447*^9, 3.685289617107182*^9}, {
  3.685289658133827*^9, 3.685289659045783*^9}, {3.686736500958513*^9, 
  3.686736654015805*^9}, {3.686736886783734*^9, 3.6867368890636*^9}, {
  3.686737023210983*^9, 3.686737078740954*^9}, {3.686737112483653*^9, 
  3.686737116451843*^9}, {3.7010086516758947`*^9, 3.701008651726253*^9}, {
  3.7010146436902122`*^9, 3.701014649620826*^9}, {3.702655245579788*^9, 
  3.702655246002738*^9}, {3.7028380043681087`*^9, 3.702838011573427*^9}, {
  3.708426390517933*^9, 3.7084263972727327`*^9}, {3.7084264884535327`*^9, 
  3.708426498577933*^9}, {3.739290714056733*^9, 3.7392907523507333`*^9}},
 CellID->1977079031,ExpressionUUID->"b87e4132-9d4b-42dc-9f39-36e721248b20"],

Cell["Here are more singular curves:", "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{{3.70904879285091*^9, 3.709048802520877*^9}},
 CellID->4559691,ExpressionUUID->"6c06f6c9-bc36-4417-9f16-d742a8799bcc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"ContourPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"x", "^", "4"}], "+", 
          RowBox[{
           RowBox[{"x", "^", "2"}], 
           RowBox[{"y", "^", "2"}]}], "+", 
          RowBox[{"y", "^", "4"}]}], "\[Equal]", 
         RowBox[{"x", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", "^", "2"}], "+", 
            RowBox[{"y", "^", "2"}]}], ")"}]}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", ".5"}], ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
      "\"\<Bean Curve\>\""}], "]"}], ",", 
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"ContourPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "^", "3"}], "\[Equal]", 
         RowBox[{"x", "^", "6"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "2"}], ",", "6"}], "}"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
      "\"\<Smooth Singular Curve\>\""}], "]"}], ",", " ", 
    RowBox[{"Labeled", "[", 
     RowBox[{
      RowBox[{"ContourPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"6", "+", 
          RowBox[{"9", 
           RowBox[{"x", "^", "2"}]}], "-", 
          RowBox[{"8", 
           RowBox[{"x", "^", "4"}]}], "-", 
          RowBox[{"7", "y"}], "+", 
          RowBox[{"9", 
           RowBox[{"x", "^", "2"}], " ", "y"}], "-", 
          RowBox[{"3", 
           RowBox[{"y", "^", "2"}]}], "-", 
          RowBox[{"8", 
           RowBox[{"x", "^", "2"}], 
           RowBox[{"y", "^", "2"}]}]}], "\[Equal]", "0"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"x", " ", ",", 
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
      "\"\<Heart Curve\>\""}], "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.686736879535702*^9, 3.686736933352382*^9}, {
  3.686736981937235*^9, 3.686737006770629*^9}, {3.686737122426345*^9, 
  3.686737345305259*^9}, {3.686737378088319*^9, 3.686737501156693*^9}, {
  3.686737532755106*^9, 3.686737544177912*^9}, {3.686737598971013*^9, 
  3.686737649858852*^9}, {3.686737750696177*^9, 3.686737777496015*^9}, {
  3.7093040822044363`*^9, 3.709304097251566*^9}, {3.737891415878531*^9, 
  3.737891456696723*^9}},
 CellLabel->"In[33]:=",
 CellID->752803986,ExpressionUUID->"62a2f894-240a-43f3-96be-686dec8d1041"],

Cell[BoxData[
 TemplateBox[{TemplateBox[{
     GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJyFWHk0lWsXNxQpTVJ9oVAabgOiVFxtUobSqDRQaUJIotS9pUup60qlTJUm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       
       "], {{{}, {}, 
         TagBox[
          TooltipBox[{
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[1.6]], 
            LineBox[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTnarlpZbtm3bXubClrFl27Zbdi3bWrVVy73n6eL9
/tvv5vuDm3Ss0iEwICAgtQi5oQhNGMISjvBEICKRiEwUohKN6MQgJrGITRzi
Eo/4JCAhiUhMEpKSjCCSE0wKUpIqpBNpSEs60pOBjGQiM1nIyg9kIzs5+JGc
5CI3ecjLT+QjPwUoSCEKU4Si/EwxilOCkpSiNGUoSznKU4GKVKIyVahKNapT
g5rUojZ1qEs96tOAhjSiMU1oSjOa04KWtKI1bWhLO9rTgY50ojNd6Eo3utOD
nvSiN334hb70oz8DGMggBjOEoQxjOCP4lZGMYjRj+I3fGcs4xjOBiUxiMlOY
yjT+4E+mM4OZzGI2c5jLPOazgIUsYjFLWMoylrOClaxiNWtYyzrWs4GNbGIz
W9jKNrazg53sYjd72Ms+9nOAgxziLw5zhKMc4zgnOMkpTnOGs5zjPBe4yN9c
4jJXuMo1rnODm9ziNne4yz3u84CHPOIxT3jKM57zgn94ySte8y//8Ya3vON/
3vOBj3ziM1/4Ssj4AwlFaMIQlnCEJwIRiURkohCVaEQnBjGJRWziEJd4xCcB
CUlEYpKQlGQEkZxgUpCSVIHff9I3k/uEPw==
             "]]}, 
           RowBox[{
             RowBox[{
               SuperscriptBox[
                TagBox["x", HoldForm], "4"], "+", 
               RowBox[{
                 SuperscriptBox[
                  TagBox["x", HoldForm], "2"], " ", 
                 SuperscriptBox[
                  TagBox["y", HoldForm], "2"]}], "+", 
               SuperscriptBox[
                TagBox["y", HoldForm], "4"]}], "\[Equal]", 
             RowBox[{
               TagBox["x", HoldForm], " ", 
               RowBox[{"(", 
                 RowBox[{
                   SuperscriptBox[
                    TagBox["x", HoldForm], "2"], "+", 
                   SuperscriptBox[
                    TagBox["y", HoldForm], "2"]}], ")"}]}]}]], 
          Annotation[#, 
           HoldForm[$CellContext`x]^4 + 
            HoldForm[$CellContext`x]^2 HoldForm[$CellContext`y]^2 + 
            HoldForm[$CellContext`y]^4 == 
           HoldForm[$CellContext`x] (HoldForm[$CellContext`x]^2 + 
             HoldForm[$CellContext`y]^2), "Tooltip"]& ]}}], {
      DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
       AxesOrigin -> {0., 0.}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, AxesLabel -> {None, None}, 
       FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> 
       Identity, AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> 
       Identity, Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> Small, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
       PlotRange -> {{-0.5, 1.5}, {-1, 1}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
     "\"Bean Curve\""}, "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )],TemplateBox[{
     GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJyFWXlYTun7f5d2lbytlobJIKnsI6L7IS3GHiZbdqaxRFFpLEkZMUNU9l32
TBFCludYSpIS2UraQzXt+9vynXnv+8x1/f769c+5TnXOeZ77uZfP8v2StW7L
ZRKJhEslkn+vK/1ux/4WIWcS1Y8Zc+qeWHg3TM5SJmduaq8wZR/j12THr5Gz
l/GVSSkHTVm3P/pNvrhAzhJS95118DVlW+f2iHSbJ2fZqv8zZWkbQqLG/Sxn
74wDeOtiU9Yv3+UUt5cz1/AfJoT/YMpsdN03t1vJme6TFSXPW02Yc3n3l9U9
5Ez1eLYJ8zBIvtlFS842Hg3tfeySCVMv14lWNslY667frLYHm7D108Iyj+XL
2P5/XzfBhN1UPSdj389ZuHbqSBMW2Zwwe0SSjOmPMhh4TMeE+dmPeyBJkLHc
FUODJ1Qasxi5vqB5RsZWqxZszCY0hK312S9jYT6GgTfDjZlGrEPAyV9lLNj9
1Oj0Ycasz77uyS+XyGj9xqwxxH7f+gUyZrxkQEppV2O2T7UOGcvovGr7o2Ij
9tqpX/Xw8TLajxE7u6fkz7D+MnY00vGi4VkjtuXQWrORFjLW+9/Hwo1YRcyG
6Z9MZMxN31KtT4AR8yq9apJcK2WdzdPGxFgZMcs1dgM186WsvePfH0PmqT/w
zJOnUlZa57Mz/YEhu79UElTKpWy8qaJoRpwhO2Z1PavnQSnLUi3AkKlHeb9b
Eyplm2yfGT23N2Red16Uua2WsueSgVpTOhSMlejdWe4upfUqmJq17FbidCn7
cLpckvlUwZy6Tj8M9lKm2ma4grmo4iBlnx2tnNI9FCy7fV6UVQ8pc/GyWT57
soId1O7hrd5NSuejYLecZ57bYyJlye15YDFOwXZ6P3ifWS+h/XRh6/ZGfX+w
QMLcPfyDPr7vwlbP0H6Q+FpC59OFZW1do6ufIGHx0+dNPRLUhdVERoW+uSah
/XVhBlfnCiOjJWzpjl17HBZ3YRaqdUpYwtIbzrf7d2E79h322B0mofPrwv5W
OJ4385GwDK3ghh1lBqz24RqDlF8ltH8DVnTSeezM+RJ26PBwp/WCAbv4Ymje
RCcJ7d+Adat+2z95pIQdnHax83JfA1Z2vWSL70AJC90yenruIgN22cTZXcdC
wlSfm2BAdSWhqwHrwB/A/XemOHRAG9230n0T3a8PqtLYeL0DcL+d2VPfmFO+
OzogY4jalzizzmzisQfND5Z3wC3V+vWZcemfTpuGdMCjgjNzojfos4TZaSlP
e3QA5qk+e5f07Cdzg3++3+iWnGqrz26onmuHfr1CB/Z8pMfWBJff3vq2HTD+
eqwwzGlz7Jt2CClfNa01To8Z3z90YuWRdjBdlfQ2wkmPLdn+w8OeIe2A8dVj
L3SHTDNc1Q6Z+enGy8t1mVmKReoYj3aoPlrRdXGGLivbEZGdP7wdMP912RtN
9vp0z3aoiJvsU+Khy25t2+lqIm2HKDfPNeZ9dNnN6QbzbpW2Ubw6sZWqdbWB
l1fG+OKDndjrH8+9LYlqg77a/v0G+3diLmn9+48+2Ubx6sQ2biw0+DmyDRar
q9lsmN+JCXYZo91/agM8bx3m/CRp7BWLNogaNNZyTIQO09FJ16tubgXMXx1W
ILPV2xLfCpPvqC2pT9ZmPQ5dDm+42krx0WZHTzsvPXKxFWJj508ZelWb9VLt
qxU8Eza5ZQdps24a9w5UzW6l+Giz/KU/r9jVuxWe2F+TX36uxb7p7xsuk7cC
5pcWi47cEzbohRK+VXTOum+rxY50+uWA8poSMC002QRNI/MXZ5WQ9N4617dY
k71XbUQJOSG+YbbbNdmnANeS0YuUtH9NdiV0httJcyWkhngqA+SaTE2/y+wg
NSXtX4NdthmxKeV9C/TsL/zuv0+D2TVNM4O/WgDzV4O1d+mIdDraAlk2FQaR
vTRYwImplyqWtEChacJG4Yk6C9FW7JgztwVUr4tXZ3tVz7XAcZ+l+lkH1Vli
xzD5t84t8Ne5GINBY9VZuDTwREprM8VDnXkqptxf97EZhmv3W3CnXI2Nc3/S
Z+jpZoqHGqtsamo8tbMZ0o0tJz9epMb0UrdnKuY3Q1GPWCehuxr7euHW6eOu
zYD1pcbGq97bDJ6NDxaMF+TMPy9Uc2ZzEzwOs2+dFSxnRiPH3FF+a4JsmmvR
rm0jNN80gb4iy616vJz9OKstKe1GE4zRrfRPN5SzuNu7rc1CmyheMmaVPFnr
86omOLXrZtzW8zI29nCOJMKpCW5V3VZUrPrn7xU6rg0Dmih+MqZUnVsj9JE4
pL9rl7IrUxamxn9oBNNhOzW3pUjZcJPBk5ueN4KXakFS1vPoogNRVxthm+Uv
djZ7pOxl3We55tJGmEB91/ivVct8xjbCIZ/5NWHVEmY9KH/mXVkjxUvC4lTr
bICRSTa/zXKTMOPC24kxMQ0wJXH/xoUmEuYZM5X/drQBxD5UfcuicuqWBnBw
dbErONMBlQuZw8olDRCwyW+g98wOMAvKC9Ee2ED7b4dB0QOqtho1QOWJFcNS
trTD4fSd8Skf6uGY6toG1v6/G49/UU/10Qa/qq71kGjltXmkXxuYzFd3sPav
B79kx5lNGa0QNH24u/2ceuoHrdDx6tMxV5t6uOtwxy1eqxV+HN5med2yHnQ9
+vXKVyqh38c+0yeV1lF+KyHKydN815s6cE84VOBnrQSsvzrYda3BbLV3Cyyp
H2zzILCO6rkFvlsdMmaSbx2EudhH97NuAVvPQdbhQ+pg1Prfx04IaYa0ZyHO
Dmp1lJ/NkHJ9Fu8fXQs1LV8KfcY0AeKlWopfI1QqP2rF7KqFLwkRr7WKGgHr
sRZSXD91jIxshLE262++M6ml+DVA6oNOW94U18DVDQGzd89ogN6zzjwqzK2B
78cE74wZ3wAnPzz9uuRoDdVTPWA91cCChw/TLhfUwctjF4pjbWugOGNYxoOr
/6zT83moac8aOv86qNydl2bYUg07YvsvtnOsg+MqPFBN+V4LEYd+zRc2VMOe
65aOoea14KTaZzUY7ZytyJtfAz+FGY4171pN+VsDtp1nVEsMqmHzGf9REcNq
wL7nkFN7H1bBDHXT2gO7q+GhVsCsocFVlJ/VMK13qsOIhVVQ5zVbZ15iFchV
dVkFGnTFuFX+d22jawtdm+haSddJqvlWSfGrgLeXPepc7CohbPCcgIitFdCy
sbhD+14F5dvfIO1aN2D6ugrIOBEQu7ytHFbQ7yfmXHL2jiyDpR7f2SQf+5vy
pwwGV0kH3dj6N5x/cefE3uFlsNp5p/ntd+Uwrt/MI/FqpXDGdNSgoLHllA/f
wGFSel5feTnktD52tAj7Cm/oPT/MMRo1w/8LJM19FhhtUwZPngcpArp/gaFO
rme+ay6l9ZdAzV+Nf9SzUni3bPkvV2OK4X1E5g+vw7/R+RWB5bD3m//0+gaj
L+ZWTXEtAkbfrR2lHOd1vRDs+vlZZu35CkfCGuM+5RbAglS1dTv0v1J+F8BY
o7/Xm5//Au1bRrzdEJgPMfTdu3F+9sN+yoOQSbbtMbdLoP/3f9152DsPtr8o
kLftL6H5mgvPTS4vSm8thmFux2Y8GfcZrmYmme19Ugyfvx409TuRA+6bHeNS
PhcB8oJs+Fhi+1zzWREs3DQsfKRaNvSgfSy1nVhxaEoWrBwS9MLraSGYHWvz
tPD/ALxs16PMpgJA3P4OUjqnnS9OKIChhzLCyhrfwm7ax7XsAdbmFzKh+62e
vXZczgcv+XG/paFv4Ir+hMwHpXmEZ17DwWXXx3iE5cHMeSUmK60yoIr2Eegb
3L9mTjrE7huXVvjuM8w58NWhkr8EjyH6laWDc6hOX4Ds5rzFcwI+wcr7+9O9
f34OL2hft/VPHR58MglC5HdfecqzoNsfcRcF80S4vOrQKZ2U91SXj+EC7WPA
qbhfZv/5EKI+NiS2V2XC4Q3Zs/Jq7sJ2Wudr3VdvzobfAP2Hzqfs1r+ifcbB
zOy523/zToO4+JzQUcGX4B6ty+zkILv9XhHgaP20avD+x2BX++iku3wJ+NB3
pZub5x+eOA9CB5VqPzN8DBa1AQOfxswFN3pvYWvTP39XOuBcfHUfr6fv/3/3
r/F5Pl/arHr+Cb6fO9bj++Pw+3z0Vvz+blwfb6vD9Slx/dzyFK5/A+6PD7qN
+9PA/XNx/2cxPryF4nML48dfUfySML78EsX3Gsafi/E/gOfD7eh8yvD8eDWd
nwLPl++i812I58/F8+eYHzyA8kNLFYc8zil/TmJ+8WWUX9GYf1zMPwvMTx5I
+XkU85e/pfx9jfnNnSi/Bcx/Lua/N9YHt6L6eKmaP0XcWVX3H8Ea64lbDql+
6LsiC/Kw3rg31RvOwyIu1qOvqt8V862DJ0rOrc+BG1i/vIrq9zzWN0+djvW9
Feufi/W/G/sDH0r94SH2D55G/cMF+wvX2or9hfoPF/sPYH/iZ6k/TcP+xfXs
sX+tefdoabzPN66pXq/dZ3wRIN77xsX+h/Er5Yr7X6+0HiiGtfUTa9bOLOWH
dW7q7YsuhkKzpinjfUp5fPpyK2VuMchVeLaMi/01Ffsvf0n9txD7Mwfqz47Y
v/lX6t9mKnxezsX+jvEu5+HHXe4kB34Db5wHfBLNg244L3ggzYtFOE+4OE/8
cN7wFTRvNHAe8U80j2hecXFeZeM840dpntXh3ONl/3dOcnFeSnGOchnNUzW6
16R7msdcnMdV3ff65d6t4he07nV3CqsGV5zvXJzvk/H/eB+a/wcQH/AIwgeE
H7iIH74gvuC+hC9cEH9wEX+8QnzCSwmfHMTv8HWEXwjfcBHf9EX8w/sS/klG
fMRPEz5iiJ+4iJ9ycR38M+GrGsRfvJzw1yrEZ1zEZ0mI33gJ4TfCd1zEd4MR
/3Eg/GeG+JAHET5cjPiRi/jREvfJjxO+PI/4k3sQ/iR8ykV8aof4lSsIv7Yi
vuUxhG+3If7lIv41Q3zMNxM+9sY48RzCz4SvuYivIxF/8zDC30MQn/N6wueE
37mI36sR3/NAwvcViP/5EML/xA+4yA9MkT/w6cQfEvAc+HjiFzbIP7jIP0yR
n/CjxE+Iv3CRv3RDfsMDiN8Q/+Ei/4lGfsS7ET9C/NjEBxN/GoD8iov8agzy
Lx5L/Msa+Rk/S/yM+BsX+Zsd8jvOiN9dRP7HtYj/GSI/5CI/DED+yBOJP07C
vOG+xC+/If/kIv9MVCqm3Q5u5p5G3c/EL/mPz3KRzy5DvssHEt8lPsxFPpyE
fJlfI76M9dPCLxOf3oF8m4t82x/5OM8hPi5RqPg6zyG+Tnyei3zeQnogoOhz
C18XOPzJnn/4/vOLWnHn8lv4gBLLs8sOaIj6ABf1AYcY+Z7gXkqu4WOwQFOm
yeasdr+yfJ6SH9pfMG7vsv/0Bi7qDVifSl5KesS2apfeueeUPLZA8WlVkaao
Z3BRz7iEegcvIr2jAPUR/oz0ka6on3BRP8H6a+V+pK8cR/2Fx5H+Yo76DBf1
mVzUb7gr6Tek73BR33FF/YdfIP2H9CEu6kPrUT/i80g/In2Ji/pS7sgqrz/P
tfEozYy5n/06MR+sS76F9KmQm46lbflt3Dfi7iOv0k6insVFPSsO9S5+kvSu
t6iH8WrSw0gv46Je1hX1NF5Heloy6m08nfQ20uO4qMeZol7Hu5Fel4d6Hg8k
PW816n1c1PvuYZ/gP5Ie+AH1Qi5tQr3wHuqJXNQTDVFv5PdJbyQ9kot6ZCLq
lTyT9Eof1DO5qGci/+vgLaR3Ut/hoj5K+qkg6qcyuleje9JbBVFvrU/NvPdu
hESILriY5OH3n34riPptAeq7QiTpu6T/CqL+W4H6sPCa9GHSjwVRP+6LfU54
TPqyAvVnYRnpz6RXCzdJryY9WxD1bG/Uu4U5pHffRH1cSCJ9nPRzQdTPP6G+
LkwgfX0i9lGhhPR30ucFUZ9XR/1e+Ej6Pen7gqjvr0H9X3hG+j/5A8IW8gfW
bj7YrfNpqSD6B+uwLwvz1px32XL8P79BcCa/4Rf0I4Sv5EeQXyGIfsVa9DME
A/Iz/ka/Q5hKfgf5IYLoh0ShXyIcJ7+E/BRB9FMise8LWeS3NKEfI5iQH9MX
/RpB9GvU0c8RtpGf8xP6PcJ+8nvIDxJEP8gX/SIhh/yiA+gnCQbkJ93BOSJY
kd9EfpQg+lEa6FcJbeRXzUc/S/AjP4v8LkH0u2zRDxP0yA97if6Z8Ib8M/LX
BNFf647+m3Cf/LccnFPCe/LnnNG/E1LJv0M8JBdEf+9/vLLCrQ==
       "], {{{}, {}, 
         TagBox[
          TooltipBox[{
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[1.6]], 
            LineBox[CompressedData["
1:eJwl1fOfEAYYBvC7LtvWZdu2edl1mZfty7Zt2/YYx9yW28JWW9hq+96nH77P
+xc8zxscGhbSKzAgIOCkiLiRCCIyUYhKNKITg5jEIjZxiEs84pOAhCQiMUlI
SjKSk4KUpCI1aUhLOtITTAYykonMZCEr2chODnKSi9zkIS/5yE8BClKIwhSh
KMUoTglKUorSlKEs5ShPBSpSicpUoSrVqE4NalKL2tShLvWoTwgNaEgjGtOE
pjSjOS1oSSta04a2tCOU9nSgI53oTBe60o3u9KAnvQijN33oSz/6M4CBDGIw
QxjKMIYzgpGMYjRjGEs44xjPBCYyiclMYSrTmM4MZjKL2cxhLvOYzwIWsojF
LGEpy1jOClayitWsYS3rWM8GNrKJzWxhK9vYzg52sovd7GEv+9jPAQ5yiMMc
4SjHOM4JTnKK05zhLOc4zwW+4Eu+4mu+4VsuconLXOEq1/iO7/mBH/mJn7nO
DW5yi9vc4S73+IVfuc8DHvKIxzzhKc/4jd95zgte8oo/+JPXvOEv/uYt73jP
B/7hXz7yif+IKH8gkQgiMlGISjSiE4OYxCI2cYhLPOKTgIQkIjFJSEoykpOC
lKQiNWlISzrSE0wGMpKJzGQhK9nITg5ykovc5CEv+chPAQpSiMIUoSjFKE4J
SlKK0pShLOUoTwUqUonKVKEq1ahODWpSi9rUoS71qE8IDWhIIxrThKY0ozkt
aEkrWtOGtrQjlPZ0oCOd6EwXutKN7vSgJxHjHUZv+tCXfvRnAAMZxGCGMJRh
DGcEIxnFaMYwlnDGMZ4JTGQSk5nCVKYxnRnMZBazmcNc5jGfBSxkEYtZwlKW
sZwVrGQVq1nDWtaxng1sZBOb2cJWtrGdHexkF7vZw172sZ8DHOQQhznCUY5x
nBOBn3/f/6dNylQ=
             "]]}, 
           RowBox[{
             SuperscriptBox[
              TagBox["y", HoldForm], "3"], "\[Equal]", 
             SuperscriptBox[
              TagBox["x", HoldForm], "6"]}]], 
          Annotation[#, HoldForm[$CellContext`y]^3 == 
           HoldForm[$CellContext`x]^6, "Tooltip"]& ]}}], {
      DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
       AxesOrigin -> {0., 0.}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, AxesLabel -> {None, None}, 
       FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> 
       Identity, AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> 
       Identity, Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> Small, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
       PlotRange -> {{-4, 4}, {-2, 6}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
     "\"Smooth Singular Curve\""}, "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )],TemplateBox[{
     GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJxdWXlczdn7v+2WZB1LhrGEhKEkNHhmRkkGmaIoS9mXFlsYy5AYEcoyvlSk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       "], {{{}, {}, 
         TagBox[
          TooltipBox[{
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[1.6]], 
            LineBox[CompressedData["
1:eJwl1fN/EAgYBvCtZdu1lm3b5rJrmcttuS3btm3buot3dTZyd3Wsu7r77tMP
3+f9C57nDQkLDx0YGBAQcF3E3FgEEZs4xCUe8UlAQhKRmCQkJRnJSUFKUpGa
NKQlHenJQEYykZksZCWYbISQnRzkJBe5yUNe8pGfAhSkEIUpQlGKUZwSlKQU
pSlDWcpRngpUpBKVqUJVqlGdGtSkFrWpQ13qUZ8GNKQRjWlCU5oRSnNa0JJW
tKYNbWlHezrQkU50pgtdCaMb3elBT3rRmz70pR/9GcBAwhnEYIYwlGEMZwQj
iSCSUYxmDGMZx3gmMJEoopnEZKYwlWlMZwYzmcVs5jCXecxnAQtZxGKWsJRl
LGcFK1nFatawlnWsZwMb2cRmtrCVbWxnBzvZxW72sJd97OcABznEYY5wlGMc
5wQnOcVpznCWc5znAhe5xGWucJVrXOcGH/AhN7nFbe5wl3t8xMfc5wGf8Cmf
8Tlf8CVf8TXf8C3f8T0/8CM/8TMPecRjnvCUZzznBb/wKy95xW/8zh/8yV/8
zWve8A//8pZ3/EdM+QOJRRCxiUNc4hGfBCQkEYlJQlKSkZwUpCQVqUlDWtKR
ngxkJBOZyUJWgslGCNnJQU5ykZs85CUf+SlAQQpRmCIUpRjFKUFJSlGaMpSl
HOWpQEUqUZkqVKUa1alBTWpRmzrUpR71aUBDGtGYJjSlGaE0pwUtaUVr2tCW
drSnAx3pRGe60JUwutGdHvSkF73pQ1/60Z8BxIx3OIMYzBCGMozhjGAkEUQy
itGMYSzjGM8EJhJFNJOYzBSmMo3pzGAms5jNHOYyj/ksYCGLWMwSlrKM5axg
JatYzRrWso71bGAjm9jMFrayje3sYCe72M0e9rKP/RzgIIc4zBGOcozjnOAk
pzjNGc5yjvNc4CKXuMwVrnIt8P2P/B82UtIV
             "]]}, 
           RowBox[{
             RowBox[{"6", "+", 
               RowBox[{"9", " ", 
                 SuperscriptBox[
                  TagBox["x", HoldForm], "2"]}], "-", 
               RowBox[{"8", " ", 
                 SuperscriptBox[
                  TagBox["x", HoldForm], "4"]}], "-", 
               RowBox[{"7", " ", 
                 TagBox["y", HoldForm]}], "+", 
               RowBox[{"9", " ", 
                 SuperscriptBox[
                  TagBox["x", HoldForm], "2"], " ", 
                 TagBox["y", HoldForm]}], "-", 
               RowBox[{"3", " ", 
                 SuperscriptBox[
                  TagBox["y", HoldForm], "2"]}], "-", 
               RowBox[{"8", " ", 
                 SuperscriptBox[
                  TagBox["x", HoldForm], "2"], " ", 
                 SuperscriptBox[
                  TagBox["y", HoldForm], "2"]}]}], "\[Equal]", "0"}]], 
          Annotation[#, 
           6 + 9 HoldForm[$CellContext`x]^2 - 8 HoldForm[$CellContext`x]^4 - 
            7 HoldForm[$CellContext`y] + (9 HoldForm[$CellContext`x]^2) 
             HoldForm[$CellContext`y] - 3 
            HoldForm[$CellContext`y]^2 - (8 HoldForm[$CellContext`x]^2) 
            HoldForm[$CellContext`y]^2 == 0, "Tooltip"]& ]}}], {
      DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
       AxesOrigin -> {0., 0.}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, AxesLabel -> {None, None}, 
       FrameLabel -> {{None, None}, {None, None}}, DisplayFunction -> 
       Identity, AspectRatio -> 1, AxesLabel -> {None, None}, DisplayFunction :> 
       Identity, Frame -> True, FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> Small, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True}, 
       PlotRange -> {{-3, 3}, {-4, 2}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
     "\"Heart Curve\""}, "Labeled", DisplayFunction -> (GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.711800555846418*^9, 3.713807758510326*^9, 
  3.737891180258465*^9, 3.737891457686799*^9, 3.7378924183945923`*^9, 
  3.737893523375412*^9, 3.737893965440465*^9, 3.74265853607207*^9},
 CellLabel->"Out[33]=",
 CellID->543098359,ExpressionUUID->"5b2a2a61-3607-43bb-bc15-af69784e301e"]
}, Open  ]],

Cell["Here are some curves of higher degree (code not given here):", \
"CodeCaption",
 CellChangeTimes->{{3.685289663934496*^9, 3.68528968939815*^9}, {
   3.685290930444755*^9, 3.685290943445024*^9}, {3.7090490883524575`*^9, 
   3.7090490890825305`*^9}, {3.71067620909538*^9, 3.710676226303623*^9}, 
   3.716034698578053*^9},
 CellID->1550428225,ExpressionUUID->"5d2311ea-566c-4aba-b616-c473fda8eda6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJxleXc8lt0f/30b90ADkcgeEQ2RSun6SHuLVF8apEdPWkpLg6SFSjS1F42n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       "], {{{}, {}, 
         TagBox[
          TooltipBox[{
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[1.6]], 
            
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
             188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 
             201, 202, 203, 204, 205, 206, 207, 208}], 
            LineBox[CompressedData["
1:eJwl0mW4DgYYBuDvqOkepo+OYdg000z31NQMG9Od023YprvbSk8z25h2nNAH
Rx/ddbv8uJ/373M91xvcpku9zkGBQOATccw9zglOcooQThNKGOFEcIaznOM8
F7jIJSK5zBWuEsU1rnODm9ziNneI5i73uM8DHvKIxzzhKc94zgte8orXvCGg
fxAxiEksYhOHD4hLPOKTgIQkIjFJSEoykpOClHxIKlKTho9ISzrSk4GMZCIz
wWQhK9nITg5ykovc5CEvH5OP/BQIer9/QQpRmE/5jCIUpRjFKUFJSlGaMnxO
WcpRngpUpBKVqUJVvqAa1alBTWpRmzrUpR71aUBDGvEljWlCU5rRnK9oQUta
0Zo2fE1bvqEd7enAt3xHRzrxPe+erwtd6UZ3etCTXvSmD33pR38GMJBBDGYI
PzCUYQxnBCMZxWjGMJZxjGcCE5nEj0xmClP5iZ/5hWlMZwYzmcVs5jCXecxn
AQtZxGKWsJRlLGcFK1nFatawlnWs51d+43f+4E82sJFNbGYLW9nGX2xnBzvZ
xW72sJd97OdvDvAP//IfBznE/xzmCEc5xnFOcJJThHCaUMIIJ4IznOUc57nA
RS4RyWWucJUornGdG9zkFre5QzR3ucd9HvCQRzzmCU95xnNe8JJXvOYNgRiB
wFtRqKz/
             "]], 
            LineBox[CompressedData["
1:eJwNwwdXiAEAAMCvKDLKCA0iKxklySwrezZtIauMopIVysoIURGRkCJblP5d
d+9dYnF5XllIEAQDhoQGQahDHGqY4Q5zuBGOcKSjHG2kUY5xrOMcb7QTnOgk
Y4w1zngnO8UEpzrNRKc7w5nOcrZJzjHZuc5zvgtMMdWFprnIdBeb4RKXuszl
rnClmWa5ytWuca3rzHa9G9zoJje7xa1uc7s73Okuc8w1z3wLLHS3e9zrPvd7
wIMessjDHvGoxR7zuCc86SlLLPW0ZzzrOcss97wXrLDSKi9a7SUve8WrXrPG
697wprXWecvb3vGu96z3vg986CMbfOwTn9roM5/bZLMtvvClrb7ytW2+8a3t
vrPD937wo51+sstuP/vFHr/6ze/+8Ke//O0fe/3rP/vs978DDgKpqUcU
             "]], 
            LineBox[CompressedData["
1:eJwNw/dazQEAANDfvReloSQJpW5WoohQkobKXtmjf3oAXqqniGSEKC0jIzIi
pJJKieKc7zvRhmt1V0NBEDTaFA6C696w2Zu2eMvb3vGurd7zvg9s86GPbLfD
x3baZbc99vrEpz7zuX2+8KWvfG2/b3zrgO987wc/OugnPzvkF7/6zWG/O+Ko
Y/5w3J9OOOmUv5x2xt/O+se/zjnvP4NIEIQMG3GBC11kjLEuNs54E0x0iUkm
u9QUl5nqctNcYborXeVqM8x0jVlmGzXHta5zvRvcaK6bzHOzW8y3wK1us9Dt
7rDIne5yt8WWuMdS91rmPsutsNIq91ttjbUe8KCHPOwRj3rM457wpKes87Rn
POs5z3vBi17ysles9z+9H1Fc
             "]]}, 
           RowBox[{
             RowBox[{
               RowBox[{
                 RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}]}], " ", 
                 RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], " ", 
                 RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], " ", "x", " ", 
                 RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], " ", 
                 RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], " ", 
                 RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}]}], "+", 
               SuperscriptBox["y", "2"]}], "\[Equal]", "0"}]], 
          Annotation[#, ((((((-(-3 + $CellContext`x)) (-2 + $CellContext`x)) \
(-1 + $CellContext`x)) $CellContext`x) (1 + $CellContext`x)) (
               2 + $CellContext`x)) (3 + $CellContext`x) + $CellContext`y^2 == 
           0, "Tooltip"]& ]}}], ImageSize -> 180, {
      DisplayFunction -> Identity, AspectRatio -> 1, DisplayFunction :> 
       Identity, Frame -> True, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], 
       Method -> {"DefaultBoundaryStyle" -> Automatic}, 
       PlotRange -> {{-5, 5}, {-15, 15}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
     "Hyperelliptic Degree 7"},
    "Labeled",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ),
    InterpretationFunction->(RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJxlWnlcTekbb9+zRoxtmsm+jyX7c2RnjCZirNn3yNjJnp1o1dgNBhVRSlSe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       "], {{}, {}, 
        TagBox[
         TooltipBox[{
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6], 
           LineBox[CompressedData["
1:eJwl1cMWIAYQBMC1bdu2bdu2bTtZ27Zt27Zt20pS+3Koni/onoSN2ldqFzBA
gAC/xZ8biMAEISjBCE4IQhKK0IQhLOEITwQiEonIRCEq0YhODGISi9jEIS7x
iE8CEpKIxCQhKclITgpSkorUpCEt6UhPBjKSicxkISvZyE4OcpKL3OQhL/nI
TwEKUojCFKEoxShOCUpSitKUoSzlKE8FKlKJylShKtWoTg1qUova1KEu9ahP
AxrSiMY0oSnNaE4LWtKK1rShLe1oTwc60onOdKEr3ehOD3rSi970oS/96M8A
BjKIwQzhL/5mKMMYzghGMorRjGEs4xjPBCYyiclMYSrTmM4MZjKL2cxhLvOY
zwIWsojFLGEpy1jOClayitWsYS3rWM8GNrKJzWxhK9vYzg52sovd7GEv+9jP
AQ5yiMMc4SjHOM4JTnKK05zhLOc4zwUuconLXOEq17jODW5yi9vc4S73uM8D
HvKIxzzhKc94zgte8orXvOEt73jPBz7yic984Svf+M4PfvKL3/zDv/wpf0AC
EZggBCUYwQlBSEIRmjCEJRzhiUBEIhGZKEQlGtGJQUxiEZs4xCUe8UlAQhKR
mCQkJRnJSUFKUpGaNKQlHenJQEYykZksZCUb2clBTnKRmzzkJR/5KUBBClGY
IhSlGMUpQUlKUZoylKUc5alARSpRmSpUpRrVqUFNalGbOtSlHvVpQEMa0Zgm
NKUZzWlBS1rRmja05c94t6cDHelEZ7rQlW50pwc96UVv+tCXfvRnAAMZxGCG
8Bd/M5RhDGcEIxnFaMYwlnGMZwITmcRkpjCVaUxnBjOZxWzmMJd5zGcBC1nE
YpawlGUsZwUrWcVq1rCWdaxnAxvZxGa2sJVtbGcHO9nFbvawl33s5wAHOcRh
jnCUYxznBCc5xWnOcJZznOcCF7nEZa5wlWtc5wY3ucVt7nCXe9znAQ95xGOe
8JRnPOcFL3nFa97wlne85wMf+cRnvvCVb3znBz/5FfD/n/8fEZ8Awg==
            "]], 
           LineBox[CompressedData["
1:eJwVx2dXiAEAgNG3kJ29iWTLlp20kC0je2SvQkKyt8jI3nvvkT0iM+ScfhBu
H+45zxOZnpmaERIEQRl/xb/yCQ2CEEKpQEUqEUZlqlCValSnBjUJpxa1qUNd
6lGfBjSkEY1pQlOa0ZwWRNCSVkTSmija0JZ2tKcDHelEZ6LpQle60Z0e9KQX
vYmhD33pR38GMJBBxDKYOIYQTwKJJJHMUIYxnBRGMJJRjGYMYxnHeFKZwEQm
MZk0pjCVaUxnBjOZxWzmMJd05jGfBSxkEYtZwlKWsZwVZJDJSlaxmizWkM1a
1rGeHDaQy0Y2sZktbGUb29nBTnaxmz3sZR957OcA+RzkEIc5QgFHOcZxTnCS
U5zmDGc5x3kucJFLXOYKV7nGdW5wk1vc5g53ucd9HvCQRzzmCU95RiHPecFL
XvGaN7zlHe/5QBEf+UQxn/nCV77xnR+U8JNf/KaUP/wHHAJaPQ==
            "]], 
           
           LineBox[{720, 721, 722, 723, 724, 725, 726, 727, 728, 729, 730, 
            731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 741, 742, 743, 
            744, 745, 746, 747, 748, 749, 750, 751, 752, 753, 754, 755, 756, 
            757, 758, 759, 760, 761, 762, 763, 764, 765, 766, 767, 768, 769, 
            770, 771, 772, 773, 774, 775, 776, 777, 778, 779, 780, 781, 782, 
            783, 784, 785, 786, 787, 788, 789, 790, 791, 792}]}, 
          RowBox[{
            RowBox[{"1", "-", 
              RowBox[{"15", " ", 
                SuperscriptBox["x", "2"]}], "+", 
              RowBox[{"15", " ", 
                SuperscriptBox["x", "4"]}], "-", 
              SuperscriptBox["x", "6"], "-", 
              RowBox[{"14", " ", 
                SuperscriptBox["y", "2"]}], "+", 
              RowBox[{"84", " ", 
                SuperscriptBox["x", "2"], " ", 
                SuperscriptBox["y", "2"]}], "-", 
              RowBox[{"14", " ", 
                SuperscriptBox["x", "4"], " ", 
                SuperscriptBox["y", "2"]}], "+", 
              RowBox[{"49", " ", 
                SuperscriptBox["y", "4"]}], "-", 
              RowBox[{"49", " ", 
                SuperscriptBox["x", "2"], " ", 
                SuperscriptBox["y", "4"]}], "-", 
              RowBox[{"36", " ", 
                SuperscriptBox["y", "6"]}]}], "\[Equal]", "0"}]], 
         Annotation[#, 
          1 - 15 $CellContext`x^2 + 15 $CellContext`x^4 - $CellContext`x^6 - 
           14 $CellContext`y^2 + (84 $CellContext`x^2) $CellContext`y^2 - (
            14 $CellContext`x^4) $CellContext`y^2 + 
           49 $CellContext`y^4 - (49 $CellContext`x^2) $CellContext`y^4 - 
           36 $CellContext`y^6 == 0, "Tooltip"]& ]}], ImageSize -> 180, 
      AspectRatio -> 1, DisplayFunction -> Identity, Frame -> True, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic},
       PlotRange -> {{-5, 5}, {-3, 3}}, PlotRangeClipping -> True, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}}, Ticks -> {Automatic, Automatic}],"Degree 6"},
    "Labeled",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ),
    InterpretationFunction->(RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[{{{{
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{0, 0}, {1, 0}, {1, 1}, {0, 1}, {0, 0}}]}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{1, 0}, {2, 0}, {2, 1}, {1, 1}, {1, 0}}]}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{0, 1}, {1, 1}, {1, 2}, {0, 2}, {0, 1}}]}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{-0.5, 0}, {-0.5, 1}}]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-1, 0}, {0, 0}, {0, 1}, {-1, 1}, {-1, 0}}]}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{0, -0.5}, {1, -0.5}}]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{0, -1}, {1, -1}, {1, 0}, {0, 0}, {0, -1}}]}}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{2, 0}, {3, 0}, {3, 1}, {2, 1}, {2, 0}}]}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{1, 1}, {2, 1}, {2, 2}, {1, 2}, {1, 1}}]}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{0, 2}, {1, 2}, {1, 3}, {0, 3}, {0, 2}}]}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{-1, 1}, 0.5, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-1, 1}, {0, 1}, {0, 2}, {-1, 2}, {-1, 1}}]}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{-2, 0}, 0.5, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-2, 0}, {-1, 0}, {-1, 1}, {-2, 1}, {-2, 0}}]}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{0, -1.5}, {1, -1.5}}]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{0, -2}, {1, -2}, {1, -1}, {0, -1}, {0, -2}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-1, -1}, {0, -1}, {0, 0}, {-1, 0}, {-1, -1}}]}, {
           RGBColor[0, 1, 1], 
           Thickness[Large], 
           Dashing[{Small, Small}], 
           CircleBox[{0, 0}, 0.5, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]], 
           CircleBox[{-1, -1}, 0.5, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], {
            RGBColor[1, 0, 1], 
            CircleBox[{0, -1}, 0.5, 
             
             NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
              3.141592653589793}]], 
            CircleBox[{-1, 0}, 0.5, 
             
             NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
              6.283185307179586}]]}}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{1, -1}, 0.5, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{1, -1}, {2, -1}, {2, 0}, {1, 0}, {1, -1}}]}}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{3, 0}, {4, 0}, {4, 1}, {3, 1}, {3, 0}}]}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{2, 1}, {3, 1}, {3, 2}, {2, 2}, {2, 1}}]}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{1, 2}, {2, 2}, {2, 3}, {1, 3}, {1, 2}}]}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{0, 3}, {1, 3}, {1, 4}, {0, 4}, {0, 3}}]}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{-1, 2}, {0, 2}, {0, 3}, {-1, 3}, {-1, 2}}]}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{-2, 1.5}, {-1, 1.5}}]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-2, 1}, {-1, 1}, {-1, 2}, {-2, 2}, {-2, 1}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-3, 0}, {-2, 0}, {-2, 1}, {-3, 1}, {-3, 0}}]}, {
           RGBColor[0, 1, 1], 
           Thickness[Large], 
           Dashing[{Small, Small}], 
           CircleBox[{-2, 1}, 0.5, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]], 
           CircleBox[{-3, 0}, 0.5, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], {
            RGBColor[1, 0, 1], 
            CircleBox[{-2, 0}, 0.5, 
             
             NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
              3.141592653589793}]], 
            CircleBox[{-3, 1}, 0.5, 
             
             NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
              6.283185307179586}]]}}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{0, -2.5}, {1, -2.5}}]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{0, -3}, {1, -3}, {1, -2}, {0, -2}, {0, -3}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-1, -2}, {0, -2}, {0, -1}, {-1, -1}, {-1, -2}}]}, {
           RGBColor[0, 1, 1], 
           Thickness[Large], 
           Dashing[{Small, Small}], 
           CircleBox[{0, -1}, 0.5, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]], 
           CircleBox[{-1, -2}, 0.5, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], {
            RGBColor[1, 0, 1], 
            CircleBox[{0, -2}, 0.5, 
             
             NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
              3.141592653589793}]], 
            CircleBox[{-1, -1}, 0.5, 
             
             NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
              6.283185307179586}]]}}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{-1, 0}, 0.5, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-2, -1}, {-1, -1}, {-1, 0}, {-2, 0}, {-2, -1}}]}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{1, -1}, 0.5, 
            
            NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
             6.283185307179586}]]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{1, -2}, {2, -2}, {2, -1}, {1, -1}, {1, -2}}]}}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{2, -1}, {3, -1}, {3, 0}, {2, 0}, {2, -1}}]}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{-1, 4}, 0.5, 
            
            NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
             6.283185307179586}]]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-1, 3}, {0, 3}, {0, 4}, {-1, 4}, {-1, 3}}]}}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{-2, 2}, {-1, 2}, {-1, 3}, {-2, 3}, {-2, 2}}]}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-3, 1}, {-2, 1}, {-2, 2}, {-3, 2}, {-3, 1}}]}, {
           RGBColor[0, 1, 1], 
           Thickness[Large], 
           Dashing[{Small, Small}], 
           CircleBox[{-2, 2}, 0.5, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]], 
           CircleBox[{-3, 1}, 0.5, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], {
            RGBColor[1, 0, 1], 
            CircleBox[{-2, 1}, 0.5, 
             
             NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
              3.141592653589793}]], 
            CircleBox[{-3, 2}, 0.5, 
             
             NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
              6.283185307179586}]]}}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{-3, 0}, 0.5, 
            
            NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
             3.141592653589793}]]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-4, 0}, {-3, 0}, {-3, 1}, {-4, 1}, {-4, 0}}]}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{0, -3.5}, {1, -3.5}}]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{0, -4}, {1, -4}, {1, -3}, {0, -3}, {0, -4}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-1, -3}, {0, -3}, {0, -2}, {-1, -2}, {-1, -3}}]}, {
           RGBColor[0, 1, 1], 
           Thickness[Large], 
           Dashing[{Small, Small}], 
           CircleBox[{0, -2}, 0.5, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]], 
           CircleBox[{-1, -3}, 0.5, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], {
            RGBColor[1, 0, 1], 
            CircleBox[{0, -3}, 0.5, 
             
             NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
              3.141592653589793}]], 
            CircleBox[{-1, -2}, 0.5, 
             
             NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
              6.283185307179586}]]}}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{-1, -2}, 0.5, 
            
            NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
             3.141592653589793}]]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-2, -2}, {-1, -2}, {-1, -1}, {-2, -1}, {-2, -2}}]}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{-2.5, -1}, {-2.5, 0}}]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-3, -1}, {-2, -1}, {-2, 0}, {-3, 0}, {-3, -1}}]}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{1, -2.5}, {2, -2.5}}]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{1, -3}, {2, -3}, {2, -2}, {1, -2}, {1, -3}}]}}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{2, -2}, {3, -2}, {3, -1}, {2, -1}, {2, -2}}]}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{4, -1}, 0.5, 
            
            NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
             3.141592653589793}]]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{3, -1}, {4, -1}, {4, 0}, {3, 0}, {3, -1}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-1, -4}, {0, -4}, {0, -3}, {-1, -3}, {-1, -4}}]}, {
           RGBColor[0, 1, 1], 
           Thickness[Large], 
           Dashing[{Small, Small}], 
           CircleBox[{0, -3}, 0.5, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]], 
           CircleBox[{-1, -4}, 0.5, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], {
            RGBColor[1, 0, 1], 
            CircleBox[{0, -4}, 0.5, 
             
             NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
              3.141592653589793}]], 
            CircleBox[{-1, -3}, 0.5, 
             
             NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
              6.283185307179586}]]}}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-2, -3}, {-1, -3}, {-1, -2}, {-2, -2}, {-2, -3}}]}, {
           RGBColor[0, 1, 1], 
           Thickness[Large], 
           Dashing[{Small, Small}], 
           CircleBox[{-1, -2}, 0.5, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]], 
           CircleBox[{-2, -3}, 0.5, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], {
            RGBColor[1, 0, 1], 
            CircleBox[{-1, -3}, 0.5, 
             
             NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
              3.141592653589793}]], 
            CircleBox[{-2, -2}, 0.5, 
             
             NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
              6.283185307179586}]]}}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{-2.5, -2}, {-2.5, -1}}]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-3, -2}, {-2, -2}, {-2, -1}, {-3, -1}, {-3, -2}}]}}, {{
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{-4, 0}, 0.5, 
            
            NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
             6.283185307179586}]]}, {
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-4, -1}, {-3, -1}, {-3, 0}, {-4, 0}, {-4, -1}}]}}}, {{
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{4, 0}, {5, 0}, {4, 1}, {4, 0}}]}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{3, 1}, {4, 1}, {3, 2}, {3, 1}}]}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{2, 2}, {3, 2}, {2, 3}, {2, 2}}]}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{1, 3}, {2, 3}, {1, 4}, {1, 3}}]}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{0, 4}, {1, 4}, {0, 5}, {0, 4}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{0, 4.5}, {0.5, 4.5}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{0, 4}, {-1, 4}, {0, 5}, {0, 4}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{0, 4}, 0.5, 
            
            NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
             3.141592653589793}]]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-1, 3}, {-2, 3}, {-1, 4}, {-1, 3}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{-1, 3.5}, {-1.5, 3.5}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-2, 2}, {-3, 2}, {-2, 3}, {-2, 2}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{-2.5, 2}, {-2.5, 2.5}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-3, 1}, {-4, 1}, {-3, 2}, {-3, 1}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{-3, 1.5}, {-3.5, 1.5}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-4, 0}, {-5, 0}, {-4, 1}, {-4, 0}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{-4.5, 0}, {-4.5, 0.5}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-4, 0}, {-5, 0}, {-4, -1}, {-4, 0}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{-4, 0}, 0.5, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{0, -4}, {-1, -4}, {0, -5}, {0, -4}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{-0.5, -4}, {-0.5, -4.5}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-1, -3}, {-2, -3}, {-1, -4}, {-1, -3}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{-1, -3}, 0.5, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{-2, -2}, {-3, -2}, {-2, -3}, {-2, -2}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           CircleBox[{-2, -2}, 0.5, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]]}}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{-3, -1}, {-4, -1}, {-3, -2}, {-3, -1}}]}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{4, 0}, {5, 0}, {4, -1}, {4, 0}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{4, -0.5}, {4.5, -0.5}}]}}, {
          GrayLevel[0.5], 
          Thickness[Tiny], 
          LineBox[{{0, -4}, {1, -4}, {0, -5}, {0, -4}}]}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{1, -3}, {2, -3}, {1, -4}, {1, -3}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{1, -3.5}, {1.5, -3.5}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{2, -2}, {3, -2}, {2, -3}, {2, -2}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{2, -2.5}, {2.5, -2.5}}]}}, {{
           GrayLevel[0.5], 
           Thickness[Tiny], 
           LineBox[{{3, -1}, {4, -1}, {3, -2}, {3, -1}}]}, {
           RGBColor[0, 0, 1], 
           Thickness[Large], 
           LineBox[{{3.5, -1}, {3.5, -1.5}}]}}}, {{}, {{}, {}, {
           GrayLevel[0], 
           PointSize[0.019444444444444445`], 
           AbsoluteThickness[1.6], 
           LineBox[{{-5., 0.}, {5., 0.}}]}, {
           GrayLevel[0], 
           PointSize[0.019444444444444445`], 
           AbsoluteThickness[1.6], 
           
           LineBox[{{0., -5.}, {0., 5.}, {5., 0.}, {0., -5.}, {-5., 0.}, {0., 
            5.}}]}}, {}, {}, {{}, {}}}, {{}, {{
           RGBColor[0.6, 0.4, 0.2], 
           AbsolutePointSize[6], 
           AbsoluteThickness[1.6], 
           GeometricTransformationBox[
            InsetBox[
             BoxData[
              FormBox["\[FilledCircle]", TraditionalForm]], {0., 
             0.}], CompressedData["
1:eJxTTMoPSmVmYGDQBGJGIGZiwAU+2BMQd8AujqEPpu4ADoug4h/2o9IcaObD
zMGwB00dTB/MHHT74fbYo4rDzYfKC+AyF91eNHF0d8PMwfAXmr0cMPdBzRGA
yaMBmDjcPJg6dBrNHvRwEcHlTnR/oNHo4QAPJzR74O5ESw8iaOIwdYhwAQAy
czRr
            "]]}, {
           RGBColor[1, 0.5, 0], 
           AbsolutePointSize[6], 
           AbsoluteThickness[1.6], 
           GeometricTransformationBox[
            InsetBox[
             BoxData[
              FormBox["\[FilledCircle]", TraditionalForm]], {0., 
             0.}], CompressedData["
1:eJxTTMoPSmVmYGAQAWJGIGZigIEP+xmwApg4nLZHo2H6DqCKcxzAbh5MHF0f
ujguc0QcUNUJOKCpg/JF0PTB1cPE0ezlQBOHqYO7E80emL0f9gMAiQokfg==

            "]]}, {}}, {}, {}, {{}, {}}}}, {{
         GrayLevel[1], 
         RectangleBox[{-2.9, 1.1}, {-2.1, 1.9}]}, {
         RGBColor[0, 0, 1], 
         Thickness[Large], 
         CircleBox[{-2, 1}, 0.5, 
          
          NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
           3.141592653589793}]], 
         CircleBox[{-3, 2}, 0.5, 
          
          NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
           6.283185307179586}]]}}, {{
         GrayLevel[1], 
         RectangleBox[{-2.9, 0.1}, {-2.1, 0.9}]}, {
         RGBColor[0, 0, 1], 
         Thickness[Large], 
         CircleBox[{-2, 0}, 0.5, 
          
          NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
           3.141592653589793}]], 
         CircleBox[{-3, 1}, 0.5, 
          
          NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
           6.283185307179586}]]}}, {{
         GrayLevel[1], 
         RectangleBox[{-0.9, -0.9}, {-0.09999999999999998, \
-0.09999999999999998}]}, {
         RGBColor[0, 0, 1], 
         Thickness[Large], 
         CircleBox[{0, -1}, 0.5, 
          
          NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
           3.141592653589793}]], 
         CircleBox[{-1, 0}, 0.5, 
          
          NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
           6.283185307179586}]]}}, {{
         GrayLevel[1], 
         RectangleBox[{-0.9, -1.9}, {-0.09999999999999998, -1.1}]}, {
         RGBColor[0, 0, 1], 
         Thickness[Large], 
         CircleBox[{0, -1}, 0.5, 
          
          NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
           4.71238898038469}]], 
         CircleBox[{-1, -2}, 0.5, 
          NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]}}, {{
         GrayLevel[1], 
         RectangleBox[{-0.9, -2.9}, {-0.09999999999999998, -2.1}]}, {
         RGBColor[0, 0, 1], 
         Thickness[Large], 
         CircleBox[{0, -3}, 0.5, 
          
          NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
           3.141592653589793}]], 
         CircleBox[{-1, -2}, 0.5, 
          
          NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
           6.283185307179586}]]}}, {{
         GrayLevel[1], 
         RectangleBox[{-1.9, -2.9}, {-1.1, -2.1}]}, {
         RGBColor[0, 0, 1], 
         Thickness[Large], 
         CircleBox[{-1, -3}, 0.5, 
          
          NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
           3.141592653589793}]], 
         CircleBox[{-2, -2}, 0.5, 
          
          NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
           6.283185307179586}]]}}, {{
         GrayLevel[1], 
         RectangleBox[{-0.9, -3.9}, {-0.09999999999999998, -3.1}]}, {
         RGBColor[0, 0, 1], 
         Thickness[Large], 
         CircleBox[{0, -4}, 0.5, 
          
          NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
           3.141592653589793}]], 
         CircleBox[{-1, -3}, 0.5, 
          
          NCache[{Rational[3, 2] Pi, 2 Pi}, {4.71238898038469, 
           6.283185307179586}]]}}, {{}, {{}, {
          Hue[0.67, 0.6, 0.6], 
          Opacity[0], 
          PointBox[{{0.5, 4.5}, {0.5, 4.5}}]}, {}}, {{}, 
         TagBox[
          InsetBox["A", 
           Offset[{4, 0}, {0.5, 4.5}], 
           ImageScaled[{0, 0.5}]], 
          "InsetString"]}, {{}, {}}, {{}, {}}}, {{}, {{}, {
          Hue[0.67, 0.6, 0.6], 
          Opacity[0], 
          PointBox[{{4.5, -0.5}, {4.5, -0.5}}]}, {}}, {{}, 
         TagBox[
          InsetBox["B", 
           Offset[{4, 0}, {4.5, -0.5}], 
           ImageScaled[{0, 0.5}]], 
          "InsetString"]}, {{}, {}}, {{}, {}}}, {{}, {{}, {
          Hue[0.67, 0.6, 0.6], 
          Opacity[0], 
          PointBox[{{3.5, -1.5}, {3.5, -1.5}}]}, {}}, {{}, 
         TagBox[
          InsetBox["C", 
           Offset[{4, 0}, {3.5, -1.5}], 
           ImageScaled[{0, 0.5}]], 
          "InsetString"]}, {{}, {}}, {{}, {}}}, {{}, {{}, {
          Hue[0.67, 0.6, 0.6], 
          Opacity[0], 
          PointBox[{{2.5, -2.5}, {2.5, -2.5}}]}, {}}, {{}, 
         TagBox[
          InsetBox["D", 
           Offset[{4, 0}, {2.5, -2.5}], 
           ImageScaled[{0, 0.5}]], 
          "InsetString"]}, {{}, {}}, {{}, {}}}, {{}, {{}, {
          Hue[0.67, 0.6, 0.6], 
          Opacity[0], 
          PointBox[{{1.5, -3.5}, {1.5, -3.5}}]}, {}}, {{}, 
         TagBox[
          InsetBox["E", 
           Offset[{4, 0}, {1.5, -3.5}], 
           ImageScaled[{0, 0.5}]], 
          "InsetString"]}, {{}, {}}, {{}, {}}}, {{}, {{}, {
          Hue[0.67, 0.6, 0.6], 
          Opacity[0], 
          PointBox[{{-0.5, -4.5}, {-0.5, -4.5}}]}, {}}, {{}, 
         TagBox[
          InsetBox["A", 
           Offset[{0, -2}, {-0.5, -4.5}], 
           ImageScaled[{1, 1}]], 
          "InsetString"]}, {{}, {}}, {{}, {}}}, {{}, {{}, {
          Hue[0.67, 0.6, 0.6], 
          Opacity[0], 
          PointBox[{{-4.5, 0.5}, {-4.5, 0.5}}]}, {}}, {{}, 
         TagBox[
          InsetBox["B", 
           Offset[{0, 2}, {-4.5, 0.5}], 
           ImageScaled[{1, 0}]], 
          "InsetString"]}, {{}, {}}, {{}, {}}}, {{}, {{}, {
          Hue[0.67, 0.6, 0.6], 
          Opacity[0], 
          PointBox[{{-3.5, 1.5}, {-3.5, 1.5}}]}, {}}, {{}, 
         TagBox[
          InsetBox["C", 
           Offset[{0, 2}, {-3.5, 1.5}], 
           ImageScaled[{1, 0}]], 
          "InsetString"]}, {{}, {}}, {{}, {}}}, {{}, {{}, {
          Hue[0.67, 0.6, 0.6], 
          Opacity[0], 
          PointBox[{{-2.5, 2.5}, {-2.5, 2.5}}]}, {}}, {{}, 
         TagBox[
          InsetBox["D", 
           Offset[{0, 2}, {-2.5, 2.5}], 
           ImageScaled[{1, 0}]], 
          "InsetString"]}, {{}, {}}, {{}, {}}}, {{}, {{}, {
          Hue[0.67, 0.6, 0.6], 
          Opacity[0], 
          PointBox[{{-1.5, 3.5}, {-1.5, 3.5}}]}, {}}, {{}, 
         TagBox[
          InsetBox["E", 
           Offset[{0, 2}, {-1.5, 3.5}], 
           ImageScaled[{1, 0}]], "InsetString"]}, {{}, {}}, {{}, {}}}}, 
      ImageSize -> 180, PlotRange -> 7],"NH 1050752 (Degree 5)"},
    "Labeled",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ),
    InterpretationFunction->(RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )]}], "}"}]], "Picture", "Lockdown",
 CellID->1679614224,ExpressionUUID->"28883724-dcb3-498f-a0af-bc91a888d4ad"],

Cell["\<\
The last curve is given as a Gauss diagram. This curve of degree 5 is \
discussed in Chapters 8 and 9 and cannot be properly represented by a \
contour, or similar, plot. The letters label infinite points, and the brown \
dots indicate where the defining polynomial is positive.\
\>", "Text",
 CellChangeTimes->{{3.685290647261074*^9, 3.685290791313065*^9}, {
   3.685361261765665*^9, 3.685361310767878*^9}, {3.685361385736845*^9, 
   3.685361402392658*^9}, 3.7010086517391357`*^9, {3.7084265409475136`*^9, 
   3.70842659780842*^9}, {3.7084462135699596`*^9, 3.7084462185379596`*^9}, {
   3.709049152062828*^9, 3.7090491521968412`*^9}, {3.710676179207143*^9, 
   3.710676185582311*^9}, 3.7147501339155703`*^9, {3.737890465753641*^9, 
   3.73789046868674*^9}, {3.739290856647733*^9, 3.739290856879733*^9}},
 CellID->840171372,ExpressionUUID->"46a55cee-f2e2-44b4-b67e-511bee98b5fc"],

Cell[TextData[{
 "The same can be plotted for a whole family of curves described by Gauss in \
his 1799 dissertation, now called ",
 StyleBox["Gauss curves",
  FontSlant->"Italic"],
 ". We start with a univariate complex polynomial in ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]], "InlineMath",ExpressionUUID->
  "72079bb5-21c9-49dc-95cb-b411721a0dea"],
 ", possibly with complex coefficients, and use the following procedure to \
replace ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]], "InlineMath",ExpressionUUID->
  "1b7cee4a-d5ef-42f6-a014-9da9a888b5d6"],
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "+", "\[ImaginaryI]y"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"1b828b3c-0092-4f90-ba52-b3067fc35ff6"],
 ", expand it, and take the formal real part, which is the monomials with a \
real coefficient."
}], "Text",
 CellChangeTimes->{{3.685361952410361*^9, 3.685362124545006*^9}, {
   3.685362237129258*^9, 3.685362300083252*^9}, {3.685362730484269*^9, 
   3.685362730884396*^9}, 3.701008651759531*^9, {3.70101469169177*^9, 
   3.701014732162899*^9}, {3.7010545005257072`*^9, 3.701054501589635*^9}, {
   3.7026552600034323`*^9, 3.7026552603787327`*^9}, {3.70283802118686*^9, 
   3.702838026990509*^9}, {3.7084266241251144`*^9, 3.708426625669484*^9}, {
   3.7084266729989743`*^9, 3.708426673279769*^9}, {3.709049213469968*^9, 
   3.7090492600326242`*^9}, 3.739291550688733*^9, {3.7392922247227335`*^9, 
   3.739292226681733*^9}, {3.7407666403140287`*^9, 3.74076665665831*^9}, 
   3.7425804568380136`*^9},
 CellID->1055270179,ExpressionUUID->"c7a1a3d2-49f8-4330-bf83-fb8820705c76"],

Cell[TextData[{
 "For this Gauss curve, ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "50272837-ae08-4d9d-9ce3-19851e5a8346"],
 " is a polynomial in ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]], "InlineMath",ExpressionUUID->
  "3bacfce8-90e9-4cc7-949c-095e53cbd158"],
 " with possibly complex coefficients. ",
 ButtonBox["ComplexExpand",
  BaseStyle->"Link"],
 " assumes that variables ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "2f1f2e4f-99f2-4eeb-b128-6724979beb5d"],
 ", ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "ddb341c5-b219-4e73-9bc8-f1f7fb9c4f53"],
 " are real:"
}], "CodeCaption",
 CellMargins->{{66, 10}, {4, 11}},
 PageBreakAbove->True,
 CellChangeTimes->{{3.7090495122348413`*^9, 3.7090495739390116`*^9}, {
   3.710676394588069*^9, 3.710676406236341*^9}, {3.71067644258931*^9, 
   3.710676452973476*^9}, {3.71067649122295*^9, 3.710676557584452*^9}, {
   3.7117213303576803`*^9, 3.711721331325796*^9}, {3.7383870851683187`*^9, 
   3.738387133635543*^9}, {3.7407666066681633`*^9, 3.740766606762116*^9}, {
   3.742580471359399*^9, 3.742580484530366*^9}, 3.743795970318399*^9},
 CellID->238771493,ExpressionUUID->"ff123703-b61c-4c94-b7a8-258bea0139b9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gaussCurve", "[", 
    RowBox[{"p_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"ComplexExpand", "[", 
    RowBox[{"Re", "[", 
     RowBox[{"p", "/.", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", 
        RowBox[{"x", "+", 
         RowBox[{"I", "*", "y"}]}]}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",\

 CellMargins->{{99, 10}, {3, 6}},
 InitializationCell->True,
 CellChangeTimes->{{3.685362127753511*^9, 3.685362135231185*^9}, {
  3.685362216344747*^9, 3.685362218138379*^9}, {3.7378904850852957`*^9, 
  3.73789048693108*^9}},
 CellLabel->"In[34]:=",
 CellID->2005941527,ExpressionUUID->"e720d313-2f5f-48d9-845e-393fbdbb3e60"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gaussCurve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "^", "2"}], "+", 
    RowBox[{"2", "z"}], "-", "1"}], ",", "x", ",", "y", ",", "z"}], 
  "]"}]], "Input",
 CellMargins->{{99, 10}, {3, 6}},
 CellChangeTimes->{{3.685362311396617*^9, 3.685362443349366*^9}, 
   3.7074882022244043`*^9, {3.7378904899248447`*^9, 3.737890490598186*^9}},
 CellLabel->"In[35]:=",
 CellID->513470036,ExpressionUUID->"0d86a22b-1bfd-48ee-a24b-1d76a0aee584"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  RowBox[{"2", " ", "x"}], "+", 
  SuperscriptBox["x", "2"], "-", 
  SuperscriptBox["y", "2"]}]], "Output",
 CellMargins->{{99, 10}, {14, 6}},
 CellChangeTimes->{3.7118005558892517`*^9, 3.737891180294361*^9, 
  3.7378924184519157`*^9, 3.7378935234160223`*^9, 3.737893965475659*^9, 
  3.742658536133301*^9},
 CellLabel->"Out[35]=",
 CellID->1048619963,ExpressionUUID->"29542e8b-c33d-4534-9d6c-f71838e88cdb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gaussCurve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "^", "2"}], "+", " ", 
    RowBox[{"I", " ", "z"}], "+", 
    RowBox[{"(", 
     RowBox[{"2", "-", 
      RowBox[{"3", "I"}]}], ")"}]}], ",", "x", ",", "y", ",", "z"}], 
  "]"}]], "Input",
 CellMargins->{{99, 10}, {3, 6}},
 CellChangeTimes->{{3.685362311396617*^9, 3.685362443349366*^9}, 
   3.7074882022244043`*^9, {3.737890494054068*^9, 3.737890495183921*^9}},
 CellLabel->"In[36]:=",
 CellID->713084623,ExpressionUUID->"51db2a9a-209c-440e-ab71-96983c60a80e"],

Cell[BoxData[
 RowBox[{"2", "+", 
  SuperscriptBox["x", "2"], "-", "y", "-", 
  SuperscriptBox["y", "2"]}]], "Output",
 CellMargins->{{99, 10}, {14, 6}},
 CellChangeTimes->{3.711800555925089*^9, 3.737891180308899*^9, 
  3.7378924184679213`*^9, 3.737893523433025*^9, 3.7378939654882917`*^9, 
  3.742658536176586*^9},
 CellLabel->"Out[36]=",
 CellID->1904910859,ExpressionUUID->"f74da64e-7fb1-4a3f-90b7-9dd5a080fbda"]
}, Open  ]],

Cell[TextData[{
 "Here are some region plots of Gauss curves; note that Gauss explicitly \
allowed the case where the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "[", "z", "]"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"04af2166-314e-486d-8b3b-dd11ea863181"],
 " had multiple zeros. These produce singularities in the Gauss curve; \
however, in the right-hand plot, not all singularities come from multiple \
zeros of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "[", "z", "]"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"ceac4186-6a60-4192-be8a-1b1ebb6be01a"],
 ". We show ",
 ButtonBox["RegionPlot",
  BaseStyle->"Link"],
 " because Gauss was specifically interested in the region where the Gauss \
curve was positive. Note also that the middle curve is \
Gauss\[CloseCurlyQuote]s original example for his fourth proof of the \
fundamental theorem of algebra in 1849."
}], "Text",
 CellMargins->{{66, 10}, {7, 6}},
 CellChangeTimes->{{3.685362629163616*^9, 3.685362804821009*^9}, {
   3.685363275028968*^9, 3.685363358199799*^9}, {3.685364369759435*^9, 
   3.685364452874006*^9}, {3.70100865177602*^9, 3.701008651792412*^9}, {
   3.701014804659493*^9, 3.7010148051865797`*^9}, 3.701014847759811*^9, 
   3.70101488074055*^9, {3.701014923482518*^9, 3.70101499644279*^9}, {
   3.7010150911121283`*^9, 3.7010150971616983`*^9}, {3.702655272547402*^9, 
   3.7026552729626427`*^9}, {3.70283804249621*^9, 3.702838042531004*^9}, {
   3.70283875180294*^9, 3.7028387701571712`*^9}, {3.708426706663127*^9, 
   3.7084267586881266`*^9}, {3.7084267959714093`*^9, 
   3.7084268002769265`*^9}, {3.709049681214738*^9, 3.7090496951651325`*^9}, {
   3.714750043973097*^9, 3.714750072388941*^9}, {3.739292236402733*^9, 
   3.739292270312733*^9}, {3.740766611930666*^9, 3.74076662150642*^9}, {
   3.740833295854089*^9, 3.740833306748822*^9}},
 CellID->2124452551,ExpressionUUID->"04553433-ee7b-40e9-b817-43a0339ca6dd"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["RegionPlot",
   BaseStyle->"CodeLink"]], "InlineCode",ExpressionUUID->
  "c98ef93d-701c-4e96-b3b6-adc553650bb8"],
 " makes and shows the region in which ",
 Cell[BoxData[
 "pred"], "InlineCode",ExpressionUUID->"d848e017-d9ff-4354-85d7-25b86c9b9182"],
 " is true (",
 Cell[BoxData[
  RowBox[{"pred", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}]], "InlineCode",ExpressionUUID->
  "346ba3c2-3acf-4b29-bea3-09048fc61d08"],
 "):"
}], "CodeCaption",
 CellMargins->{{66, 10}, {4, 11}},
 CellChangeTimes->{{3.707502257967031*^9, 3.707502319969995*^9}, {
   3.70750359489366*^9, 3.707503594893696*^9}, 3.707505744682959*^9, {
   3.708431557543789*^9, 3.708431557622789*^9}, {3.7084475040611677`*^9, 
   3.708447517350497*^9}, 3.709049739174533*^9, {3.709307921370525*^9, 
   3.709307932028186*^9}, {3.713718741375709*^9, 3.713718749308929*^9}, 
   3.739292415030733*^9, {3.740833368326337*^9, 3.7408333684281807`*^9}, {
   3.7425805111893473`*^9, 3.742580536570437*^9}},
 CellID->2112346315,ExpressionUUID->"e638926a-06de-444e-af75-696771bbdfae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g1", "=", 
  RowBox[{"gaussCurve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", "^", "2"}], "+", "I"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", "^", "2"}], "-", 
       RowBox[{"2", "I"}]}], ")"}], "z"}], ",", "x", ",", "y", ",", "z"}], 
   "]"}]}]], "Input",
 CellMargins->{{99, 10}, {3, 6}},
 CellChangeTimes->{{3.685364338662073*^9, 3.685364354702995*^9}, 
   3.707488206816462*^9, 3.707585909272533*^9, {3.737890499511462*^9, 
   3.7378905255632877`*^9}, 3.73789059158153*^9},
 CellLabel->"In[37]:=",
 CellID->1610909635,ExpressionUUID->"bb1c2a03-d739-4a66-a275-5f9e67db5af7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "x"}], "+", 
  SuperscriptBox["x", "5"], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["x", "2"], " ", "y"}], "-", 
  RowBox[{"10", " ", 
   SuperscriptBox["x", "3"], " ", 
   SuperscriptBox["y", "2"]}], "-", 
  SuperscriptBox["y", "3"], "+", 
  RowBox[{"5", " ", "x", " ", 
   SuperscriptBox["y", "4"]}]}]], "Output",
 CellMargins->{{99, 10}, {14, 6}},
 CellChangeTimes->{3.7426585362284718`*^9},
 CellLabel->"Out[37]=",
 CellID->1150597737,ExpressionUUID->"1b1c468e-f815-4d3f-b00d-5056fc59130b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g2", "=", 
  RowBox[{"gaussCurve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "^", "5"}], "-", 
     RowBox[{"5", 
      RowBox[{"z", "^", "4"}]}], "+", 
     RowBox[{"9", 
      RowBox[{"z", "^", "3"}]}], "-", 
     RowBox[{"5", 
      RowBox[{"z", "^", "2"}]}]}], ",", "x", ",", "y", ",", "z"}], 
   "]"}]}]], "Input",
 CellMargins->{{99, 10}, {3, 6}},
 CellChangeTimes->{{3.685364338662073*^9, 3.685364354702995*^9}, 
   3.707488206816462*^9, 3.707585909272533*^9, {3.737890499511462*^9, 
   3.737890555277871*^9}, 3.737890591581623*^9},
 CellLabel->"In[38]:=",
 CellID->1074118411,ExpressionUUID->"1fb2bdb4-1f0f-43ce-8dbf-85600f6df572"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "5"}], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"9", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["x", "4"]}], "+", 
  SuperscriptBox["x", "5"], "+", 
  RowBox[{"5", " ", 
   SuperscriptBox["y", "2"]}], "-", 
  RowBox[{"27", " ", "x", " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{"30", " ", 
   SuperscriptBox["x", "2"], " ", 
   SuperscriptBox["y", "2"]}], "-", 
  RowBox[{"10", " ", 
   SuperscriptBox["x", "3"], " ", 
   SuperscriptBox["y", "2"]}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["y", "4"]}], "+", 
  RowBox[{"5", " ", "x", " ", 
   SuperscriptBox["y", "4"]}]}]], "Output",
 CellMargins->{{99, 10}, {14, 6}},
 CellChangeTimes->{3.737890599940906*^9, 3.737891180346797*^9, 
  3.737892418500983*^9, 3.737893523472328*^9, 3.737893965519217*^9, 
  3.7426585362789917`*^9},
 CellLabel->"Out[38]=",
 CellID->5924524,ExpressionUUID->"9065bff4-3999-42ea-af40-b970945fcff8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g3", "=", 
  RowBox[{"gaussCurve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "I"}], ")"}], "^", "3"}], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", "I"}], ")"}], "^", "2"}]}], ",", "x", ",", "y", ",", 
    "z"}], "]"}]}]], "Input",
 CellMargins->{{99, 10}, {3, 6}},
 CellChangeTimes->{{3.685364338662073*^9, 3.685364354702995*^9}, 
   3.707488206816462*^9, 3.707585909272533*^9, {3.737890499511462*^9, 
   3.737890555277871*^9}, 3.737890591581668*^9},
 CellLabel->"In[39]:=",
 CellID->235293942,ExpressionUUID->"116a7f3d-1091-416e-ada1-8b678808a61b"],

Cell[BoxData[
 RowBox[{"x", "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  SuperscriptBox["x", "5"], "+", 
  RowBox[{"4", " ", "x", " ", "y"}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["x", "3"], " ", "y"}], "-", 
  RowBox[{"6", " ", "x", " ", 
   SuperscriptBox["y", "2"]}], "-", 
  RowBox[{"10", " ", 
   SuperscriptBox["x", "3"], " ", 
   SuperscriptBox["y", "2"]}], "-", 
  RowBox[{"4", " ", "x", " ", 
   SuperscriptBox["y", "3"]}], "+", 
  RowBox[{"5", " ", "x", " ", 
   SuperscriptBox["y", "4"]}]}]], "Output",
 CellMargins->{{99, 10}, {14, 6}},
 CellChangeTimes->{3.7378905999641237`*^9, 3.737891180363028*^9, 
  3.737892418518991*^9, 3.737893523492919*^9, 3.737893965535022*^9, 
  3.742658536328521*^9},
 CellLabel->"Out[39]=",
 CellID->789227106,ExpressionUUID->"50d86618-8370-41f0-955f-255390b51aff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Row", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RegionPlot", "[", 
      RowBox[{
       RowBox[{"g1", ">", "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "7"}], ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "7"}], ",", "7"}], "}"}], ",", " ", 
       RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", " ", 
     RowBox[{"RegionPlot", "[", 
      RowBox[{
       RowBox[{"g2", ">", "0"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "7"}], ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "7"}], ",", "7"}], "}"}], ",", " ", 
       RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"RegionPlot", "[", 
      RowBox[{
       RowBox[{"g3", ">", "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", " ", 
       RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}], "}"}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellMargins->{{99, 10}, {3, 6}},
 CellChangeTimes->{{3.685364485065027*^9, 3.685364528018166*^9}, {
  3.7378936724372663`*^9, 3.7378937057243757`*^9}},
 CellLabel->"In[40]:=",
 CellID->1308903178,ExpressionUUID->"0e64b2b0-b693-4aea-992d-f3aba7bba60c"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJx1W3dYVMfXXnpdel0MYsMVa5RVY7sT19hi2aCx/1bFWNcYsa+9BXtfS1DR
xYYNNCq2lTt21x6irlEkihsUseAKSN9P7uYdPq9P+Geed2fuzDtnzjlzZuZQ
K/aXmJH2EonkgaNEUlVGRq66bbWGUZRpJTWDtdJQhjvf+n2oRRbE8NoRY88q
dCYOeJf7mh7y1PcMxxqUUUptBcM+rcodUvWOBDh/zYNJhnh3hsdMeZhvVvgw
/HDnd8kauT/5L17iEvyAH9i+Zxh8gcEXGHyBwRcYfIHB97/kJOYlLsEPeJSt
P4bBFxh8gcEXGHyBwVe8bmK5iHkAi0vwAwY/YPADBj9g8AMGP2DwwzjgJ5aL
mAewuHxt659h8AUGX2DwBQZfYPBDv+AHDH7A4CfmASwuPW3jMQy+wOALDL7A
4Id+wA8Y/IDBDxj8xDyAxSX4AYMfMPiJxx9o+53H+MAYHxjjA6MfYHEJPsDg
A3zKJg8C/K+8iLj/BNt3rF9gcYnxgOEPgOG/gLva5s8w+ACDj7j/8baSzQcY
8gWGvgLDvoDBDxj8gMEPGPyAwQ8Y/FCCHzD4AYMfMPgBgx8w+AGDHzD4ifYh
8l92I9ZTsZ5A7uJ5AIMvMPgCgy8w+AKDr2ifJP/l18V+VOynxH5AbHeYn3gd
gDEuMPiJ9m0x/mJfFO87Yj8v9qPA4A8M/mI9AQZfYPD6r7hCvG+L90XxPgR+
wOAHDH5ivRXrBTD4/VecI44jwA8Y/IDBDxj8xHYj1ktg8AGG3P4r7gI/YPAD
Bj9g8BPbrdgugMEHGHyAITdxHAi7Aj9g8AMGP2DwE/sRsZ0Cgx8w+AGDHzD4
wY7ADxj8gMFP7MfEfkJsl8DgAww+wFhXYFEcLY5bxXHiF35V7LfEfkJkh0Sk
92I9E68r8RK+D6Bvhe9kNFEYz5fOFXgEU4nwl9EO9cCo32lrT8T16HeYwFdK
0B58gFGP9kNsmPFAf8Czhe9cWDvUA8+31RO03yaUduw7tAe28bcj+B7yBMb3
KPE9MOYNjHkBzxTwRx4lvgdeaCs5tLfxDyaoxzqhHrxQj3mI+58q4Bf8ElvJ
oR7yRr1tvgFsPNiVmDfao3+UkDfqoX/A4Cuep5gXsJj3f5XoD+uH38EH+HM9
tWN6ge/hn4DF64L4BFg8LvQfv0OewFhPYOgLvoc/AIZ8gBFPiOsxT+jH53zs
CNYZ+gGM78Ab6wOM/Q0Y32Fen/cTzOQJjO/e2ebJ7FqMxf4HfhJ6JcbiffFz
OfoyOaI9/Cr4AmO+2AfQXnxuFPsf6Anw53KyY3LD+iBuQXvx+RDtsL5if4Hf
8T0w5Cw+v+E78BD7B+gx+gOGnQBDXuLzlNi/iM8/sFvwEvcLjP1MbM/iuBi/
o3+xvxDH07Av8AWGPxPbI76H3DEO1hN+DPITx29ie0I99As80A480E5sL4gX
8B3sxfDjuFKjxo9kdCq7JLseSrfElP4ab/EisSGrpToT4kIHUlewFw86Shjv
Decu8CzggcW/W4T+S7mfBD6SL/rBuJa8iH7Sf/yp++OjEWplmBjTxfyxxHjL
p/N3SqexJlUIxfdnbN/T48K83OhCW7t/40BnorPNg2L8e7bxKfrB769sPHlg
8Ge/2+RAgDEe2sltfEhf2/x5jOtnq2dyAQY//A4+tnWTsHGAMT7kCTliXPCB
nNA/1hEl+kG7bbZx2frfs60/KbDJn/l9EWbrLz5Pw36ShPIqmzfqYR+ox3xQ
D/tGfbLQ/zPWHvLD75A3xgVGifGBwRf2Db8BeaMd1hUY7YDBB/3BjtAv8Of7
qi/zX8BivwW/Bwz/B7mhHhj18CeoB0Y9/Au+AwZ/7I/4DljsJ1GP9QKGPKCX
4jgJ7YHR3uaP3Fh7+DG0B0Z76PHnfHxFfHxZe+j1534+QHT/EMDaN1poOqpS
BzJ7Af58PsGi+QSz72FPaA89QHtgtIe/QxwAuWO/BYY/gV+E/SLuBN8oG98v
1hnr+Pk+I2F+A3bP/N+/vIDBA/sYMPQbvGBH4nMRMNrDb6M9/DYw7HuTreQx
X9gl1gXtxXENMOwLfh/2i3kBQx4YD3qJejEv8BD7IWDIH+su9lvwe2L/Bh7Q
e7FdwF6x3ugX/GCPmB/2AfQP/Hmc4sLilM/jDAnbR4AhF+gx+gFGP9AnfAd9
AgYf7F/AWGfoC+zz8/vFALavY1/C92KM/Q4YvNA/4nXoH+IdxBdYZ8S7wOIS
eib+HfoIPySOK7AfQG7QP/hR4E62dWD7Lrt3/RfD/qBX0BPoA/QE8se6AcOe
8D3iSODPz52OX8Qh0Bv4BeDP78HcCOwecoedQu7QW4yH8wzGgx3DLsTnfHZe
+VcukDPsEPsj9AEl1hfjYv0hN8TpGAfzwTiYD+SN+UC+2JfE+xbWCXqP8XDu
hByBIX/4cdQDgyf0BfYFfWfnlH/1Hfbx+boFM4zzAvQL9gM+GBcY64W4HesF
OYv9JPQf42E/Axa/Y6MeeoS4GfPGd5g3eOO8hBLrDYx9EH5FfI8DuX8uR2cm
R8hBXIrfWfE75IJxoQfQZ+gB7AG/i++38B14iXmL34+gLxgfeozf4V+Bxff1
qId84W+xPtAfrA/iIZwr4S9wroB/xP4Ae8W82L3Iv3Y2yKZHzF+iHv4B9Zgv
5AV7gFzBF/KCnsBeYacYB/oqrodeoB56gXrIDfWQG+pxTkc9/ADqIX/UQ96o
hz2jHvb8uZ8KZfWwX/hDyB/2CflDrmIM+4W8sK7AsEfYBeJRyB9+FRj6Dz3H
OuN7rCvWDfoDzNbvs33LmcUp2HeBIT/oMfwP5AyM7zBf2APkgHUHBi/oH/iL
8yKgj5gv5gH+6Bd+DuPCDwJD7pjv5/erdixeAgYf6C/mj7gFchHP9/P8AWc2
P/ADX6y7mA/sB34V499eXTXfBLw70PT4d39b6/uxeU6JPlBpdKh+N73xffh5
WanHF3k3q5/NOalq6Mf8P1X0WWCI8aNzV9coMX5aD7Tbn7Fdr1pdyfzCgFmm
8abuQV/km2z2/b2r/G8HOn3L1w3Uk4t48Tt7yuEGP0rjHNm98u4x/dboHe3Z
Oj+NfrdL1aE6/2XGVt/tmvklzJ+1v3d/sKV7MdO3tbcHZ5vHFrP3kBl3phWl
dCtnPE/Vsw41rX3DeIyPKeslff+C3YcmuhrrqBflsveQpNu7sq078nmvdYJ8
2fnj2diTvtqvPL/Ij7gb2M419Ztsdn8a1ydohOnuY84nNvVbZct8Fkd2mrDU
VZfqxuKV3buyzOaKoC/yFxYOW9ZFvqSAm3KrZFN8TCGTW4zg389y4nfzNx/2
jrJEWZgfnJCZtEtzrZDl6R1slnJYEyJh907370uDdC72JPpwnxzjjQomhzav
q/T3GCd+N03/6kKIbp6E1O1TpX8pbNzBJ3P6Sac6EPH7f91LCx10SzwJX5Ob
YZhWfR8b+12Vve3/4n19U/jGRsoGnqT9vg2VKUer72fnf73gvOyCR/V7urC+
e5k/H6WvKncx//1w+8hodZgPEb9nH/nnj5bK/wURP1plvzs58fvv8gEOrZTf
BpGV3/TOkHXwI+L357n1B/1hHSsjaa9upsu6b+fE77OLXZQDLCoZqbj0ZH67
jX5k3f0lHZJ3htIijyG95aE+5JSiqV1qqyDqXjO27cWrDsSyb2Lb5GEe9Fu+
8dWEFSGk2V7PcYb5Vt48d4yz7rk7Xf7y98mmMRb+bsy352RRb7n7mjltlN0K
+I5FY6Plg71J2rsa+zR3P/ApHUIitRvyObKh048W+0x+xSWfSYaiUu4nvayX
/M5TftyV1Qma1+70wPbwCuPzfK798WnZxrJ3rGx9P/KIqk8QTdg2+aVxczln
1q2+I7v1gQ9p3mmfanAZ15Tbc0PmGEQki6WPzF9VcAW1HLy1eyr4jou3+epW
OJKQ7i/uWNt60PPKcyXGW37EOmPRfXOqNxkWuO0vqyGQBOSMcWr6pz99+XRs
XLsfw8jvB7o9s47wpeMupkSq/w6mA5xrPjQrEvmilJT+lt0yOuWHKv1K5BM2
ql4bR8uoJV1YL77y+t5rsrTgalzWMEU1KZimydLravv7kjF92jw35wXT9ALt
TP09Kc2SPXtsnRxA733XYp4hfhe/dXvpbMO1ABor+OddfMvC3rlmbQDTy07b
Gs80qINoRnDVvr+Xvx15YIop05fhCW8n19Uu8KVHuhumGrJdqdPmke/MLr60
QOWxMX6cMzXf1qssSV505qMq+zzIX1t0JUmVI6Wlq7s66oIP8eEJzR+ZXT/F
x5sDe0g3urG40qZ3ziTm6v4UxU0v2mGBYXv8XDv66HXbcaZLLvRQ6JWrCt0R
vodu31hTiCu99pN+qkl1lO87wGBNcXNh+0b2i423rCs8aa0Py5fpezixfcNx
1FO31O/tSIhrSGXKRxc6sf7lpXrDCf5Ri/sDpP+zpy+Duzyw7jjJP/ojs6fc
IqGGji1HmrbJqP2eO6MtC+3YO9/QWWWvzSPtqd/rmqvic6rfzyv9zwVpvyvh
BzX/JzH+gYQmDf/aTmc6x/+mnV2WElfCb37droX6IuWfX7YrNM4q5Ev75Lnq
ppewuHuGXc9mSi8ZOfhm1lVFuoS2WjLASTen+v38uHd0hDbXn/4tWd5dOrWU
X93g2uXC47609d89d2oOfuQzc2YtNBzwpb9aTjw37/nIO85eYrSavGiU+dls
w4MC3q1L7yHSkZQnijl+2sN5/NwF3ZTyd2l8hxaSY6o0My/p4lpP27j6Hju6
xnK15UIOd+1A1xDtyJd8wdpvlui35XDZtpK/ril5W/c7XxLx0u87+etCvjDK
57iqRgAxbwgtS9lfwv9vVJ8Bq/ba09kZM18Z4/L4C90dp5lC7GhWrC5Q+yaX
t28wwUPnUcyPejg0TLsnh7/7C72gGP+B3V/MVY6pige+LBeNqyq5Rw1Sxlgc
7ciQp/80VOeZ+S2bjklS5zgT381kr+ptHt86fZbZrDjJXc/7K1x72MxNu2ge
ZXGxp+Hz/WKkX+dwp86e7Cl3saMF9T2posDMtdEk6+KTcvgetpLr2K94jOUR
5dIHdJ9gmlHIuUsTZNrAj9zWtOtaw6Yc7laPBfet3sUc5DLEbthplcyObF5a
z1X3Ipdb1+Tpm5/MvvTkn3VbKvkirmBUzcT4zr40894Bu9T3hWx/fF0yqpf0
u2LO77vl5cZW1e/1c5roe0pPFPPh9SYvMoTbkb5u/dfHW05yA2LKg3XvJOTR
Xqe18R1LuIKXJNtqkpBc6boUxSMvMpHe/l2VUcC5Z+u/Dj/kSx45hddX7/zI
2ec9O6945U/ObMi4KJtUypXfim8nvyijC1c3Oa1q+Sm+u/5HbbW3jK6d9+sh
DZWQfoW9ItSzwr54z89fFrRCP96RrGoWwSn3H+Uqh0/U5zm7kIkZO1qoV0iI
quHMJM1EZ3Lo+rBB0jl2ZMquzYdVV1xI+uSz3aUDZaRDxoByYx87Mm9h5Pxa
iTIyt967r9Xz7dj5raVXp1GWWHuSnDTrrvWFjL1rZsSNma03HOISZDG7Vc5S
0n1YRx9dbyf2Tp7j8scVGXWl41s/vqII9SVd1ll6S0fu42z9+5LYhNQfpGOd
ydxfKzZodnuRcN2w5spnriRmkv86vWt1/kCjeR/bK3/wI+mbHpxUJLixd/pN
ow/O1J+S0rjh1x5bFwQQn/VejdXK3dyb0KQucm0AadQhvJX8TylpWLR6jmFK
ABndOuSZdZ6e82mx76wiLphcEvS/Ot/gbuL9FvLUHdwPZ5K6S0fLyJg7Wznl
CF9yKnHINdnTYOK1vVt/aXt/ln9gvuB9XjE8gMlpXMf8IuOIgC/y9JOmfjPZ
0EtGU7LfX1Co/Nk9SkT+gUAd58fuP1i+1JEL6+I7h9AHk6v8/05enK+gPj0i
TTFeRmfmvPHXtf0yfyFD8A8hNEo43yTx4nyFpF+0K/TRAdQzM/eR1bqbxbH9
LxnbyHkPFldgHU+t8su09g+grzvO2aa558Z4jgr4/lf9cRf2joF7jy3nZ1Qa
a/rQSIH3fpZXsOn3Je+Nk11Y3IPzR3T91s+t31fnrY86+mSPKtKTTtk25ahq
kxPjvbhu4hPrdAcqzo8IGJYbonV3pS+F/TqFF+dTnNlgXqSf50prdK7ab4/x
4vyJF8u1O+IXSti9U9Sp0+MM4VZ+kCDnL98dXB/18tQ2tvI/x/bMMp84w+L2
YXem84quhZz4HJgx/mkv+VAJXaJ4aZRJqvMtoHe3nq36x9i2ksmJT/M9qrpd
yNOXJQc0O33ZuP52fyzQH3Jj7x2Qd4sHWxcbpuWz+2nsZ0Wpitfm+xZ2P501
uftCw5XzrF3yquuPzbU8iThf4+Zkh+/layx8j0ZP0lTxfuz+Jnb+ACobV872
g9cuVf5vMy/OZ18a2nqgtF42P+/Kg4T42g5EnO8190MVrs9hXRv1mjRAutFS
nf98bm8H+ZpcrtfAmgG6mv/vHjiu6JWxYR47Z6GsPeJxD2m9XC5GntBEPeID
J77XObpj6xDLoxfcxUFXb1l/KefE75bmskbTTRPzWX5XM0O5JeXbSnZ/dPzm
k9OKKcXc8akLJpsW+32R31V3ftf1+oESYnnZpLb2uoXdo0emXwjT/lzEeOD3
ccfPhapbWLldMx3W6pOq871g34hD2kmf/SDtGSR6twkmKRM3PDAHWrnGs46f
UDVxYOdi6Kn7vh5XZTNdmZ++IeyLruz+eOfEzB3x3X1Ij6bnotQbnL7IP2k2
4963ylrV+Sd1TWlb4vsFsHNUyHD1G3NjP9K45rgM6x03du9dY2i8o67Ag4jz
VdpE3r8taxlAOjnfDdRF+bH7ZviRDgWv71lHhJC7f6kS46N8v8hnCRodft/a
JYTIGm2aZ+hVnc/iOu3qM/M5VzJI2Od96QX31Yv0R4q58rTZYywRdpT0+7hD
kxlMBi+ZZZAlVPJTHeqF6rrkcz2HWJfoGxXxnTzCGihreZGfktt3l1stvOfD
5+NNSmd6t4txht7oRdLOT1coa7lQ9y78YFOxN5EUaa4oBvjS8Bkrv5XnBZML
khX+usn+NPNdWJb5Dxnp1dJxnybLn6asvX3H2i2MSg8euyM75U/rJXRK0ASF
0YldZH/zO/1ojT7fP627MZTG7J3xyvyHPzkUMWhlfL8wqq33JM40yZ+sCZjQ
Tv6HjJ54bIosifShH0cea5DVIIj+dsuuycVBHlRif6T7mHQ/Gr9hxcr4Nh7E
vaZma/xtPzr3WZfpBntXOvrY1V7yn33o8BsNTfPCXchh1eQK/yJvelua9tH4
wYFGna4xTx/tQc3NDoWpwyr5K+VdVuhVjvTu8e+XxidVcPfaFPeVrnKkXiVX
6iXGhtBZf/85vb+fhMq6uAyxNAmhN7ufPaQwW/nYG9GtlPWCaN7FtjetvSt4
6b6JXeQbC/gXNWObKjeU8q+EuKSAv56dX5LyQyn/TXKRn+7qB+5ieOYI07Ay
PirxYJKmbxC5O2NYuHpDOV/cO3m+vq87XbA8r5na38LvPbXmL+tFJ3rH625H
6f23/LTRh5Tyk840ol7UGdmrd/xmrv8Z1ep8fvv9K1nWOxa+41XLdJMkn5WO
c149Mb9xJ5ObjZ5meprPJ3Ne71MGetO8Ifcaq//8wNXeXtdLW8eLNrmpCtA5
fOCCGx+5bm36lj9SefmYqnMBF5FvuC/rmc+7dtvcSd68iMsK65RvXpbPjSn5
K1lzz8KRX/JqaC87kaXRwxXyO2+53+4nqS3HnUnKE4dI5bN33Hpnx0uyfu5k
yFfRBzQ+Fm72vPaHVMtDaOc9t+6bf7Vyy77e8638STBdX9BcKd1eybkkpz62
ringKsLrbNVsKeWajXI4rxhTwPnwT5oqe5Zy9T3qxayKDCI5l2YOM3Wv4GA3
kblLQnXeEvKHZuAZRZMQkiyMb+XOXyzQaUIquWHHdt2WxTh+Ovem/BZ/3YFu
O1r3ifl/HqRd/0HHVRYHcumXGRdkLT3I66jXLZR2riT8YehhzfhP507TiTvW
/h6kScX9EiPvR8gLt/fmUB86YdCCoZaWQaRg6wuP1Ho+xLBnVyd5wyCS7nh7
a/wmP3p34+Y66h2hpHOPgqbqHX6ke6+4NfGbQonj4H5OqU8++TfN7DhD9zBy
6Y5TE/VJf/IofVNxSmB1/tHE2fWLU/pW54e9LO98QRYTRgMapHmkflu9zyXa
1c7kerP4i70T7yZxTrpfwuiyZT9t02Tnclum+w6RLs3n1YIcqvNF0f/FlNER
6p/DSFFKhsnK57A8neQRRyzGGzl83xG1F+uHvOSWC/Guge0fvKB/lJvQwppr
PJnHqfV/Buk2n+c+Nhq7QVP8lruoH/6rwZkyvz8kcUSSKjyd+2n7msuyaSVc
+Y2Ze1RqA7fP+3VN9bEyLjF03lr9kPN8xpvEuYZHH3jH1Wc2apK382rPy1MM
E/7ijwv3W4ncGeE+8C+urFVVPHue2y7cZ37gOq6pOs8b+FiBTxl/zFbPd3B5
uFNV+ZbNy5I7qLHydB7f4btlLZTfvGTvdTgHvhPioXz2+xVhnT6wd7wY23mV
yxLOSS/ZO+yMqZa28uA8do7C7w9vLXFKPf+Bh59Q9dVON+S84DclL15gaGnh
x+/oW0+96yVbV/n7l0/NbXP5I3zpfVlUPsvHUh2ZXUcrvcD2/dbCucTCvR56
XK95WlR9j7lzon3qgkLO40HfnnLuPXtXyHtvOCczV/9/gOPR3q3kJ6XkTLtp
cwwLA2jUiDo95YOr8/vtl5VNM62U0Oxn9/8xxznTjpt+Xq/vJKGjDn6VrvB0
ZnH86ptZCw2T7Ni5wGdT5GCptDq/3pA4v6u87APLBwu3xQUsLsM5F+uTuW7b
1vjfs1n82PTRRqV0ZBbL+8jUzfbW8f+w+M++z9KClOFv2DvJ+siw9vJfXrF8
r8y49rXVI0rZe3R0SNW9SnV+uWvZtd80Q8q4A8K7UhrrJ+qnjw3UDmkcfzmr
vXKoPbm2rup8dZxbfGGDn87qQFb0klxVOFbnj2d/zH1r7mlH20zzCtUWupAB
I4X7IBZnhXg8WGTIOcI98F+6QxPmSohw3krlZnzjkmF1cSdpgl0eZHkw8gU7
PqboD3KxbWrnGF9I2f1s1pxeZ1X2PmS+cJ+wj80LuIb9gCDdE1/SVV51n7SH
WxYUPdJS7kcWCvfHu6rz6v/FL2ckh2uNAeRhWf8/ZNeTuB++8olSFwaS9f3a
e2kDvdg7ys64jHEGH2+SPEnDK3oHsvMki1eE+eq57/f2HWdKC2b3ua3XZ7vp
8kJIkRDf72R5NLDnjsuHlKTskRFZ36p13M5lbN9SMzE7jOD+EXrmXK9KPlt5
yW/pt63Pw+hSeZU/3Mm7j2o1tbxxKDsvIo7d3rnqfmknHzl4dHnK6xC6LbXK
fpL4fVdKfpByQfSssD94sXf4TPdVZ2S/e9NeWRE3ZemBdK5DZm+LnzdN259z
U9YrkHYW4rpd7B0f58uE4nM3ZEWB7Dy5ZkrZPk3Mp/Okv/SM6pQPWXMp2mL0
/RRX65Kbq4N92bsX3kGX12lrlMUG0653vrJucPQmi8jYCf1HB9Imbv2M1g9e
5O+9DXx0/wukaTeF+3WWd5awoOrdcQ+f8f6Zc2qFH3UX3qeS+UsVB3bEj/Jh
953s/T9R+tao2c/XH1g+ROrgw86L7p6tnHVWd9pG4HOE2dX6jy+GmFSpvHt+
bKDWzZ1KBP34nc8pin9kbeVEY591JUo7OxZX9x6brTFMq+QWr7qxWxPhRNc2
b/RA5iUhNbyHzjR0dKYrJ+1sqdSmsfNkXPrm84qA43yQ9t2PUjtHWi7wO833
3FTXaPW28mO2V9kHz/xE3yfnTiqSQ0msso9HqlZCu+2PzjJflJGXpoyppujq
fL0aJd3jDKPK+BmyPj+bHINovfeXhpkiKviVPx9vqHYJpCOzY1fEZ5fxV9Lq
xJke+9MOZ59lmYdX5/PhvnLDA6fJpuuf4syVY9bGu5fwS9fLZ+jretP3aQNe
mp0K+bWPxuUaPQzsPKhUkZAAow+RFhi/0nYpZP8PpIoKXh0/qJQfvNXNuekM
f/JrT21z5Z/FfEh2ja+0+wPJDtv+xwfPD/v9bqtA0nbLlThDRBmTU/PHxf0t
M1/xUd2b3pVNcqDFQduXx8e85vc+eNpAefRT3Lll1xmF40u+6cwf9JqQjzzu
Q+f+WXU/WZ+dO2N2nPxGeVrH/5R7a4m+6wP+yrGv2yvPW7hKl4I5+szH/K59
tX42RRRxL2Oq7PAJ/3HgwfyUdVaus3CufM7eSzskHvjL/OMbPnxRUGf5QCdy
SLi/e8UX1R5VR33WjewR3rPy+SNbB9yznnQl02zxIb/0r/OjTAY3mim8A+Vz
MXs8p7U74UrfCfeEb9m9c+S6+emKe/9wjVpuiVSusvJZwj3sc3beHFPcRKdZ
msXRnRX7VJZSvly4b3zK9V1Za6Alo4SfJZxznnJ5EbkXFZcs/D3DH1s0Lx9z
E9qMyzF/VcSnu4zy1v78hO3nOzvPTFOlZ3OIp7cJcUQmd8LqME/fMY/325bY
Ufo+i8UxHTMHjzetzeEWjm2wS5VSwV05F31YVfmC6/Sk481HBwLpoPJFmeZT
ZVwMabg5vmUg/WHzkifmemUsf2XVZosufkYRN9dHVWG86kPrCO8ChVyfSYsH
WhJOcwsFv2Nl+0DyzsqJpvwPXMw1z4uybHcyUrjvt3DPp9daHr/FkyRs+HOl
fuIHrvm2zNCsWt6k83XaUC0p5B4KcZQ/Wbz5doD2f6Us3+pbh6xnVm874mLv
E6TdF0rLS1J6yWdJiOfZhH2qqDK+y4rnq/QP7AnedbEfIk9ihO29gRT/OFOu
nF3JP1sU7NC0jhOpbYvD2bvJZeH+4xinfJPR+mIbJ6LhfBYZ+tmxc/aRv317
y5USIonV2qVKndm59k7yjVOqCXYk4Olj177zQ0lu++Cxk4wSsumwZ6pCl8Lt
vrC+m9TOg2Sv/emZuTCZW9Z+65m7o31IYf6cBspcKcufvNmrMlru4k27zh+4
TD8mkFD+qKe20ItuujFrgmlIIDkj5G3s4TJ77+8m7+NPuvcT/DlXoN/3wchV
v0e2Hv6/uuqmoWT73M4huss+tMvAsg3xjsHs3s/+r9p2qR2C6PFbP/WS76nO
r6x/d1t5t8bV//+J/ITWDU50lCuD6fi+56ebalTnTzTP6VFDTavzmNx6j31t
HCijd5ce55Q/2tEc84mBlrmhtEP0iKuKmxI6SJ/RU/pb9f934F5h5sWiSG2g
hB76ppebjqvOd645rrZRNjGYPNIP/ZDiVsn+3wPv+ZX/BO9RbfKkPwrvxh/Y
PWKH24FTTM0sfMLfxl5SqStV+92upz2Xz//Ppof8SUu5TPukiB905OIg6XfV
+aF4vysIGXFMNbeAb2m752T5oQPUs18Y60jJwStfZcgGWdj/l9zs33SQ9Lf3
fL8Jd11T//El+nsjrsvOFLF80sV9aYoq/AU/LPKek65VHheR20FleZTF7sVe
CfH9Y76pcD9TwvkI56anfKTw7l3O8k/tlZe3xbvbk/wFa2caInPYfB32++Wb
9+RzlX/3P6eY7Uxnx6UeUxTkceUBEQ3Vg51oJ5s/5tbtvxio+9rCxQrr8JIb
/s+Ka4q6+V/8H8xd4V0rh4v4+kOMJaaCc5/pPs709AXLhxkmvBe+4FwnupQa
d9kTubB/5XFLyawmWVMcyK72P/tqu7xm7/4hcbW+k/76hmseODrWst7xi/xM
5+Cq/aGcS+4d66cLC6Chwr1pCVfjcUmEVutPE3q0SdQ8LOZGJIdel5mLuAXT
N4SpG1RyKuGcV8zyv2KbJAXpjvmSVbb9kHt69FiA7oYfGV7zqJvOpYSb2/Kb
cK1rIDmQ3vu8LKuMvfOvGzR/k6Z1BTeq7uP3yzoFkyunZqssJyu5wkFeTrp9
ZVy/sw3+tm62Z/d61+aOvSPLdiCjfcyz9dPKWf7T53F7df7TQ+cNZcaLdmSQ
sA9UMrmA94plS2toK5yIa55TR6VT9f/LT4ze0kFZ5Ety7gTVU18JoTrhXd2T
njnSuJv8N3/6MOmCi66mO5XbhS40ZPvSa4sbnFSUu5Hma0ce0BT40vAlmtX6
ZfZkgn9pM+UhN2bHE/cESLXnKvkjc2vdsR4s4+MaRJQaN9rTsfseKZS5RfzY
GRmpirqVPPaBul+9mWR6aE8zGrp0lT4LI8SaMFD6xo7WLHizPT72PVehrdKP
j7xk6G+r9BJ/8tc4WaS6RTGfItzLOJLSTh3LU+xy+VG3q+a1iTO0nLAxvvkD
Ln1fxG5VbSl9KrwfW7j5cX+2UHq7kt1vzwyWns7nMlZPqa/+JZj6eAfP1HtW
chei88eb2hXxsjzDDP3dSs5ZOO/5EBffJ0ma1kWcn7VPbe0JezJX2AfcSAR5
w59wcqI9jsVMaBcoJZElE94bF7hQ3f7792WcD2ndcT+vaOREWh/dNMHw1pOo
x9byDNjrQmbEzb5W2MiHPBzQbY9qpifdmnHhlXmfP9kp8Prk/3LjVVLfYNJ3
15Zppks+RBe9X6F0Cv60n0wdKLX3Iy3DvnHXnQkh4Z7znFMV/jS57vYArVZG
9vbZkxDfwZ/UfjJtvn6ijFzvph9usXciSfsTb1qDpXT9zrSJhjNh9JKQ/2NP
25VP+se8P4ft+/U+ecHU0e/5jzO7VaY8/sgNavtraUqFG809ftI19YMv8fm9
9Hu5gx/tFHM8WHs6hBb4DOzfM9qfZNS8ePHRTBntnPRmuGmGJzEfnrhSn+xP
jw/9eZwp2YV2n9YvVNfwk96NHumpm+dCFk4adE1BfOiYwh3z252ypxF7LndI
nuNGIec/hfu9Sj7JucclxUp7+kp4r3Yj9jmCPyauKx+/Mv/mT9QVNb5Wf/Sl
xc7rmysvh5DSicJ9DPOL9dZHuafWOs/uCxaObTvCdDaMvFjUvI62lT3R1Yha
pef8abMAy6r4X2TUcH5ZobGJEz30dVpr+WtPevpwz/uylT600VxdA3XbIr7z
61GXZOHuZGrmlTra577k/wB/+Lrm
     "], {{{
        EdgeForm[], 
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6], 
         Opacity[0.3]], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNm3f8l+P3x+/rum4zCZkhlXytRIlIqCSSjJJsCQ0hUvaoyPZDskN2VlZG
9p5fe8+vnb336neevV7vx6c/zuM673Nf677uc87rnHN9Pm2Hjh5wYK6q6oa6
qkq0iwSlIGTN3SJvF7RM0LJBiwfNFzR/UMugBYIWDFrCMn4/GxRTVi2ClvTz
heBj8ueiXThoMfdhrqWDmnn9ZdyyfmvPyzorem1+r+Dx/N4yNjk15r046MX4
/YLXbOt5me+/3kuroC2if/OgZkFt4vdS7re8+zDv8+7bPmj9oDWDOgSt6rXZ
y388ht/ruO8qQWsErVRp7g7eB+fXItabnfRO20TbKuhlz93G/V7xPGsHdfJ8
rDN/jO0S7SbsN/gls/aCbHWvuZ7bNT2ulffX1ftYi7OLcYsHdQz+Na/TLWgj
87xHd7es/3bQW0Gdgzb1eqxzX+x9ZLRjg3r6jFhnRsi/jPaLoDc9d++gy0M+
LWnuzedZs5fHbcAZxPP3/I5fBv++19wq9rtc0DJBV4e8B988aHrS2n05o+A/
oS/vHP2+TVrnXa/fP+ijoG2Ddgr6NKhf0PZBm0X/XkEfWMaeNvNcPf375phv
62gHcL7Rd42gw0K2ULSjov0s5PsH7RU0NGhwyHcMOi6ezQz6NmTfBH0eNCho
z6Ad4vnAoCPi+YBoB8873vvc2+3OQT9Ev6+j3YVvGf07BB2V9F3Rr5X5hnzb
oGN8Tuv52/Ct9vC6+7kdEjTKLesOyuozIugA74P174y51g76Ab2I9qdo9w1a
N/hfoh0e9Evwv3psv5inddD3wf+RtN64oMO8Huf0M/MEfRf84Zax5llBk4JO
5D1jjp2DVqSNvusF/Yxexu91gibE765B/4bs0KC/gv4MOjhojtebEPRE0hoT
g34P/jco+FOCjg46hvPI4k/mLIIfErRS0PrR9x/vvwSfg47l3eNZ56Dj4/cH
QZOCxnPGIds96O/4vVvWu5wZdLbf6aSgyW5Zq230+TdpLydHe1q056KnIX80
fj8SdEH8PiPo/4Iu8/PzWAt7Cpof3+ezY50L3Zd1T0vqf2nQRZbRb0bQlUFX
BV0RdH6ldW4MutyyqzwX4652yzoLo/dBU4N/Ltr/Jj2/0nMw5jrvdRp7SVr/
2qCbPDd9p3tf9Ns++rQNeod3SOp7ayUfjf8GC7YPfpWglYNu93jWaWAVmHGX
34F1zk2a4x50OOgGP7sv6LZKc6wag0vWedxv2Ux0APsJWiToofh9h+d4POhe
z/GY5+b3BUn8o/59q9d4wn2Z+2HPwR6ftOyBoL1jbK+gRZOwl/cAC5/2e4G/
4CS4BD6Bl4v7N3i7hH+Duy39G7xd0r8ZAw608pgV/LuBtWDfc+4PRoONz1TC
+mZ+DkZiY9jyKK+34jxzgVFgDtjb2usypk0lLGSOtv59m3Vhuvfa2nO18hzt
va92HsMaq3oNML6d9waWruqxi2Xh60teDxxc3ePBPjARP4g/7+E1wDgwDyzt
NM87dPIz1lnL45fOwt3XPS84uG4l/KbPylUTBneZZz1+g5/d55kXvoG3tGAh
GNjL+wPrN/b863m/4CC43XWePXX1Gl38HNwEI5kHPAUz36iEZWsmYfKOnGcW
Rn7otcFJMHKaMZM9DUjCYzAYLAZ3t6iEuVt6T+wVjOzrvffz73fMsy7xxqve
D5jc32vhz/AV+B2wdXuP+V8ljAVrweTZ0e7AvpMwHtwmvgDLwUgwGHwE1xeO
/jcm4fFaSXi7eyXsBXfBNvzihV4b3AUHB3ku8A4c7GD8BOPAXDB2n0p4BeaA
E2A7eAn2NTAVjO1ozB/mucC1UV6b5yO8zgF+1tG4ehBknP2xEm6O9RiwlXjr
kOB3ScJdsHaI597PhH2CU8ON0WP8/DA/Y73D/fuPSth7VNUUZ7CvdYy3YOJI
4+1xlXAYbAX7djfugrFg6wTPmYyrJ1TCWLAR/OtsLAX/wFWwFvzjHOfiXiVc
hWddYiLiId7vRGPrqZUwFb05vmrC0Qau0jZiB1pwbpuYo38WPoOxk70W+Aw2
owvtsjC4Zv0kDJ5SCXfBTfB4quef7Hkvsg6tlBTj9vZz+oGP+DZ8HBjAHODb
pdZ1sA98BbORg+MLGEsnWy+vdD/WuMq/T0/C8kuqJjzm2ULG3os9BtxrYDgt
mLdgEk5Oq+Rzb/f+mHeGx0xOwt1bvNfpfo8zk/D7mko4P8PrNjCYecHkZkm4
CfaBkWAjmPlQ0IPex52Wsa+7/Bvsvct7WC0Lj5vHXOcl4fcsnyPz3uN93+ff
rH+/f1/mvbBvMBs5+2mZlIuCgS2SMJj1LkzC7Ec8L/t91Ht62Ptm3if8Psz3
pH+D0/Bg9+JJOA1G94m9L5L1+yx/E77VK9Hn5SRMbVMJG8CKzUK2VBL2Lhjj
FsjKf3qHbJkkLKUF08DI/kn5LTi9XFKOCo4tm4RDYBDYAN/R/ZgDLF4+KbcE
c/rGOsvaL2+XlOOR320e/IqpKd+jBbPAFnAAfGntGA3fvnJSfoVP/zwJG+fm
x0m5JdiCT6c//rxdkn+Hfz34Mf49NAub8MHfJfl85lwtKSfD/3+dhFfg06Dg
26cmDKDFh10Vso95p0o4RD7Y13v41LJVjSHgzdJJdQHijg5JORy5FbUJvgmx
0OiQHxi0etDgoDVSE5bQ4vv7+Dn75j2+9L4O8Tt+Ffw+WXjEONpvzY/I8sP4
QnwQvgg/SItvOif4LULeyT69k30yvn3DZL9VCVfABPBo6xjXJuj34Idl+WT8
YpessePdBwzA/5Mv4dsP8nhyOvBry5i7S9Kzzzi3oL+DXz3L159g/p/gCVw3
MCaAB92SfBz+DczAv+Pbd0vKo5CBSeRuYNZfrJOUa/VNejfGgCtz3BcbZ85p
lWx6iaS4eLvYQ/ssP7dxUkufnkm2ip1uFe0mSf5yStCmST4Lv4sMW8XGF3H/
PZPyHJ4n+yR8H3bPnE9VsjNqONhaneVf8C39ol0s6XcL8/iUOUm+Hj+P3uGb
WljX8APY6/PWS3SyYf/Y/iVJdo6NY8fYP7aPnWHb2PVf/mZ8L2wXWybWnJWU
txPPYMfEddjywCSbxB6x0bbmiRmxc2yc2gh23qifYHfEWtg9+NfbdrZKkq29
Fu2rSbHa17YrbOqtpBh0R9sNdkTc1dBp9PndpLiNmI2YiFgI3aTGgi/AD2C7
zI0tU2cgfkJvhyXVCJgL/e2cpMNDk/TgAetOd+sGtkIcNdy638U6iX1QZxhv
3ST/Rz8/wbekpriH9lDr9Ya2wceT9B6dR7/QJTCIb76RdYl4Af/YzXqHToLf
zayTM62DPbznIdbpada7XtY96qjgB7oDJoAZ6Au+HD/O9+ebb5Ga6jW0xLHY
X1/bF/i1dRJmoV/UJV+2Pva3TnJ+e9uW0AtydfQF3dkhyYdjB9vaFvCxxOuf
WqcGWq/wefhQvj++Z6ck39fJ3+5n+w3qGnwr/MnuPm++z27+RvhXMAB95Fz3
bNhptLsm+Tu+8xCfG+e6V2o616E+W85mmHVmRFLcPMbnBM9ZHepnyPdLiomP
s56MtBw9Pci6Orc1zxz7ex6wZZRtAaw40PpMO8o8dcXDk/CLMwU7yIXANvKc
nS07xPK3zYMv46Idy1kHf2RSboN9IRtjOXMzz7aeZ6zHXpn0DPkBSe/Me832
XtkbOMecQ6LdMCseJU4+Oik/4r2oZ7I2Nr5+VtxO/ExOdrT7HJuUW+1qXWQs
ukndkme7VaptHu0+45PyKeTYMzw2e3vSM+TUAycGP7oSjpKjgTXI4A8M/m6v
yxwnJOUmR1Sq0zIPPgeMRE4+QX2PfkfiD7Kwk/c5KSknOdXyE60PXbPemfxh
A7fE/qcm5RVT3OcUj+2eFVcTY5+VFGcTY5+RdLaX+JyZi7h/o2i7eUw3y4jT
wSiwbSH3OdNjN82KoYnnN8mK7Ymjz0mK9ZFvnMWz7k1J326Q5d095vykeWZ5
TuYiLu8ZbY+sGLqHZcTRxNPIiKUvSoqzkdH/Qs9DXYU6Dlh2XbTXJ9UU8DeX
JvkzcIt6BLUIMPCypDiYcVM9lpiQPn3c93LzPL/Efa6wnPnAwyvM96xUy+gR
7bWcgfdwtXlqHWDaDUm4xj6nm0d2nfkeHrOp7esq2+9099nSdn+j9R8/SL2D
mJSc/v6kvB79nGVbuCWpzwD35Tfx6m3mB7jPrZa/k2QP2AJ4eEdqws+7kuoJ
6P7dnp/3u9p7u8dy7OKLpDh+tUp6fa91e6T3SozJfuGpTYCx93jsA34X5Pjp
B5NwBmx8KDXl1w9b/4klybHxD6zJ2uQP2AxyMPSxpBr46cE/mVRrmFiphgFP
bEgsQLxBDPJ0Uj/6zJf0e6L7Ip9QyT6etY0ge8pyMJj8ltyWeA/+ZsueM48d
vGjbwW5esO2A4c8nzYHtPpNk7+j7S9b55z0PfcgDyQepYe6UdX/Jb3hyxeUq
vffjPgewlLiKd8Vvkzvhz980D1bQvmE5mPym5dg0sdeO9qXEWLvbN76X5DOp
Kb2fFA/h8/6X5Pfwdx/4Gz3ib8F+PrR8vPmPkvKCXbPuLfi2/d0yFgwnfiJm
oibz4Tz9P/P35RnxFTEX8S613RWtG7Otk7Otn+SYxHzoODj7VVKNEpvFR1AH
Zg5kPHvffp2a1BH2G98k5ZPkm9Qlt6mUW8I3aqH0a8joRwz8vXn6f+M+fTwP
z8DMH5PqhuDbr0n1O2yc+iH3XuARuPSTefb1u/d2n/tja7/5GbjEfMxLTH2U
58efzL13S4pnqQFSN8ReyaXgx1mfs3MY6mDkIZPdl37Y7D8eM87tXw15Ut2N
mhu1N3jqZuR7/1i+h3NA8kHiYNagzvad3xlMnuO1yWepc1Dj3sRyLnCIkbE1
9kqexX7hsTuez/FYnlEzol5EzgV/t2W1a0nzmb/bfeZzbna19aRxj80e1rUt
Xmx7ZG/UYqi/o2fcDXAvQJxGfRlfzt0E91L0p94Dzz0Nz8hViJee9jPkW7gu
tCg6ltXnM8/R3PMsap4+1PWp9VMz72h+Les19xzYQifvrbOfL+H+tC1d28Fe
Wrj/3LmzfE9L9+/oOZbyPPhfeN6bu1fucLEz7IT7gs39fGn3p4a0jNftVYkn
Z3zVz5Bzdw+/oZ8v5z6tzCOn5fcb/iYL+PyxO9bF1t7zt5lbg8qqUeO7iPPg
yQu+97PR3u8KHksthPozPo3YDp768e9+hpw7X/ijrL/UX9A3YnxiYuJhagzU
PakzvlpCL4r8zYA6fFxRrkhsyr0A9rtv1j0B/vbdeP5pVry9XvR/vyjeJY8g
tgRnu4f8gyLfjO9FPr6STyYexYdB1NN5D/oR++JLqNt38ruD3cSmzMG7dvY7
0q5rvl+s83mWPzk61t28KCd/O9p3svD0k+D/zvLJHwf/V5afWD34R6xjKwZ/
h/WK2Jz35QyujDnbFuWR60T7pL/vxiH/JutbnRnyHkX54pvRvpD1nZ8K/vGi
XIozWM/nc0iM7V5Ug9gq+I+Kzuba4DsXxXcfRvtjVg3gYc6mKC/lLIjPiT2I
nYmhiQGIi7izIYYhN+LvOna236O2hU9L5vF5fH/q3TP9vowl7uJuGv24vtIc
5HLEgdwlkc+QyxC7E1cTM7D+Rt4DcSP9WR/fzph9vbcOHks+xDw8p77V3nrI
+mt7D//x3tjDyX7f0/y+5BHEVsQn5BUNGfyUqimvIKdgXFefFTEbPPM1cpsp
trl1rG/4Xur2+FvWZx/UM4i1eEfm5vlq7oPes2fer6G72HFz95th26Fmii2B
OdzZgDu0e/i7oDuH1dKfzYK/v6hOhI6MsZ6cHu3YWvWCjYp0CPkawS9eq3Z2
QLSTinC8XbSlVg1ur2j3rhW3tfYlPDW74dGOrBWrjYj22KKYbYlofy169/1D
Pl8t+dBor6iFZevG82Vq1c46Bb9krXpQ++AXqlXXOz3aH7Ji6/WD/yIrvj8W
n1qrRvYl36hWLblbtBvW+jsjbLpzLbv+OsvesLUe0faslRt8G/I7ivKCA2vZ
HnZ3IjZX6+73omj3KKrBdIl2dK264WbR9qr1N0GbR9unVo6xAfZXq1Y4POs7
8Y02DvlrtXIp4plhlhOLkns3fMZg+8mRWXeE+GHiYmJizpAaHXeQ4BHnjhzc
nvu3Qfb/xJLElJ96D6zFPR+2vIf1iPmpue9pfeL5mcaEIcYFiOfEMMSzzHm6
sQVcbKy5i/fDuL28Z+4tuc8Y7Hcd7vflO+3jd6Td1/wg6zl3AYzbOytWH2h+
gN+BuSZZ/4db1sbrsvcvPJ6xO3r+QX6nkX7fPf3uxGPEZiO85xHuA9+I3YnP
abcxz1pbu0+L+J4PZtWhj4nv26aoHplCfndWbfvfkN2ZVae/GhstqhEujz1l
1Y9vCdmtQfuGfKmQP5VVH30tZK8X4cXMkO9UVP9bKtphtXKqUbXsEF14nO9Q
FL8sEbJHs+riDwf/TFZNdIHg78uqr88ffF2rTvBKEZaD42Owy1r1sA1DdlpR
/PBwkX6j2+vG8y2L6tqHoSNFeQd+aFNj2SnRnlqUh/WM9ohaudnR6FxRzr5w
yB7IqnW8HPwCRTnr7yHrXyv3rkO2R60cdUa0R2bV0B8p8nf4uqNCvnqt+s2q
tewNWxsY/L9ZmNUv+J+z4p052IPlO4T89Cx8uyz4i2vZ0OcxxxdFOfsgLliK
cnl8xp32Gy9Gu3NRrfzE6HNSrXzyLfx/rZrOZ8F3qhXz4JNmZ/mlj6Ndu1b9
4rXgDy6KMW8M2aFZd3j4jE38Lo8F/0vW/cZpwQ8sqj2ch7+1fL8i/4vvXTza
fWrl55cHv6f92K7RnlsrX/0uxj1UFNulaHepVZu4N9phRTl9s2iH1KoX3A0W
FNWbtynyrfjVySE/p1bO3BJdrlUj2JozyapzXxf8+kW18AXZT60aweDgf/J3
ubmWf8e3XxzyqUW17FNDdlFR/kjtjRoc9YdG3Y2a27nmqTPgE/Gbc/OZrLte
YmxqF4ylL/H2Vpbzm3mpDRKbUPsjPvmg0t/fkMtQx6B+11izp9c622Mb9RDG
IpvqPeC397Y/xI8RsxAnNWIoeGIValb9fJ7Lem/kCtQbtrXv5Ry39ll9YB91
mn1yP/th6gr4K55/6rHULc523EWtlT1s53WH2F/vVSk/Ik9b1HseaF9K/YS6
NrVvZDtY3vjNHIt4LPncbJ9bf8v7eM6F4huOK8pzZ8W33qfojuLx4BctquM+
FPzoojueI6I9suhu5v6QH1B0d7EkMU9RrHRyyLcruufZNtoniu4erg/52Kz7
mROjnZFVW2gVz48q2s+W4LztaEI8vzGrFrFJyCdmfZNz4vmUonsa9BQ/wvmv
FbLji/Rn6VpxDDFM71qxxY8+g818Dr3No1O0/MaXkgeTD+PHvor2waL7kqt4
36z7qAVrxWTEY0/in401K9SKpYij3uC9s+6mWtaK7YjrFqsVVxFTzYl2v6w7
41WCH1+UF+dasR1x3Y7BD65Vu+RvS9BT4nxytYm14tYzoz2rVr3supBPy4pp
OUt8E+f5fchOrVXP3b7oO/GNwJbXs/BlUvAb1Trz46PtW1THBVseML5cix/I
ihvbE6dl1arZ++is/bcGA322xwW/RdG90PNZWAvOkle9lBXjtauFW2BWW+K1
WvVg/DQ5Kr76EvxhUe55VrQ3F9UV/4hxl9aKBx4L2aNFfx8xqugsOIf32Fet
+sb8RdgGrp1RKzcjLzskyyfiD/8M2R9F9wzEEXxjvu8VnG0t278y+HOy8vEW
RTaDvTybhfHgOz5yUpafBBPADHDh+uAn1MqhaLuYvysrRiE+WblI59A3/hmG
eIVYhRy3Y1GeS/zO9+BbTMTWsv52plnIF6l1bzEqK+8l58U+1raNHJSVo5Kf
Ei+M8fmvE7JPsur61A/Or1VDAK+Iv8Gs+7NiF+KW82rl4eTgYO+lxl/ilCOy
YpUrsvwIPmRZ3qPW/cdJRfE9sf1H0WeNWjFj85CNKMopz+fdi+6b14rnHWr9
PwexVYei+Oo99KJWPnpN8COLfCmxwyWOH+bGKbVilQvj+QVFNeblauVa5Fnk
W+OyeOKXD7NimKm1vj3f/emsuJCY8GxspJYfQ7/ezdKxV7NsAP2flRWDEn8O
L9ofe5sc7TG17p57F9U7qHVQ8xhbxP8T7d9Fd1b44Bvth6+NOcfVumPYPto/
s+46hhIL1bqvvin4ZYk50B/st9ad+Y/B/1B0v3dBVmxBXPFdyL4tuuv7Ldrb
s/4m5Zfgfy66o6PWspu/9XlZmAFe7Buye2p9o23w/7XuXQ4P+cysvz0BH/Y3
RjQHX2rdn+0WbS66Vzkk2ulZf7v0UlE8hy4Ri3UrisfAjbN95tcEf3CtO+Lr
gj+y1l0hZzA56xzIg8l7wf1Tor0p645921pxDLb5fPR5rui+mjiUOJVYFPyZ
ZH8IRq1gnKK2tF+t+tKMIlwEE8/HtxT93cDX+K2iu9YpWbEacdrJWfkDuUOf
ohganaQWRY5BfsG3uizre83ChxXd91+ahbtg7n0hu7fo/p8znll0zo9l5Rvk
GmcFP63oLmmroniOWI5vhV3xvYidnyzCR87+maLzH1Ls49D5aG8runfvWoTl
4PhO0e5c6y5tdsg/K7qLPrTonXnfW6K9oNY9yhtZ8fTHlfz32fbhD2Xlb+Ru
xPh7FcX5l9fSD3Tj/wGFL283
           "]], 
          PolygonBox[CompressedData["
1:eJwtmHv4T1UWxs8++5hEiSGVmEKDSngkhSIKo+R+G4xQhERu82DItQzjNpQo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           "]]}]}, {}, {}, {}, {}}, {{
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwt0ksvXHEYgPFTM2ysLCzqEhmqUwu3oFZTdGPvI9gUZdzvdCJklMTtOxCX
BauuumJBxL11Z+fyOfxOYvHked73/5/JnMmJtXa3JD8EQZBGBsLORi6KUIYa
JHDuwl40CC74DLeRIEiau1GrezjNs6jDhrnPvd96mIvNJYjh1vyJR/gz33Ep
3/M39690guP8YHevB/W6HuIFc0P4vbqRl7CICeeVdk9cwc9cxZN85LwZKfOL
+VFX61d9rE9wihXsYBmjzpt4hL/zPOYw4DNbdvX6n/7Km+Z+PaN7+Yavw2fB
Qfg7+MidSp5GOS7NFbznvIwPzV94Crt2cV6zS+qU7uLV8H/Uf3VUZyETnfhl
38bt+IGf6MAfdwud7esCHkce/pvzeSx8VmzjI3K8CJH3d+INRK9Aig==
         "]], 
        LineBox[CompressedData["
1:eJwl1WmUjQUcx/E7M8YMoYwsbZZOdbK9KBTqXRJ1hKk3docZoRhrJymhnBOj
MMfY12SSoSZO9rHNYCypUJ2OslZka4bKktLnf7z4+v5+v+e5d+69z3OvRv1y
MocmJRKJPP+kciVkyIOTE4lbKYnEOv6P1yffPlhfTuYNehJv5BR+0J7OW/Q0
LuYq/JD9Lt6m38nbuSY3sdfiEj2DS/lufsxeh8v02ryX63IL+/38lX4fH+QH
uLV9B76RD9vq8xEutj2DnfjW9pPtUf6Zt9o6oIV+Rn+cz/ILtiJ5vLxNPs/r
eQM24mtsxx/2TbwZWzBZ7+Rx1/hX/TecwTS9uz1JPhfPhwuYYe9jT5cv4lI8
J/Ltfe13yOWowGXMtWfZa8pX8Cf+wjx7tr2WfA3XcQML7QPsteV/cBP/Yql9
p8tYglLswm7sQRmyXPd6zluNQqxCTrxnz/WRx66UF8fnpw+N64QhKNYX2VfI
83ktrsp/IwODcdA5g7gAr+B7fSBXx3LMjs/Uli1XQ1Z85vos+8dyHq/T+8kp
6CEnc09eiiXxGvUFvBDzsTheF657bD73cHwmd4/PCIvQLe6duEdwKF4H3nP+
akx2bhf9fe7KU7jc/hxX8FR+yZ7LmXFP8WX7SfkD+UNMxzTMieuIl7FGn+S8
efGc3Dn+Dl7EDb0r5/KX3DOuoXyaZ+mz0UvO5Jv2X+Q5cpE8N96z3jvuDblP
XHMswXTHe9sqyb04ldPiPcuVOdW1n+geeAND0B/d0MTjuvBpvC6vcv4P3JB/
jOsoN5BHYDgK9BH2pzFSf4pH8VQe61gzuXl8/3FKb8pv8mfc3jnj+CiftDWW
x8ZxfKqPsj+Lt/R2/Dbn8TuOtZHb4kmc01vzOP6cn49rysf5d9sTckf5XS7U
J/IxvRW3xASstI+P3wv7CbkkHh/WS+MaYi/2YYV9JB+L+8Z5YzhXb4MD8bp4
OL6zF+qjeVJ8d+R7cC/q4UD8Ftk/kYfJy7EPO/T9vDteq+NN4+/amvEw7LIX
6DnxmvWHUaY/wkdwGDX06ngtvk/xHUZVvVr83mCT3sh5y+RX5WVxXfU9esP4
rONzxxcoQrb7pap7ogrSkYbKidv/h/wPJAXW/Q==
         "]], 
        LineBox[CompressedData["
1:eJwl0r9LlHEcB/Cvl0sOdoPQ7N9h5u8gvRK0O20zD1yUmsxWPbwcUqg7f4A3
qA0hSmJ6JSicgqWL+C+Ek4K6mDqpvR4cXrw/v56H5+Cqe991vC0LIWQZj4WQ
iZJp5lmiSIltdoh7YO1BCOsRz3yQjymVhzCnX1T3c6gfkENUsaUv2H9TL6h7
SfOGuFkfm+oZNz+o1P/WP5IVpNnQ5+3eqwd5yC+znNlXdQ8H0TvlCce81ncz
4WaVYJbUd5Hi2qw7+i3qMfUKl+zqr+SU3SR/aI++iX32+EmRc3fN7p/RQkbf
KJuoo4F6RsyfyjNZK0/lS8+/4KM+y1/1E1nDKMtuhqNvVyfs8uSie7OE2T/Z
Ji9kl3kq2uu/cKRulc/5zHc3WdbUSbsCs3wye2V2KzvljbyL3f8n/gMhuktV

         "]]}}}], {
    DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {Automatic, Automatic}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, PlotRange -> {{-7, 7}, {-7, 7}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJx1XHl8jMf/3yRyZyP3sVFnkKJoCEqaGTbuYh1NURYRijhKJW3wdUSstog0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     "], {{{
        EdgeForm[], 
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6], 
         Opacity[0.3]], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmnkcl1MWxt+7WLNkTbJmKbtkSSJZk2wRSYPs+04kZCuSpET27CHGNvZ9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           "]], 
          PolygonBox[CompressedData["
1:eJwtmHn8iFUWxt/73qtiUqnIGJKlTY3RqKmIFkJ2ykgTopIIiUJZKpGUIu2U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           "]]}]}, {}, {}, {}, {}}, {{
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwt0ktLVWEUh/FXT4LHy0AHaRRB0Adw7kS8NPACeSmyIE0dZajgN/GCWlpZ
2T01rUE6sm8RIV5CneggEAXvvwUOHp7/u9Y6e6+9z77V1d/Sl5NSmkIuIheh
HLdRgUpsYlBz2tC3TEp38fJKSs08h1m802tWy4k+53I7CvJSesAtahm+yq/w
x/xrXlB7iGn5Ef/AIj7q31PLl9s4yx0odL3HfF+tgG/wG6yaf8u/1DpjH/kJ
z3AhL+GrmS3np3IJbspzmEev83de4d94hmOc4BS7mPf7PS7FgtlFnMnn2ME2
tlCMD3o9/J67eRlF6MI/tU+u9TP242vO5SiL68Vzq5/JbXHPeHfIeu7W2EW/
KfbSb+QvkdUaeD3erfxZnuQ153r5UK6WD7iGpzAZO+iN8wTG8ALPsW/ujt6R
XBfPghrk26E2do73i1Fzf81Uyf/lIXk47hP3xEj8J7yBAd/PdWinzOX3dgGc
XFQp
         "]], 
        LineBox[CompressedData["
1:eJwl1GuQjmUYB/An7cE5FZlRYWvM5NCicsyxSUtqzdSMQyHMEBl8kNMHOcwg
pzKDpd1hmsywbWiMkqJdKmVX67B2t5zZHCKTdUqYJr9rfPjt/7qu537ffd/7
fp43Y9SkNyY+kCTJFH+yayRJqnpFSpJ05UVqUotDruXQTd2d2tShzGwVvdS9
qUs9Dpt9wsvqPtTnISrM1vCKOosGPMxvZp/ymvp1GtKI380+I1s9gCY8zlGz
9Wx7MEkK5Fmz0erv2ckfFFJEI96O95SnrN3EUP0wMniKM2Zb2GPNVnnBbIq6
mL2cpYR9tGSy68/Ic9Zu5/1YT0taccGskFnq2bSmDX+a/cAc9VyeJZNLZj8x
Tz2f53iev8x+ZoH6Q16gA5fNSlioXkRHOvG3WSmL1UvoTBeqzQ5w0PkeoozD
lFNBJU3cAwetuWF9T9+tO0vV3eRHsecc4bS+QlZSHmcU5xf/xzyHNDfRythr
llNPv0Ke4Hjsp/9Rbf0ydSc+5or+F/Oj6j2yvb4dbWMv4nOQ4n2WyCMsoq5+
sWzLAmro58tKMpnHZa8viu+t/lZe1M9UZzBO3Vyme91NuSvWclV9jWqeYLTZ
k3KM/Mp7jJVN9e/KZnIa8eBMle/F/SSflrupivOWv5pN50f1DLmfUr5zfZrZ
dKbGvWM2Q+4wvyQ/0LemhbqYkngv9sUzaV7GLFL1aaTHsxffJe4lH2uhM50Z
zzfjGclssyGyKs7DujvyNv8yjO18wxeuvRXPqHpIPL+xZ4xls35T7AuDGUQB
J70mL/YmXq8fIzfKXfJL10aqR/EOjc1GyM3m5+VE/bY4Ex5TD5cT5Nex77HX
8Tui/0fe4ob6Ovnqz+NZibPkzdgLOZQq9Qbvf4wU/U19apwXWxjI//H5ZW7U
1p3Rr5Mb9dn8F7898lH5CHdd6y/XysrYP/rqX6Uft/X9rD+pzlOXx29h7K88
YZYr8/VZ3NX3lavjs5kf16+O3zb9SnVOPItcN+shr8mX4rzUvWVTZ1nH16lN
LWqSTlpy//f8HuiiyE0=
         "]], 
        LineBox[CompressedData["
1:eJwl0jtP02EUB+C3LYxOLKKT8TpogkGN0cQPwUdAJ4WipVO5RJBBFrUuLlIv
E7PhTiWYKsXYFhQIJiSGRGNaTWnUxdHnjcOT3znnff/n3zY91jvQk06EEAoc
UuTlFNPMsEqFKjU26HQvSy0ZQotrqRAetnmWR1zVP+GPuuK8yUv9FX6bfdB/
Uedpbw/hsXzBZX45f+98T/1JvcUEl/T35EX5gAN1yb0G3fq/+gvyPJ+5T8ru
SfmcLpruvHF/J+4i4XxCnjE/Hakzct6db5zU39afknfkUVlmkNf6rFyRP2SD
w7RoM0uxEHfRET8vdfbtTZolCAyYvaXEK2c3zI6or8vO+N74GZjiKUXzjFyU
yyyxpp/zbDruo48TZv1y1rwuh/Xrcc5x9S2Zi++WX90pqId4py/HnWzE7+ls
RD3KEOfMhmXR/Kcc13+MvxFn1Tl5V1bld3eeqceo6TfjTrb1u9xM/P/P/QMr
81uI
         "]]}}}], {
    DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {Automatic, Automatic}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, PlotRange -> {{-7, 7}, {-7, 7}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJyFXGd0E0fXdpG75SIDARFMJwJCR0Ao2QUBIVSRgGlB1NBkSmhGEDoo9GJE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     "], {{{
        EdgeForm[], 
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6], 
         Opacity[0.3]], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNm3n8l1MWx59772NfQnZCtqREyFIoKdIqQohSUdlbSBIh+xqRCIkwluwj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           "]], 
          PolygonBox[CompressedData["
1:eJwtmHkYVtMaxc8+eycSaXBLNCkRUVJK0UCpRCUUDYaIa2oyhwwVGhSppEHz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           
           "]]}]}, {}, {}, {}, {}}, {{
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwd1ElsjWEUh/HblkgMS7Zip6ghpqI1zzHPqqZqTYuKYWElQVFaU0urqJnE
LIREqYQWiZWaJeZgQSxMian4nS6ePuf8z/u997v3e7+2yVkyIT8pkUi08yeZ
o26GlmiNVHRFJp6iKiWRuIId2ImhqGqUSGx1cZl6O6fq26EtOqA9SuQd+TOn
8Rcea/0r9RjuxF9lv9UF6hr1Ot6jH4f16vFcib0oM+8r+82Z/IenyF+rJ3M/
rpfVqzepi7AZxeiPAfhrtoVvWreVD+inYpt6Gh/CQVSYH+YjmI6n+Cu7x+vi
3rBHP8x1yeqkMFKwV/5AloL7sad+hjwbWZiFmTgsn8NzMRvzkIMj8jyej1w0
tccCPipfxM30C7k55+JNXMuLuQU3jnvAHesr+bgsD/tiTz6JE4H5MtlyLEVL
2Qo+Kb/O+fpWaKI+ETlO4xTOyM9iCd7iHd7jHM64vti5WexgreGVyEcusjAO
U8xGWXsZN6wv4NFYbe+1WIPdcd7M+qgzkI7e6IUd8p78i3vwT55k/URs1BfG
+VB3527YgFprSnFVPcFsf/wm2CUbKktSD+EEZ2NGnDn9zsjwz7rB8dkoxW19
SeTWDeKB2I5b8nJUx/M2O4aj2C27xi/xArWoie+PH2Z1/BzVeILH+CSv4G/c
2X7fuQt/5JGxRj2CyzEs9tYPj2cR98qP9IO4FAPic+M+450x78cP9X25BBnx
+frMsPk2LuRL8Zurn6nT+WL8nuot8d7yBX33eEfU3fh8PMM4A/E84zvjo/oD
6tSdwtZ05CJ0iL31aXzXvH2cI/2q5IZH0fA/6j9uTJ1J
         "]], 
        LineBox[CompressedData["
1:eJwt0ckuQ2EYxvFjHm7CzJYSEjY2VnYuwQWwttIQEkMNO7chkSAI3ZrTmmKO
IW2lqHlY+Z3E4p/n/T9f8p0356vq7e/pywuCYAAt+UFQKC8UjQVBUEESupQ5
jQwGeaU+KbP8EU8Y4rX6E/nMc3jBCK/Tn8pX/oZ3jPF6/aX84J/4wgRv0N/I
b/6DX8T4rkzJdbmBOM4xh6x+T+5jNbyPR9zzJZtlTnbrV8wz5jiesMOf5QO6
nC/zKfMG0tjmGXmPTudLfDLcAbfY4nfyGrPO23Gg65DDuNIv8nE5zVuR5G3h
P8OZfoGPyhiPmqtRgyochvvr581R8xqaeIJHwm/xY2zyo3Bf71eOMpSiBMUo
+n/fPzFkTxE=
         "]], 
        LineBox[CompressedData["
1:eJwl0rdKRFEUBdBn7kyNoRC0UD/FnGNhwMYcGgVRsREMYG0AM6igKCIj2Bgx
YWzt1P8QXBeLxT773Dszb4bJ7xquG4qLomiGXxZZYosDYlxyxTU3TCdG0SRT
TFCcYObJfB4fRW8U6h96kSxgnAf9zNmCeZ587u1idjHzKJ/6mJwjj1v9xPmp
+ch8HM7JDfdljhzhxnzo3itZ+rueLTPp40rfd/ZCuv6mZ8gUVs2d8otvfsJ3
ce8uPB9b5hZ3WmmkmSY27etlAzXUUcuGfZWspoJk71Ep1+3LZZJeJhNlB+2s
6MthRyklLPHoNWtcmNvc22cvsBuyG2aANLtBuWt/KXv1nfDZpJr7w/OGZ+PZ
nVm7nvDd9G65HX4/eUJN3P9/4Q8AJ0Xs
         "]], 
        LineBox[CompressedData["
1:eJwl0ckuQ2EYBuAfXZjneRYsuBx3oFuzSlSJ4TpsTV00pBptsNNSU6yIsORC
PH8snrzf956e07+nE8mVueWaEEKKm9oQ7mSZCvc8UKXBh25df2M0EcIIs3Uh
HPBt3pcldvm178lpdviyb8siU2So6kqedWUuyIo9bR5nk7L9Ul8wX8h2exut
DOs2+DSnZJ41fuzrspszc5ZTluw5js0L8kguyhPZEM9PMp6TeQ71H/KBx3hW
nuLzeaeeZ154Jet8q+7pitfiM2kkp9+UQ/om2UwL5/p0fIf6DtkZ7yWv35Jj
8TfIHnop6jNyUt8n+xngWr8rZ/SD8Xviu0n8/49/Xn45kg==
         "]]}}}], {
    DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {Automatic, Automatic}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, PlotRange -> {{-5, 5}, {-5, 5}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}]},
  "RowDefault"]], "Output",
 CellMargins->{{99, 10}, {14, 6}},
 CellChangeTimes->{3.711800556156398*^9, 3.737891180705312*^9, 
  3.7378924188932333`*^9, 3.737893523870812*^9, 3.7378937070238523`*^9, 
  3.737893965921996*^9, 3.7426585365592213`*^9},
 CellLabel->"Out[40]=",
 CellID->1680966670,ExpressionUUID->"aa25be53-5f79-4035-8be9-e3aa1b4b3e13"]
}, Open  ]],

Cell[TextData[{
 "In the right-hand plot, there are three singular points, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"41c99f94-f0ca-40df-b667-04bce0201a50"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "1"}]}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"2270021f-0105-4661-93fc-17a19db80f58"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.2"}]}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"e1b1381f-ce1d-4d97-aeb9-385f8e80026b"],
 ". The first two come from multiple zeros of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "\[InvisibleSpace]", "3"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"31b6afe8-0dbe-4f41-b927-976c44a3324e"],
 "; the last does not. We will discuss Gauss curves more in Chapter 4."
}], "Text",
 CellMargins->{{66, 10}, {7, 6}},
 CellChangeTimes->{{3.685364551837582*^9, 3.68536456382632*^9}, {
   3.685364595035216*^9, 3.685364628267966*^9}, {3.68536467556362*^9, 
   3.685364777528132*^9}, 3.70100865180507*^9, {3.701015121754033*^9, 
   3.7010151369260607`*^9}, {3.7026552860752983`*^9, 3.70265528653857*^9}, {
   3.702838057496593*^9, 3.702838063308622*^9}, {3.708426819230562*^9, 
   3.7084268566387496`*^9}, {3.7084268971358304`*^9, 
   3.7084269102084627`*^9}, {3.7383872723181*^9, 3.738387284217003*^9}, {
   3.739292279046733*^9, 3.739292279254733*^9}, 3.7392925366397333`*^9, {
   3.740766628969913*^9, 3.740766629105939*^9}},
 CellID->2060716425,ExpressionUUID->"c8e31067-48b0-46fb-af20-9b59f8ec8dad"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5 Rational Functions", "Subsection",
 PageBreakAbove->True,
 CellChangeTimes->{{3.685364880491963*^9, 3.685364886647589*^9}, 
   3.685364924609409*^9},
 CellID->1992179806,ExpressionUUID->"22ec0293-0d34-49d1-963c-9bf804b24abf"],

Cell[TextData[{
 "Actually, you have seen higher-degree algebraic curves before. For \
instance, the graph of the polynomial function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "-", 
     RowBox[{"p", "[", "x", "]"}]}], "=", "0"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"072a5750-f045-4093-a884-ad2f3255f4f7"],
 " is an algebraic curve, but the curve properties are simple, and there is \
no advantage in thinking of them in curve terms. Graphs of rational functions \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    FractionBox[
     RowBox[{"p", "[", "x", "]"}], 
     RowBox[{"q", "[", "x", "]"}]]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"4b1ced79-97df-4632-97df-92a8f2def233"],
 " can also be thought of as algebraic curves in the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"y", " ", 
      RowBox[{"q", "[", "x", "]"}]}], "-", 
     RowBox[{"p", "[", "x", "]"}]}], "=", "0"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"b1f7532a-af6d-4abc-8067-119b1404b4f5"],
 "."
}], "Text",
 CellChangeTimes->{{3.685365184440301*^9, 3.685365365316837*^9}, {
   3.68536605886736*^9, 3.685366110297761*^9}, {3.685366165671137*^9, 
   3.685366170599418*^9}, {3.7010086518172207`*^9, 3.701008651839213*^9}, {
   3.701015186306047*^9, 3.701015291675168*^9}, 3.7010545026138153`*^9, {
   3.702655293963395*^9, 3.7026553020672073`*^9}, {3.702838069051794*^9, 
   3.7028380985200644`*^9}, {3.702838788052889*^9, 3.702838798491127*^9}, {
   3.7084269258706617`*^9, 3.708426978499389*^9}, {3.7084476537961397`*^9, 
   3.708447654428203*^9}, {3.7090498549501095`*^9, 3.709049856022217*^9}, {
   3.7392925533667336`*^9, 3.739292553518733*^9}, {3.739292646553733*^9, 
   3.739292648881733*^9}, 3.739292765114733*^9, {3.7408333924047823`*^9, 
   3.740833392791552*^9}},
 CellID->1148459065,ExpressionUUID->"dde42569-9d48-4553-a456-9ee962171c5b"],

Cell["\<\
Some examples showing asymptotes using code developed later in the book are:\
\>", "CodeCaption",
 CellChangeTimes->{{3.685365184440301*^9, 3.685365365316837*^9}, {
   3.68536605886736*^9, 3.685366110297761*^9}, {3.685366165671137*^9, 
   3.685366170599418*^9}, {3.7010086518172207`*^9, 3.701008651839213*^9}, {
   3.701015186306047*^9, 3.701015291675168*^9}, 3.7010545026138153`*^9, {
   3.702655293963395*^9, 3.7026553020672073`*^9}, {3.702838069051794*^9, 
   3.7028380985200644`*^9}, {3.702838788052889*^9, 3.702838798491127*^9}, {
   3.7084269258706617`*^9, 3.708426978499389*^9}, {3.7084476537961397`*^9, 
   3.708447654428203*^9}, {3.7090498549501095`*^9, 3.709049856022217*^9}, {
   3.7392925533667336`*^9, 3.739292553518733*^9}, {3.739292646553733*^9, 
   3.739292648881733*^9}, 3.739292765114733*^9, 3.7408333924047823`*^9},
 CellID->1929471539,ExpressionUUID->"cdddc2e4-028f-4d38-a04d-fe310463e2d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{GraphicsBox[
      TagBox[
       RasterBox[CompressedData["
1:eJzsvQd4Hdd1Lko7cYl9HSdfYjv3fnl55b73fe978UtxHMd2HF/7Jr65qc9W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        "], {{0, 349}, {360, 0}}, {0, 255}, 
        ColorFunction -> RGBColor], 
       BoxForm`ImageTag[
       "Byte", ColorSpace -> "RGB", ImageResolution -> {72, 72}, Interleaving -> 
        True], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
      ImageSizeRaw -> {360, 349}, PlotRange -> {{0, 360}, {0, 349}}],
     RowBox[{"y", "\[Equal]", 
       FractionBox["1", 
        RowBox[{"3", "-", 
          RowBox[{"4", " ", "x"}], "+", 
          SuperscriptBox["x", "2"]}]]}]},
    "Labeled",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ),
    InterpretationFunction->(RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[
      TagBox[
       RasterBox[CompressedData["
1:eJzsvQeUVWd2Joq723a77c7qbofXnmf7eXm1/Xpmnu2e1XaPPc/z3nprZs2a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        "], {{0, 349}, {360, 0}}, {0, 255}, ColorFunction -> 
        RGBColor], 
       BoxForm`ImageTag[
       "Byte", ColorSpace -> "RGB", ImageResolution -> {72, 72}, Interleaving -> 
        True], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
      ImageSizeRaw -> {360, 349}, PlotRange -> {{0, 360}, {0, 349}}],
     RowBox[{"y", "\[Equal]", 
       FractionBox[
        RowBox[{"0.2`", " ", 
          SuperscriptBox["x", "3"]}], 
        RowBox[{"3", "-", 
          RowBox[{"4", " ", "x"}], "+", 
          SuperscriptBox["x", "2"]}]]}]},
    "Labeled",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ),
    InterpretationFunction->(RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[
      TagBox[
       RasterBox[CompressedData["
1:eJzsvdd7FNmWL8g5PT23z+3ue7pn5mFe57+Y1/nm6b70fF19Tp/q8iC88N57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        "], {{0, 348}, {360, 
        0}}, {0, 255}, ColorFunction -> RGBColor], 
       BoxForm`ImageTag[
       "Byte", ColorSpace -> "RGB", ImageResolution -> {72, 72}, Interleaving -> 
        True], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
      ImageSizeRaw -> {360, 348}, PlotRange -> {{0, 360}, {0, 348}}],
     RowBox[{"y", "\[Equal]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
           RowBox[{"2", "+", "x"}], ")"}], "4"], 
        RowBox[{"10", " ", 
          SuperscriptBox["x", "2"]}]]}]},
    "Labeled",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}, {
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {1, 1}]& ),
    InterpretationFunction->(RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2}], "]"}]& )]}], "}"}]], "Picture",
 CellChangeTimes->{{3.685365618643364*^9, 3.685365663124647*^9}, {
   3.68536583505269*^9, 3.685365881862915*^9}, 3.685366020101485*^9},
 CellID->568486219,ExpressionUUID->"16e23caa-5a8e-4ba7-9a29-22fa7e8fd4b1"],

Cell[TextData[{
 "The first has two vertical asymptotes and one horizontal one. As mentioned \
earlier, the slope of a vertical line can be entered using our ",
 Cell[BoxData[
 "line"], "InlineCodeText",ExpressionUUID->
  "2e6639e0-7928-4b94-abcd-8c661a9b8468"],
 " function as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"0e8ead64-7059-44a1-9fbe-cfe63e5e25ff"],
 ", which we interpreted as saying that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"5e6f6e9b-b1f7-4df0-a163-4edf28eef8d7"],
 " is a point at infinity, but then both vertical asymptotes pass through \
that point, so ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"6feb6fc9-5864-481a-ae90-f74223dfb6c1"],
 " becomes a singular point. The second plot has the same two vertical \
asymptotes but also a third asymptote called, in high-school algebra, a ",
 StyleBox["slant asymptote",
  FontSlant->"Italic"],
 ". The right-hand plot shows one vertical asymptote, but here is a case \
where the curve does not approach the asymptote at both ends, again making \
the infinite point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"63911a87-0ea6-451a-8e53-8c70c47e4408"],
 " singular. However, we show in Chapter 7 that this rational function also \
approaches ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"96b67bd9-8820-42d5-83d7-a24d23c9e7fd"],
 " as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "\[Rule]", 
    RowBox[{"\[PlusMinus]", "\[Infinity]"}]}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"632f7a61-81e0-4f30-a147-fe6dfaf242ac"],
 ", making that singularity even worse! We will see later that rational \
function curves of degree 2 or higher are always singular."
}], "Text",
 CellChangeTimes->{{3.685366223555666*^9, 3.685366590490824*^9}, {
   3.685366633508404*^9, 3.685366695267834*^9}, {3.685366848435637*^9, 
   3.685366882556969*^9}, {3.685367096676477*^9, 3.685367170582965*^9}, {
   3.685367246759922*^9, 3.685367260458612*^9}, {3.685367317259285*^9, 
   3.685367317460374*^9}, {3.685367358652661*^9, 3.685367433476652*^9}, {
   3.701008651849818*^9, 3.701008651892976*^9}, {3.701015313658193*^9, 
   3.701015313952573*^9}, {3.701015346845955*^9, 3.701015407241276*^9}, 
   3.7010545036624126`*^9, {3.7026553209719*^9, 3.702655321410564*^9}, {
   3.702838210698126*^9, 3.7028382262406387`*^9}, {3.7028388082595387`*^9, 
   3.702838808264263*^9}, {3.708427503245721*^9, 3.70842760773302*^9}, {
   3.7090499972743406`*^9, 3.7090500019368067`*^9}, {3.709304221150765*^9, 
   3.709304221326573*^9}, {3.740833419622655*^9, 3.740833421197083*^9}},
 CellID->393137230,ExpressionUUID->"0259302d-7e99-444d-8364-0b2cb5c8c89f"],

Cell[TextData[{
 "Do not confuse ",
 StyleBox["rational function curves",
  FontSlant->"Italic"],
 " with ",
 StyleBox["rational curves",
  FontSlant->"Italic"],
 "; every rational function curve is a rational curve, but the converse is \
not always true. We will discuss rational curves in the next section."
}], "Text",
 CellChangeTimes->{{3.685367468797611*^9, 3.685367572256775*^9}, 
   3.701008651901987*^9, {3.708427618590272*^9, 3.708427627357191*^9}, {
   3.7090521598625917`*^9, 3.7090521874683523`*^9}, 3.73929365116708*^9},
 CellID->1797726438,ExpressionUUID->"81b9297f-7e58-4f4e-8fbd-8af58aa38ebc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6 Parametric Curves", "Subsection",
 CellChangeTimes->{{3.685447550760136*^9, 3.685447571876586*^9}},
 CellID->1440813823,ExpressionUUID->"54ef6c22-a138-442b-9880-1d1f9fd42ee4"],

Cell[TextData[{
 "Aside from algebraic curves, there are also parametric curves. A ",
 StyleBox["parametric curve",
  FontSlant->"Italic"],
 " is the image of a continuous function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"F", "[", "t", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "1"], "[", "t", "]"}], ",", 
      RowBox[{
       SubscriptBox["f", "2"], "[", "t", "]"}]}], "}"}]}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"145239ce-1ce9-47f9-a11b-9b1d73ba243e"],
 " of one real variable taking values in the affine plane, possibly augmented \
by infinite points. This function may have a domain that is a bounded open or \
closed interval in the line or perhaps the entire real line. The study of \
parametric curves with differentiable parameterization is part of ",
 StyleBox["differential geometry",
  FontSlant->"Italic"],
 ", while ",
 StyleBox["algebraic geometry",
  FontSlant->"Italic"],
 " includes the the study of algebraic curves. Curves in ",
 StyleBox["topology",
  FontSlant->"Italic"],
 " are required to have only continuous parameters. The connection between \
these ideas is one of the key ideas in this book:"
}], "Text",
 CellChangeTimes->{{3.685447598865251*^9, 3.685447859030126*^9}, {
  3.685447900390935*^9, 3.685447943881859*^9}, {3.685448164693625*^9, 
  3.685448215304819*^9}, {3.685448290562977*^9, 3.685448330827441*^9}, {
  3.701008651912274*^9, 3.7010086519238586`*^9}, {3.7010154438741837`*^9, 
  3.70101545517625*^9}, {3.701054504718342*^9, 3.701054505726206*^9}, {
  3.702655343992219*^9, 3.702655343996813*^9}, {3.702838246842354*^9, 
  3.702838267773888*^9}, {3.7084276801391077`*^9, 3.7084276949742327`*^9}, {
  3.7084280694956837`*^9, 3.708428090510684*^9}, {3.7090522871513195`*^9, 
  3.709052290425647*^9}, {3.709052359371541*^9, 3.709052364520056*^9}},
 CellID->732319589,ExpressionUUID->"21dc23ef-76e6-4cce-ac9a-df857b4d5afc"],

Cell[TextData[StyleBox["Every real plane algebraic curve is the union of \
continuously parameterized curves.",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{
  3.7010155144325247`*^9, {3.7028399503883677`*^9, 3.702839951291625*^9}},
 CellID->1791365495,ExpressionUUID->"a4bbefdb-dc52-428b-9309-d5d0f6f4da95"],

Cell["\<\
Since we are only requiring the parameterizing functions to be continuous, we \
will not, in general, be able to explicitly describe the parameterizing \
functions, but we will be able to approximate these curves well by giving as \
many points on them as desired.\
\>", "Text",
 CellChangeTimes->{{3.685448428683479*^9, 3.685448778654727*^9}, 
   3.701015613112069*^9, {3.708428102983035*^9, 3.708428123294105*^9}},
 CellID->866551366,ExpressionUUID->"7439302c-d3e5-4001-9b58-08d4f3233b82"],

Cell[TextData[{
 "Consider, as an example, the conic ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["x", "2"]}], "+", 
      SuperscriptBox["y", "2"], "-", "1"}], "=", "0"}]}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"336f26b0-f55c-47be-baa2-8be6a3410283"],
 ". It is the union of two parametric curves:"
}], "CodeCaption",
 CellChangeTimes->{{3.7010247037633266`*^9, 3.7010247141714077`*^9}, {
   3.702839114473012*^9, 3.7028391144761343`*^9}, 3.702839966268229*^9, 
   3.709302466623116*^9, {3.7093075156615677`*^9, 3.709307556531067*^9}, {
   3.7093076182435007`*^9, 3.709307618243537*^9}, {3.709307902091263*^9, 
   3.709307906243497*^9}, {3.7383878820741253`*^9, 3.7383878820795116`*^9}, {
   3.742580748652154*^9, 3.742580748656856*^9}},
 FontTracking->-0.05,
 CellID->2042198055,ExpressionUUID->"425c8f62-9155-4fb8-99fc-685288634b31"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "=", " ", 
   RowBox[{
    RowBox[{"y", "^", "2"}], "-", 
    RowBox[{"x", "^", "2"}], "-", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"t", "^", "2"}], "+", "1"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F2", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", 
     RowBox[{"-", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"t", "^", "2"}], "+", "1"}], "]"}]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.685448996069925*^9, 3.685449065759312*^9}, {
  3.685449141089816*^9, 3.685449153065862*^9}},
 CellLabel->"In[41]:=",
 CellID->2139064031,ExpressionUUID->"391d4de6-4674-44d6-b7ca-c26d71339f43"],

Cell["In both cases, the parameter domain is the whole real line:", \
"CodeCaption",
 CellChangeTimes->{
  3.708428137193616*^9, {3.7090524297525787`*^9, 3.709052430261629*^9}},
 CellID->225434590,ExpressionUUID->"62ec5fbb-2386-4590-9a0b-9725b2cdc028"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"f", "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"F1", ",", "F2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "4"}], ",", " ", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.685449116369979*^9, 3.685449122011871*^9}, {
  3.6854491595773*^9, 3.68544928822748*^9}},
 CellLabel->"In[44]:=",
 CellID->718000822,ExpressionUUID->"b62a8645-1b72-4043-a198-8779f03dc999"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdlwlQVWUUxx/vPVke8GAyTUMSjdySQgtzo/M5zWg6WWrmYKOmNrahURqT
RhuSpGZIROSYM0mMpUYOEpmZej6XplGaNLO0XDJRXHB5smYvNe49/+/OeO/A
XL7Lud9ylv/v3B4zcybM8no8nrb2X+v+3L3l295pDWqPfSXq7A6VnaomBbXv
90DW3dMTdHJ89x6hn+L1t3OObJpzJKhftG6b4nX08Hm+yT8E9S/etP3etHgd
W6Paf4L6sUm1SXeuiHPsygpXhS9443RN7OKxa3rE66PW4zmxOjxsclrOsjj9
7owuhTMOB/SAuF3pcb44HZO0vD5hUMCxW/f7H7eN/ypGvzF3c9w/pwJ6TEnq
6JLUGJ18j+/BIVMC+ovI1qJ1+dH6YvLjvrwfY3TL8H1Nw/dFOXaTnrCuKF25
3rqi9Wb7HJE6vn25XenRetHQtQVD+0TqhtXB86uLonRq2dKsfjM7OHZrcoq2
D/nXr4eM+qvbG/Mida/R1sR+vSWlbuGy2Ehd07+2un+tT6+YNbls1uQO+u2K
C29WXPA6doFTK6NPrfTqqiVqwxLl16XWtkZ79dC9lx7Ye8kn4+cj5N7XpzeN
zK4Zme1x7KZUZDxZkeHRQ/M7Ds7v6NVeCZQ+ccy6IrTfHl5neR6huwzb2HHY
xjAbu//mL2+bvzzMZzOP12Uev8F/2X4Nc23e1h/ztt7gZ+w4XeVl9nrXeakV
jy5X+X4rHruu8RbbD61cb78f5h1PvzD98opWPqyPD8ioCvOHdYOL6ga3OvNe
svwYbOZCy69rr3KZPW8j7z1ovfAPzziUO/VQ7hW+vGVDw5YNbRyc9uiO2r4h
Z500228X+SPrvT0tXGfP28B/jpv20IL4Fv4y8dnTvXef4z62XTPH2Mc8yz77
3szb7XnqsX4Tj5ne+vYfvnrsr4k/Hd/1o/FdT/PnA/tVDOzXxBLnk3yXPV8j
r7T3e5Jzqvf0+mR2Ixfb/jjJSYXWH408vzLh/Zbyv51zNdjzHuGmTk9daf/h
7rnjonLHHeJXrVvUFb7Vfvwbl1tuOR/iz+z3DvDOmFU6ZlWI+/pHJPpH7Oee
0QtToheGuNnO311suz89xNW2/U5+2dv7JW/vEOfbeb2DJb9DfMD+fzUXn7/l
686BEEvYk7dJXpjxia2em8b7XWNzmXFSpnl/gsxPZv6HZX0ajfXnyv7oJexv
neyfYrH/RDkfpeB8C+X8pHH+KPEX5cJfteJPugx/ZlS9+kj8hWM0/HOr0K/w
a+J/Mv5fJPGhLojPUokf9SjO7lmc3cgfS3wpGfEtlfhTBeK/QfKFBmSV35dV
3sQ37OsMeZBPlZJvZPLtV8lH+g35mCr5SiXIV+QzmXyeKvlODcj3Itk3/YB6
OCf1QgWol1KpJzL1tE3qjQ6i3qplXjqBeiyUeqV01Gu61DNNQz0fknloN+od
+kBGH+R2HeeN0P+JA+go9OVJ0R81GPoDfVJGn0pEv1QJ9KtYnqtB0Ldo0T9L
/Gz9gz4qo4/Vop+qDPrZU56rTdDXCtFf9QD0F/qsjD4XiH6rc9DvGnmuYqDv
E0X/1XroP/igDB/WCD9UA/gxUp6rroYvwh+VB/6AT8rwaZHwS90Lfh2W56oN
fCsV/qmvwT/wURk+7hN+qgD4OVueqyjwtZvwVxn+viB8Vl7wWcolqL6vv2tU
pxMJOlz4TU5WOKgMz11j5bJXrvlUEtYzdq79qJ9v3q8ai/MYuw9x3o1yXuXy
hyqAv+4Rf6kO8KexWwN/LxB/K1c8VAXidU7ipUKIp7GbgHivlXgrkw8ByQeV
j3w5I/miUpBPxq4c+ZYh+aZc+aiqkK+lkq/qdeSzsYtEvldKvitXPci4vV6K
pV5UNerJ2GWh3gZJvSlXPWJ8ja7bd49KQD0buybhPfThBrnqn2ZBH94TfaB8
6Eea6Ae59IU2Q39+Ef2hJdAnM+9p6Ndbol9k9G236BtlQf/Oiv6RH/po1rkd
+rlc9JNc+kofQH9TRH+pBfp8zb43kUu/aSn0fbXoO4HvBL6T4UOK8IHywI/O
wg+aBL6YcxgehYRHFHpFeDVPeEWGZyw8ozaf8K678I7AcwLPyfAyR3hJieCp
cDUEHV49BDwmw2sJ72Xy38xzcHgHg8dk+gXwmChT+okg1gePGTwmVz9C4DGD
x+Tqb2gi+h/jn0L0R+Avmf4pFf49jP4qDf4Hfxn8JdOvDUL8JK/PoA9ppmL0
eyb+rn6QwF8Gf01+OZwEfxn8JVc/SuAvg7+0GP2syW/wl8FfcvXDOP9VBn9p
Ffrp71BfhuM/of7a0I+fQn0mol839Qse4/wRytXvK/BYg8dGPxzugscaPFau
7w0FHmvw2OiXw13wWIPHyvW9o8BjDR4b/XS4Cx5r8NjhdBD6Cx5r8Njot8Nd
8FiDxw6n74D+g8caPFZ+fC8afoDHOh18cX1vKvBYg8eGXw5399/8Patc37sK
PHa46/pedji9FXwFf7Xh7/96Oxbd
     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
          35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
          52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
          69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
          86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
          102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 
          115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126}], 
         LineBox[{127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 
          139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 
          152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 
          191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 
          204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 
          217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 
          230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 
          243, 244, 245, 246, 247}]},
        RowBox[{
          RowBox[{
            RowBox[{"-", "1"}], "-", 
            SuperscriptBox[
             TagBox["x", HoldForm], "2"], "+", 
            SuperscriptBox[
             TagBox["y", HoldForm], "2"]}], "\[Equal]", "0"}]],
       Annotation[#, -1 - HoldForm[$CellContext`x]^2 + 
         HoldForm[$CellContext`y]^2 == 0, "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-4, 4}, {-4, 4}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw113k0Vd/7B3Au1+yeG4pSpqTMoYnSsw0JoU9F+GggpVGDEBlDhhKKJKFE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        "]]},
      Annotation[#, "Charting`Private`Tag$70232#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw113k0Ff//B3Au1+7OLQopISl7KKH0npAQ+lSEDxUprVRCZA1ZSiiSFCWE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        "]]},
      Annotation[#, "Charting`Private`Tag$70232#2"]& ]},
    Axes->{False, False},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{True, True}, {True, True}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"ScalingFunctions" -> None},
    PlotRange->{{-4, 4}, {-4, 4}},
    PlotRangeClipping->True,
    PlotRangePadding->{{0, 0}, {0, 0}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{3.711800556222142*^9, 3.737891180864792*^9, 
  3.737892419067523*^9, 3.737893524056123*^9, 3.737893966144795*^9, 
  3.7426585366706057`*^9},
 CellLabel->"Out[44]=",
 CellID->1859446405,ExpressionUUID->"04873b13-1634-4299-a8e1-010c1aa2e5ab"]
}, Open  ]],

Cell[TextData[{
 "Note above that the Wolfram Language gives the same point sets, but on the \
right, it treats the two parameterized curves as separate, with different \
default coloring. In the second case, the two colors represent different ",
 StyleBox["topological components",
  FontSlant->"Italic"],
 ", while the first picture shows one ",
 StyleBox["algebraic component",
  FontSlant->"Italic"],
 ". This is because there is no algebraic equation with a full real solution \
set: just one of the topological components on the right. For that to happen, \
these equations would have to be factors of the original equation ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]], "InlineMath",ExpressionUUID->
  "0bca0fe3-2502-4d11-b404-f90f1924dea4"],
 ", but since ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]], "InlineMath",ExpressionUUID->
  "560d998e-e7df-4165-914a-e7d52fcd864a"],
 " is of degree 2, the factors would have to be of degree 1, which are lines, \
but the two topological curves on the right are clearly not lines."
}], "Text",
 CellChangeTimes->{{3.685449294019457*^9, 3.685449380614444*^9}, {
   3.6854494150391*^9, 3.685449503601124*^9}, {3.685449719575476*^9, 
   3.685449805042635*^9}, {3.685449873948214*^9, 3.685449911269042*^9}, {
   3.701008651947661*^9, 3.70100865199181*^9}, {3.70102406350114*^9, 
   3.701024064500195*^9}, 3.7075028900710573`*^9, {3.7084281514527955`*^9, 
   3.7084281972597957`*^9}, {3.708428233183796*^9, 3.7084282874527955`*^9}, {
   3.7090524889925013`*^9, 3.709052547611363*^9}, {3.7090526251461153`*^9, 
   3.7090526277383747`*^9}, {3.709060006382531*^9, 3.709060015596756*^9}},
 CellID->23311398,ExpressionUUID->"433153ea-8eaa-4e85-ad27-21e2e360bf66"],

Cell[TextData[{
 "A different case is the following cubic curve, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "=", 
    RowBox[{
     SuperscriptBox["x", "3"], "-", 
     RowBox[{
      SuperscriptBox["x", "2"], " ", "y"}], "+", 
     RowBox[{"x", " ", 
      SuperscriptBox["y", "2"]}], "-", "x", "-", 
     SuperscriptBox["y", "3"], "+", "y"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"ae136215-2543-4078-b8f8-2a2e5711af56"],
 ", which we have seen before: "
}], "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{{3.701024148571681*^9, 3.701024148987755*^9}, {
  3.70265537416286*^9, 3.70265537479425*^9}, {3.7028389322449408`*^9, 
  3.702838932247984*^9}, {3.7090526725748577`*^9, 3.7090526927268734`*^9}, {
  3.738387404374131*^9, 3.738387404378104*^9}, {3.742580760966774*^9, 
  3.742580760982428*^9}},
 FontTracking->0.1,
 CellID->952642432,ExpressionUUID->"5ab5e9f0-f49d-4b21-a31c-bc31ac8a2d19"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"y", "^", "2"}], "-", "1"}], ")"}], "\[Equal]", "0"}], ",", 
       
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "y"}], ")"}], "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "t"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", "t", "]"}], ",", 
         RowBox[{"Sin", "[", "t", "]"}]}], "}"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "2"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{
  3.685449969884559*^9, {3.685450048161854*^9, 3.685450247246805*^9}},
 CellLabel->"In[45]:=",
 CellID->1570766239,ExpressionUUID->"90012550-1861-4f66-8746-13ae27c3ec01"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1lntIlXcYx0+tyyBcW/+EsWa3P/bHKJIEoRNPZf8UB1yXSVnLbhZptTKk
rdDMJKJkievoKA0quogVmtIN4zkVVFia1NSN5m25gx2P54zaKnS1zvt7nu8P
9rK9HHl4j7/Lc/k8z/dMXvfNkszhHo/nZOzPsedbK9N2pXfwvLsj48dvCPOz
K1ufxj68sql1VVNrmI/scP7Tzis7Nueeax3gS5kryjJXtPHurtd5Xa8H+Ni0
haXTFj7mpaHUKjoT4SPZU0qyp7Tw3tPh/NPhCP/ZmHqw7sUd3p6WP7/CH+VT
Zv1tzhg8E/tEedwnznOLJw3VJgzVRtnjPAUtDcZ6/pB3T8D1XuDF+18fm/00
WfcXyvm0Rs9vlvtph95fJP7RPvXvkPhPX6n/fomP8jW+Iomfvtb4A4HOmUk1
7ZTjZOnKAD+RfNG3w2qrZvWGuVLySQs0n2/+cZ4uerpsQk6krp8Xjc79cnRu
N3WZff3si/cvjvf30Inq68eqr4f4e+PPb5T8WVPCFm+IA3ec5xn5Sp1/POeC
lOSilOReulDceL64sY8nOctLe2nqhP6U9Xl97Nk49sc5a4J0w7gV5F8ctyuD
1COWL8v39KGs409lH30u5/De4jGJ0+/30fqU7+J+T+rlBXIvNYofPEv8ojLx
k8vFb0qTOLhd4qLlEie3Sdw0wtSrmxOTanb54sK0+IM9934KdHLV3ZsBzgrT
wba4s/c3dXCu5JHAYZbkmYKSd14udaDjyqXWicqVS+WQwGWe1JkqlMvml95H
L71R6jfnP+Ac4YIeKqf+QeeEKIHTBOGKZiinf5t6RumVsW/BJQ1EnKfZvru4
pRbD6b4G7PeZ7we9yj1pH1CZ3g+Od6p/Z5Vj7SsqUY6VWwLHhZqPfOU4XfOl
fUwZ0tcEbrXv6Zxyi/pNbKgoLF/aTanVsy9G6kM0KrZqVUkPJd7oO3V4eojA
6X7lJUN4IfBVYe4PUqfyB4vvsQ77cA7OxT24F37AL/gJvxEH4kKciBt5QF6Q
J1f/27wiz8g76oC6rJX5YuuGOqKuqLObAzcn4AjrwRm4A4c6zyyn4BZcg3PX
PLZ9gT5B36CPXPOeLqsekOZT8237eozUg31aD8yBL7RemBuYI8el3nbuYA5h
LmFO/aBcHJB9nK5czJRz7VxcIvfyMOUCc/Qj5QJzF3NYObBzGnMccx1zHnMf
OgAuoBPQDegIdAU6Ay6gQ9Cl/9Ot/9S1mO5BB6GL0ElwAB2FrkJnobvQYXAA
nYZuQ8etrmt+wAF+B+B3AfI7VjnQPmTtS9SdwUGh1m+1cuCqL+scsBbfYx32
4RwXX/Ze+AG/4Kf794xHEw171dzzjmG3GX15a+2v5pwha6+Zda+sPWr8eWEt
7oWFv7CoA+y/6x5oAGew4BwWfQdbIvdaWy9+Wfuz+G3tFonLWinzO2s1L3Nh
3wNiJUig
     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
          35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
          52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
          69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
          86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
          102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 
          115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 
          128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 
          141, 142}]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "2"], "+", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              RowBox[{
                TagBox["x", HoldForm], "-", 
                TagBox["y", HoldForm]}], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {-1 + HoldForm[$CellContext`x]^2 + 
          HoldForm[$CellContext`y]^2 == 0, 
         HoldForm[$CellContext`x] - HoldForm[$CellContext`y] == 0}, 
        "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
         LineBox[{143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 
          155, 156, 157, 158, 159, 160, 161}]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "2"], "+", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              RowBox[{
                TagBox["x", HoldForm], "-", 
                TagBox["y", HoldForm]}], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {-1 + HoldForm[$CellContext`x]^2 + 
          HoldForm[$CellContext`y]^2 == 0, 
         HoldForm[$CellContext`x] - HoldForm[$CellContext`y] == 0}, 
        "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-2, 2}, {-2, 2}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     TagBox[
      {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
       Opacity[0.3]], LineBox[CompressedData["
1:eJxF1OlLE3AcgPFdusMI3XROK03QLY1KBCVqpCvteGFMTTIERa1lVmiTDg8k
xNTarJliKlOnM1suXJNykU7LDBNvESGczXROWyIbtuY2Nyto39+Lh89/8ARl
5iZewWEwmPi//ZNxKPaCPYj8wSW5oRtLDkDaCEEKuj9So3GQI6jIFqFqIBuH
ZK6HHZxbIoGRci+cUopMDNUqeCHI6HfhwTU0IljP4Vp1NHdwtG3x4zE/N1BZ
x5ImkAkg4QF7pcoDD1LcSTGCLSxoSIt9LDRgwBuXmwp5CzsDLq+HB1Kieh3g
SRM7lau2g2MZ7Br+iBVUW2TbdLkFLC9VstyVZlAVwSq7K9wEG5+WDBtvmUD5
xHL9NcsGaBxsd/v91gCuSprMvmo9KB/JO3sidwnslO6eWcvRgOkVcr/7lbNg
FtYWH7M1DNZFWg2v8K9B7dFxBbe6K9oldpeNc7P5C1hWLQphHJ8FcypydcYp
DXhKu4xPblkC93ulUMVVevDwlkn9bcoACsxJesHoBjh4rkDifckEXsxP3fv9
ziZIk7XOZeaZwWxVYXpmrQVcmVYxfWutoIJNIw49tIPUUmzPxksHKJ5Jkk48
3wEXS8RH6HpMjMt6doA/5xcW1O1MS08bcWBx+KS3AEsAZTxncCfGDbQP9XE+
25CNoqG4QAoRHM9wriURSaDtnry83wN5QJQSHOqJLO3vTncykFF7rs7JwpCS
2clPjngk/0xr84taZEvaeTa1ATl22/61uAnJak/2SexAajAU4bYKGfeeX5Aw
j+RPB/r2aZGStbE3TB3SRmcZ7evIrvx5XocTOf+okuCFJ4Oktsi2IiIya+rJ
AtcTKVplF/V6I/udPxhMP+RPn2c9on3I/98C/wC9n07L
        "]]},
      Annotation[#, "Charting`Private`Tag$70292#1"]& ], 
     TagBox[
      {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
       Opacity[0.3]], LineBox[CompressedData["
1:eJxdm3lUTf/3/xtQpIEihEqUqCSUKZuKNGhCCe80iKS5lKiQIRKaB5pLcxo1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        "]]},
      Annotation[#, "Charting`Private`Tag$70292#2"]& ]},
    Axes->{False, False},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{True, True}, {True, True}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"ScalingFunctions" -> None},
    PlotRange->{{-2, 2}, {-2, 2}},
    PlotRangeClipping->True,
    PlotRangePadding->{{0, 0}, {0, 0}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{3.711800556275573*^9, 3.737891181033474*^9, 
  3.7378924192294683`*^9, 3.737893524221734*^9, 3.737893966303726*^9, 
  3.742658536847386*^9},
 CellLabel->"Out[45]=",
 CellID->1533697691,ExpressionUUID->"d6d93673-68e8-461b-af18-038d4629a5cc"]
}, Open  ]],

Cell[TextData[{
 "In this case, the curve has two algebraic components because ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]], "InlineMath",ExpressionUUID->
  "3bcd02ea-e6b8-432b-8212-e48038bee186"],
 " factors as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"x", "-", "y"}], ")"}]}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"4911a0d8-bf80-4059-95d7-2af6a65ce1ee"],
 ", but for the parametrization on the right, there is only one topological \
component because, as a point set, it is connected. For those not familiar \
with topology, see the first section of Chapter 4."
}], "Text",
 CellChangeTimes->{{3.7010247846976757`*^9, 3.701024817152974*^9}, 
   3.701054506925515*^9, {3.702655383714917*^9, 3.7026553840822678`*^9}, {
   3.702838897599453*^9, 3.70283889760252*^9}, {3.7084283179537954`*^9, 
   3.7084283573257957`*^9}},
 CellID->1649310459,ExpressionUUID->"f0b53a4c-e583-4b91-8384-9016daac6a4e"],

Cell[TextData[{
 "In general, if a curve is defined with an exact (integer or rational number \
coefficients) polynomial equation, then the Wolfram \
Language\[CloseCurlyQuote]s ",
 ButtonBox["Factor",
  BaseStyle->"Link"],
 " can decide if the curve can be factored into integer factors or not. If a \
curve can be factored, possibly with non-rational or complex coefficients, we \
call the curve ",
 StyleBox["reducible",
  FontSlant->"Italic"],
 "; if not, we call it ",
 StyleBox["irreducible",
  FontSlant->"Italic"],
 ". The Wolfram Language does not have built-in factoring for numerical \
polynomials, but we will see that, as in the previous example, reducible \
curves always have singular points, although possibly complex. Using these \
singular points, we can often visually guess the decomposition, possibly \
using the interpolation algorithm, covered in the next section, and ",
 Cell[BoxData[
 "nDivide"], "InlineCodeText",ExpressionUUID->
  "2186047a-34fe-4399-a5e9-d4c4045942ed"],
 ", covered in Appendix 1, to verify."
}], "Text",
 CellChangeTimes->{{3.68545108420782*^9, 3.685451240585108*^9}, {
   3.685451312851443*^9, 3.68545146505747*^9}, {3.685451555779521*^9, 
   3.685451592116396*^9}, {3.685451634199065*^9, 3.685451650645838*^9}, {
   3.685451824653192*^9, 3.685451842733685*^9}, {3.701008652016*^9, 
   3.701008652040351*^9}, {3.7010249047855377`*^9, 3.701024917544093*^9}, {
   3.701025098200568*^9, 3.701025118679481*^9}, {3.70105450798236*^9, 
   3.701054509150209*^9}, {3.702655391843295*^9, 3.702655392162238*^9}, {
   3.707502892287553*^9, 3.707502895820451*^9}, {3.7084283814797955`*^9, 
   3.7084283966227956`*^9}, {3.7084284419867954`*^9, 3.708428494400796*^9}, 
   3.7090528638809867`*^9, 3.709053186598255*^9, {3.709060043662216*^9, 
   3.7090600896831493`*^9}, {3.7093043885744467`*^9, 3.709304388805633*^9}, {
   3.709304633061928*^9, 3.709304687495019*^9}, {3.710676936316932*^9, 
   3.710677014712757*^9}, 3.710677088605216*^9, 3.711721332326317*^9, 
   3.7153323269415903`*^9, 3.715332803446642*^9, {3.740833474726779*^9, 
   3.7408334799244432`*^9}, {3.740833541437868*^9, 3.740833598475688*^9}, {
   3.7425808175577993`*^9, 3.7425808244156017`*^9}},
 CellID->241968937,ExpressionUUID->"a178f4c4-62f9-4de3-91ab-bf347a6fd2b7"],

Cell["\<\
A problem one might run into with reducible curves would be the following \
degree 5 curve, which should have the same point set as the example above:\
\>", "CodeCaption",
 CellChangeTimes->{{3.685452746652901*^9, 3.685452768679718*^9}, {
   3.685452850152856*^9, 3.685452854187334*^9}, {3.685452919714807*^9, 
   3.6854529239151*^9}, {3.685452983541021*^9, 3.685453056110894*^9}, 
   3.7010545102452993`*^9, {3.7084285170297956`*^9, 3.7084285344447956`*^9}, {
   3.708449144709937*^9, 3.708449152877937*^9}, 3.709053222807876*^9, {
   3.710677343961756*^9, 3.71067734587379*^9}, 3.7392945383652163`*^9, 
   3.742580834708312*^9},
 CellID->1585380388,ExpressionUUID->"903614d2-a9e5-4b78-a838-874a76c62a5a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", "^", "2"}], "+", 
       RowBox[{"y", "^", "2"}], "-", "1"}], ")"}], "^", "2"}], 
    RowBox[{"(", 
     RowBox[{"x", "-", "y"}], ")"}]}], "]"}]}]], "Input",
 Editable->False,
 CellChangeTimes->{{3.685452782780339*^9, 3.68545282396876*^9}, {
  3.685452905884235*^9, 3.685452911619642*^9}},
 CellLabel->"In[46]:=",
 CellID->1658572787,ExpressionUUID->"09d5ed48-601c-4ba9-9e2f-71ee5b508451"],

Cell[BoxData[
 RowBox[{"x", "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  SuperscriptBox["x", "5"], "-", "y", "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["x", "2"], " ", "y"}], "-", 
  RowBox[{
   SuperscriptBox["x", "4"], " ", "y"}], "-", 
  RowBox[{"2", " ", "x", " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["x", "3"], " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["y", "3"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["x", "2"], " ", 
   SuperscriptBox["y", "3"]}], "+", 
  RowBox[{"x", " ", 
   SuperscriptBox["y", "4"]}], "-", 
  SuperscriptBox["y", "5"]}]], "Output",
 CellChangeTimes->{3.7118005563094187`*^9, 3.737891181061905*^9, 
  3.737892419277603*^9, 3.737893524255101*^9, 3.737893966328875*^9, 
  3.742658536889925*^9},
 CellLabel->"Out[46]=",
 CellID->610877696,ExpressionUUID->"f4bef11a-5930-4943-aaed-dfa494f885b0"]
}, Open  ]],

Cell["Attempting a contour plot, we get:", "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{{3.685452928432501*^9, 3.685452947967917*^9}, 
   3.708428572657796*^9, 3.7090532258551807`*^9},
 CellID->1882112198,ExpressionUUID->"ab992f08-68fd-4fb2-ab59-e92299f67ffa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"g", "\[Equal]", "0"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.685452858746521*^9, 3.685452878514433*^9}},
 CellLabel->"In[47]:=",
 CellID->225591476,ExpressionUUID->"12e72f9f-a171-4a1d-a8af-add1e35c62e4"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJzF1TtIQlEYB3CJiIaWoKYMKqSpuSXCgh6YDuEY2RDUYFlU1NQQjkEPJBra
iggakpBeZFk01OBQmGRl70IwEcseJva833fvXxCkMwRdkB/ncM93vvt5HsWt
3ca2DJVKNfjzk5SfbcUu/4rFv/KxpXgmYUnABptGZ9PE4ZrU7X+F3TTuBZbq
pBef4TnFeYITUhhdFOop7iPkHB9gL8UNw0uKE4IGGheE65RXAE7SPDcwk+Je
wQGKe57WW5rHL2wj5XECXdR9BMuoLt60TlGeHmGz6TsOYIjycAubU15hzo3u
wV3KcxcuGpqDF0M7cIbmFbfSW13ord6ECZrXCWP9Jl+/aRU6aJxDWHtTT0Sj
X4Ae6p+B8jLf+CuNHFermOfMz1qfnYe9nJewhYHIcm4oqZPrAj+nW/qs9y5o
5boKO8f/o7BuXhfCPnxJzz4c5nUprJrXPbTzPhE2RvP6YBXvO2E5j1N4yPtY
2HY+J+Ab5XEJa2iea23tL9bJHlPcpGaKm7QjpT3K55p2RHYsTVt5z0dxb2EB
1f1OWySrltWk9OtlHXyuQv6+IOS4Ich5huE71SUC6/nch+N8L8ATvjdgCd8r
kOvxApf4XoJc1zjkuiZgJ997UL4XqxSVPJX9/9/tbwTk/rE=
   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115}], 
       LineBox[{116, 117, 118, 119, 120, 121, 122, 123, 124}]},
      RowBox[{
        RowBox[{
          TagBox["x", HoldForm], "-", 
          RowBox[{"2", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "3"]}], "+", 
          SuperscriptBox[
           TagBox["x", HoldForm], "5"], "-", 
          TagBox["y", HoldForm], "+", 
          RowBox[{"2", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "2"], " ", 
            TagBox["y", HoldForm]}], "-", 
          RowBox[{
            SuperscriptBox[
             TagBox["x", HoldForm], "4"], " ", 
            TagBox["y", HoldForm]}], "-", 
          RowBox[{"2", " ", 
            TagBox["x", HoldForm], " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "2"]}], "+", 
          RowBox[{"2", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "3"], " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "2"]}], "+", 
          RowBox[{"2", " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "3"]}], "-", 
          RowBox[{"2", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "2"], " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "3"]}], "+", 
          RowBox[{
            TagBox["x", HoldForm], " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "4"]}], "-", 
          SuperscriptBox[
           TagBox["y", HoldForm], "5"]}], "\[Equal]", "0"}]],
     Annotation[#, 
      HoldForm[$CellContext`x] - 2 HoldForm[$CellContext`x]^3 + 
       HoldForm[$CellContext`x]^5 - 
       HoldForm[$CellContext`y] + (2 HoldForm[$CellContext`x]^2) 
        HoldForm[$CellContext`y] - HoldForm[$CellContext`x]^4 
       HoldForm[$CellContext`y] - (2 HoldForm[$CellContext`x]) 
       HoldForm[$CellContext`y]^2 + (2 HoldForm[$CellContext`x]^3) 
        HoldForm[$CellContext`y]^2 + 
       2 HoldForm[$CellContext`y]^3 - (2 HoldForm[$CellContext`x]^2) 
       HoldForm[$CellContext`y]^3 + 
       HoldForm[$CellContext`x] HoldForm[$CellContext`y]^4 - 
       HoldForm[$CellContext`y]^5 == 0, "Tooltip"]& ]}],
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{175.03125, Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
  PlotRange->{{-2, 2}, {-2, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.711800556359666*^9, 3.737891181152273*^9, 
  3.7378924193873873`*^9, 3.7378935243714314`*^9, 3.737893966446047*^9, 
  3.742658536969939*^9},
 CellLabel->"Out[47]=",
 CellID->2049604012,ExpressionUUID->"7bab3e0f-e427-49ca-ab38-36863a1c3de8"]
}, Open  ]],

Cell[TextData[{
 "The entire algebraic component defined by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"], "-", "1"}], "=", "0"}]}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"89377306-810a-462d-a873-2ffe50336e52"],
 " is missing. ",
 ButtonBox["ContourPlot",
  BaseStyle->"Link"],
 " works using Gauss\[CloseCurlyQuote]s definition of a curve by finding \
where the sign of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "[", 
    RowBox[{"x", ",", "y"}], "]"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"5b4ac67d-0f2f-4606-afa6-5cf950814352"],
 " changes, but since ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineMath",ExpressionUUID->
  "051b2503-3c47-4f20-bf8f-f521eb3493a6"],
 " occurs squared in the equation of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]], "InlineMath",ExpressionUUID->
  "2a302d87-ce68-49b3-9991-d9a92abe0029"],
 ", the sign of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"d99251ac-a531-44fb-8554-12635df5c5b8"],
 " does not change near ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineMath",ExpressionUUID->
  "a3b2f693-3550-4350-a74f-fac5c0bf3f88"],
 ". Since we will be using Gauss\[CloseCurlyQuote]s idea even in our more \
sophisticated plotting in Chapter 4, we want to avoid polynomials like ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]], "InlineMath",ExpressionUUID->
  "798842ea-1bdd-4434-a333-367c4d288f50"],
 " that have a factor that is raised to the second or higher power. Again, if \
the equation is given exactly, as is ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]], "InlineMath",ExpressionUUID->
  "905889f2-0313-46e1-a12b-63f67d087afa"],
 ", then often we can use the Wolfram Language\[CloseCurlyQuote]s ",
 ButtonBox["Factor",
  BaseStyle->"Link"],
 " to see if there is any repeated factor and discard all repetitions. Unlike \
factoring, which is hard and theoretically impossible for numerical \
polynomials, it is easy to find and delete repeating factors numerically to \
get a square-free polynomial; for that, use ",
 Cell[BoxData[
 "sqFree"], "InlineCodeText",ExpressionUUID->
  "d2f11484-f5e2-45e9-8c99-9487e24dd399"],
 ", created for this book, which works with both exact and numerical \
polynomials."
}], "Text",
 CellChangeTimes->{{3.685453080395682*^9, 3.685453232923986*^9}, {
   3.685453269357157*^9, 3.685453269605129*^9}, {3.685453332686998*^9, 
   3.685453455786788*^9}, {3.685453490059933*^9, 3.685453490291814*^9}, {
   3.685453551133387*^9, 3.68545389146369*^9}, {3.685453968200792*^9, 
   3.685454019203651*^9}, {3.685454049235306*^9, 3.685454076796208*^9}, {
   3.685454276148312*^9, 3.685454391172111*^9}, {3.685454839065181*^9, 
   3.685454860189006*^9}, {3.685455120993977*^9, 3.685455121843026*^9}, {
   3.701008652052355*^9, 3.701008652089916*^9}, {3.701025354927989*^9, 
   3.701025383340419*^9}, {3.70102541933501*^9, 3.7010255431415586`*^9}, {
   3.7026554034984217`*^9, 3.702655403509214*^9}, {3.702838301748456*^9, 
   3.702838326773965*^9}, {3.702928948062252*^9, 3.702928948065199*^9}, {
   3.707502526253497*^9, 3.707502527127596*^9}, 3.7075028973729677`*^9, {
   3.7084285871427956`*^9, 3.708428589965996*^9}, {3.708428626368636*^9, 
   3.708428628291828*^9}, {3.7084286631093097`*^9, 3.708428667701769*^9}, {
   3.708428698610859*^9, 3.7084287192049184`*^9}, 3.708449321200937*^9, {
   3.709053850572646*^9, 3.709053859982587*^9}, {3.709053986485236*^9, 
   3.7090540119737844`*^9}, 3.7090601025080757`*^9, {3.7093044034870996`*^9, 
   3.7093044036864033`*^9}, {3.709304562103798*^9, 3.709304604230131*^9}, {
   3.710677371615169*^9, 3.710677430317481*^9}, {3.71067778216922*^9, 
   3.710677786238531*^9}, 3.715332330069325*^9, {3.715332572971068*^9, 
   3.7153325755133142`*^9}, 3.715332607091012*^9, {3.7383878412507553`*^9, 
   3.738387841256361*^9}, 3.7392947224076185`*^9, {3.73929499042272*^9, 
   3.7392950019487195`*^9}, 3.7392959388557196`*^9, 3.740833798540444*^9, {
   3.740833834124629*^9, 3.740833834516675*^9}, {3.740833884539351*^9, 
   3.740833885763667*^9}},
 CellID->1668577983,ExpressionUUID->"fa15ed4f-b14c-4bb2-9409-e891c7516577"],

Cell[TextData[{
 Cell[BoxData[
 "sqFree"], "InlineCode",ExpressionUUID->
  "0772d200-7ea5-49a7-8ce5-2ee31ec27b16"],
 " is explained in Appendix 1, which discusses numerical linear algebra in \
more detail. However, make sure you evaluate Appendix 2 before experimenting \
with any of the math in this chapter:"
}], "CodeCaption",
 CellChangeTimes->{{3.701025590949956*^9, 3.7010255912612*^9}, {
   3.707502554861452*^9, 3.707502579373789*^9}, 3.708449495601937*^9, {
   3.709053799198509*^9, 3.709053800328622*^9}, {3.7093044801392612`*^9, 
   3.709304485548061*^9}, {3.710677674028836*^9, 3.710677694901239*^9}, {
   3.710678315423268*^9, 3.710678320071963*^9}, {3.710679263763046*^9, 
   3.710679341766264*^9}, {3.710679375727702*^9, 3.710679418400941*^9}, 
   3.711721333316938*^9, 3.71371879822899*^9, {3.714742047842952*^9, 
   3.7147420537584543`*^9}, 3.715332335581815*^9, {3.715332684036426*^9, 
   3.7153326866566353`*^9}, {3.738387803181693*^9, 3.738387810378252*^9}, {
   3.7392950094677196`*^9, 3.73929503668172*^9}, 3.7392950687117195`*^9, {
   3.7392958201647196`*^9, 3.7392958208277197`*^9}, {3.7425808864869137`*^9, 
   3.7425809121358747`*^9}},
 CellID->1948697755,ExpressionUUID->"7366aaeb-6a54-4a96-83c7-c2693b9f8af0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gs", "=", 
  RowBox[{"sqFree", "[", 
   RowBox[{"g", ",", "x", ",", "y", ",", "1.*^-12"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.685454504711528*^9, 3.685454545680929*^9}, {
  3.737890681975007*^9, 3.737890711453308*^9}},
 CellLabel->"In[46]:=",
 CellID->490067888,ExpressionUUID->"3aa09456-4389-4fd8-888d-03e8c991a7a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "0.10860441456458086`"}], " ", "x"}], "+", 
  RowBox[{"0.10860441456458063`", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"0.10860441456458081`", " ", "y"}], "-", 
  RowBox[{"0.10860441456458081`", " ", 
   SuperscriptBox["x", "2"], " ", "y"}], "+", 
  RowBox[{"0.10860441456458092`", " ", "x", " ", 
   SuperscriptBox["y", "2"]}], "-", 
  RowBox[{"0.10860441456458061`", " ", 
   SuperscriptBox["y", "3"]}]}]], "Output",
 CellChangeTimes->{3.7118005563767233`*^9},
 CellLabel->"Out[46]=",
 CellID->1138840103,ExpressionUUID->"f4a2af18-7109-41a3-b18f-cd09b2b14815"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gs", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"gs", "/", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"gs", ",", 
      RowBox[{"x", "^", "3"}]}], "]"}]}], "]"}]}]], "Input",
 Editable->False,
 CellChangeTimes->{{3.685454585830813*^9, 3.685454612386741*^9}},
 CellLabel->"In[48]:=",
 CellID->59083550,ExpressionUUID->"e8e3c00f-e53e-4407-826e-e4362ffa8a1d"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \\\"0\\\"]\\) \
encountered.\"",2,170,5,18178834967190252033,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.737891181183012*^9, 3.737892419408519*^9, 
  3.7378935243832283`*^9, 3.737893966463619*^9},
 CellLabel->"During evaluation of In[170]:=",
 CellID->129104499,ExpressionUUID->"875c93eb-4e17-4b9a-b659-7a5461b83f12"],

Cell[BoxData["ComplexInfinity"], "Output",
 CellChangeTimes->{3.7118005563953247`*^9, 3.73789118121589*^9, 
  3.737892419417101*^9, 3.737893524390751*^9, 3.737893966473154*^9, 
  3.742658537013667*^9},
 CellLabel->"Out[48]=",
 CellID->2056931804,ExpressionUUID->"77cd6213-3484-412a-afa2-a848a4e9d00a"]
}, Open  ]],

Cell[TextData[{
 "Now, you will notice we have ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]], "InlineMath",ExpressionUUID->
  "18f9eb28-aa7a-42b7-8f9a-e4794d5a016d"],
 ", except now coefficients are treated as numerical quantities. "
}], "Text",
 CellChangeTimes->{{3.701025647805757*^9, 3.701025661660849*^9}, {
   3.707502468078826*^9, 3.707502482116302*^9}, {3.710678289390672*^9, 
   3.710678334543661*^9}, 3.73929632753572*^9, {3.740833948907154*^9, 
   3.740833961186461*^9}},
 CellID->1036474757,ExpressionUUID->"a299ab53-c34a-4839-beb9-4ea91176a61c"],

Cell["\<\
For the rest of this book, we will assume all curves are given by square-free \
polynomials.\
\>", "Text",
 CellChangeTimes->{{3.701025720861266*^9, 3.701025721212566*^9}, 
   3.7392965773767195`*^9, {3.740834006618895*^9, 3.740834006986209*^9}},
 FontSlant->"Italic",
 CellID->1791380082,ExpressionUUID->"a1937442-1ea5-4031-a61b-62d2e85a88c6"],

Cell[TextData[{
 "If a curve is reducible, then each factor of a square-free defining \
polynomial defines a sub-curve, which will be called an ",
 StyleBox["algebraic component",
  FontSlant->"Italic"],
 " of the curve. Topological components, which we will also call ",
 StyleBox["connected components",
  FontSlant->"Italic"],
 ", will be defined in Chapter 4."
}], "Text",
 CellChangeTimes->{{3.685532533510767*^9, 3.685532542790593*^9}, {
  3.685533071236867*^9, 3.685533103789776*^9}, {3.7010537744936867`*^9, 
  3.7010537895396223`*^9}, {3.7084287818741846`*^9, 3.7084288100029974`*^9}},
 CellID->1052327782,ExpressionUUID->"cf4b488d-a503-4817-aa52-1173042c08f9"],

Cell["\<\
We end this section by looking at several more curves that can be described \
as parametric or algebraic curves.\
\>", "Text",
 PageBreakAbove->True,
 CellChangeTimes->{{3.685532533510767*^9, 3.685532542790593*^9}, {
  3.685533071236867*^9, 3.685533103789776*^9}, {3.7010537744936867`*^9, 
  3.7010537844929132`*^9}, {3.708428823843381*^9, 3.708428825259523*^9}},
 CellID->88069984,ExpressionUUID->"de2f8d27-8f6c-4a72-9cc0-a72cd202c836"],

Cell[TextData[{
 "The bow curve where ",
 Cell[BoxData[
  RowBox[{"t", "\[NotEqual]", "0"}]], "InlineCode",ExpressionUUID->
  "e5f983e2-9843-44e4-8e80-97b553652303"],
 ", is given parametrically by:"
}], "CodeCaption",
 CellChangeTimes->{{3.701053819409093*^9, 3.70105381967246*^9}, 
   3.702840013860015*^9, {3.7090542213327184`*^9, 3.709054224659051*^9}, {
   3.740834040509118*^9, 3.740834040515052*^9}, {3.740834073768818*^9, 
   3.740834084624474*^9}, {3.742585077215911*^9, 3.7425850772188263`*^9}},
 CellID->4307234,ExpressionUUID->"35c00ede-9f95-4bf2-af65-359083017564"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Fbow", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"t", "^", "2"}]}], ")"}], "/", 
     RowBox[{"t", "^", "3"}]}], ",", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"t", "^", "2"}]}], ")"}], "/", 
     RowBox[{"t", "^", "4"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.685533131345131*^9, 3.685533199744635*^9}},
 CellLabel->"In[49]:=",
 CellID->1524721487,ExpressionUUID->"199f0042-b591-4f1c-9f48-b1f4edbbb5b4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["t", "2"]}], 
    SuperscriptBox["t", "3"]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["t", "2"]}], 
    SuperscriptBox["t", "4"]]}], "}"}]], "Output",
 CellChangeTimes->{3.7118005564238977`*^9, 3.737891181230434*^9, 
  3.737892419429785*^9, 3.7378935244078417`*^9, 3.737893966487524*^9, 
  3.7426585370552397`*^9},
 CellLabel->"Out[49]=",
 CellID->661080422,ExpressionUUID->"c81f576f-9531-4278-bdcc-06ecaf1df304"]
}, Open  ]],

Cell[TextData[{
 "We will show in Chapter 2 that this parameterized curve is contained in the \
algebraic curve ",
 Cell[BoxData[
  RowBox[{"fbow", "=", "0"}]], "InlineCode",ExpressionUUID->
  "c53104d2-1615-41df-93d5-5f63d4ccd056"],
 ", which defines the same affine point set:"
}], "CodeCaption",
 CellChangeTimes->{{3.701053875912219*^9, 3.7010538834741287`*^9}, 
   3.7010545113493137`*^9, {3.702655434626536*^9, 3.702655435001884*^9}, {
   3.702838951482667*^9, 3.7028389582215137`*^9}, 3.7028400166193323`*^9, {
   3.709054216415227*^9, 3.709054229080493*^9}, {3.709054326829028*^9, 
   3.709054334911028*^9}, {3.709060134643156*^9, 3.709060163556675*^9}},
 CellID->71672358,ExpressionUUID->"93fd1dfc-9309-4297-9b99-d391e0ec8cf6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fbow", "=", " ", 
   RowBox[{
    RowBox[{"x", "^", "4"}], "-", 
    RowBox[{
     RowBox[{"x", "^", "2"}], "y"}], "+", 
    RowBox[{"y", "^", "3"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.685538938382713*^9, 3.685538965658481*^9}},
 CellLabel->"In[50]:=",
 CellID->2006478586,ExpressionUUID->"737d6e9e-5699-4efc-8e31-523052b9d4db"],

Cell[TextData[{
 "This curve is quite difficult to plot. Below, we show three plots, ",
 ButtonBox["ParametricPlot",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["RegionPlot",
  BaseStyle->"Link"],
 ", and a region plot without boundary, with a plot from Chapter 4:"
}], "CodeCaption",
 CellChangeTimes->{{3.701053899488799*^9, 3.701053911717847*^9}, {
   3.70105395896045*^9, 3.701054008261771*^9}, 3.701054512397232*^9, {
   3.702655487546445*^9, 3.702655487865793*^9}, {3.709054337400028*^9, 
   3.7090543381790285`*^9}, {3.7090543942470284`*^9, 3.709054410545028*^9}, {
   3.7106784375465*^9, 3.71067843876235*^9}, {3.714749808972596*^9, 
   3.714749830314266*^9}, 3.7392969141977196`*^9, {3.742585183703816*^9, 
   3.742585184231048*^9}},
 CellID->949886061,ExpressionUUID->"e413bede-51e5-4b26-af3d-cabcca6df5b5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"ParametricPlot", "[", 
       RowBox[{"Fbow", ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", " ", 
          RowBox[{"-", "20"}], ",", 
          RowBox[{"-", ".1"}]}], "}"}], ",", " ", 
        RowBox[{"PlotRange", "\[Rule]", ".4"}], ",", 
        RowBox[{"Axes", "->", "False"}], ",", " ", 
        RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}], ",", " ", 
      RowBox[{"ParametricPlot", "[", 
       RowBox[{"Fbow", ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", ".1", ",", "20"}], "}"}]}], "]"}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
    RowBox[{"RegionPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "^", "4"}], "-", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "y"}], "+", 
        RowBox[{"y", "^", "3"}]}], "<", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", ".4"}], ",", ".4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", ".4"}], ",", ".4"}], "}"}], ",", " ", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
    RowBox[{"Show", "[", 
     RowBox[{
      GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1WXlY1dXWJotUHK5S+pGJAw6RmlJqmUOLHAjFKWlQUSRRwjTUMBT04hDi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         "], {
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[0.3], EdgeForm[None], 
           GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmQnY11MWx+89kazRRprSXhQVJpJSKEW7ipTKmiUqFCPaZIkQBmPPMnbG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              "]], 
             PolygonBox[CompressedData["
1:eJwtl3nwl1MUxt97EqW9RIVUlooIJS1IRSSRsiUZI4yEaowZoUT2ZSgtlhaV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              
              "]]}]}, {}, {}, {}, {}}], {{}, {{}, {}, 
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.016666666666666666`], AbsoluteThickness[1.6], 
           LineBox[{{-0.33035355027081426`, -0.37532190426816436`}, \
{-0.26732970831211744`, -0.2976933339966764}, {-0.20301888352092431`, \
-0.22113128020437722`}, {-0.09774206323488081, -0.1022080675611775}, \
{-0.09774206323488081, -0.1022080675611775}, {
            3.155330634554984*^-78, -2.0300699252378733`*^-78}, {
            0.0977420632348761, -0.10220806756117387`}, {
            0.0977420632348761, -0.10220806756117387`}, {
            0.16449184139276352`, -0.17664141038348558`}, {
            0.2296416311114623, -0.2524871096466404}, {
            0.33035355027080476`, -0.3753219042681578}}]}, 
          {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
           0.016666666666666666`], AbsoluteThickness[1.6], 
           LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQ7bv6+CqJpOv6qw+uvbFE7Nz6OXGestWvD+73CM2s
FKydYo/OX/5S3IDv+5H93Fr6UvZuc+wZWZ+FsX49vp9zkeVr+SWL7D9IndKw
f3xqv+dqxU3CB5bbT79sp1y9/+z++zJ/XS+XrrXfn8P6baHzhf3zLx/sSni0
0f6fq+OuZ7Mv7r9ksmxnd9hW+5uPK13vP7u0//3n9iWaEjvttzB/zctSurJf
e+PUj8809trvtrfWm+99df/8tc2mL48esF+xZguLety1/VIz57SyKx+2X5CR
ongy6Pr+PyK7JJ6uP2rP37VoTrv0jf3nS+eHqBedsP96d4ZvR8KN/coL8xl9
y85h8P0mnt/3Iub6ftEt927xXTtv3z7hzINDd6/uVwrbtpP5wXn7d+0RPpxh
V/ZvjLvyllv8vL3uMd1Pl28D3bv7xEPdp2ftj/O//TEz7+L++LTT81pLz9hr
15zwtOS5sN/i0yN2xzun7C+b9WtfTT273/et/b96lZP2zsVvXiw9dGq/15nQ
NvnQ4/YPrvxIuaRzYj/rsz8WW4qO2lu2/lPZu+jo/gYDmYtVDUD/mZe9kFE+
vH9RxV2O6w0H7bcaWAU9W3Ng/2WON1IWr/fZ6/6V2LgneNf+y7zen1lu7cDg
o8c3AACxFJA=
            "]]}, 
          {RGBColor[0.560181, 0.691569, 0.194885], PointSize[
           0.016666666666666666`], AbsoluteThickness[1.6], 
           LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQ7bv6+CqJpOv6qw+uvbFE7Nx6s78SG/cE77Lfzuv9
meXWDnt0vo+fu+Yt9f32jxIz07V599qzpF5LMGQ7ZL+lfuOanmkH7G/WdTOW
Nx6xd9q2S2vO7EP2xw7HvNzEdty+UIFhgdKUI/YMQXOSBKaftHdvE0hhqTtm
35TzhYXF5Ix92+1u26KwE/aqW9oa0++fs9d6FnegXfKUvbvRA8OLZy/Yp9U/
N5958LT905ss1z6YXrI3Xp9afd71rP3DzVOzFVddtk9cURHDNP2c/aMnRv35
OlftA79/sA2aft7++72slsod1+xZFNO35v0/b//17gzfjoQb9soL8xl9y85h
8D03Pc1vnXfDPrNtnlPh3dP29rfm/0owvWE/xdl5s96zE/YM9els30qv2zsJ
l9+/Jn3Mfien5guV9mv2ERPe71BsP2z/Kyz61OmKq/ZvJ6+4d13poL2gdJrg
3aAr9m+sHzalXd1rL7I7ZwWL1GV7BvYVXC+377Tv/HBGIOLiRftPc/5JPX+5
1f52c/NkweoL9unrBWXaMzfZS0z1Kb9peM5+Wc7vydez19kfu2ebvjHitP2a
jfF/js5dYS/abtejnXvCPnWOnWF05mL7Y4aKBv2FR+0Pmqj5R8+faz8jzlO2
+vVB+xthmZWCtVMw+OjxDwCw+QWU
            "]]}}, {}}},
       AspectRatio->1,
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{Automatic, Automatic},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{None, None}, {None, None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImageSize->{142.82291666666782`, Automatic},
       Method->{
        "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
         "AxesInFront" -> True},
       PlotRange->{{-0.4, 0.4}, {-0.4, 0.4}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}},
       Ticks->{Automatic, Automatic}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.685539382263612*^9, 3.685539448617167*^9}, {
  3.685539483284666*^9, 3.685539502337506*^9}, {3.6868347280726614`*^9, 
  3.6868347295101786`*^9}, {3.6868347741242237`*^9, 3.6868347754523644`*^9}, {
  3.6868348761422725`*^9, 3.686834891462694*^9}, {3.686835371563727*^9, 
  3.6868353831059246`*^9}, {3.737893813976357*^9, 3.7378939287811317`*^9}},
 CellLabel->"In[51]:=",
 CellID->341595429,ExpressionUUID->"45bc4455-a0c8-4b4d-b242-25cadaace7b7"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          FaceForm[
           Opacity[0.3]], 
          RGBColor[0.880722, 0.611041, 0.142051]], 
         LineBox[CompressedData["
1:eJwdVXk8ld/zlwqVJaWiRZYoQoqQ+MxTsreIpGhRSFGSKFJCkT17pZQQkZ0K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          "]]}, 
        Annotation[#, "Charting`Private`Tag$70353#1"]& ]}}, {{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          FaceForm[
           Opacity[0.3]], 
          RGBColor[0.880722, 0.611041, 0.142051]], 
         LineBox[CompressedData["
1:eJwdVXk8FNz3tkWlRajeSKS06S2EvFQPSYiyZd9Kg0pZs6TolaWoVJKtxZY0
JEvKEua+lrHOjHVmCpGotKnsEt/5/e4/5/N87jn3POfcc5+73sXL3FWAj49v
CT8f3//ZuXneGokl/28ta4hK94XX473RJHp7WpDp+SqyLfyAXCwnkmzWPqmy
yrKUaHyajOgbvUSo3qJEc2kB2XarTHcy/QKZ5xCLmYAcMtmnwHRbGkRCrcXf
FvM/Jpe9Gf6GMb7kssZgde/GVBJ/gOWq7O5NhDa1iUwHppCn6y73ndlyljxe
b7ZvR0YCUVXhX7fQ3J1oXn0ZldVxiwjEvtmbtdaZDDr13xPOCycvB8ZVHlo4
ELFQz+2lx8JIcL72stxuWyKWI/rsNSOUSK3bulih2JIMck4ri3sFkYq0dfs7
HEzIre58wSssL7LtkG7PrSWHSVThxtJr5AwxNDbz9Bs9RMoP6pYyRE+T8n8S
n8Yc0Sc3xU6tPXHZlUiHOb5YUKZDEjIz1L7xO5HZC40h35K1CXNgSG9djD0R
MRvOENoAojgscXK/qS3Jfbz9dHCQFmne+aluMtiSNIUraFHT1YiU4JBt91kT
snS5/esvHqpkcyMc/TcfJuMqmROBRruIicYu9XfiRsQn/fbuUF1l0vj9Xmi/
hz5JWuiY8OOtIrEuqGfpvNIhotKPKu75byNKWV47g+5okztDwezD8ltJboPd
bSchkNHk+RcnSzaRJTM26aXqWsS0v19NPFeerNnQ+btLTo2s8guy2lO6hsh5
iejqqG8jOx2baj1C/yI2ftqGrulbiIaHUvNdy9VEKsLsu9CWzWS741P9CJWV
xOLUqOCRSxuJoeSNm03XV5ATDV8a+jbKkfS/83UEDBeSxOuGIr72kkRqtC80
QlWEeM6YVizeK0FeeY6Qou3CJOkAVmKnOPk4LLvMQVuI6LszX+3QESOPmn2+
bB3kI7mCF2zvCSwmXVKb1j91m6T9a2AxT3/CR9Li7fu2Wk7QvNbyzW75d542
1pxpl3NknMa97UOppv+hHTt4KvHJsVFaLMOHRCbM0I5GrPmU9HGEpjg1MSws
O047+v6t/IkFQ7QTN4xVTwp8ptEMc9sr+t/TTE9Y03a4fqJ9HeZ8qaIP0CJ0
JicSuj/QTnuqL5gt6KfJusaqW86/py2R+FXt9+E1baGTtViyxFuaRP32r4dv
NdMewaAyZTOTVuMUU5yxqZHWa7Uw9+7RZtopRdVN/7bSaXm/PJYapTXQ5lar
rpN1qKYJ7NFkxcfW0PS6zvb1Xi6mrc+qek43fEGzLvQrtsxMxieRsrV3TJIh
kTyst4iagbN9spQLJhk4yekR2WvxBPLqR7XyyrLxbm/5r7G4QvQaL22sHilA
5MEBme/nXmH5smq4cMtQo2F6JGG2DgVXtUcL6DVQztYrfz1Ah9UlZ89nQbWg
BKyRNKmux/BXigNVvg5Bp1THH55txKW8L60dznRYCvV4yF5owbqJJzt+RDWg
D5EJRkoMfPIWMf/I1wj6XbVhmX4GVghUnhP2bwTFRmC1hRILhU++RKUaN4FM
9HVFNreCzLUmjFc141TApwCaeBvWmGbTJpa3QDzufdwb6zYo37m4M9+hBYnf
alb86m4DSVqg+nm4BUu0jZ6JSrejYvex6fJtDOh2lejo2LSjS2pZdJ87AxIB
8T1qjHaMWWs5FHAYmBQxz1y2oANTLS6+qYuZMNH4+UFdqwPX9dwkT2oyoShi
sykrowNW+56unLvFxOcxn17+zg7Iafg/EyplIlzcMbZbsBPtnRmO1j1M+HhT
snY6d2K659JvfRkWXg7Rmj5Ed2Lp+lC56/+wwP92iZ/p8048iKAcuGvBwjMx
vlP+3Z1Q/uYUEOTBQq+ooLqTQBe01xD+Q2EsrD1htVFiSxcGjR/6y9xloeG1
rM594y7cTZN5uiCbhW5bVyd+7y7MvfJokyxh4b/QcclDcV24k+B92qGOBTvf
ffSQ510Ypu62/9bGglm7xMPMji7sYUt+4/SwUGxEia/+1YU2saudih9YEL7T
5/lOjI2GlgH1qW8s0KxvVAvvYMPsc2G+0RgLB5otxzUOsaHX9d1SdZqFV8YX
EerKxgH7GUKb5fGrXZLXc4mN7+knlv6eY8FJfY+sXTIbAVdD3v2aZ6FfsPLw
bCEbLpm1Ps95OMdFpKGhkY2BD6sjDXj+530SJmr72bg5UxdU+ZuF8uNSaycm
2Gha43NAZoqF5HVpVseXcNBi3BziO8qCLfdZmuh6DvgKtzvU8/gasO3bp1U5
GPJdUKHwkQXrb0czlAw44Ir8LZ/Yx0Lk+LvHxXYcrNooRtvIYSE/vtcq5gwH
ppwqHw6DheuFWYtfhnBQsbWnqaSGBbe3gn+0Yjm4FO69nFnKQrXIMmO5hxxY
rUnTks9jQaxgftotj4NF1w4uqEhj4eGc6HeJCg4o7UFvM+6wMDW4ZXxbEwfM
+O+TvZG8/Pc6qvM5HLT1WOieC2RB4TnzZ9YgB4/UIvzPnGTBf/K10IqfHKxf
XbCQYcPCiB3FfWyWA5Oos/vuG7AQt0HD02IhF1a1xev7d/P6I37ryG0ZLlK6
JFb3SrJwLk7FLWAzFzg8sC9dgIX7AbGp75W4cFSQ1/0xwkSYZNzH7n+4KJ/n
/4fFm9f9p+X/ctnPxX2FK4t0G5lId300FXSIi44QCT/TF0yQ7rB9G8y5GNnS
u3g2jRf/cfn5Pce4eM29cxSBTEBQLrzAjYuNy6O9+o7z3k+lxrrqM1xcuuJ8
Y4cxE10mUnl+vly8+/koWkmdieQdluH1gVz8pp9fNyzLhFlZ8RDtIhcX1zwf
sl/ERH/u48XOYVzcnf1pe/0XA4yTqVLZkVzMfijghHQzIPPPBaWUaC4E/PUf
7qplIOdej63mDS4GPg22FjxlQK7ySmL0LS6aa8ICp+IZ+Kn0qjf6DhfdzIZL
S0MYyBCIktybwMW1j5OVvygMdKhJ/5WVxMWDvtJvOcYMNDXJl9WkcKFZ+atI
Q5WBGIeFlSn3uRDLupPyUJqnJ2f03yo+5EL4hYV0nwADWra3R26n8vz3m0r1
feTpkbPVG2oaF/tVNreVtrTgd8iKHP90LlZa7xD3KmxBa2qBwyQPC1b+iRdK
aMGnxokBpQxefVtPTF4IbsGgSrfcRh5+H21cxXFqQYLL0Ld2nn/MI6qVlG4L
6n2jVoKHp/31Vh3c3IKoGC/r07x8/KGJexxFW3Dx6ZC7FY+Prs2N0eMjzbg/
Iv5DiMf35mdjU6uOZhRqWMYG8upZdG7EYk9JM+JiYtj5vHqptWpfV95rRhu/
vXk+rx9q79TGBkObMXvz37BAXr/cLAXUcl2aMRy95M2ieC6W+Rm5nT7YjFjp
3Ab321ysL5/ZsXFbM4KfDxbExXKRmtmg8GZpMwzbxFuPXuXittHiXO2uJlC3
JGZ8j+DiYOao1FhpEzLajB7b8e5b1PP7Rer9JmiWKMg+O89FySozHVlKEwxm
F/1I9Ofi8rNrfw3oN6FsVijHxoeLSuXjLbmKTWgfz9A+cZKLUYf3O2xGG3H3
m7Jp+VEunMZHNJXDG3EqsnAsyIQ3X91e2frujTAI7MpaxZvv1Us52WeMGtFy
Sav51z4ubLxlo4ckGnHcbrPWQd770Tv/4c/jrAbscjnCXTTKwR6j8fqfLfVw
2RMxJ/WVg6N/rn5AUT26DR+5rB7ioH+tf3dWYj3sVJ1sOtkcyIzL15a71OO3
xBVrrzIOiqT7hlfM0HHxY+zl9AscNDOmjhX9TceTnu3Ryuc4KHS/WW68io7s
den5L3l6JBBUbDc/V4f6dWVl6Y4csCVy+vJa62B9zXlYEBwEh3ilqfjXYWWG
v/IePg5a5dTFP1fXQssvRdoglI29uqfCNX1q0Hd14KZwABtOy87Txhxq8OTp
H5nqs2yYlk69rjeowdpldarKjmwU3PzjXypXg0/ndDtHtdgoup1f8l9bNSSJ
B7ZPd+GneepXV41qhPV2dxr7dYHFkZk7tfo/DOsH8Wmf7oLhUXedXKH/kF+X
4qp6vAtvlt+uEf5FoPE7Wn+9SRd0b1YuWMIgGArbu2uZIm9/1/i8UQTBwJn9
4wbvO1FBzU5YPEJDzjbXlAbLToS1jvV+7qvEu0P5Fc16HYgumnTfq1sOo5Vp
rJK9HUiM6WTZbC3H9LvSnU/UOuBJP3AicXk5nDzpQ3cVOkBvOKQS0lMG1aCS
yCze/66yxytqKLAMe3e6CybR2xHmkpo6U1yK7lpJIY5RO6LnKObtB0swNjX/
gH2iDZ4m86pCtGJ4FlwSfVXNQsKkM7/6dAHSj2UnOU+04EH79nDZtlywf3eX
V5Q1QTY60f61bzZSm60jP7Y3oE3fJfKHxCNkbNAjT0TqMesUrVylmI4y+6JI
7q067L164NHnqQc4c/Pb2c2KtRhHvpuJdApmW3yDNoxXo1g6f3fwnwS8sjBM
mf71HybWRHxKjI2H2DsFobxJgn7HUWaPRRwOzoio6WwkoEdk54bF3sKR9NrE
YmoVGul25Tfab2BL0SWTQI1KRLdfPO0meg01+WRfwp9X8PMWXHi18SoOt7M3
B9eWo+v3/pXMR1Ew0/zgkFxSBq/++8krBiJQZfYzL6KmFCrytVFKtuHYHvw2
XJ1ZgnOpmhP9vWEwnzzw/un0Syyz1aykp/8LPdxNMt/wEkSuTcq7NxQevnuF
fJ1f4FxmSBWTXITo67BjF4uLETP6nPyYCkZPoCazQLgYl79OHKvSOA+p2lu3
nD2fQ3tn4ecrFYFYsu3RaMy7IqjMOQZ4uQcgdZIT52lWBIfaZ23Vkv64M1wS
f769EDy5lBMf9cPPkcRrdqaFoD483xPX7ov1wZe/2PQWoIN+kJ7zxgcKlQ/v
avgWQGqlecjLaW9Qrjm+fC1YgHvvW1vHVnvjw8n4gC7dfNSKVQlfoHpixSel
Qfb5Z/gYrcp5K3cWT45rshUr87Cryu1v+1ceWDPMclZemQfl/YstwyNOY4TV
aqzm/hTTp5cenDA8Bbe1GmI/mnMx633hesruk8gcHc3k18xFqmFbnZqWO0qL
tpgbZOSgZrxY6KSmG1690dC4IpWD6SR6wXlbV5zl9zuk9lcOJkqiGnItXSFy
73vd+5U5sLPVG3xr5oqQB5pTOityQOKNNxkccsW6/dL6ggt5/r+9mzZpuQLy
Tf7J41QInhHRlZRxhXOJsrVEGxXBSZYhee8oCB085MBkUhG4rJ8y30tBT5pW
fXQLFeYKW/XM31CwVvgfJn8DFasvJ3+faaegeH/5g4kqKvR8PLqtaykQ7shR
HH1KxX8cyTZkU7AwkBFWnMM7X6dXOj2TgpkOuT0BT6iQKJ2zFUyjQF33Z89M
JhULrk09a0qiIKjcuWXhPSo4MpeLKDEUTFN36DCSePFoiWVEUfDdzGlNXAIV
Y3lN9rvDKUjyDxpdG0eFTUs8felFCpgOO8cHblKxZEHZieAgCnw7+mypN6j4
c2//j4/nKLii4L3e+xoVsUpvPax8KPiRTTfaHU2FXZQGu+4sBf8D4EWUlw==

          "]]}, Annotation[#, "Charting`Private`Tag$70377#1"]& ]}}}, {
    ImageSize -> Small, DisplayFunction -> Identity, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"ScalingFunctions" -> None}, 
     PlotRange -> {{-0.4, 0.4}, {-0.4, 0.4}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{0, 0}, {0, 0}}, Ticks -> {Automatic, Automatic}}],
   GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJx1WXlY1dXWJotUHK5S+pGJAw6RmlJqmUOLHAjFKWlQUSRRwjTUMBT04hDi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     "], {{{
        EdgeForm[], 
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6], 
         Opacity[0.3]], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmQnY11MWx+89kazRRprSXhQVJpJSKEW7ipTKmiUqFCPaZIkQBmPPMnbG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           "]], 
          PolygonBox[CompressedData["
1:eJwtl3nwl1MUxt97EqW9RIVUlooIJS1IRSSRsiUZI4yEaowZoUT2ZSgtlhaV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           
           "]]}]}, {}, {}, {}, {}}, {{
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwt0rdSVkEchvFDlCBIDpJBSQICl+IlWIg2OiPJdA8CIijB1hmQBjEUxBJF
UDAhBoRWzIB2/HaG4pnn/e979ptvz56Ks5fOXIyJoug+uoWQp3BT+BYbRRlY
lMd4HNNyDy7LvbzD2Xgu5/B39Mkd3M8/OR8v5AL+hdtyFw/yHy7CinyFi1Ea
F0Ul/NJaOdeby/gqKlBmruQ1/Uk+ZT7B11CNcnMNv9PXc4O5jq+HZ8NvmBt4
Q3+aG81NfAPNqDS38Bf9SvgfWMJyOAce4QEmwtk9e89zC9jGY2tP8QRb5lb+
j1F5HpvIt+crf0aj7h9G5Dl8RJ7+E39ArW4fw/Is3iNXv85vUaXbw5A8g9fh
HvRveBWlul3clS/webyS//Id7uZClNhznNvCOa3/5gHu5NxwL/o8PhfehfUf
fIvbw93jIaYwiWfWs8K92pMZ3pfvKQPHkI40HEUqUpCMJBxBIhIQD9uj2MPv
8gCp4lGx
         "]], 
        LineBox[CompressedData["
1:eJwl0rkvZXEYBuDj3gQzSOiYTjERtaVBiQ7RoLKUEtsfQKGQGYUEjUasCQmx
FMTa2FsUaG2FbRpDYn9+UTx5v/c7955zzzk3u6mtujUhiqI/HMaiKI9mtixH
5RjDXOpDcpwJ8uniyr5AvvDKtj7Cm7mQa/MDmfEoupe7TIYL6iWO/zM/kaX/
l3tME9fLHX8O5+KX/ir3mSVJr3L83dwrF2WqXdzcQR25eq3sY9nxDP2HeYcF
ksPvDfcQ7o8Dn1ki3eca9UEGWA3XlWnsksoeK/b9MokLGjinnhFi4TmSQA0p
zrvgO+3mNiJ+2s3b/TVXkKNXytbwTO0T9RnZo5fyWy+TLTzax/Qp2a3fyiL5
Ed6beYcT82m4B270OXlGMZ/hfdqtyzu5JjfZCO9Y75RHHMe+/xtf07hOPA==

         "]], 
        LineBox[CompressedData["
1:eJwl0jsvX2EABvDjGiUl8Q2ENKayuQwubQfXgWJoMVAT0Y+AIK2UMLTEJWKg
RYIoSRMSbTfMakCLpW6Ly8Lg8jsx/PI8z3vO+3cGKQ3vK1sjgiDo4VgZjgyC
Sab4xlfaaCeXWya81xG+I3/KX6xxYf8O78iIqCB4oV/qC3KHXf6yRxcv+ccr
9rnybreckdHul+k3ermMsWf1j/qcjLOr9Xu9Rj6x5/U+fVkm2bXhPQao44B6
DollhFHGwr/JNE2ckcAQq35rUyaxTiIbrDj/Igd5xymNfOaYE474zyLxNJDs
u364268vyUT7rR7NG57a35336neySqY7ey0/UUGmXSmvPS+Vz+wS+YEiMuxi
ee55oUyzC2QneTy388Nv9DxHptrZcos/4Xc735bNtJDFeOTj/8cD2b1Kdw==

         "]]}}}], {
    DisplayFunction -> Identity, AspectRatio -> 1, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {Automatic, Automatic}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, PlotRange -> {{-0.4, 0.4}, {-0.4, 0.4}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],GraphicsBox[{
     GraphicsComplexBox[CompressedData["
1:eJx1WXlY1dXWJotUHK5S+pGJAw6RmlJqmUOLHAjFKWlQUSRRwjTUMBT04hDi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      "], {{
        RGBColor[0.368417, 0.506779, 0.709798], 
        AbsoluteThickness[1.6], 
        Opacity[0.3], 
        EdgeForm[None], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmQnY11MWx+89kazRRprSXhQVJpJSKEW7ipTKmiUqFCPaZIkQBmPPMnbG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           "]], 
          PolygonBox[CompressedData["
1:eJwtl3nwl1MUxt97EqW9RIVUlooIJS1IRSSRsiUZI4yEaowZoUT2ZSgtlhaV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           
           "]]}]}, {}, {}, {}, {}}], {{}, {{}, {}, {
        RGBColor[0.368417, 0.506779, 0.709798], 
        PointSize[0.016666666666666666`], 
        AbsoluteThickness[1.6], 
        LineBox[{{-0.33035355027081426`, -0.37532190426816436`}, \
{-0.26732970831211744`, -0.2976933339966764}, {-0.20301888352092431`, \
-0.22113128020437722`}, {-0.09774206323488081, -0.1022080675611775}, \
{-0.09774206323488081, -0.1022080675611775}, {
         3.155330634554984*^-78, -2.0300699252378733`*^-78}, {
         0.0977420632348761, -0.10220806756117387`}, {
         0.0977420632348761, -0.10220806756117387`}, {
         0.16449184139276352`, -0.17664141038348558`}, {
         0.2296416311114623, -0.2524871096466404}, {
         0.33035355027080476`, -0.3753219042681578}}]}, {
        RGBColor[0.880722, 0.611041, 0.142051], 
        PointSize[0.016666666666666666`], 
        AbsoluteThickness[1.6], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQ7bv6+CqJpOv6qw+uvbFE7Nz6OXGestWvD+73CM2s
FKydYo/OX/5S3IDv+5H93Fr6UvZuc+wZWZ+FsX49vp9zkeVr+SWL7D9IndKw
f3xqv+dqxU3CB5bbT79sp1y9/+z++zJ/XS+XrrXfn8P6baHzhf3zLx/sSni0
0f6fq+OuZ7Mv7r9ksmxnd9hW+5uPK13vP7u0//3n9iWaEjvttzB/zctSurJf
e+PUj8809trvtrfWm+99df/8tc2mL48esF+xZguLety1/VIz57SyKx+2X5CR
ongy6Pr+PyK7JJ6uP2rP37VoTrv0jf3nS+eHqBedsP96d4ZvR8KN/coL8xl9
y85h8P0mnt/3Iub6ftEt927xXTtv3z7hzINDd6/uVwrbtpP5wXn7d+0RPpxh
V/ZvjLvyllv8vL3uMd1Pl28D3bv7xEPdp2ftj/O//TEz7+L++LTT81pLz9hr
15zwtOS5sN/i0yN2xzun7C+b9WtfTT273/et/b96lZP2zsVvXiw9dGq/15nQ
NvnQ4/YPrvxIuaRzYj/rsz8WW4qO2lu2/lPZu+jo/gYDmYtVDUD/mZe9kFE+
vH9RxV2O6w0H7bcaWAU9W3Ng/2WON1IWr/fZ6/6V2LgneNf+y7zen1lu7cDg
o8c3AACxFJA=
         "]]}, {
        RGBColor[0.560181, 0.691569, 0.194885], 
        PointSize[0.016666666666666666`], 
        AbsoluteThickness[1.6], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQ7bv6+CqJpOv6qw+uvbFE7Nx6s78SG/cE77Lfzuv9
meXWDnt0vo+fu+Yt9f32jxIz07V599qzpF5LMGQ7ZL+lfuOanmkH7G/WdTOW
Nx6xd9q2S2vO7EP2xw7HvNzEdty+UIFhgdKUI/YMQXOSBKaftHdvE0hhqTtm
35TzhYXF5Ix92+1u26KwE/aqW9oa0++fs9d6FnegXfKUvbvRA8OLZy/Yp9U/
N5958LT905ss1z6YXrI3Xp9afd71rP3DzVOzFVddtk9cURHDNP2c/aMnRv35
OlftA79/sA2aft7++72slsod1+xZFNO35v0/b//17gzfjoQb9soL8xl9y85h
8D03Pc1vnXfDPrNtnlPh3dP29rfm/0owvWE/xdl5s96zE/YM9els30qv2zsJ
l9+/Jn3Mfien5guV9mv2ERPe71BsP2z/Kyz61OmKq/ZvJ6+4d13poL2gdJrg
3aAr9m+sHzalXd1rL7I7ZwWL1GV7BvYVXC+377Tv/HBGIOLiRftPc/5JPX+5
1f52c/NkweoL9unrBWXaMzfZS0z1Kb9peM5+Wc7vydez19kfu2ebvjHitP2a
jfF/js5dYS/abtejnXvCPnWOnWF05mL7Y4aKBv2FR+0Pmqj5R8+faz8jzlO2
+vVB+xthmZWCtVMw+OjxDwCw+QWU
         "]]}}, {}}}, {
    ImageSize -> Small, AspectRatio -> 1, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {Automatic, Automatic}, 
     DisplayFunction -> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> {142.82291666666782`, Automatic}, 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, PlotRange -> {{-0.4, 0.4}, {-0.4, 0.4}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.711800556500752*^9, 3.737891181465445*^9, 
  3.737892419673293*^9, 3.737893524646779*^9, 3.7378938680908823`*^9, 
  3.7378939332444267`*^9, 3.7378939667395563`*^9, 3.742658537197023*^9},
 CellLabel->"Out[51]=",
 CellID->1845746623,ExpressionUUID->"1128fa68-a1ed-4e1a-8ec3-57ed53181a5b"]
}, Open  ]],

Cell[TextData[{
 "In general, an algebraic curve that can be locally parameterized by a pair \
of rational functions of one variable is called a ",
 StyleBox["rational curve",
  FontSlant->"Italic"],
 ". In Chapter 7, we will show that conics are rational curves. Singular \
cubics are rational curves. In Chapter 5, we will show that an irreducible \
curve of degree ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]], "InlineMath",ExpressionUUID->
  "9fd47b84-f60f-44e6-91a1-5de7e9ed9dac"],
 " has at most ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"d", "-", "2"}], ")"}]}], "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"7810f72c-99ec-4de0-a70d-a39cde3f42cb"],
 " singular points. A classical theorem of algebraic geometry says that \
rational curves have many or complicated singularities. Conversely, if a \
curve has the maximal number of singularities for that degree, as seen above, \
then it is rational, but there is no simple method to find the rational \
parametrization."
}], "Text",
 CellChangeTimes->{{3.685546708401365*^9, 3.685546787835841*^9}, {
  3.685546819405086*^9, 3.685546941864945*^9}, {3.685546976529382*^9, 
  3.685547049905951*^9}, {3.685547084693316*^9, 3.685547254018652*^9}, {
  3.685549273843423*^9, 3.685549275875697*^9}, {3.701008652161538*^9, 
  3.7010086522111273`*^9}, {3.701054050880521*^9, 3.701054094095358*^9}, {
  3.702655463679687*^9, 3.702655463684538*^9}, {3.7026555117628593`*^9, 
  3.7026555233859787`*^9}, {3.708428871903187*^9, 3.7084288899599924`*^9}, {
  3.709054765201104*^9, 3.7090547662232065`*^9}, {3.709055067493331*^9, 
  3.7090550754071217`*^9}, {3.7093054783054934`*^9, 3.709305496101369*^9}},
 CellID->970586772,ExpressionUUID->"a417550e-559f-4896-a8f2-0000101ae174"],

Cell["\<\
In Chapter 3 of Fischer (2001), he gives several examples of complicated \
algebraic curves derived from parametric curves. \
\>", "Text",
 CellChangeTimes->{{3.68553967964533*^9, 3.685539708141751*^9}, {
   3.685545227575345*^9, 3.685545365299581*^9}, {3.68554545345359*^9, 
   3.68554545778937*^9}, {3.685546528099579*^9, 3.685546533564727*^9}, {
   3.685546583662237*^9, 3.685546597486635*^9}, 3.686832412671948*^9, {
   3.686832555388994*^9, 3.686832596718134*^9}, 3.701008652222642*^9, {
   3.7010541117038717`*^9, 3.701054121631667*^9}, {3.702655530289671*^9, 
   3.7026555436736813`*^9}, {3.707502699723892*^9, 3.707502704837405*^9}, 
   3.7075029000724688`*^9, {3.7084289382328196`*^9, 3.7084289599779935`*^9}, {
   3.709054896336217*^9, 3.7090548969342766`*^9}, {3.7090549503776207`*^9, 
   3.7090549544530277`*^9}, {3.7090551296795487`*^9, 
   3.7090551322338037`*^9}, {3.709304930685286*^9, 3.709304930688493*^9}, {
   3.710678792900444*^9, 3.710678797988185*^9}, {3.7392971112987194`*^9, 
   3.7392971188977194`*^9}},
 CellID->366094392,ExpressionUUID->"b3dba1a8-e2a2-4d11-bccd-fca759ff2611"],

Cell[TextData[{
 "The degree ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]], "InlineMath",ExpressionUUID->
  "135a4c44-10f0-4760-96e9-6d19a0efdc96"],
 " Chebyshev curve is given parametrically in the Wolfram Language by:"
}], "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{{3.7090551366982503`*^9, 3.709055144632044*^9}, {
  3.7093047594260387`*^9, 3.709304782345796*^9}},
 CellID->429522593,ExpressionUUID->"6194fb64-6012-4df5-b8bb-413f642489af"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Cheb", "[", "d_", "]"}], ":=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ChebyshevT", "[", 
        RowBox[{
         RowBox[{"d", "-", "1"}], ",", "t"}], "]"}], ",", 
       RowBox[{"ChebyshevT", "[", 
        RowBox[{"d", ",", "t"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.686832624551418*^9, 3.686832762986615*^9}, {
  3.686832806940231*^9, 3.686832825201887*^9}, {3.737891573448138*^9, 
  3.7378915814276648`*^9}},
 CellLabel->"In[52]:=",
 CellID->407797689,ExpressionUUID->"badc136a-4031-4138-a356-3eed179c7160"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Cheb", "[", "4", "]"}], ",", 
    RowBox[{"Cheb", "[", "5", "]"}], ",", " ", 
    RowBox[{"Cheb", "[", "6", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.685546521474423*^9, 3.685546524147678*^9}, {
   3.685546607534644*^9, 3.6855466414243*^9}, {3.685547279545978*^9, 
   3.685547312747078*^9}, {3.685547710774734*^9, 3.685547711278263*^9}, {
   3.686832418537426*^9, 3.686832419152254*^9}, {3.68683276973927*^9, 
   3.686832791019859*^9}, 3.686832866610816*^9, {3.7378916018637743`*^9, 
   3.737891608139089*^9}},
 CellLabel->"In[53]:=",
 CellID->1235441446,ExpressionUUID->"935fed6b-122f-45d9-8e7b-4fae4c26a0f4"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, 
      TagBox[{
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJw1m3k01W+0xlWSSpMmoUFJlCSVhNollSIkCalUGqSkaFBRIjImFEURkQoh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         "]]}, 
       Annotation[#, "Charting`Private`Tag$70430#1"]& ]}}, {
    DisplayFunction -> Identity, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {"ScalingFunctions" -> None}, 
     PlotRange -> {{-1., 1.}, {-0.9999999635426067, 1.}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],
   GraphicsBox[{{{}, {}, 
      TagBox[{
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJwsmnc81v/3/yVJaGooVCRJ3imphDoqlWQlqaQligaShpZdMkoIRZKVlL3n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         "]]}, 
       Annotation[#, "Charting`Private`Tag$70453#1"]& ]}}, {
    DisplayFunction -> Identity, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {"ScalingFunctions" -> None}, 
     PlotRange -> {{-0.9999999635426067, 1.}, {-1., 1.}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],
   GraphicsBox[{{{}, {}, 
      TagBox[{
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJwsmnlczd/zxysRqYRQShIlhFSSpAlpQ5IiEVkiJCSVrSxRKFIkpJ0WStq0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         "]]}, 
       Annotation[#, "Charting`Private`Tag$70476#1"]& ]}}, {
    DisplayFunction -> Identity, Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Small, 
     Method -> {"ScalingFunctions" -> None}, 
     PlotRange -> {{-1., 1.}, {-0.9999999919050473, 1.}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.7118005565924273`*^9, 3.737891181711074*^9, 
  3.737891618991159*^9, 3.7378924199163322`*^9, 3.73789352488136*^9, 
  3.7378939670019703`*^9, 3.742658537337557*^9},
 CellLabel->"Out[53]=",
 CellID->1062211846,ExpressionUUID->"bd4589f3-7297-42fc-9cd8-db1f5fb7095e"]
}, Open  ]],

Cell[TextData[{
 "Fischer (2001) shows that ",
 Cell[BoxData[
  RowBox[{"Cheb", "[", "d", "]"}]], "InlineCodeText",ExpressionUUID->
  "e7734ccf-ed5e-4a8a-ae52-e5b8df117b20"],
 " is algebraic of degree ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]], "InlineMath",ExpressionUUID->
  "7c34ddc5-5af1-47af-80be-c5ff91bb6d5f"],
 " with ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"d", "-", "2"}], ")"}]}], "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"0aabb603-f296-4cb5-a234-8e265fe21197"],
 " singularities, which, as mentioned, is the maximum number allowed for an \
irreducible curve of degree ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]], "InlineMath",ExpressionUUID->
  "0641a419-df7f-4507-95b0-4e01b4971147"],
 ". For example, the equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"8", " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["y", "3"]}], "+", 
     RowBox[{"3", " ", "y"}], "+", "1"}], "=", "0"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"6d1a6075-a2de-44f0-96ea-7200571a2835"],
 " has three singularities, the maximum for a degree 4 curve."
}], "Text",
 CellChangeTimes->{{3.68554733808837*^9, 3.685547338755389*^9}, {
   3.685547381660618*^9, 3.68554751954443*^9}, {3.685547577513923*^9, 
   3.685547627099465*^9}, {3.685548011605999*^9, 3.685548091152166*^9}, {
   3.686832948902841*^9, 3.686833052523542*^9}, {3.686833085195375*^9, 
   3.686833097619906*^9}, {3.686833136892451*^9, 3.686833221853531*^9}, {
   3.686833373017868*^9, 3.686833447204017*^9}, {3.701008652233878*^9, 
   3.7010086522492332`*^9}, {3.701054163375534*^9, 3.701054208929119*^9}, {
   3.7010545134616756`*^9, 3.701054517541333*^9}, {3.702655567813615*^9, 
   3.702655567818512*^9}, {3.702838355193975*^9, 3.70283835519873*^9}, {
   3.702928996946918*^9, 3.702928996951599*^9}, {3.708429038430838*^9, 
   3.7084290418931837`*^9}, 3.708450321874937*^9, {3.7090551768432646`*^9, 
   3.70905518099568*^9}, {3.709055375049083*^9, 3.709055416802258*^9}, 
   3.709060226004569*^9, {3.710678855230601*^9, 3.710678883423193*^9}, {
   3.7392971943417196`*^9, 3.7392971993737197`*^9}, {3.7392974259607196`*^9, 
   3.73929742705672*^9}},
 CellID->45000079,ExpressionUUID->"939fb217-2ae0-4150-872b-61944975c814"],

Cell["\<\
Another family of interesting parametric curves is the rose curves given by: \
\
\>", "CodeCaption",
 CellChangeTimes->{{3.685548108116659*^9, 3.685548173817042*^9}, {
   3.707502757780273*^9, 3.707502758307646*^9}, 3.7090552350570855`*^9, {
   3.7395286945564423`*^9, 3.7395286955384426`*^9}},
 CellID->402084009,ExpressionUUID->"25c0afbf-8ab4-4315-8690-e6e76374c04e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Rose", "[", "k_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "t", "]"}], 
      RowBox[{"Cos", "[", 
       RowBox[{"k", " ", "t"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Sin", "[", "t", "]"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"k", " ", "t"}], "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.685548192882047*^9, 3.685548261279018*^9}, {
  3.685548571940782*^9, 3.68554857363127*^9}, {3.685548670769521*^9, 
  3.685548699737961*^9}, {3.685548743843057*^9, 3.685548744219551*^9}},
 CellLabel->"In[54]:=",
 CellID->1842385801,ExpressionUUID->"380bd37b-3ce6-4257-838f-1a68f328e602"],

Cell[TextData[{
 Cell[BoxData[
  FormBox["k", TraditionalForm]], "InlineMath",ExpressionUUID->
  "a2cb76af-83b4-4aa1-a8e8-f6a9b57869a6"],
 " can be any constant real number. This gives an algebraic curve for each \
rational number ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]], "InlineMath",ExpressionUUID->
  "43ad532b-6f15-43b6-9695-3535e786bd11"],
 ", but it is not algebraic for irrational ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]], "InlineMath",ExpressionUUID->
  "4afb2634-8682-46d0-b002-cf356672d32e"],
 ". For more detail, see ",
 ButtonBox["mathworld.wolfram.com/Rose.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Rose.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/Rose.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.685548612786952*^9, 3.685548625327233*^9}, 
   3.685548706585169*^9, {3.685548757434744*^9, 3.685548807172455*^9}, {
   3.685548908351404*^9, 3.685548929584347*^9}, {3.68554907222341*^9, 
   3.685549092428784*^9}, {3.685549134533468*^9, 3.685549141829054*^9}, 
   3.701008652261235*^9, {3.7010542567431307`*^9, 3.701054307722534*^9}, {
   3.708429073527347*^9, 3.708429098847879*^9}, {3.7090555347410507`*^9, 
   3.709055553185895*^9}, {3.709305010156252*^9, 3.709305038202278*^9}},
 CellID->411451314,ExpressionUUID->"ce315383-859e-4dcb-b9f8-14517585a847"],

Cell[TextData[{
 "Use ",
 ButtonBox["ParametricPlot",
  BaseStyle->"Link"],
 " to show these beautiful curves:"
}], "CodeCaption",
 CellChangeTimes->{{3.743796134637825*^9, 3.743796141104843*^9}},
 CellID->683819206,ExpressionUUID->"25971275-124d-4763-a1e9-4632801c4f64"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Rose", "[", "3", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{
        RowBox[{"-", "2"}], "Pi"}], ",", 
       RowBox[{"2", "Pi"}]}], "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}], ",", " ", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Rose", "[", 
      RowBox[{"2", "/", "3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{
        RowBox[{"-", "3"}], "Pi"}], ",", 
       RowBox[{"3", "Pi"}]}], "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{
  3.685549250773804*^9, {3.685549344171419*^9, 3.685549411802364*^9}, {
   3.685549457327944*^9, 3.685549479743815*^9}, {3.73789223516817*^9, 
   3.7378922732511883`*^9}},
 CellLabel->"In[55]:=",
 CellID->364891058,ExpressionUUID->"50e4d4b1-109b-4c04-9361-c3fa307a0607"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwkW3VU1N/TxiZEkRBEUQkRFSVtZEQBEUQJQcIiRQVJRb4gpSgGoKCihLSE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        "]]},
      Annotation[#, "Charting`Private`Tag$70501#1"]& ]},
    Axes->{False, False},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{True, True}, {True, True}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"ScalingFunctions" -> None},
    PlotRange->{{-0.5624999733966309, 1.}, {-0.880086250767437, 
     0.8800861243487048}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.05], 
       Scaled[0.05]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwkWHc8le/7l8ooZYRUKkWojIyMUldFGWVlJRIl9IkGpSKjkIZKyEh29t7n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        "]]},
      Annotation[#, "Charting`Private`Tag$70525#1"]& ]},
    Axes->{False, False},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{True, True}, {True, True}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"ScalingFunctions" -> None},
    PlotRange->{{-1., 0.9999984807579303}, {-0.9999984175690927, 
     0.9999981706566508}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.05], 
       Scaled[0.05]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.73789118187843*^9, {3.737892229232439*^9, 3.737892240933774*^9}, {
   3.737892276077009*^9, 3.737892301823618*^9}, 3.7378924201154947`*^9, 
   3.7378935250766287`*^9, 3.7378939671981297`*^9, 3.742658537457399*^9},
 CellLabel->"Out[55]=",
 CellID->562938211,ExpressionUUID->"39671d60-21b8-49b7-b72f-8287da74e0a4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Q&A", "QASection",
 PageBreakAbove->True,
 CellChangeTimes->{3.6502707881907787`*^9, 3.651158679291786*^9},
 CellID->532690973,ExpressionUUID->"518b7c52-c54e-499a-bd78-d12a150a0d2e"],

Cell["Here are two thought questions to be answered later.", "Answer",
 CellChangeTimes->{{3.685549556298962*^9, 3.685549583601946*^9}, {
  3.709055675808156*^9, 3.70905568905348*^9}, {3.7090560067342453`*^9, 
  3.7090560115517273`*^9}, {3.710679548492884*^9, 3.71067955239088*^9}, {
  3.711802875766652*^9, 3.711802876382593*^9}},
 CellID->958156859,ExpressionUUID->"f8c2ce47-f262-4eee-8621-72bf9335f3e3"],

Cell[TextData[{
 "In Shreeram Abhyankar\[CloseCurlyQuote]s book ",
 StyleBox["Algebraic Geometry for Scientists and Engineers",
  FontSlant->"Italic"],
 " (1990), he gives the following picture of a quartic ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "4"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "db0504a7-d3f1-4504-a1dd-a689ce06a16c"],
 " surrounded by a conic ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Q", "2"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "123c231f-e697-4de9-a232-48c91a8ca85b"],
 " in the plane:"
}], "Question",
 CellChangeTimes->{{3.701055752480125*^9, 3.7010557742714663`*^9}, {
   3.702838376547461*^9, 3.7028383780828733`*^9}, 3.708429821838348*^9, 
   3.708450711084937*^9, {3.709055624303006*^9, 3.709055655324108*^9}, 
   3.7090557668382583`*^9, {3.7090610817579327`*^9, 3.7090610836043797`*^9}, {
   3.710679000753615*^9, 3.710679016754488*^9}, {3.7118027586076736`*^9, 
   3.71180275893493*^9}, {3.711802807407446*^9, 3.711802807790831*^9}, 
   3.7118029059907084`*^9, {3.7395288176054425`*^9, 3.7395288261324425`*^9}, {
   3.740834467555065*^9, 3.740834467840878*^9}},
 CellID->1909944007,ExpressionUUID->"17c6abea-e4c8-4062-87a7-689d10159e9b"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQlwE2fW9+sABhsbL7KtvbVZ3VJbiyVLlmxkyY5tGRvMjtkSCBDCEoZl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    "], {{0, 354}, {600, 0}}, {0,
     255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag[
   "Byte", ColorSpace -> "RGB", Interleaving -> True, MetaInformation -> 
    Association[
     "XMP" -> Association[
       "DublinCoreSchema" -> Association["Format" -> "image/png"], 
        "PhotoshopSchema" -> 
        Association["ColorMode" -> 3, "ICCProfile" -> "sRGB IEC61966-2.1"], 
        "BasicSchema" -> 
        Association[
         "CreateDate" -> 
          DateObject[{2018, 8, 27, 10, 32, 44.}, "Instant", "Gregorian", -7.],
           "CreatorTool" -> "Adobe Photoshop CC 2018 (Macintosh)", 
          "MetadataDate" -> 
          DateObject[{2018, 8, 27, 10, 36, 43.}, "Instant", "Gregorian", -7.],
           "ModifyDate" -> 
          DateObject[{2018, 8, 27, 10, 36, 43.}, "Instant", 
            "Gregorian", -7.]], "MediaManagementSchema" -> 
        Association[
         "DocumentID" -> 
          "adobe:docid:photoshop:62fcf124-4792-f645-a4f2-1d26bc84ebfc", 
          "History" -> 
          Association[
           "History[1]" -> 
            Association[
             "Action" -> "created", "InstanceID" -> 
              "xmp.iid:e1b5d90e-fdf3-46e3-9a8b-97d3f2419695", "When" -> 
              DateObject[{2018, 8, 27, 10, 32, 44}, "Instant", 
                "Gregorian", -7.], "SoftwareAgent" -> 
              "Adobe Photoshop CC 2018 (Macintosh)"], "History[2]" -> 
            Association[
             "Action" -> "saved", "InstanceID" -> 
              "xmp.iid:94196aaa-2d63-4a2a-b069-c58abee47ee9", "When" -> 
              DateObject[{2018, 8, 27, 10, 36, 43}, "Instant", 
                "Gregorian", -7.], "SoftwareAgent" -> 
              "Adobe Photoshop CC 2018 (Macintosh)", "Changed" -> "/"]], 
          "InstanceID" -> "xmp.iid:94196aaa-2d63-4a2a-b069-c58abee47ee9", 
          "OriginalDocumentID" -> 
          "xmp.did:e1b5d90e-fdf3-46e3-9a8b-97d3f2419695"], 
        "RightsManagementSchema" -> 
        Association[
         "History" -> 
          Association[
           "History[1]" -> 
            Association[
             "Action" -> "created", "InstanceID" -> 
              "xmp.iid:e1b5d90e-fdf3-46e3-9a8b-97d3f2419695", "When" -> 
              DateObject[{2018, 8, 27, 10, 32, 44}, "Instant", 
                "Gregorian", -7.], "SoftwareAgent" -> 
              "Adobe Photoshop CC 2018 (Macintosh)"], "History[2]" -> 
            Association[
             "Action" -> "saved", "InstanceID" -> 
              "xmp.iid:94196aaa-2d63-4a2a-b069-c58abee47ee9", "When" -> 
              DateObject[{2018, 8, 27, 10, 36, 43}, "Instant", 
                "Gregorian", -7.], "SoftwareAgent" -> 
              "Adobe Photoshop CC 2018 (Macintosh)", "Changed" -> "/"]]], 
        "PagedTextSchema" -> 
        Association[
         "History" -> 
          Association[
           "History[1]" -> 
            Association[
             "Action" -> "created", "InstanceID" -> 
              "xmp.iid:e1b5d90e-fdf3-46e3-9a8b-97d3f2419695", "When" -> 
              DateObject[{2018, 8, 27, 10, 32, 44}, "Instant", 
                "Gregorian", -7.], "SoftwareAgent" -> 
              "Adobe Photoshop CC 2018 (Macintosh)"], "History[2]" -> 
            Association[
             "Action" -> "saved", "InstanceID" -> 
              "xmp.iid:94196aaa-2d63-4a2a-b069-c58abee47ee9", "When" -> 
              DateObject[{2018, 8, 27, 10, 36, 43}, "Instant", 
                "Gregorian", -7.], "SoftwareAgent" -> 
              "Adobe Photoshop CC 2018 (Macintosh)", "Changed" -> "/"]]]]]],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->{249.59765625, Automatic},
  ImageSizeRaw->{600, 354},
  PlotRange->{{0, 600}, {0, 354}}]], "Picture",
 CellChangeTimes->{{3.737891727514904*^9, 3.737891734413055*^9}, {
   3.737891803220998*^9, 3.737891819231949*^9}, 3.744380242377059*^9},
 CellID->1990853940,ExpressionUUID->"7358460c-050e-4766-acca-ff6ba2bf380b"],

Cell[TextData[{
 "This is meant only to be illustrative, not literal. It is too bad he did \
not think to use the Chebyshev quartic for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "4"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "3aeb14a6-0270-4616-bf66-b512a5bc543d"],
 ". Give at least two reasons why ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "4"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "c9cede61-89c3-4c9a-840e-1567bb9ecac2"],
 " is not an actual plot of a square-free real plane algebraic curve. This \
question will be answered in Chapters 4 and 5."
}], "Answer",
 CellChangeTimes->{{3.685549913356518*^9, 3.685549950427965*^9}, {
   3.68554998322986*^9, 3.685550027013698*^9}, {3.685550074161109*^9, 
   3.685550101242227*^9}, {3.685550138523337*^9, 3.68555014437097*^9}, {
   3.685614721281577*^9, 3.685614733649839*^9}, {3.685615057049454*^9, 
   3.685615090969762*^9}, {3.685616897075431*^9, 3.685616910115462*^9}, {
   3.701008652277515*^9, 3.701008652292194*^9}, 3.701054368494606*^9, {
   3.702655625643365*^9, 3.7026556298654213`*^9}, {3.7028383852206697`*^9, 
   3.702838389124967*^9}, {3.7084298423664007`*^9, 3.7084298451026745`*^9}, {
   3.710679664064654*^9, 3.710679678400377*^9}, 3.711721334261845*^9},
 CellID->339465673,ExpressionUUID->"c425b502-2eb0-4336-8c7c-d67c7d07123f"],

Cell["A plot of Newton Hyperbola 336941 is shown below:", "Question",
 CellChangeTimes->{{3.685616912776959*^9, 3.685616946780266*^9}, 
   3.701054402414578*^9, {3.7010557678004923`*^9, 3.701055772191966*^9}, {
   3.7084298559667606`*^9, 3.708429857990963*^9}, 3.708450758489937*^9, {
   3.711802810374754*^9, 3.711802810702787*^9}, 3.711802909726509*^9, 
   3.7408344968655157`*^9},
 CellID->1682999679,ExpressionUUID->"7d01df33-1b32-4a00-8efc-d875a2493463"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"newtonHyperbola", "[", 
     RowBox[{"336941", ",", "x", ",", "y"}], "]"}], "\[Equal]", "0"}], ",", 
   " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.685616951305322*^9, 3.685616956617416*^9}, {
   3.685617427407101*^9, 3.685617468760467*^9}, 3.742585270632044*^9},
 CellLabel->"In[56]:=",
 CellID->1668490316,ExpressionUUID->"2eaa647e-e030-44af-873e-10efc65dc38a"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmXc81t///+0te++9uVBKqXMSimREg0SkqGRUSoXKKjM0STRERUZmhXOU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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl1FV4EAQUBeBtwMZgm5JSAqMbCSmlW3ogHUqXo1EUUFJaUro7pLsR6e5Q
ultKEFD49/Hwn/t0Hs+NbNohKjowICDgAxFzg4hFbOIQTAhxCSUe8QkjnIiY
Lh+SgIQkIjFJSMpHJCM5KUhJKj4mNWlISyTpSE8GMpKJzGQhK9nITg5ykovc
fEIe8pKP/HxKAQpSiMIU4TM+pyjFKE4JSlKK0pShLOUoTwUq8gWVqEwVqlKN
6tQgiprU4ktqU4e61KM+DWhIIxrThK/4mqY0ozktaEkrWtOGtrSjPd8QTQc6
0onOdKEr3ejOt3xHD77nB3rSi978yE/0oS/96M8ABvIzgxjMEIYyjOGM4BdG
MorRjGEs4/iV8UxgIpOYzBSmMo3pzGAms5jNHOYyj/ksYCGLWMwSfmMpy1jO
ClayitWsYS3rWM8GNrKJzWxhK9vYzg5+Zyd/sIvd7GEv+9jPAQ5yiMMc4SjH
OM4JTnKK05zhLOc4z5/8xQUuconLXOEq17jODW5yi9vc4S73uM8DHvKIv3nM
E57yjOf8wwte8i+veM0b/uN/3hIz/kCCiEVs4hBMCHEJJR7xCSOciMD3v+Md
L16BzA==
        "]], LineBox[CompressedData["
1:eJwV0VdbDgAAQOHPP0BGSciIpIxsmUlWIQrZIZnZW0nJishM9qZsGakoRTJC
fpDXxfs85/6EZ2SnbGoTCAQaaSva0Z4gOtCRTnQmmBC6EEpXwuhGd3oQTk96
0Zs+RNCXfkTSnygGEE0MAxnEYIYQy1CGMZwRjGQUoxlDHGMZx3gmMJFJxDOZ
BKaQyFSmMZ0ZzCSJZGYxmzmkMJd5pJLGfBawkHQWsZglLGUZy1lBBitZxWoy
WUMWa1nHejawkf8DstnMFrayje3sYCe72M0e9rKP/Rwgh1wOksch8ingMIUc
4SjHOM4JijjJKYo5zRlKOMs5znOBi1yilMuUcYWrXOM6N7jJLW5zh7vc4z4P
eMgjyqngMU94yjOe84KXvKKS17zhLe+o4j3V1FDLBz5SRz2faKCRz3yhia80
843v/OAnLfziN39o5S//ALjnWvg=
        "]], LineBox[CompressedData["
1:eJwVzsN2HQAAANGX2rZT27bN1G5TK6lt27Zt2/qB2rZT83Zxz5nlBIeGh4QF
BQKBCK6Iq1zjOje4yS1uc4e73OM+D3jIIx7zhKc84zkveMkrXvOGt7zjPR/4
yCci+MwXvvKN7/zgJ7/4zR/+/h+OFAgEEYnIRCEq0YhODGISi9jEIS7xiE8C
EpKIxCQhKclITgpSkorUpCEt6UhPBoLJSCYyk4WsZCM7OchJLnKTh7zkIz8F
KEghClOEohSjOCUoSSlKU4aylKM8FahIJSpThapUozo1qEktalOHutSjPg0I
oSGNaEwTmtKM5rSgJa1oTRva0o72hNKBjnSiM13oSje604Oe9CKMcHrTh770
oz8DGMggBjOEoQxjOCMYyShGM4axjGM8E5jIJCYzhalMYzozmMksZjOHucxj
PgtYyCIWs4SlLGM5K1jJKlazhrWsYz0b2MgmNrOFrWxjOzvYyS52s4e97GM/
BzjIIQ5zhKMc4zgnOMkpTnOGs5zjPBe4yCUu8w95yHo3
        "]], 
       LineBox[CompressedData["
1:eJwNxGeADgQAANDPGVlH9grZe6YoK9l7ZGbvUHcie0fZe+9NlE32njdwx51d
isyy9/Z+vJetXWiDkDiBQCBYYUGBQDgRRHKcE5wkimhOcZoYYjnDWc5xngtc
5BJ/8heX+Zt/uMJV/uUa17nBTW5xm//4nzvc5R73ecBDHvGYJzzlGc95wUte
8Zo3vOUdgbiBQByCiEs84pOAD0hIIhKThKQEk4zkfEgKUpKK1KQhLelITwYy
komPyEwWsvIx2chODnKSi9zkIS/5yE8BClKIwhShKMUozieU4FM+oySl+Jwv
KE0ZylKO8nxJBb6iIpWoTBWqUo3q1KAmtahNHepSj/o04Gsa0ojGNKEpzfiG
5rSgJa1oTRva0o72dKAjnejMt3ShK934ju8JIZTu/EAPevIjvehNH/rSj/4M
YCCDGMwQhjKMnxjOCH7mF0YyitGMYSzjGM8EJjKJyUxhKtOYzgxmMovZzGEu
85jPAhayiMUsYSnLWM4KVvIrq1jNb/zOGtayjvVsYCOb2MwW/mAr29jODnay
i93sYS/72M8BDnKIwxzhKMcII5wIIjnOCU4SRTSnOE0MsbwHbA+OtQ==
        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"-", "1"}], "+", 
          TagBox["x", HoldForm], "-", 
          RowBox[{"0.2`", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "2"]}], "+", 
          RowBox[{"0.008`", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "3"]}], "-", 
          RowBox[{"0.000064`", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "4"]}], "+", 
          RowBox[{"1.0240000000000012`*^-7", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "5"]}], "-", 
          TagBox["y", HoldForm], "+", 
          RowBox[{
            TagBox["x", HoldForm], " ", 
            TagBox["y", HoldForm]}], "+", 
          RowBox[{"0.2`", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "2"], " ", 
            TagBox["y", HoldForm]}], "+", 
          RowBox[{"0.008`", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "3"], " ", 
            TagBox["y", HoldForm]}], "-", 
          RowBox[{"0.00006400000000000002`", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "4"], " ", 
            TagBox["y", HoldForm]}], "-", 
          RowBox[{"0.2`", " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "2"]}], "+", 
          RowBox[{"0.2`", " ", 
            TagBox["x", HoldForm], " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "2"]}], "+", 
          RowBox[{"0.2`", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "2"], " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "2"]}], "+", 
          RowBox[{"0.008`", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "3"], " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "2"]}], "+", 
          RowBox[{"0.008`", " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "3"]}], "-", 
          RowBox[{"0.008`", " ", 
            TagBox["x", HoldForm], " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "3"]}], "-", 
          RowBox[{"0.008`", " ", 
            SuperscriptBox[
             TagBox["x", HoldForm], "2"], " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "3"]}], "+", 
          RowBox[{"0.000064`", " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "4"]}], "+", 
          RowBox[{"0.00006400000000000002`", " ", 
            TagBox["x", HoldForm], " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "4"]}], "+", 
          RowBox[{"1.0240000000000012`*^-7", " ", 
            SuperscriptBox[
             TagBox["y", HoldForm], "5"]}]}], "\[Equal]", "0"}]],
     Annotation[#, -1 + HoldForm[$CellContext`x] - 0.2 
       HoldForm[$CellContext`x]^2 + 0.008 HoldForm[$CellContext`x]^3 - 
       0.000064 HoldForm[$CellContext`x]^4 + 
       1.0240000000000012`*^-7 HoldForm[$CellContext`x]^5 - 
       HoldForm[$CellContext`y] + 
       HoldForm[$CellContext`x] 
        HoldForm[$CellContext`y] + (0.2 HoldForm[$CellContext`x]^2) 
        HoldForm[$CellContext`y] + (0.008 HoldForm[$CellContext`x]^3) 
        HoldForm[$CellContext`y] - (0.00006400000000000002 
        HoldForm[$CellContext`x]^4) HoldForm[$CellContext`y] - 0.2 
       HoldForm[$CellContext`y]^2 + (0.2 HoldForm[$CellContext`x]) 
        HoldForm[$CellContext`y]^2 + (0.2 HoldForm[$CellContext`x]^2) 
        HoldForm[$CellContext`y]^2 + (0.008 HoldForm[$CellContext`x]^3) 
        HoldForm[$CellContext`y]^2 + 
       0.008 HoldForm[$CellContext`y]^3 - (0.008 HoldForm[$CellContext`x]) 
       HoldForm[$CellContext`y]^3 - (0.008 HoldForm[$CellContext`x]^2) 
       HoldForm[$CellContext`y]^3 + 
       0.000064 
        HoldForm[$CellContext`y]^4 + (0.00006400000000000002 
         HoldForm[$CellContext`x]) HoldForm[$CellContext`y]^4 + 
       1.0240000000000012`*^-7 HoldForm[$CellContext`y]^5 == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{175.06640625, Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
  PlotRange->{{-20, 20}, {-20, 20}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7118005568617477`*^9, 3.742658537707345*^9},
 CellLabel->"Out[56]=",
 CellID->1637047242,ExpressionUUID->"649b8ce7-8875-4c5f-bf98-e6ef404d6f3a"]
}, Open  ]],

Cell["\<\
We will see later that there is obviously missing information about the full \
curve. Without further plotting or calculations, give several possible ways \
this curve could be completed to the entire affine (or projective) plane. \
Chapter 10 gives the answer to this question.\
\>", "Answer",
 CellChangeTimes->{{3.685617490004286*^9, 3.685617505305993*^9}, {
   3.6857095603954706`*^9, 3.6857095623429537`*^9}, {3.700222144730847*^9, 
   3.7002223189958563`*^9}, {3.7010086523030033`*^9, 3.701008652312203*^9}, 
   3.70842987126429*^9, 3.7090560244970217`*^9, {3.709473069829158*^9, 
   3.709473070715816*^9}, {3.710679694993377*^9, 3.710679706464608*^9}},
 CellID->1513831009,ExpressionUUID->"1e741915-bc1c-4d0b-b0fa-ea437667e743"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 CellChangeTimes->{3.650270852705229*^9, 3.65115870052378*^9},
 CellID->170962084,ExpressionUUID->"65fd70d4-ea1a-4b5c-a57b-8007ce3b8400"],

Cell[TextData[{
 StyleBox[ButtonBox["For more on Gaussian functions, go to Wolfram MathWorld ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/GaussianFunction.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/GaussianFunction.html"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/wbbQVTSY",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/wbbQVTSY"], None},
  ButtonNote->"http://wolfr.am/wbbQVTSY"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.6511948809300756`*^9, 3.6511948892178*^9}, {
   3.651194932463626*^9, 3.651194932467025*^9}, 3.655013463296049*^9, 
   3.6640102579191008`*^9, 3.697472133741184*^9, {3.711471316260997*^9, 
   3.711471335354191*^9}, 3.7114713965872097`*^9, {3.711471945695513*^9, 
   3.711471955670023*^9}, {3.711472051039448*^9, 3.711472157518298*^9}, {
   3.711472271718939*^9, 3.71147227206221*^9}, {3.7114723180866737`*^9, 
   3.7114723488541813`*^9}, 3.711472411105101*^9, {3.711472533055881*^9, 
   3.711472536162768*^9}, {3.711475583951935*^9, 3.7114755848464212`*^9}, {
   3.7114756961423798`*^9, 3.711475696453912*^9}, {3.7114757940701303`*^9, 
   3.711475824357519*^9}, {3.711475937877605*^9, 3.7114759600209017`*^9}, 
   3.7395290159224424`*^9},
 CellTags->"LastCellOfAPage",
 CellID->26626102,ExpressionUUID->"8cd3e504-8436-4d8a-85bb-50285d1aceac"],

Cell[TextData[{
 ButtonBox["If you\[CloseCurlyQuote]d like to learn more about Fermat\
\[CloseCurlyQuote]s last theorem, try Wolfram|Alpha ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframalpha.com/input/?i=Fermat%27s+last+theorem&lk=1&\
rawformassumption=%22ClashPrefs%22+-%3E+%7B%22FamousMathProblem%22,+%\
22FermatsLastTheorem%22%7D"], None},
  ButtonNote->
   "http://www.wolframalpha.com/input/?i=Fermat%27s+last+theorem&lk=1&\
rawformassumption=%22ClashPrefs%22+-%3E+%7B%22FamousMathProblem%22,+%\
22FermatsLastTheorem%22%7D"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/wbbT5ADJ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/wbbT5ADJ"], None},
  ButtonNote->"http://wolfr.am/wbbT5ADJ"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.6511948809300756`*^9, 3.6511948892178*^9}, {
   3.651194932463626*^9, 3.651194932467025*^9}, 3.655013463296049*^9, 
   3.6640102579191008`*^9, 3.697472133741184*^9, {3.711471316260997*^9, 
   3.711471335354191*^9}, 3.7114713965872097`*^9, {3.711471945695513*^9, 
   3.711471955670023*^9}, {3.711472051039448*^9, 3.711472157518298*^9}, {
   3.711472271718939*^9, 3.71147227206221*^9}, {3.7114723180866737`*^9, 
   3.7114723488541813`*^9}, 3.711472411105101*^9, 3.711472533055881*^9, {
   3.711802261190146*^9, 3.711802261193074*^9}},
 CellTags->"LastCellOfAPage",
 CellID->1070349993,ExpressionUUID->"ea5feee3-1c73-435d-877c-032f7c769815"],

Cell[TextData[{
 ButtonBox["Try R. Dickau\[CloseCurlyQuote]s fractal curves Demonstration at \
the Wolfram Demonstrations Project for some fun with Hilbert and Moore curves \
you can adjust ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/HilbertAndMooreFractalCurves/"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/HilbertAndMooreFractalCurves/"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/vt3x0r9n",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/vt3x0r9n"], None},
  ButtonNote->"https://wolfr.am/vt3x0r9n"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.6511948809300756`*^9, 3.6511948892178*^9}, {
   3.651194932463626*^9, 3.651194932467025*^9}, 3.655013463296049*^9, 
   3.6640102579191008`*^9, 3.697472133741184*^9, {3.711471316260997*^9, 
   3.711471335354191*^9}, 3.7114713965872097`*^9, {3.711471945695513*^9, 
   3.711471955670023*^9}, {3.711472051039448*^9, 3.711472157518298*^9}, {
   3.711472271718939*^9, 3.71147227206221*^9}, {3.7114723180866737`*^9, 
   3.7114723488541813`*^9}, 3.711472411105101*^9, 3.711472533055881*^9, {
   3.711802261190146*^9, 3.711802261193074*^9}},
 CellTags->"LastCellOfAPage",
 CellID->1244731958,ExpressionUUID->"02b24e8f-e119-489d-b32c-eb971602ceb0"],

Cell[TextData[{
 ButtonBox["Per my mention of Cassini ovals, try E. J. O. Martos\
\[CloseCurlyQuote]s Demonstration ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/CassiniOvals/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/CassiniOvals/"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/vt3CIAjn",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/vt3CIAjn"], None},
  ButtonNote->"https://wolfr.am/vt3CIAjn"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.6511948809300756`*^9, 3.6511948892178*^9}, {
   3.651194932463626*^9, 3.651194932467025*^9}, 3.655013463296049*^9, 
   3.6640102579191008`*^9, 3.697472133741184*^9, {3.711471316260997*^9, 
   3.711471335354191*^9}, 3.7114713965872097`*^9, {3.711471945695513*^9, 
   3.711471955670023*^9}, {3.711472051039448*^9, 3.711472157518298*^9}, {
   3.711472271718939*^9, 3.71147227206221*^9}, {3.7114723180866737`*^9, 
   3.7114723488541813`*^9}, 3.711472411105101*^9, 3.711472533055881*^9, {
   3.711802261190146*^9, 3.711802261193074*^9}, {3.739532910229745*^9, 
   3.739532964746745*^9}},
 CellTags->"LastCellOfAPage",
 CellID->367315410,ExpressionUUID->"a4830843-7fb1-40a0-939b-4edbdddcfed8"]
}, Open  ]]
}, Open  ]]
},
Saveable->False,
WindowToolbars->{},
BlinkingCellInsertionPoint->False,
CellInsertionPointCell->None,
WindowSize->{830, 800},
WindowMargins->Automatic,
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"Introduction to Numerical Plane Curves",
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{"\[ThinSpace]", "\[ThinSpace]", 
          StyleBox[
          "A Numerical Approach to Real Algebraic Curves with \
\[LineSeparator]the Wolfram Language", LineSpacing -> {1, 1}, FontFamily -> 
           "Source Sans Pro", FontSize -> 24, FontColor -> GrayLevel[1]], 
          "\[ThinSpace]"}, "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {65, 75}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{
                    "00b-Dayton-ChapterOverview_UsageNote.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{
                    "00b-Dayton-ChapterOverview_UsageNote.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                  Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter Overview and Usage Note\"", 
              TooltipDelay -> 0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter Overview and Usage Note", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"02-Dayton-Perspective.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"02-Dayton-Perspective.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                  "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Classical vs. Numerical Perspectives\"",
               TooltipDelay -> 0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "Classical vs. Numerical Perspectives", 
              "Tooltip"]& ]}, "RowWithSeparators"], Alignment -> Right], 
         ImageSize -> {100, 30}, FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> 
         Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> RGBColor[0.2, 0.1, 0.1], 
             ImageSize -> {35, 30}, Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Introduction" :> 
          NotebookLocate[{"00a-Dayton-Introduction.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Chapter Overview and Usage Note" :> 
          NotebookLocate[{"00b-Dayton-ChapterOverview_UsageNote.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace] \
1\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Introduction to \
Numerical Plane Curves" :> 
          NotebookLocate[{"01-Dayton-PlaneCurves.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]2\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Classical vs. Numerical Perspective" :> 
          NotebookLocate[{"02-Dayton-Perspective.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]3\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Special Points and Lines" :> 
          NotebookLocate[{"03-Dayton-SpecialPointsLines.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]4\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Gauss Decomposition" :> 
          NotebookLocate[{"04-Dayton-GaussDecomposition.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]5\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]A Classical Interlude" :> 
          NotebookLocate[{"05-Dayton-ClassicalInterlude.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]6\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Fractional Linear Transformations" :> 
          NotebookLocate[{"06-Dayton-FractionalLinearTransformations.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]7\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Asymptotes, Conics, and Cubics" :> 
          NotebookLocate[{"07-Dayton-AsymptotesConicsCubics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]8\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Global Plots" :> 
          NotebookLocate[{"08-Dayton-GlobalPlots.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]9\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Harnack's Theorem and Newton Hyperbolas" :> 
          NotebookLocate[{
            "09-Dayton-HarnacksTheorem-NewtonHyperbolas.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]10\[ThickSpace]\[ThickSpace]|\[ThickSpace]\
\[ThickSpace]Final Examples" :> 
          NotebookLocate[{"10-Dayton-FinalExample.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "Appendix 1: Topics in Numerical Linear Algebra" :> 
          NotebookLocate[{"Appendix-1-Topics-NumericalLinearAlgebra.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Appendix 2: Global Functions" :> 
          NotebookLocate[{"Appendix-2-GlobalFunctions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "References" :> 
          NotebookLocate[{"References.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> RGBColor[0.2, 0.1, 0.1], 
   CellMargins -> {{0, 0}, {0, -1}}, CellFrameMargins -> {{27, 0}, {1, 7}}, 
   Background -> RGBColor[0.2, 0.1, 0.1], CellTags -> "DockedCellLogoCell"], 
  Cell["BARRY H. DAYTON", "Text", FontFamily -> "Source Sans Pro", FontWeight -> 
   "Light", FontSize -> 15, CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> 
   False, CellMargins -> {{0, 0}, {-1, -1}}, 
   CellFrameMargins -> {{27, 0}, {2, 4}}, CellFrameColor -> 
   RGBColor[0.8, 0.2, 0.2], FontTracking -> "Extended", FontColor -> 
   GrayLevel[1], Background -> RGBColor[0.8, 0.2, 0.2], CellTags -> 
   "DockedCellLogoCell"]},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page", CounterFunction :> FrontEnd`RomanNumeral], 
       "PageNumber"], 
      StyleBox[
       RowBox[{
        "    ", "A", " ", "Numerical", " ", "Approach", " ", "to", " ", 
         "Real", " ", "Algebraic", " ", "Curves", "with", "the", "Wolfram", 
         "Language"}], "Header"]}], "Header", 
    CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], None, None}, {
  None, None, 
   Cell[
    TextData[{
      StyleBox[
       RowBox[{" ", " ", "    "}], "Header"], 
      StyleBox[
       CounterBox["Page", CounterFunction :> FrontEnd`RomanNumeral], 
       "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 17}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageHeader"->True},
ShowCellBracket->Automatic,
ShowAutoSpellCheck->False,
ShowPredictiveInterface->False,
ShowSyntaxStyles->False,
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> "Verdana",
        FontSize -> 7, FontSlant -> "Plain", FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Verdana", FontSize -> 7, 
       FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "WPL Specific", "Section", 
       CellChangeTimes -> {{3.6556608433734913`*^9, 3.6556608489412746`*^9}}], 
      Cell[
       StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
       If[CurrentValue[
           EvaluationCell[], "FontFamily"] === "Source Sans Pro", Inherited, 
         If[CurrentValue[
            EvaluationCell[], "FontFamily"] === "WolframCodeSans", Inherited, 
          Inherited 0.9]], FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["CodeLink"], 
       ButtonBoxOptions -> {
        Appearance -> None, ButtonFunction :> (FEPrivate`FrontEndExecute[
           FrontEndToken["OpenHelpLink", {
             Part[#, 1], Null}]]& ), ButtonSource -> ButtonContents, 
         Evaluator -> None, Method -> "Preemptive"}], 
      Cell[
       StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
       Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxDividers -> {
          "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}]}, Closed]], 
   
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth -> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, 
       AutoStyleOptions -> {
        "FormattingErrorTooltips" -> False, "HighlightComments" -> False, 
         "HighlightEmphasizedSyntaxErrors" -> False, 
         "HighlightExcessArguments" -> False, "HighlightFormattingErrors" -> 
         False, "HighlightGlobalToLocalScopeConflicts" -> False, 
         "HighlightGraphicsCompatibilityProblems" -> False, 
         "HighlightLocalScopeConflicts" -> False, "HighlightMissingArguments" -> 
         False, "HighlightNoKernelPresent" -> False, 
         "HighlightOrderOfEvaluationConflicts" -> False, "HighlightStrings" -> 
         True, "HighlightSymbolContexts" -> False, "HighlightSymbolShadowing" -> 
         False, "HighlightSyntaxErrors" -> False, "HighlightUndefinedSymbols" -> 
         False, "HighlightUnknownOptions" -> False, 
         "HighlightUnwantedAssignments" -> False}, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey -> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey -> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 44}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       StyleData["AnswerKeyNumberedSection"], 
       CellMargins -> {{64, Inherited}, {8, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       18, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["AnswerKeySectionNumber"], CellBaseline -> Baseline, 
       FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["IndexLinkGuide"], 
       CellMargins -> {{64, Inherited}, {48, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["Index"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["IndexSubentry"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["FunctionName"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro Semibold", FontWeight -> "Bold"], 
      Cell[
       StyleData["IndexColumn"], 
       CellMargins -> {{66, 0}, {Inherited, Inherited}}, TabSpacings -> {2.}, 
       MenuSortingValue -> 10000, FontFamily -> "Source Sans Pro", 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
         GridBoxItemSize -> {"Columns" -> {{25}}}, 
         GridBoxSpacings -> {"Columns" -> {{2}}}}], 
      Cell[
       StyleData["IndexSubsection"], 
       CellMargins -> {{64, Inherited}, {9, 28}}, 
       CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
       10000, FontFamily -> "Source Sans Pro", FontSize -> 24], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {12, 32}},
           FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {6, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 67}, CounterIncrements -> 
          "Exercise", MenuSortingValue -> 10020, MenuCommandKey -> "2", 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth -> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, PageBreakBelow -> False, 
          CounterIncrements -> "Question", MenuSortingValue -> 10030, 
          MenuCommandKey -> "3", FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth -> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, LineSpacing -> {1.125, 1., 2.}, 
          MenuSortingValue -> 10032, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 14}}, FontFamily -> 
          "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Italic", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1.3, 1., 2.}, 
          MenuSortingValue -> 10010, MenuCommandKey -> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], 
          CellMargins -> {{99, Inherited}, {2, 12}}, StripStyleOnPaste -> 
          True, DefaultFormatType -> DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", PageBreakWithin -> False, GroupPageBreakWithin -> 
          False, GeneratedCell -> True, CellAutoOverwrite -> True, 
          ShowCellLabel -> False, DefaultFormatType -> 
          DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221], $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, ShowCellLabel -> False, 
          SpanMaxSize -> 1, FontSize -> 
          14, $CellContext`GeneratedCellStyles -> {
           "Output" -> "ExerciseOutput"}], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Closed]], 
      Cell[
       StyleData["ExerciseSummaryCell"], PageWidth -> 700, CellFrame -> 0, 
       CellMargins -> {{64, Inherited}, {8, 10}}, 
       CellGroupingRules -> {"SectionGrouping", 64}, PageBreakBelow -> False, 
       ShowCellLabel -> False, CellFrameMargins -> 0, ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1], 
       GridBoxOptions -> {GridBoxBackground -> {"Columns" -> {{
              RGBColor[0.990997, 0.539528, 0.155779], 
              RGBColor[0.989487, 0.434699, 0.0320439]}}, "Rows" -> {{None}}}, 
         GridBoxItemSize -> {"Columns" -> {
             Scaled[0.7], 
             Scaled[0.3]}, "Rows" -> {{Automatic}}}}], 
      Cell[
       StyleData["ExerciseSummaryHeading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1]], 
      Cell[
       StyleData["ExerciseSummarySubheading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 15, FontColor -> 
       RGBColor[1., 0.9294117647058824, 0.7215686274509804]], 
      Cell[
       StyleData["ExercisePreviewButtonText"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> "Plain", 
       FontColor -> RGBColor[0.6, 0.6, 0.6]], 
      Cell[
       StyleData["ExercisePreviewButtonTextHighlight"], ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> 
       "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            RGBColor[0.8, 0.043, 0.008]], CellMargins -> {{81, 10}, {4, 8}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            GrayLevel[0.2]], 
          CellMargins -> {{80, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 10}, {4, 1}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, Inherited}, {Inherited, 0.5 Inherited}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 10}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 15], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, CellFrameLabelMargins -> 4, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Echo"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Echo", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]]},
      Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth -> DirectedInfinity[1], 
       TextAlignment -> Left, LineSpacing -> {0.6, 1}, 
       AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth -> DirectedInfinity[1], 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       StyleData[
       "IndexNavigationLink", StyleDefinitions -> StyleData["Hyperlink"]], 
       MenuSortingValue -> None, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Crosslink"], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 1, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 1, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.95 Inherited], 
      Cell[
       StyleData["NoLabel"], ShowCellLabel -> 
       False, $CellContext`GeneratedCellStyles -> {
        "Output" -> "ExerciseOutput"}], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, 2018)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "p:1"->{
  Cell[632, 23, 573, 12, 93, "Section",ExpressionUUID->"ebcbd362-cd7d-49ee-88c5-afa8c2e543b3",
   Evaluatable->False,
   CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {"Subsubsection", 0}, {"Exercise", 0}},
   CellTags->"p:1",
   CellID->282314649]},
 "LastCellOfAPage"->{
  Cell[1368087, 25221, 1488, 28, 70, "MoreExplore",ExpressionUUID->"8cd3e504-8436-4d8a-85bb-50285d1aceac",
   CellTags->"LastCellOfAPage",
   CellID->26626102],
  Cell[1369578, 25251, 1535, 30, 70, "MoreExplore",ExpressionUUID->"ea5feee3-1c73-435d-877c-032f7c769815",
   CellTags->"LastCellOfAPage",
   CellID->1070349993],
  Cell[1371116, 25283, 1389, 28, 70, "MoreExplore",ExpressionUUID->"02b24e8f-e119-489d-b32c-eb971602ceb0",
   CellTags->"LastCellOfAPage",
   CellID->1244731958],
  Cell[1372508, 25313, 1323, 26, 70, "MoreExplore",ExpressionUUID->"a4830843-7fb1-40a0-939b-4edbdddcfed8",
   CellTags->"LastCellOfAPage",
   CellID->367315410]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"p:1", 1454756, 27014},
 {"LastCellOfAPage", 1455039, 27020}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[632, 23, 573, 12, 93, "Section",ExpressionUUID->"ebcbd362-cd7d-49ee-88c5-afa8c2e543b3",
 Evaluatable->False,
 CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {"Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:1",
 CellID->282314649],
Cell[1208, 37, 996, 15, 190, "Text",ExpressionUUID->"bfbf2b50-c4c7-4776-b98b-ff896557f378",
 CellID->534820456],
Cell[2207, 54, 1054, 21, 68, "Text",ExpressionUUID->"d5f1fae6-2aaa-49c2-ba1f-8d694c7173e2",
 CellID->1508341297],
Cell[3264, 77, 1523, 26, 116, "Text",ExpressionUUID->"c09d921f-ff40-4539-b965-e6cd71c978b4",
 CellID->1795209491],
Cell[4790, 105, 416, 5, 37, "CodeCaption",ExpressionUUID->"02d499e1-0943-4cb9-9a58-fb7eee0d7f25",
 CellID->2088158534],
Cell[CellGroupData[{
Cell[5231, 114, 462, 11, 29, "Input",ExpressionUUID->"3aed2853-1640-4714-93b3-9c951a0903d7",
 CellID->1502721664],
Cell[5696, 127, 466, 11, 40, "Output",ExpressionUUID->"9382f14b-f892-4504-868d-522fc0c65fbd",
 CellID->1456512468]
}, Open  ]],
Cell[CellGroupData[{
Cell[6199, 143, 513, 13, 29, "Input",ExpressionUUID->"c6a2a814-8a1f-42b9-a60f-5834dad6e2a5",
 CellID->738254982],
Cell[6715, 158, 430, 11, 61, "Output",ExpressionUUID->"5ba7c0de-ffdf-4140-bda0-c934bc6d0df4",
 CellID->438957523]
}, Open  ]],
Cell[CellGroupData[{
Cell[7182, 174, 554, 14, 29, "Input",ExpressionUUID->"6b8009dc-8d53-4f66-adf8-4b2827c3c734",
 CellID->1838453755],
Cell[7739, 190, 436, 9, 40, "Output",ExpressionUUID->"20177444-00af-4e31-bbac-3533695f8058",
 CellID->952761616]
}, Open  ]],
Cell[8190, 202, 593, 11, 90, "Text",ExpressionUUID->"af8ba69f-d6f6-40fc-993b-d994bf1a7d26",
 CellID->940222529],
Cell[8786, 215, 703, 14, 70, "CodeCaption",ExpressionUUID->"93c99296-6e76-408e-9b4f-d4414326557d",
 PageBreakAbove->True,
 CellID->1505406291],
Cell[CellGroupData[{
Cell[9514, 233, 292, 6, 70, "Input",ExpressionUUID->"f6ce9a48-a129-401b-937c-7c772564baed",
 CellID->784418743],
Cell[9809, 241, 410, 8, 70, "Output",ExpressionUUID->"6bce6125-608c-479e-bb91-4fef9f987a7f",
 CellID->1426408080]
}, Open  ]],
Cell[10234, 252, 1560, 27, 70, "Text",ExpressionUUID->"04f5e587-55a3-4815-be68-67514575dacb",
 CellID->2061743155],
Cell[11797, 281, 1254, 23, 70, "Text",ExpressionUUID->"a3914152-26c7-4c54-9cc7-afa22ae61a79",
 CellID->2068561740]
}, Open  ]],
Cell[CellGroupData[{
Cell[13088, 309, 180, 2, 70, "Subsection",ExpressionUUID->"1d25da2b-2436-4da6-b150-2aee7cef5d44",
 CellID->704402897],
Cell[13271, 313, 2203, 47, 70, "Text",ExpressionUUID->"e40101ec-309d-4faf-9a77-b501bb047a90",
 CellID->1969627615],
Cell[15477, 362, 738, 10, 70, "CodeCaption",ExpressionUUID->"d92d2bc9-fe56-466d-bd10-c6a695554e06",
 CellID->2073482407],
Cell[CellGroupData[{
Cell[16240, 376, 482, 13, 70, "Input",ExpressionUUID->"9396d4e4-3d95-4ce1-a61e-aad544ee03c8",
 CellID->70906800],
Cell[16725, 391, 442, 8, 70, "Output",ExpressionUUID->"ba70bde2-89f1-4690-af98-9248c26e0315",
 CellID->1280649099]
}, Open  ]],
Cell[17182, 402, 1264, 31, 70, "CodeCaption",ExpressionUUID->"462f1cad-3cc3-4662-9fc1-6eb1a4403ea3",
 CellID->1393475705],
Cell[CellGroupData[{
Cell[18471, 437, 520, 13, 70, "Input",ExpressionUUID->"cb5ef45f-f56d-4246-b39f-0ebc7ab4d3dd",
 CellID->897547249],
Cell[18994, 452, 3756, 76, 70, "Output",ExpressionUUID->"d2c317e2-a817-490b-9910-bc5230f153c6",
 CellID->1788296659]
}, Open  ]],
Cell[22765, 531, 1249, 29, 70, "Text",ExpressionUUID->"c8b84a2c-e1a1-45c9-abb8-2775557df0d1",
 CellID->987453315],
Cell[24017, 562, 1902, 41, 70, "Text",ExpressionUUID->"dfeb4a09-6a1c-4b5f-b1c9-1b52e0ec1371",
 PageBreakAbove->True,
 CellID->374241189],
Cell[25922, 605, 906, 25, 70, "DisplayFormula",ExpressionUUID->"87977640-16d0-4e50-98fa-04c12edf286f",
 CellID->402679298],
Cell[26831, 632, 1376, 24, 70, "Text",ExpressionUUID->"7b2d4d3b-ea05-4122-b288-bc85cc3fe9b3",
 CellID->2039545107],
Cell[28210, 658, 959, 30, 70, "DisplayFormula",ExpressionUUID->"de3bf2d5-0d51-4df2-8116-0f3ed23d50dd",
 CellID->451176329],
Cell[29172, 690, 1152, 25, 70, "Text",ExpressionUUID->"c6dec0ee-4d59-4cc4-ac71-7b17b73b56d2",
 CellID->500639935],
Cell[30327, 717, 924, 20, 70, "CodeCaption",ExpressionUUID->"66dcdc94-64bc-4c71-87e0-d65b5fbc6da8",
 CellID->414458599],
Cell[CellGroupData[{
Cell[31276, 741, 703, 16, 70, "Input",ExpressionUUID->"074ac557-0f8e-4b18-b1e8-03f95b1f0f4e",
 CellID->1516206172],
Cell[31982, 759, 438, 9, 70, "Output",ExpressionUUID->"3945e821-ecfb-4b9a-8d88-f9481886ae84",
 CellID->1868308048]
}, Open  ]],
Cell[CellGroupData[{
Cell[32457, 773, 832, 20, 70, "Input",ExpressionUUID->"ee6143af-452e-48dd-91fb-b91adcc7f408",
 CellID->1905770788],
Cell[33292, 795, 439, 9, 70, "Output",ExpressionUUID->"3b6c8b12-0ec5-4e2b-a441-f1532559f8b8",
 CellID->147476302]
}, Open  ]],
Cell[33746, 807, 536, 12, 70, "CodeCaption",ExpressionUUID->"01906240-f68d-43f6-bb65-edb6a3f16be7",
 CellID->232267465],
Cell[CellGroupData[{
Cell[34307, 823, 400, 10, 70, "Input",ExpressionUUID->"9a892caa-5fdb-433a-9b48-f89aca6030c3",
 CellID->1741497656],
Cell[34710, 835, 438, 9, 70, "Output",ExpressionUUID->"25b614b3-5099-495b-97ad-12781f73afc0",
 CellID->438079076]
}, Open  ]],
Cell[35163, 847, 490, 9, 70, "CodeCaption",ExpressionUUID->"b79745b9-e7de-4f62-8c9c-72bb1b73b360",
 CellID->1560680741],
Cell[CellGroupData[{
Cell[35678, 860, 336, 8, 70, "Input",ExpressionUUID->"8ff687f1-7847-4628-a499-ec212306b1d0",
 CellID->995949529],
Cell[36017, 870, 424, 9, 70, "Output",ExpressionUUID->"044a98c3-f21e-4990-bf70-89c96fe4237f",
 CellID->1221088416]
}, Open  ]],
Cell[36456, 882, 440, 7, 70, "Text",ExpressionUUID->"7240f084-e0f6-473f-8fae-3f8f39648acf",
 CellID->315440015],
Cell[36899, 891, 1965, 44, 70, "Text",ExpressionUUID->"1d7db5e9-4067-4b7e-bf07-820351c5b706",
 CellID->1610691309],
Cell[38867, 937, 1098, 22, 70, "CodeCaption",ExpressionUUID->"c3224869-7813-404a-8654-3a9cefd4702c",
 CellID->1857459928],
Cell[CellGroupData[{
Cell[39990, 963, 462, 13, 70, "Input",ExpressionUUID->"98c18a1c-475c-4bd4-b537-9120a3608fd7",
 CellID->359233457],
Cell[40455, 978, 446, 9, 70, "Output",ExpressionUUID->"a905cbae-1fa7-439f-aa88-bf31abb5f150",
 CellID->1479276980]
}, Open  ]],
Cell[CellGroupData[{
Cell[40938, 992, 604, 18, 70, "Input",ExpressionUUID->"d09c5eb3-1c74-4e73-9720-8162359acea4",
 PageBreakAbove->True,
 CellID->571038911],
Cell[41545, 1012, 468, 11, 70, "Output",ExpressionUUID->"26932def-0ae9-4c1d-ad1d-b3f5beea396a",
 CellID->790021541]
}, Open  ]],
Cell[CellGroupData[{
Cell[42050, 1028, 285, 8, 70, "Input",ExpressionUUID->"ecb38c96-c297-4c37-913e-a62814e2b07f",
 CellID->42349697],
Cell[42338, 1038, 438, 8, 70, "Output",ExpressionUUID->"65c65ed5-4e56-416a-92ae-ca4354f26f30",
 CellID->650186]
}, Open  ]],
Cell[CellGroupData[{
Cell[42813, 1051, 338, 8, 70, "Input",ExpressionUUID->"2bc04539-239a-4474-9dc2-51ebedf2246e",
 CellID->1013426058],
Cell[43154, 1061, 389, 9, 70, "Output",ExpressionUUID->"237bbfcb-1596-4005-baa4-e0d7edbe2290",
 CellID->190257867]
}, Open  ]],
Cell[43558, 1073, 1166, 31, 70, "Text",ExpressionUUID->"06e1f160-500e-472e-80b9-60a16d31f5dc",
 CellID->249039608],
Cell[44727, 1106, 857, 18, 70, "Text",ExpressionUUID->"da1a4eff-af71-44bf-b371-318882766756",
 CellID->163063653],
Cell[45587, 1126, 302, 5, 70, "Text",ExpressionUUID->"5fb16cc4-f111-44c4-ba06-53cc6d715544",
 CellID->421682399],
Cell[45892, 1133, 689, 20, 70, "DisplayFormula",ExpressionUUID->"fbfd7ee2-1065-4895-8979-099f251c9699",
 CellID->877499497],
Cell[46584, 1155, 1674, 36, 70, "Text",ExpressionUUID->"138bba24-2959-4a3c-9f3e-9f79c3bbee21",
 CellID->520044893],
Cell[48261, 1193, 1067, 25, 70, "Text",ExpressionUUID->"f639a8a6-2a2f-4dee-8df3-a3c22ebe0c3a",
 CellID->136073361],
Cell[49331, 1220, 2598, 54, 70, "Text",ExpressionUUID->"4a4221e1-d672-4c9c-a080-962b68a44e84",
 CellID->2062377919],
Cell[51932, 1276, 893, 15, 70, "CodeCaption",ExpressionUUID->"c9ae959d-9f05-4e70-93d8-3e06bf584b84",
 CellID->247148051],
Cell[52828, 1293, 1962, 54, 70, "InputOnly",ExpressionUUID->"9dad2e49-9d12-425a-9609-75dea1b94f3c",
 InitializationCell->True,
 CellID->136165244],
Cell[CellGroupData[{
Cell[54815, 1351, 477, 13, 70, "Input",ExpressionUUID->"8fe69005-b542-4032-91b1-97f57686eaa1",
 CellID->1999622053],
Cell[55295, 1366, 445, 8, 70, "Output",ExpressionUUID->"c7975138-5d06-44cd-a74b-480264a66e96",
 CellID->60820286]
}, Open  ]],
Cell[CellGroupData[{
Cell[55777, 1379, 335, 8, 70, "Input",ExpressionUUID->"090a98b7-d5d6-4f94-b9bd-0b4bd5158a4c",
 PageBreakAbove->True,
 CellID->2091471130],
Cell[56115, 1389, 405, 9, 70, "Output",ExpressionUUID->"4e037239-2e84-4cd8-af3a-61a23d0d29f4",
 CellID->4330830]
}, Open  ]],
Cell[56535, 1401, 1196, 17, 70, "Text",ExpressionUUID->"7016fbe4-f07a-4863-91a6-c4683025f9e6",
 CellID->870779928]
}, Open  ]],
Cell[CellGroupData[{
Cell[57768, 1423, 172, 2, 70, "Subsection",ExpressionUUID->"460e7d9f-3b4d-41e1-a0cc-e109d5757814",
 CellID->97195591],
Cell[57943, 1427, 414, 7, 70, "Text",ExpressionUUID->"b42816dd-b32a-4572-8106-da7000e32957",
 CellID->1478726217],
Cell[58360, 1436, 413, 9, 70, "CodeCaption",ExpressionUUID->"1779bb41-e5d6-463e-9dae-feead3eaf820",
 CellID->642294212],
Cell[CellGroupData[{
Cell[58798, 1449, 2008, 57, 70, "Input",ExpressionUUID->"062681c0-0400-48e6-8564-07ac992920a1",
 CellID->123282388],
Cell[60809, 1508, 16783, 307, 70, "Output",ExpressionUUID->"84595024-d48c-4b8f-8b88-32b9b84709df",
 CellID->1921299459]
}, Open  ]],
Cell[77607, 1818, 1148, 24, 70, "CodeCaption",ExpressionUUID->"bb105efa-8d84-4d54-830f-c6cd53b411e3",
 CellID->1832859408],
Cell[CellGroupData[{
Cell[78780, 1846, 738, 21, 70, "Input",ExpressionUUID->"6b81cf42-6435-489b-8812-40c51bb46a98",
 CellID->1362637688],
Cell[79521, 1869, 7957, 153, 70, "Output",ExpressionUUID->"5a2465e4-9d41-4ee8-8a7e-015f5f8cb642",
 CellID->1715891121]
}, Open  ]],
Cell[87493, 2025, 2029, 42, 70, "Text",ExpressionUUID->"65341ccb-b814-46a3-ab0a-bced18c9dc2e",
 PageBreakAbove->True,
 CellID->1116772803],
Cell[89525, 2069, 251, 3, 70, "CodeCaption",ExpressionUUID->"2eb19713-d0c3-4513-9470-e31d00c2188c",
 CellID->593425241],
Cell[CellGroupData[{
Cell[89801, 2076, 1649, 47, 70, "Input",ExpressionUUID->"24c0f1df-7eae-483c-a5cd-424662751593",
 CellID->783968819],
Cell[91453, 2125, 10920, 229, 70, "Output",ExpressionUUID->"0671bb6f-c03f-46f9-a1fa-8e8110bcc814",
 CellID->424175084]
}, Open  ]],
Cell[102388, 2357, 1458, 32, 70, "Text",ExpressionUUID->"ff6acd5b-316d-4daa-a712-5bbee24adf11",
 CellID->911542903],
Cell[103849, 2391, 503, 11, 70, "CodeCaption",ExpressionUUID->"a5527fa5-0401-477d-a6c7-7890b13d8548",
 CellID->1786011262],
Cell[CellGroupData[{
Cell[104377, 2406, 526, 12, 70, "Input",ExpressionUUID->"28770129-fcf8-4802-a369-8148641a0729",
 CellID->153233023],
Cell[104906, 2420, 519, 12, 70, "Output",ExpressionUUID->"52034e76-934d-46b8-adfe-7763caa1569b",
 CellID->1612412395]
}, Open  ]],
Cell[CellGroupData[{
Cell[105462, 2437, 453, 9, 70, "Input",ExpressionUUID->"8a4289d3-208c-441e-a96c-8dea06947ad0",
 CellID->346558734],
Cell[105918, 2448, 425, 8, 70, "Output",ExpressionUUID->"5aebe583-03f4-44be-89a3-84768e677a47",
 CellID->718981272]
}, Open  ]],
Cell[CellGroupData[{
Cell[106380, 2461, 453, 9, 70, "Input",ExpressionUUID->"eeef83b1-d2bf-4183-a6a3-538373e13dbc",
 CellID->636991674],
Cell[106836, 2472, 425, 8, 70, "Output",ExpressionUUID->"c8826ab1-a849-4018-ad9a-53a0697cd968",
 CellID->27756835]
}, Open  ]],
Cell[CellGroupData[{
Cell[107298, 2485, 677, 20, 70, "Input",ExpressionUUID->"ec012bee-97fc-4b9c-90d1-91d8f9c0b050",
 PageBreakAbove->True,
 CellID->459516272],
Cell[107978, 2507, 13911, 271, 70, "Output",ExpressionUUID->"58302c4d-1084-4046-8e17-59791dedee3d",
 CellID->505174446]
}, Open  ]],
Cell[121904, 2781, 1016, 19, 70, "Text",ExpressionUUID->"abb9e7bb-c1e2-4da1-8c70-f31a02712087",
 CellID->74460890]
}, Open  ]],
Cell[CellGroupData[{
Cell[122957, 2805, 317, 4, 70, "Subsection",ExpressionUUID->"0a8656ad-9eca-496e-87e3-8be33e15d1f1",
 CellID->1628695676],
Cell[123277, 2811, 4153, 91, 70, "Text",ExpressionUUID->"cd97f1ed-21c1-40b2-8f90-9fa8f2884bdf",
 CellID->1661661870],
Cell[127433, 2904, 315, 5, 70, "CodeCaption",ExpressionUUID->"4b1c2d10-6c2a-498f-a1fc-73c667c23721",
 PageBreakAbove->True,
 CellID->438824402],
Cell[127751, 2911, 134388, 2210, 70, "Picture",ExpressionUUID->"bbf2424f-8351-4e32-ad74-9f4d327b338a",
 CellID->1359321250],
Cell[262142, 5123, 256, 4, 70, "CodeCaption",ExpressionUUID->"4a2bdcea-1c3d-4373-996e-6f4d0b679519",
 PageBreakAbove->True,
 CellID->1673703502],
Cell[CellGroupData[{
Cell[262423, 5131, 1293, 37, 70, "Input",ExpressionUUID->"593a90e5-a460-41c9-8e3d-48f5ed49b3b4",
 CellID->46466061],
Cell[263719, 5170, 16740, 311, 70, "Output",ExpressionUUID->"1eb17194-9130-4d39-8d5e-fe4434383fea",
 CellID->1464057331]
}, Open  ]],
Cell[280474, 5484, 1667, 25, 70, "Text",ExpressionUUID->"972a55ea-2404-42a8-808a-a89b1390d0b6",
 CellID->1906247015],
Cell[282144, 5511, 5152, 140, 70, "Input",ExpressionUUID->"d831976e-e309-427d-888c-5b80dfbc978c",
 InitializationCell->True,
 CellID->157950131],
Cell[287299, 5653, 918, 19, 70, "CodeCaption",ExpressionUUID->"7aa565b3-670b-492f-8a12-02aa8e866b94",
 CellID->16348883],
Cell[CellGroupData[{
Cell[288242, 5676, 366, 7, 70, "Input",ExpressionUUID->"acc956a8-37e8-4709-9bb4-2f27e01fc950",
 CellID->2045253412],
Cell[288611, 5685, 748, 19, 70, "Output",ExpressionUUID->"0b3ced75-9dcf-41a7-86f1-db578980eec8",
 CellID->543934791]
}, Open  ]],
Cell[289374, 5707, 371, 6, 70, "CodeCaption",ExpressionUUID->"e79b7bc1-6119-4570-b3c4-5c298f776f5b",
 CellID->14482418],
Cell[CellGroupData[{
Cell[289770, 5717, 1819, 47, 70, "Input",ExpressionUUID->"bc4588d2-d29d-4021-8f0e-11bcd5eb74ca",
 CellID->740347215],
Cell[291592, 5766, 51185, 882, 70, "Output",ExpressionUUID->"15bb5dc6-a1cb-4fcf-81a7-ed0c4ec8b793",
 CellID->74147058]
}, Open  ]],
Cell[342792, 6651, 1046, 16, 70, "Text",ExpressionUUID->"1a34eac0-3243-491b-8f6f-c09f986766c1",
 PageBreakAbove->True,
 CellID->495391787],
Cell[343841, 6669, 235, 3, 70, "CodeCaption",ExpressionUUID->"13eb2eed-2713-435e-81c5-ba05ad5c4c3d",
 CellID->381695321],
Cell[344079, 6674, 22409, 447, 70, "Picture",ExpressionUUID->"d2366454-fff6-4ac3-b43a-e0f8d8597aa8",
 CellID->338274239],
Cell[366491, 7123, 1914, 44, 70, "Text",ExpressionUUID->"7ed3a781-cc71-4633-ad03-fcb3dc6d6ab1",
 CellID->255664690],
Cell[368408, 7169, 206, 2, 70, "CodeCaption",ExpressionUUID->"a81d5aea-f795-4f95-bb7c-5aa05bd1798f",
 CellID->433701136],
Cell[CellGroupData[{
Cell[368639, 7175, 1997, 54, 70, "Input",ExpressionUUID->"77141080-b3f4-4f43-a932-55a5b9d2669c",
 CellID->1989150830],
Cell[370639, 7231, 23826, 428, 70, "Output",ExpressionUUID->"bb26fb3a-d21d-48ec-bfe5-87fb961f82b1",
 CellID->649088546]
}, Open  ]],
Cell[394480, 7662, 781, 16, 70, "Text",ExpressionUUID->"59fa22c2-2a0e-4cf7-934f-74381ac1f6ff",
 CellID->1780066961],
Cell[395264, 7680, 313, 6, 70, "CodeCaption",ExpressionUUID->"b925b931-8f86-4302-b2ce-b6575adf95ab",
 PageBreakAbove->True,
 CellID->836131144],
Cell[CellGroupData[{
Cell[395602, 7690, 1121, 34, 70, "Input",ExpressionUUID->"3f99b59f-9d7b-4486-9f63-1a1edd884b3d",
 CellID->990727170],
Cell[396726, 7726, 15587, 294, 70, "Output",ExpressionUUID->"27a9564e-1b13-4591-9738-f633ced05867",
 CellID->14265862]
}, Open  ]],
Cell[412328, 8023, 685, 11, 70, "Text",ExpressionUUID->"45b0b80c-6733-4074-a534-0252a6b446d5",
 CellID->1278050510]
}, Open  ]],
Cell[CellGroupData[{
Cell[413050, 8039, 181, 2, 70, "Subsection",ExpressionUUID->"815521f1-7a0f-49cf-9593-f4603e03a7b8",
 CellID->1063484276],
Cell[413234, 8043, 1743, 37, 70, "Text",ExpressionUUID->"b9a040e7-3435-432a-808f-842fc8cb17a3",
 CellID->473832751],
Cell[414980, 8082, 713, 11, 70, "Text",ExpressionUUID->"62e367be-97bf-4c1d-acf1-ae355467ec33",
 CellID->837682981],
Cell[415696, 8095, 401, 6, 70, "CodeCaption",ExpressionUUID->"baf9cef9-1e2b-4aa9-bb0d-642119ce7bb3",
 PageBreakAbove->True,
 CellID->35071935],
Cell[CellGroupData[{
Cell[416122, 8105, 2475, 68, 70, "Input",ExpressionUUID->"2d1a5a71-8117-4590-931c-398555ca9d14",
 CellID->1043492267],
Cell[418600, 8175, 27977, 506, 70, "Output",ExpressionUUID->"8eaeca8c-4425-4c42-8ac4-f68a2a92e8b0",
 CellID->1395657817]
}, Open  ]],
Cell[446592, 8684, 498, 10, 70, "Text",ExpressionUUID->"cecccaf0-17c8-4a60-91bc-67547cd286d3",
 CellID->1623070067],
Cell[447093, 8696, 216, 3, 70, "CodeCaption",ExpressionUUID->"50aedd4b-7795-425a-973b-9cd17852db0d",
 CellID->1601331875],
Cell[CellGroupData[{
Cell[447334, 8703, 2994, 83, 70, "Input",ExpressionUUID->"434294b5-6921-4d5c-aa11-a74fbc5181bc",
 CellID->1319758921],
Cell[450331, 8788, 31586, 576, 70, "Output",ExpressionUUID->"1b6d541f-22b4-4202-8752-f417c36adaca",
 CellID->2004537785]
}, Open  ]],
Cell[481932, 9367, 1704, 32, 70, "Text",ExpressionUUID->"b87e4132-9d4b-42dc-9f39-36e721248b20",
 CellID->1977079031],
Cell[483639, 9401, 214, 3, 70, "CodeCaption",ExpressionUUID->"6c06f6c9-bc36-4417-9f16-d742a8799bcc",
 PageBreakAbove->True,
 CellID->4559691],
Cell[CellGroupData[{
Cell[483878, 9408, 2912, 77, 70, "Input",ExpressionUUID->"62a2f894-240a-43f3-96be-686dec8d1041",
 CellID->752803986],
Cell[486793, 9487, 28910, 528, 70, "Output",ExpressionUUID->"5b2a2a61-3607-43bb-bc15-af69784e301e",
 CellID->543098359]
}, Open  ]],
Cell[515718, 10018, 401, 6, 70, "CodeCaption",ExpressionUUID->"5d2311ea-566c-4aba-b616-c473fda8eda6",
 CellID->1550428225],
Cell[516122, 10026, 57444, 1222, 70, "Picture",ExpressionUUID->"28883724-dcb3-498f-a0af-bc91a888d4ad",
 CellID->1679614224],
Cell[573569, 11250, 889, 13, 70, "Text",ExpressionUUID->"46a55cee-f2e2-44b4-b67e-511bee98b5fc",
 CellID->840171372],
Cell[574461, 11265, 1613, 32, 70, "Text",ExpressionUUID->"c7a1a3d2-49f8-4330-bf83-fb8820705c76",
 CellID->1055270179],
Cell[576077, 11299, 1287, 30, 70, "CodeCaption",ExpressionUUID->"ff123703-b61c-4c94-b7a8-258bea0139b9",
 PageBreakAbove->True,
 CellID->238771493],
Cell[577367, 11331, 702, 19, 70, "Input",ExpressionUUID->"e720d313-2f5f-48d9-845e-393fbdbb3e60",
 InitializationCell->True,
 CellID->2005941527],
Cell[CellGroupData[{
Cell[578094, 11354, 463, 11, 70, "Input",ExpressionUUID->"0d86a22b-1bfd-48ee-a24b-1d76a0aee584",
 CellID->513470036],
Cell[578560, 11367, 458, 11, 70, "Output",ExpressionUUID->"29542e8b-c33d-4534-9d6c-f71838e88cdb",
 CellID->1048619963]
}, Open  ]],
Cell[CellGroupData[{
Cell[579055, 11383, 544, 14, 70, "Input",ExpressionUUID->"51db2a9a-209c-440e-ab71-96983c60a80e",
 CellID->713084623],
Cell[579602, 11399, 415, 9, 70, "Output",ExpressionUUID->"f74da64e-7fb1-4a3f-90b7-9dd5a080fbda",
 CellID->1904910859]
}, Open  ]],
Cell[580032, 11411, 1931, 36, 70, "Text",ExpressionUUID->"04553433-ee7b-40e9-b817-43a0339ca6dd",
 CellID->2124452551],
Cell[581966, 11449, 1221, 28, 70, "CodeCaption",ExpressionUUID->"e638926a-06de-444e-af75-696771bbdfae",
 CellID->2112346315],
Cell[CellGroupData[{
Cell[583212, 11481, 666, 18, 70, "Input",ExpressionUUID->"bb1c2a03-d739-4a66-a275-5f9e67db5af7",
 CellID->1610909635],
Cell[583881, 11501, 540, 15, 70, "Output",ExpressionUUID->"1b1c468e-f815-4d3f-b00d-5056fc59130b",
 CellID->1150597737]
}, Open  ]],
Cell[CellGroupData[{
Cell[584458, 11521, 670, 18, 70, "Input",ExpressionUUID->"1fb2bdb4-1f0f-43ce-8dbf-85600f6df572",
 CellID->1074118411],
Cell[585131, 11541, 990, 29, 70, "Output",ExpressionUUID->"9065bff4-3999-42ea-af40-b970945fcff8",
 CellID->5924524]
}, Open  ]],
Cell[CellGroupData[{
Cell[586158, 11575, 642, 17, 70, "Input",ExpressionUUID->"116a7f3d-1091-416e-ada1-8b678808a61b",
 CellID->235293942],
Cell[586803, 11594, 835, 22, 70, "Output",ExpressionUUID->"50d86618-8370-41f0-955f-255390b51aff",
 CellID->789227106]
}, Open  ]],
Cell[CellGroupData[{
Cell[587675, 11621, 1499, 41, 70, "Input",ExpressionUUID->"0e64b2b0-b693-4aea-992d-f3aba7bba60c",
 CellID->1308903178],
Cell[589177, 11664, 84423, 1437, 70, "Output",ExpressionUUID->"aa25be53-5f79-4035-8be9-e3aa1b4b3e13",
 CellID->1680966670]
}, Open  ]],
Cell[673615, 13104, 1665, 38, 70, "Text",ExpressionUUID->"c8e31067-48b0-46fb-af20-9b59f8ec8dad",
 CellID->2060716425]
}, Open  ]],
Cell[CellGroupData[{
Cell[675317, 13147, 235, 4, 70, "Subsection",ExpressionUUID->"22ec0293-0d34-49d1-963c-9bf804b24abf",
 PageBreakAbove->True,
 CellID->1992179806],
Cell[675555, 13153, 1909, 41, 70, "Text",ExpressionUUID->"dde42569-9d48-4553-a456-9ee962171c5b",
 CellID->1148459065],
Cell[677467, 13196, 920, 13, 70, "CodeCaption",ExpressionUUID->"cdddc2e4-028f-4d38-a04d-fe310463e2d0",
 CellID->1929471539],
Cell[678390, 13211, 286912, 4736, 70, "Picture",ExpressionUUID->"16e23caa-5a8e-4ba7-9a29-22fa7e8fd4b1",
 CellID->568486219],
Cell[965305, 17949, 3087, 65, 70, "Text",ExpressionUUID->"0259302d-7e99-444d-8364-0b2cb5c8c89f",
 CellID->393137230],
Cell[968395, 18016, 610, 13, 70, "Text",ExpressionUUID->"81b9297f-7e58-4f4e-8fbd-8af58aa38ebc",
 CellID->1797726438]
}, Open  ]],
Cell[CellGroupData[{
Cell[969042, 18034, 185, 2, 70, "Subsection",ExpressionUUID->"54ef6c22-a138-442b-9880-1d1f9fd42ee4",
 CellID->1440813823],
Cell[969230, 18038, 1935, 40, 70, "Text",ExpressionUUID->"21dc23ef-76e6-4cce-ac9a-df857b4d5afc",
 CellID->732319589],
Cell[971168, 18080, 314, 5, 70, "Text",ExpressionUUID->"a4bbefdb-dc52-428b-9309-d5d0f6f4da95",
 CellID->1791365495],
Cell[971485, 18087, 501, 8, 70, "Text",ExpressionUUID->"7439302c-d3e5-4001-9b58-08d4f3233b82",
 CellID->866551366],
Cell[971989, 18097, 925, 20, 70, "CodeCaption",ExpressionUUID->"425c8f62-9155-4fb8-99fc-685288634b31",
 CellID->2042198055],
Cell[972917, 18119, 842, 26, 70, "Input",ExpressionUUID->"391d4de6-4674-44d6-b7ca-c26d71339f43",
 CellID->2139064031],
Cell[973762, 18147, 252, 4, 70, "CodeCaption",ExpressionUUID->"62ec5fbb-2386-4590-9a0b-9725b2cdc028",
 CellID->225434590],
Cell[CellGroupData[{
Cell[974039, 18155, 933, 25, 70, "Input",ExpressionUUID->"b62a8645-1b72-4043-a198-8779f03dc999",
 CellID->718000822],
Cell[974975, 18182, 16022, 286, 70, "Output",ExpressionUUID->"04873b13-1634-4299-a8e1-010c1aa2e5ab",
 CellID->1859446405]
}, Open  ]],
Cell[991012, 18471, 1713, 30, 70, "Text",ExpressionUUID->"433153ea-8eaa-4e85-ad27-21e2e360bf66",
 CellID->23311398],
Cell[992728, 18503, 922, 22, 70, "CodeCaption",ExpressionUUID->"5ab5e9f0-f49d-4b21-a31c-bc31ac8a2d19",
 PageBreakAbove->True,
 CellID->952642432],
Cell[CellGroupData[{
Cell[993675, 18529, 1442, 42, 70, "Input",ExpressionUUID->"90012550-1861-4f66-8746-13ae27c3ec01",
 CellID->1570766239],
Cell[995120, 18573, 24861, 444, 70, "Output",ExpressionUUID->"d6d93673-68e8-461b-af18-038d4629a5cc",
 CellID->1533697691]
}, Open  ]],
Cell[1019996, 19020, 1100, 25, 70, "Text",ExpressionUUID->"f0b53a4c-e583-4b91-8384-9016daac6a4e",
 CellID->1649310459],
Cell[1021099, 19047, 2273, 40, 70, "Text",ExpressionUUID->"a178f4c4-62f9-4de3-91ab-bf347a6fd2b7",
 CellID->241968937],
Cell[1023375, 19089, 716, 11, 70, "CodeCaption",ExpressionUUID->"903614d2-a9e5-4b78-a838-874a76c62a5a",
 CellID->1585380388],
Cell[CellGroupData[{
Cell[1024116, 19104, 528, 15, 70, "Input",ExpressionUUID->"09d5ed48-601c-4ba9-9e2f-71ee5b508451",
 CellID->1658572787],
Cell[1024647, 19121, 931, 26, 70, "Output",ExpressionUUID->"f4bef11a-5930-4943-aaed-dfa494f885b0",
 CellID->610877696]
}, Open  ]],
Cell[1025593, 19150, 272, 4, 70, "CodeCaption",ExpressionUUID->"ab992f08-68fd-4fb2-ab59-e92299f67ffa",
 PageBreakAbove->True,
 CellID->1882112198],
Cell[CellGroupData[{
Cell[1025890, 19158, 453, 12, 70, "Input",ExpressionUUID->"12e72f9f-a171-4a1d-a8af-add1e35c62e4",
 CellID->225591476],
Cell[1026346, 19172, 4404, 101, 70, "Output",ExpressionUUID->"7bab3e0f-e427-49ca-ab38-36863a1c3de8",
 CellID->2049604012]
}, Open  ]],
Cell[1030765, 19276, 4284, 86, 70, "Text",ExpressionUUID->"fa15ed4f-b14c-4bb2-9409-e891c7516577",
 CellID->1668577983],
Cell[1035052, 19364, 1237, 20, 70, "CodeCaption",ExpressionUUID->"7366aaeb-6a54-4a96-83c7-c2693b9f8af0",
 CellID->1948697755],
Cell[CellGroupData[{
Cell[1036314, 19388, 368, 8, 70, "Input",ExpressionUUID->"3aa09456-4389-4fd8-888d-03e8c991a7a1",
 Evaluatable->False,
 CellID->490067888],
Cell[1036685, 19398, 625, 15, 70, "Output",ExpressionUUID->"f4a2af18-7109-41a3-b18f-cd09b2b14815",
 CellID->1138840103]
}, Open  ]],
Cell[CellGroupData[{
Cell[1037347, 19418, 384, 10, 70, "Input",ExpressionUUID->"e8e3c00f-e53e-4407-826e-e4362ffa8a1d",
 CellID->59083550],
Cell[1037734, 19430, 450, 9, 70, "Message",ExpressionUUID->"875c93eb-4e17-4b9a-b659-7a5461b83f12",
 CellID->129104499],
Cell[1038187, 19441, 301, 5, 70, "Output",ExpressionUUID->"77cd6213-3484-412a-afa2-a848a4e9d00a",
 CellID->2056931804]
}, Open  ]],
Cell[1038503, 19449, 563, 11, 70, "Text",ExpressionUUID->"a299ab53-c34a-4839-beb9-4ea91176a61c",
 CellID->1036474757],
Cell[1039069, 19462, 354, 7, 70, "Text",ExpressionUUID->"a1937442-1ea5-4031-a61b-62d2e85a88c6",
 CellID->1791380082],
Cell[1039426, 19471, 670, 13, 70, "Text",ExpressionUUID->"cf4b488d-a503-4817-aa52-1173042c08f9",
 CellID->1052327782],
Cell[1040099, 19486, 447, 8, 70, "Text",ExpressionUUID->"de2f8d27-8f6c-4a72-9cc0-a72cd202c836",
 PageBreakAbove->True,
 CellID->88069984],
Cell[1040549, 19496, 578, 11, 70, "CodeCaption",ExpressionUUID->"35c00ede-9f95-4bf2-af65-359083017564",
 CellID->4307234],
Cell[CellGroupData[{
Cell[1041152, 19511, 590, 18, 70, "Input",ExpressionUUID->"199f0042-b591-4f1c-9f48-b1f4edbbb5b4",
 CellID->1524721487],
Cell[1041745, 19531, 578, 17, 70, "Output",ExpressionUUID->"c81f576f-9531-4278-bdcc-06ecaf1df304",
 CellID->661080422]
}, Open  ]],
Cell[1042338, 19551, 736, 13, 70, "CodeCaption",ExpressionUUID->"93fd1dfc-9309-4297-9b99-d391e0ec8cf6",
 CellID->71672358],
Cell[1043077, 19566, 371, 10, 70, "Input",ExpressionUUID->"737d6e9e-5699-4efc-8e31-523052b9d4db",
 CellID->2006478586],
Cell[1043451, 19578, 813, 16, 70, "CodeCaption",ExpressionUUID->"e413bede-51e5-4b26-af3d-cabcca6df5b5",
 CellID->949886061],
Cell[CellGroupData[{
Cell[1044289, 19598, 20290, 363, 70, "Input",ExpressionUUID->"45bc4455-a0c8-4b4d-b242-25cadaace7b7",
 CellID->341595429],
Cell[1064582, 19963, 48853, 844, 70, "Output",ExpressionUUID->"1128fa68-a1ed-4e1a-8ec3-57ed53181a5b",
 CellID->1845746623]
}, Open  ]],
Cell[1113450, 20810, 1844, 36, 70, "Text",ExpressionUUID->"a417550e-559f-4896-a8f2-0000101ae174",
 CellID->970586772],
Cell[1115297, 20848, 1114, 17, 70, "Text",ExpressionUUID->"b3dba1a8-e2a2-4d11-bccd-fca759ff2611",
 CellID->366094392],
Cell[1116414, 20867, 461, 10, 70, "CodeCaption",ExpressionUUID->"6194fb64-6012-4df5-b8bb-413f642489af",
 PageBreakAbove->True,
 CellID->429522593],
Cell[1116878, 20879, 911, 23, 70, "Input",ExpressionUUID->"badc136a-4031-4138-a356-3eed179c7160",
 CellID->407797689],
Cell[CellGroupData[{
Cell[1117814, 20906, 700, 14, 70, "Input",ExpressionUUID->"935fed6b-122f-45d9-8e7b-4fae4c26a0f4",
 CellID->1235441446],
Cell[1118517, 20922, 68781, 1154, 70, "Output",ExpressionUUID->"bd4589f3-7297-42fc-9cd8-db1f5fb7095e",
 CellID->1062211846]
}, Open  ]],
Cell[1187313, 22079, 2457, 54, 70, "Text",ExpressionUUID->"939fb217-2ae0-4150-872b-61944975c814",
 CellID->45000079],
Cell[1189773, 22135, 379, 7, 70, "CodeCaption",ExpressionUUID->"25c0afbf-8ab4-4315-8690-e6e76374c04e",
 CellID->402084009],
Cell[1190155, 22144, 698, 18, 70, "Input",ExpressionUUID->"380bd37b-3ce6-4257-838f-1a68f328e602",
 CellID->1842385801],
Cell[1190856, 22164, 1351, 28, 70, "Text",ExpressionUUID->"ce315383-859e-4dcb-b9f8-14517585a847",
 CellID->411451314],
Cell[1192210, 22194, 271, 7, 70, "CodeCaption",ExpressionUUID->"25971275-124d-4763-a1e9-4632801c4f64",
 CellID->683819206],
Cell[CellGroupData[{
Cell[1192506, 22205, 1063, 29, 70, "Input",ExpressionUUID->"50e4d4b1-109b-4c04-9361-c3fa307a0607",
 CellID->364891058],
Cell[1193572, 22236, 89432, 1489, 70, "Output",ExpressionUUID->"39671d60-21b8-49b7-b72f-8287da74e0a4",
 CellID->562938211]
}, Open  ]],
Cell[CellGroupData[{
Cell[1283041, 23730, 188, 3, 70, "QASection",ExpressionUUID->"518b7c52-c54e-499a-bd78-d12a150a0d2e",
 PageBreakAbove->True,
 CellID->532690973],
Cell[1283232, 23735, 406, 5, 70, "Answer",ExpressionUUID->"f8c2ce47-f262-4eee-8621-72bf9335f3e3",
 CellID->958156859],
Cell[1283641, 23742, 1204, 24, 70, "Question",ExpressionUUID->"17c6abea-e4c8-4062-87a7-689d10159e9b",
 CellID->1909944007],
Cell[1284848, 23768, 54732, 917, 70, "Picture",ExpressionUUID->"7358460c-050e-4766-acca-ff6ba2bf380b",
 CellID->1990853940],
Cell[1339583, 24687, 1333, 24, 70, "Answer",ExpressionUUID->"c425b502-2eb0-4336-8c7c-d67c7d07123f",
 CellID->339465673],
Cell[1340919, 24713, 459, 6, 70, "Question",ExpressionUUID->"7d01df33-1b32-4a00-8efc-d875a2493463",
 CellID->1682999679],
Cell[CellGroupData[{
Cell[1341403, 24723, 624, 16, 70, "Input",ExpressionUUID->"2eaa647e-e030-44af-873e-10efc65dc38a",
 CellID->1668490316],
Cell[1342030, 24741, 25074, 457, 70, "Output",ExpressionUUID->"649b8ce7-8875-4c5f-bf98-e6ef404d6f3a",
 CellID->1637047242]
}, Open  ]],
Cell[1367119, 25201, 745, 11, 70, "Answer",ExpressionUUID->"1e741915-bc1c-4d0b-b0fa-ea437667e743",
 CellID->1513831009]
}, Open  ]],
Cell[CellGroupData[{
Cell[1367901, 25217, 183, 2, 70, "MoreExploreSection",ExpressionUUID->"65fd70d4-ea1a-4b5c-a57b-8007ce3b8400",
 CellID->170962084],
Cell[1368087, 25221, 1488, 28, 70, "MoreExplore",ExpressionUUID->"8cd3e504-8436-4d8a-85bb-50285d1aceac",
 CellTags->"LastCellOfAPage",
 CellID->26626102],
Cell[1369578, 25251, 1535, 30, 70, "MoreExplore",ExpressionUUID->"ea5feee3-1c73-435d-877c-032f7c769815",
 CellTags->"LastCellOfAPage",
 CellID->1070349993],
Cell[1371116, 25283, 1389, 28, 70, "MoreExplore",ExpressionUUID->"02b24e8f-e119-489d-b32c-eb971602ceb0",
 CellTags->"LastCellOfAPage",
 CellID->1244731958],
Cell[1372508, 25313, 1323, 26, 70, "MoreExplore",ExpressionUUID->"a4830843-7fb1-40a0-939b-4edbdddcfed8",
 CellTags->"LastCellOfAPage",
 CellID->367315410]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

