(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    605393,      13032]
NotebookOptionsPosition[    489872,      10734]
NotebookOutlinePosition[    570960,      12414]
CellTagsIndexPosition[    570879,      12409]
WindowTitle->Fractional Linear Transformations
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Fractional Linear Transformations", "SectionInline",ExpressionUUID->
   "816b533c-7df3-44cd-919c-07ba077ff36f"],
  $Line = 0; Null]], "Section",
 Evaluatable->False,
 CellChangeTimes->{{3.647005965691028*^9, 3.64700596569107*^9}, {
  3.702918672313233*^9, 3.7029186723132563`*^9}, {3.703266985425777*^9, 
  3.7032670037839746`*^9}, {3.705854012958376*^9, 3.7058540129584007`*^9}, {
  3.727974481237521*^9, 3.727974481237536*^9}},
 CounterAssignments->{{"Section", 5}, {"Subsection", 5}, {
   "Subsubsection", 5}, {"Exercise", 5}},
 CellID->282314649,ExpressionUUID->"1a49bb50-e93f-4036-aba6-a592a90f4888"],

Cell["\<\
Since the days of Felix Klein (around 1870), any discussion about any kind of \
geometry mentions the transformations that leave geometry invariant. \
(Abhyankar, 1990) has suggested that the proper group of transformations is \
the group of fractional linear transformations, or FLTs. While these \
generally work, we will keep the discussion simple by focusing on the plane \
invertible case.\
\>", "Text",
 CellChangeTimes->{{3.69400853029371*^9, 3.694008673713662*^9}, {
   3.694008723202985*^9, 3.694008908736667*^9}, {3.718196659932569*^9, 
   3.718196689764188*^9}, {3.72278939208601*^9, 3.722789429041605*^9}, {
   3.7227894654814787`*^9, 3.722789490395979*^9}, {3.7227896435987053`*^9, 
   3.722789681528223*^9}, {3.722789756982641*^9, 3.7227897632071743`*^9}, {
   3.729010758792094*^9, 3.729010781390357*^9}, {3.729352224633531*^9, 
   3.72935222469748*^9}, {3.737982610013502*^9, 3.737982650739963*^9}, 
   3.738431423530816*^9},ExpressionUUID->"75b022a7-1647-41fd-98f8-\
248e7e4c752c"],

Cell["\<\
This chapter includes half a dozen different functions for fractional linear \
transformations, all using the same basic function name, some variant of \
\[OpenCurlyDoubleQuote]FLT\[CloseCurlyDoubleQuote].\[NonBreakingSpace] For a \
full listing, see Appendix 2. I have also added a summary of these different \
functions and how they relate to the overall topic at the end of this chapter.\
\>", "Text",
 CellChangeTimes->{
  3.738509417655532*^9, {3.743141111711928*^9, 3.7431411415264*^9}},
 CellID->1515262201,ExpressionUUID->"f9bd700d-3538-471f-9bfa-54510f8c5074"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.1 The Group of Fractional Linear Transformations", "Subsection",
 CellChangeTimes->{{3.69400853029371*^9, 3.694008673713662*^9}, {
  3.694008723202985*^9, 
  3.69400891579095*^9}},ExpressionUUID->"23a03a9d-d196-4632-b31d-\
5c105e07e79a"],

Cell["\<\
A fractional linear transformation is a transformation of the plane given by\
\>", "Text",
 CellChangeTimes->{{3.729007613364921*^9, 3.729007613604191*^9}, 
   3.7379826746676693`*^9},ExpressionUUID->"3290f411-4637-43aa-a4e5-\
03b6b9d2b608"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"F", "(", 
     RowBox[{"x", ",", "y"}], ")"}], " ", "=", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         SubscriptBox["a", 
          RowBox[{"1", ",", "1"}]], "x"}], "+", 
        RowBox[{
         SubscriptBox["a", 
          RowBox[{"1", ",", "2"}]], "y"}], "+", " ", 
        SubscriptBox["a", 
         RowBox[{"1", ",", "3"}]]}], 
       RowBox[{
        RowBox[{
         SubscriptBox["d", "1"], "x"}], "+", 
        RowBox[{
         SubscriptBox["d", "2"], "y"}], "+", 
        SubscriptBox["d", "3"]}]], ",", 
      FractionBox[
       RowBox[{
        RowBox[{
         SubscriptBox["a", 
          RowBox[{"2", ",", "1"}]], "x"}], "+", 
        RowBox[{
         SubscriptBox["a", 
          RowBox[{"2", ",", "2"}]], "y"}], "+", " ", 
        SubscriptBox["a", 
         RowBox[{"2", ",", "3"}]]}], 
       RowBox[{
        RowBox[{
         SubscriptBox["d", "1"], "x"}], "+", 
        RowBox[{
         SubscriptBox["d", "2"], "y"}], "+", 
        SubscriptBox["d", "3"]}]]}], ")"}]}], ","}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.729007860635914*^9, 3.72900786911045*^9}, {
   3.729352224701847*^9, 3.7293522443232737`*^9}, {3.7335117400098753`*^9, 
   3.733511740927853*^9}, 3.7379826849316587`*^9},
 CellID->1246962250,ExpressionUUID->"d0064d62-0fd1-4094-8b0a-280bd54d3053"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"i", ",", " ", "j"}]], TraditionalForm]], "InlineMath",
  ExpressionUUID->"c6bbd34e-e1d3-4412-a50e-f3a19abe3731"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "j"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "29b4b37b-1fe0-4d9d-8a90-3208105c1fb7"],
 " are fixed real (or sometimes complex) numbers so that an inverse function \
of the same type exists."
}], "Text",
 CellChangeTimes->{{3.7290076572767677`*^9, 3.729007657692009*^9}, 
   3.737982695131878*^9, {3.738431450213044*^9, 
   3.738431450876316*^9}},ExpressionUUID->"f83e6f31-4a1e-4e3c-8b02-\
8ff1826c9506"],

Cell[TextData[{
 "Note that the equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["d", "1"], "x"}], "+", 
     RowBox[{
      SubscriptBox["d", "2"], "y"}], "+", 
     SubscriptBox["d", "3"]}], "=", "0", " "}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"6951fc7e-2fff-495d-a580-b3706b1494f9"],
 " defines a line. Often ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "1"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "b255d70c-d431-4634-8bb9-6ee8dd346c7f"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["d", "2"], "=", "0"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"f2d667c5-6391-4abe-a01c-849ffd743b53"],
 ", so this will be the infinite line. In either case, in the domain of the \
FLT, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "\[VeryThinSpace]"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"26dadc72-2720-4281-acb0-0e2d02a21beb"],
 "\[VeryThinSpace], as shown above, will be the set of affine points with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["d", "1"], "x"}], "+", 
     RowBox[{
      SubscriptBox["d", "2"], "y"}], "+", 
     SubscriptBox["d", "3"]}], "\[NotEqual]", "0"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"d234496c-d3ce-4aa7-985b-e26a255c0e33"],
 "."
}], "Text",
 CellChangeTimes->{{3.694009514259967*^9, 3.694009674347963*^9}, {
   3.694009737620896*^9, 3.694009798648171*^9}, {3.694265635705762*^9, 
   3.694265635705973*^9}, {3.69426588354353*^9, 3.694265884887418*^9}, {
   3.722789833138914*^9, 3.722789840086677*^9}, {3.7227898733650084`*^9, 
   3.722789877572865*^9}, {3.729007680004765*^9, 3.7290077191342297`*^9}, 
   3.72935222474689*^9, {3.733511750642048*^9, 3.733511753239917*^9}, {
   3.737982737827025*^9, 3.737982748123137*^9}, {3.738431489892247*^9, 
   3.738431494708241*^9}, {3.743141157114223*^9, 
   3.7431411612500668`*^9}},ExpressionUUID->"c0d7c309-d299-4393-a5c0-\
13d5d4c8fc42"],

Cell["\<\
The notation above suggests we describe the FLT compactly by the matrix\
\>", "Text",
 CellChangeTimes->{{3.694009811049891*^9, 3.694009839537713*^9}, 
   3.722789891871251*^9, 
   3.737982792403179*^9},ExpressionUUID->"2a40287d-647b-483c-8e38-\
4aeb3a98098d"],

Cell[BoxData[
 FormBox[
  RowBox[{"A", "=", 
   RowBox[{
    RowBox[{"(", GridBox[{
       {
        SubscriptBox["a", 
         RowBox[{"1", ",", "1"}]], 
        SubscriptBox["a", 
         RowBox[{"1", ",", "2"}]], 
        SubscriptBox["a", 
         RowBox[{"1", ",", "3"}]]},
       {
        SubscriptBox["a", 
         RowBox[{"2", ",", "1"}]], 
        SubscriptBox["a", 
         RowBox[{"2", ",", "2"}]], 
        SubscriptBox["a", 
         RowBox[{"2", ",", "3"}]]},
       {
        SubscriptBox["d", "1"], 
        SubscriptBox["d", "2"], 
        SubscriptBox["d", "3"]}
      }], ")"}], "."}]}], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.7290078047483683`*^9, 3.729007821827963*^9}, 
   3.7379828014111958`*^9},
 CellID->1343904174,ExpressionUUID->"21f304bc-196c-4777-a3c8-ff4ced032068"],

Cell["\<\
This is more compact as well as useful because the FLT is actually given by \
this two-step procedure using matrix multiplication:\
\>", "Text",
 CellChangeTimes->{{3.694010234555175*^9, 3.694010290589186*^9}, {
  3.722789907230728*^9, 3.722789951489604*^9}, {3.737982812763255*^9, 
  3.737982815730637*^9}, {3.738431511068737*^9, 
  3.73843151188418*^9}},ExpressionUUID->"165c182e-7bcc-4a62-b3b5-\
c70114689601"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], " ", "\[RightTeeArrow]", " ", 
    RowBox[{"A", "(", "\[NoBreak]", GridBox[{
       {"x"},
       {"y"},
       {"1"}
      }], "\[NoBreak]", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"u", ",", "v", ",", "w"}], "}"}], " ", "\[RightTeeArrow]", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["u", "w"], ",", " ", 
      FractionBox["v", "w"]}], "}"}]}]}], TraditionalForm]], "DisplayFormula",\

 CellChangeTimes->{{3.72900783857203*^9, 3.729007846349477*^9}},
 CellID->949111220,ExpressionUUID->"1f8bfd1d-44de-4c4f-a0fa-aea541ca1f71"],

Cell["In the Wolfram Language, this becomes:", "CodeCaption",
 CellChangeTimes->{{3.694173975952446*^9, 3.694173990863982*^9}, {
   3.718196941897211*^9, 3.718196959585748*^9}, 3.7227899600733*^9, 
   3.737983181210128*^9},ExpressionUUID->"48b6a8fb-a776-4bec-83c5-\
745677359f11"],

Cell[BoxData[
 RowBox[{
  RowBox[{"flt", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_"}], "}"}], ",", "A_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"u", ",", "v", ",", "w"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", " ", 
      RowBox[{"A", ".", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "1"}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", "w", "]"}], "<", "1.*^-6"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"u", "/", "w"}], ",", 
         RowBox[{"v", "/", "w"}]}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694174039585369*^9, 3.69417427646364*^9}, {
  3.694174483164258*^9, 3.694174487364505*^9}, {3.6941760381896*^9, 
  3.694176041621873*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"d368798d-20a4-43a8-8973-40076763c521"],

Cell["As an example:", "CodeCaption",
 CellChangeTimes->{{3.694174543510893*^9, 3.694174548910441*^9}, 
   3.694174765319226*^9, 
   3.722789962344818*^9},ExpressionUUID->"7fdfc377-0f59-451c-9222-\
a69a9fb252e4"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"A", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.694174563986187*^9, 3.694174607935974*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"bec87b3a-5fde-423b-85b6-5e97c29a07ba"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", 
      RowBox[{"-", "2"}]},
     {"0", 
      RowBox[{"-", "1"}], "0"},
     {"0", "1", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.694174583042343*^9, 3.694174608650575*^9}, 
   3.718197460527084*^9, 3.72935069347141*^9, 3.729350979865615*^9, 
   3.729351042163974*^9, 3.729351102386973*^9, 3.733049128487752*^9, 
   3.733160786549953*^9, 3.733161264069936*^9, 3.733161552175531*^9, 
   3.733161765026389*^9, 3.7335119179797487`*^9},
 CellLabel->"Out[3]//MatrixForm=",
 CellID->949579936,ExpressionUUID->"29fe9f61-e145-45e8-a21d-6b0e13ba82aa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p", "=", 
  RowBox[{"RandomReal", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694174615077766*^9, 3.694174646241403*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"a35c94e0-1509-4dd4-bcb1-8788a9b2a0db"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.8168741963155348`", ",", 
   RowBox[{"-", "1.3389746274611714`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.694174648414405*^9, 3.729350693514064*^9, 
  3.729350979905533*^9, 3.729351042207659*^9, 3.7293511024280663`*^9, 
  3.7330491430654078`*^9, 3.733160786571035*^9, 3.733161264086989*^9, 
  3.733161552192874*^9, 3.733161765043296*^9, 3.7335119179975967`*^9},
 CellLabel->"Out[4]=",
 CellID->1639003495,ExpressionUUID->"5385a228-40ca-4dea-aaaf-99d0f1f1e39a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q", "=", 
  RowBox[{"flt", "[", 
   RowBox[{"p", ",", "A"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694174652873677*^9, 3.694174668674223*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"446b9662-a294-4ce0-9744-1251cd5af4f1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.5402345451517364`", ",", 
   RowBox[{"-", "3.950073306340745`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.694174659823273*^9, 3.694174676383883*^9}, 
   3.7293506935630503`*^9, 3.729350979955473*^9, 3.729351042258296*^9, 
   3.729351102477433*^9, 3.733049145753133*^9, 3.733160786592464*^9, 
   3.733161264105551*^9, 3.7331615522156553`*^9, 3.733161765062573*^9, 
   3.733511918039867*^9},
 CellLabel->"Out[5]=",
 CellID->959000396,ExpressionUUID->"b227dc82-83a7-4b2a-99c7-26aef01eebdd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"flt", "[", 
  RowBox[{"q", ",", 
   RowBox[{"Inverse", "[", "A", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694174692092511*^9, 3.6941746996433*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"1e2e71bb-41a3-4dcf-8da0-c6f619eed2be"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.816874196315535`", ",", 
   RowBox[{"-", "1.3389746274611714`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.694174701248724*^9, 3.7293506936135597`*^9, 
  3.729350980001103*^9, 3.729351042308419*^9, 3.7293511025280657`*^9, 
  3.7330491530767612`*^9, 3.7331607866125298`*^9, 3.733161264124036*^9, 
  3.733161552238125*^9, 3.733161765081212*^9, 3.73351191807438*^9},
 CellLabel->"Out[6]=",
 CellID->1054884837,ExpressionUUID->"b1a12590-81e2-4e32-aa51-892aec57dcf6"]
}, Open  ]],

Cell[TextData[{
 "This suggests that this FLT, as determined by matrix ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "eb04744d-812b-4768-a4a5-2d36fcf6459a"],
 ", is invertible with inverse ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", 
    RowBox[{"-", "1"}]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "026652f4-11f7-4aea-9758-7057fe4e5595"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.694011836774281*^9, 3.694011909817756*^9}, {
   3.694174785461471*^9, 3.694174803013592*^9}, {3.694174848151496*^9, 
   3.694174934132056*^9}, {3.694174999315451*^9, 3.694175002138213*^9}, {
   3.7227899912698174`*^9, 3.722790020516412*^9}, {3.722790069851026*^9, 
   3.7227900895304413`*^9}, 3.722790119884753*^9, {3.7293445137928457`*^9, 
   3.729344515182852*^9}, {3.734101927588818*^9, 
   3.734101928020783*^9}},ExpressionUUID->"36d0441b-7af7-4785-a604-\
439399bfe716"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B", "=", 
  RowBox[{"RandomInteger", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[7]:=",ExpressionUUID->"c1b4050f-acbc-45ac-9c78-ea0ccd58b606"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2", ",", "4"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.72935069366389*^9, 3.729350980055161*^9, 
  3.729351042357938*^9, 3.7293511025777683`*^9, 3.73304917138246*^9, 
  3.733160786631312*^9, 3.733161264141821*^9, 3.7331615522599707`*^9, 
  3.733161765099516*^9, 3.7335119181052*^9},
 CellLabel->"Out[7]=",
 CellID->1971949474,ExpressionUUID->"df7d87b3-36cc-48ba-8b80-5f4cdffa9c52"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"flt", "[", 
  RowBox[{"p", ",", " ", 
   RowBox[{"B", ".", "A"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"flt", "[", 
  RowBox[{"q", ",", "B"}], "]"}]}], "Input",
 CellLabel->"In[8]:=",ExpressionUUID->"2ce6cef2-6efd-4b29-a41e-981ff2e4c16b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "3.51777138081141`"}], ",", 
   RowBox[{"-", "0.9077183236241725`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7293506936936283`*^9, 3.729350980105472*^9, 
  3.72935104240786*^9, 3.72935110262774*^9, 3.733049176777589*^9, 
  3.733160786651763*^9, 3.7331612641596327`*^9, 3.733161552277567*^9, 
  3.733161765116827*^9, 3.733511918125558*^9},
 CellLabel->"Out[8]=",
 CellID->439685367,ExpressionUUID->"16f7f314-14d7-4d33-b244-ef9e7bce1d32"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "3.5177713808114097`"}], ",", 
   RowBox[{"-", "0.9077183236241725`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7293506936936283`*^9, 3.729350980105472*^9, 
  3.72935104240786*^9, 3.72935110262774*^9, 3.733049176777589*^9, 
  3.733160786651763*^9, 3.7331612641596327`*^9, 3.733161552277567*^9, 
  3.733161765116827*^9, 3.733511918132176*^9},
 CellLabel->"Out[9]=",
 CellID->300733842,ExpressionUUID->"9e74deee-43bf-4b9b-9f9f-518d66fd265e"]
}, Open  ]],

Cell[TextData[{
 "We can generalize the following for invertible matrices ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "da35cf68-4154-4377-a2cf-3767231daf4f"],
 ", ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]], "InlineMath",ExpressionUUID->
  "5be7b669-7205-4db1-a75e-c96d23a51043"],
 ":"
}], "Text",
 CellChangeTimes->{{3.694011913483134*^9, 3.694011935066428*^9}, 
   3.722790111552601*^9, {3.722790186186652*^9, 3.722790223327121*^9}, {
   3.729346228569025*^9, 3.729346236982696*^9}, {3.73410190932006*^9, 
   3.734101914203239*^9}, {3.737984171850582*^9, 
   3.7379841933535433`*^9}},ExpressionUUID->"6ffa1a02-60f8-45b4-99e4-\
93eb3bd579ea"],

Cell[CellGroupData[{

Cell[TextData[{
 "The composition of two FLTs is an FLT; in particular, the composition of \
the FLT given by matrix ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "1d8c2687-4827-4c6b-9b58-b8240bfc22a6"],
 " with the FLT given by matrix ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]], "InlineMath",ExpressionUUID->
  "7f91aa1e-7ac4-4c46-a94e-1bb31515c328"],
 " is the FLT given by the matrix product ",
 Cell[BoxData[
  FormBox[
   RowBox[{"B", " ", "A"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "8710f7b3-1487-4645-8c69-7dd2243db4e9"],
 "."
}], "ItemNumbered",
 CellChangeTimes->{{3.7290132174992113`*^9, 3.729013218026475*^9}, 
   3.734101633631359*^9, 3.737984204626341*^9, {3.7384316259659357`*^9, 
   3.738431627011709*^9}},ExpressionUUID->"b2eaf707-f8a9-4b39-a471-\
df4dc8e68c33"],

Cell[TextData[{
 "The FLT ",
 Cell[BoxData[
  FormBox["\[ScriptCapitalI]", TraditionalForm]], "InlineMath",
  ExpressionUUID->"df418758-c672-404a-9f5a-3be400839f23"],
 " defined by the identity matrix is the identity transformation; that is, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[ScriptCapitalI]", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"56a52320-5127-49cb-8335-9d3dad056a16"],
 " for all ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], "."}], TraditionalForm]],
  FontWeight->"Plain",ExpressionUUID->"eda21dce-bef0-43ea-878d-5356b9253f45"]
}], "ItemNumbered",
 CellChangeTimes->{{3.729013041995988*^9, 3.72901304916903*^9}, 
   3.729352224780476*^9, 3.734101660773875*^9, {3.742660676891583*^9, 
   3.7426606778159103`*^9}},
 CellID->1115444364,ExpressionUUID->"67b0cefe-8894-4daf-a8a8-738a0cb39642"],

Cell[TextData[{
 "Each FLT has an inverse FLT, and the inverse of the FLT given by ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "bd959f38-a46e-401c-ae67-af9f609addab"],
 " is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", 
    RowBox[{"-", "1"}]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "5c88ef45-88a3-4bdc-8fc9-fa3d77970616"],
 "."
}], "ItemNumbered",
 CellChangeTimes->{{3.729013258026937*^9, 3.7290132582901983`*^9}, {
  3.737984247489695*^9, 3.737984277745716*^9}},
 CellID->1233155251,ExpressionUUID->"35ae3bd4-1e94-454d-9ce0-1f65b4b6284d"]
}, Open  ]],

Cell["\<\
These facts can by defined as the set of FLTs in a group of transformations.\
\>", "Text",
 CellChangeTimes->{{3.694012688713947*^9, 3.694012790108725*^9}, {
   3.7227903476047697`*^9, 3.722790390163939*^9}, {3.722790426980453*^9, 
   3.722790427332664*^9}, {3.729346270710849*^9, 3.729346271182579*^9}, 
   3.737984296298184*^9, 
   3.738431660038526*^9},ExpressionUUID->"b89220d7-64c1-4f9d-b894-\
7dc3848ce158"],

Cell[TextData[{
 "We have failed to mention a technicality: if we multiply a matrix by a \
nonzero constant ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineMath",ExpressionUUID->
  "1fae3920-893c-4404-9456-55c74062f37a"],
 ", that is"
}], "Text",
 CellChangeTimes->{{3.694012799351896*^9, 3.694013134576305*^9}, {
  3.694013167927463*^9, 3.694013169630421*^9}, {3.694013444525472*^9, 
  3.694013451013968*^9}, {3.718197254259117*^9, 3.718197281786944*^9}, {
  3.722088141264732*^9, 3.722088142156426*^9}, {3.7227904432415648`*^9, 
  3.722790470225151*^9}, {3.722790510937532*^9, 3.722790565775865*^9}, {
  3.729010912045863*^9, 3.729010933400668*^9}, {3.737984321026229*^9, 
  3.737984335026219*^9}},ExpressionUUID->"94329d10-2b7a-4aa4-a39b-\
2c0b94d85ee6"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"c", " ", "A"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", GridBox[{
        {"c", "0", "0"},
        {"0", "c", "0"},
        {"0", "0", "c"}
       }], ")"}], "A"}]}], ","}], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.694012799351896*^9, 3.694013134576305*^9}, {
   3.694013167927463*^9, 3.694013169630421*^9}, {3.694013444525472*^9, 
   3.694013451013968*^9}, {3.718197254259117*^9, 3.718197281786944*^9}, {
   3.722088141264732*^9, 3.722088142156426*^9}, {3.7227904432415648`*^9, 
   3.722790470225151*^9}, {3.722790510937532*^9, 3.722790565775865*^9}, {
   3.729010912045863*^9, 3.729010943422778*^9}, 3.7379843380017548`*^9},
 CellID->90577311,ExpressionUUID->"bcdb7bcc-7acc-4976-91c1-16c15ac3174d"],

Cell[TextData[{
 "then we still get the same FLT due to the division at the end, so the group \
of FLTs is not the group of invertible ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", "\[Times]", "3"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"5d1a0ce5-f93a-482d-8b62-eb1401fdfd05"],
 " matrices but rather the group quotient by the nonzero constant diagonal \
matrices."
}], "Text",
 CellChangeTimes->{{3.694012799351896*^9, 3.694013134576305*^9}, {
   3.694013167927463*^9, 3.694013169630421*^9}, {3.694013444525472*^9, 
   3.694013451013968*^9}, {3.718197254259117*^9, 3.718197281786944*^9}, {
   3.722088141264732*^9, 3.722088142156426*^9}, {3.7227904432415648`*^9, 
   3.722790470225151*^9}, {3.722790510937532*^9, 3.722790565775865*^9}, {
   3.729010912045863*^9, 3.729010912525138*^9}, 3.7290129219034033`*^9, {
   3.729352224814069*^9, 3.729352224846904*^9}, {3.734101706054307*^9, 
   3.734101706325674*^9}, {3.734101949342956*^9, 3.7341019509888563`*^9}, {
   3.7379843729303493`*^9, 3.737984373145776*^9}, {3.7379844257943077`*^9, 
   3.737984490394431*^9}, {3.7384317670999727`*^9, 3.738431768358755*^9}},
 CellID->1373146773,ExpressionUUID->"6d30d49e-2126-43d9-b6a2-671f22e4c9e9"],

Cell[TextData[{
 "This group is generally known in mathematical literature as the projective \
general linear group ",
 Cell[BoxData[
  RowBox[{"PGL", 
   RowBox[{"(", 
    RowBox[{"3", ",", "\[DoubleStruckCapitalR]"}], ")"}]}]], "InlineCode",
  ExpressionUUID->"74463019-9120-4966-8a3a-011e7f0ab0bc"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.694012799351896*^9, 3.694013134576305*^9}, {
   3.694013167927463*^9, 3.694013169630421*^9}, {3.694013444525472*^9, 
   3.694013451013968*^9}, {3.718197254259117*^9, 3.718197281786944*^9}, {
   3.722088141264732*^9, 3.722088142156426*^9}, {3.7227904432415648`*^9, 
   3.722790470225151*^9}, {3.722790510937532*^9, 3.722790565775865*^9}, {
   3.729010912045863*^9, 3.729010912525138*^9}, 3.7290129219034033`*^9, {
   3.729352224814069*^9, 3.729352224846904*^9}, {3.734101706054307*^9, 
   3.734101706325674*^9}, {3.734101949342956*^9, 3.7341019509888563`*^9}, {
   3.7379843729303493`*^9, 3.737984373145776*^9}, {3.7379844257943077`*^9, 
   3.737984490394431*^9}, {3.7384317670999727`*^9, 3.7384318171011477`*^9}},
 CellID->327709986,ExpressionUUID->"929a291a-f8ee-4557-9940-631108bfb776"],

Cell[CellGroupData[{

Cell[BoxData[{"A", "\[IndentingNewLine]", 
 RowBox[{"flt", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", "A"}], "]"}]}], "Input",
 CellLabel->"In[10]:=",ExpressionUUID->"c5510a3d-ff57-47cb-af58-0e482cacd740"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.718197441394697*^9, 3.718197468550452*^9}, 
   3.7293506937469378`*^9, 3.7293509801568832`*^9, 3.729351042453961*^9, 
   3.729351102676908*^9, 3.733049187464424*^9, 3.733160786673627*^9, 
   3.733161264178238*^9, 3.733161552296405*^9, 3.7331617651350517`*^9, 
   3.733511918171822*^9},
 CellLabel->"Out[10]=",
 CellID->1404661103,ExpressionUUID->"de761180-d8ff-45e5-b781-a3435f956cfe"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{{3.718197441394697*^9, 3.718197468550452*^9}, 
   3.7293506937469378`*^9, 3.7293509801568832`*^9, 3.729351042453961*^9, 
   3.729351102676908*^9, 3.733049187464424*^9, 3.733160786673627*^9, 
   3.733161264178238*^9, 3.733161552296405*^9, 3.7331617651350517`*^9, 
   3.7335119181776*^9},
 CellLabel->"Out[11]=",
 CellID->851426650,ExpressionUUID->"0a318bf2-897c-4292-82dd-3162480e3a7f"]
}, Open  ]],

Cell[TextData[{
 "This means that the point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"9effb727-df8a-43a0-bfed-a60f7971255b"],
 " was not in the domain of the FLT defined by ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "9e6737b1-93eb-49e0-8039-7bbb9db8de1e"],
 ". For this matrix, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["d", "1"], "=", "0"}], ",", 
    RowBox[{
     SubscriptBox["d", "2"], "=", 
     RowBox[{
      SubscriptBox["d", "3"], "=", "1"}]}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"eea14ce3-18c4-44cd-87bd-75d1a6cb1ce8"],
 " is giving the line ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["d", "1"], "x"}], "+", 
     RowBox[{
      SubscriptBox["d", "2"], "y"}], "+", 
     SubscriptBox["d", "3"]}], "=", 
    RowBox[{
     RowBox[{"y", "+", "1"}], "=", "0"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"5942765f-61d2-42a2-9866-d7e928df33b3"],
 " as the affine line not in the domain. The routine ",
 Cell[BoxData[
 "flt"], "InlineCodeText",ExpressionUUID->
  "cb621e77-f5c2-4bc4-96ef-132e3e93ea39"],
 StyleBox[" returns the empty list in this case.", "InlineFormula"]
}], "Text",
 CellChangeTimes->{{3.694175414101023*^9, 3.694175773550296*^9}, {
  3.718197558762632*^9, 3.718197564338857*^9}, {3.722790613104692*^9, 
  3.722790681273159*^9}, {3.7293463915350647`*^9, 3.72934646195208*^9}, {
  3.729352224880457*^9, 3.729352224914019*^9}, {3.73798937216682*^9, 
  3.73798938831079*^9}, {3.7384318544109163`*^9, 3.73843185705357*^9}, {
  3.743166547278101*^9, 
  3.7431665481537027`*^9}},ExpressionUUID->"704dfdd2-3e01-453d-8f4a-\
41504e17ac7a"],

Cell[TextData[{
 "In fact, these FLTs easily extend to the entire projective plane. The \
formula is actually simpler since the FLT given by ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "1dd88a21-1f40-40fd-9789-03cc7c79f068"],
 " simply sends the projective point"
}], "Text",
 CellChangeTimes->{{3.694013505611804*^9, 3.694013752024591*^9}, {
   3.694013891597328*^9, 3.694014203273232*^9}, {3.694175805526512*^9, 
   3.694175839623852*^9}, {3.722791606869424*^9, 3.7227916121969013`*^9}, {
   3.7227916751765213`*^9, 3.722791683342684*^9}, 3.722791717547263*^9, {
   3.7290133197239933`*^9, 3.729013335197633*^9}, {3.737989405270549*^9, 
   3.737989471814395*^9}},ExpressionUUID->"6150d19b-c751-409c-8272-\
c54822680720"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}], " ", Cell[
   "\[RightTeeArrow]",ExpressionUUID->"0e8193f3-33be-4c65-a8ab-5c45e141814d"],
    " ", "A", " ", 
   RowBox[{
    RowBox[{"(", GridBox[{
       {"x"},
       {"y"},
       {"z"}
      }], ")"}], "."}]}], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.694013505611804*^9, 3.694013752024591*^9}, {
   3.694013891597328*^9, 3.694014203273232*^9}, {3.694175805526512*^9, 
   3.694175839623852*^9}, {3.722791606869424*^9, 3.7227916121969013`*^9}, {
   3.7227916751765213`*^9, 3.722791683342684*^9}, 3.722791717547263*^9, {
   3.7290133197239933`*^9, 3.729013341785912*^9}, 3.729346694093446*^9, {
   3.733049293504951*^9, 3.733049302436453*^9}, 3.737989482246394*^9},
 CellID->120951910,ExpressionUUID->"01aba291-4d1a-4687-b771-0a5791ddfa93"],

Cell[TextData[{
 "In this case, the fact that the point is only defined up to a nonzero \
constant multiple complements the fact that matrix ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "8fef4972-1080-4cfa-bcd9-5ed12e404e50"],
 " is also only defined up to a nonzero constant multiple."
}], "Text",
 CellChangeTimes->{{3.694013505611804*^9, 3.694013752024591*^9}, {
   3.694013891597328*^9, 3.694014203273232*^9}, {3.694175805526512*^9, 
   3.694175839623852*^9}, {3.722791606869424*^9, 3.7227916121969013`*^9}, {
   3.7227916751765213`*^9, 3.722791683342684*^9}, 3.722791717547263*^9, {
   3.7290133197239933`*^9, 3.7290133221060667`*^9}, {3.729346534902232*^9, 
   3.729346535269368*^9}, {3.737989496638392*^9, 3.737989497133638*^9}, {
   3.73798955821412*^9, 3.7379895606456347`*^9}},
 CellID->1221659312,ExpressionUUID->"c7d31506-6a0a-4c31-97b2-59c9d0fbbe81"],

Cell["\<\
Here is the code for projective FLT (For a complete list of global functions, \
see Appendix 2):\
\>", "CodeCaption",
 CellChangeTimes->{{3.718197588248722*^9, 3.718197610905856*^9}, {
   3.722791758605747*^9, 3.722791792661162*^9}, 3.729346529069434*^9, {
   3.7431666066903887`*^9, 3.743166606897756*^9}},
 CellID->977497591,ExpressionUUID->"166ca8e1-836e-4d50-9b52-47439555eb56"],

Cell[BoxData[
 RowBox[{
  RowBox[{"flti", "[", 
   RowBox[{"p_", ",", "A_"}], "]"}], " ", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"u", ",", "v", ",", "w"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "p", "]"}], "\[Equal]", "2"}], ",", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", " ", 
        RowBox[{"A", ".", 
         RowBox[{"Append", "[", 
          RowBox[{"p", ",", "1"}], "]"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", " ", 
        RowBox[{"A", ".", "p"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", "w", "]"}], "<", "1.*^-6"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"u", ",", "v", ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"u", "/", "w"}], ",", 
         RowBox[{"v", "/", "w"}]}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694175849699021*^9, 3.694175873751477*^9}, {
  3.694175919369369*^9, 3.694176028148223*^9}, {3.694176063350289*^9, 
  3.694176077462546*^9}, {3.694176111031021*^9, 3.694176129006497*^9}, {
  3.694789991764426*^9, 3.694789993380034*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"df8509f9-dc1e-45a6-833b-8441c1777df0"],

Cell[TextData[{
 "Unlike the affine FLT, the projective FLTs are defined on the entire \
projective plane. The points of the affine plane, where the affine FLT was \
not defined, now go to the infinite line. In the previous example using ",
 Cell[BoxData[
 "flti"], "InlineCodeText",ExpressionUUID->
  "43d498dc-98e9-4774-8f86-d7286e24f953"],
 ", ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "2581ed97-7eff-4752-88eb-f0760bb0e016"],
 " could be either affine or projective. The output will be affine if the \
result is not infinite or projective otherwise."
}], "Text",
 CellChangeTimes->{{3.694013505611804*^9, 3.694013752024591*^9}, {
   3.694013891597328*^9, 3.694014203273232*^9}, {3.694176210649396*^9, 
   3.694176227057863*^9}, {3.694176265354819*^9, 3.694176266523313*^9}, {
   3.6941763256668*^9, 3.694176415653231*^9}, {3.722791891616602*^9, 
   3.722792022528336*^9}, 3.722792068797387*^9, {3.729013520787347*^9, 
   3.729013541193013*^9}, 3.72935222494765*^9, {3.729373495180344*^9, 
   3.729373499066122*^9}, {3.7379897226382*^9, 3.737989723125269*^9}, {
   3.7379898369654217`*^9, 3.737989849268793*^9}, 3.738431890227622*^9, {
   3.7384320532861967`*^9, 3.738432062874131*^9}},
 CellID->1026267757,ExpressionUUID->"12c097da-1142-42f9-86c5-86e75fcfbbd4"],

Cell[TextData[{
 "Use the function ",
 Cell[BoxData[
 "flti"], "InlineCode",ExpressionUUID->"d2615d7d-872e-4b51-bd88-0244aef81c80"],
 ", and not the other variants in this chapter, to get:"
}], "CodeCaption",
 CellChangeTimes->{{3.7384321040205297`*^9, 3.7384321111799297`*^9}, {
  3.7431666269863043`*^9, 3.7431666300176697`*^9}},
 CellID->1116831534,ExpressionUUID->"ae4de914-a302-4bf6-bf82-a99c6ce4da41"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"flti", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", "A"}], "]"}]], "Input",
 CellChangeTimes->{3.7384321521092453`*^9},
 CellLabel->"In[13]:=",ExpressionUUID->"cd30c726-f95a-4c05-b2a8-0931556c81e0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "3"], ",", 
   RowBox[{"-", 
    FractionBox["2", "3"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.729350693809318*^9, 3.72935098021806*^9, 
  3.729351042520097*^9, 3.729351102739644*^9, 3.7330492044099617`*^9, 
  3.733160786709045*^9, 3.733161264202632*^9, 3.7331615523273697`*^9, 
  3.733161765160884*^9, 3.7335119182096148`*^9},
 CellLabel->"Out[13]=",
 CellID->1244166589,ExpressionUUID->"40f3074c-290c-4b84-85f9-fb63bc0e9077"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"flti", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "2", ",", "1"}], "}"}], ",", "A"}], "]"}]], "Input",
 CellChangeTimes->{{3.7384321521092453`*^9, 3.7384321550193987`*^9}},
 CellLabel->"In[14]:=",
 CellID->183917385,ExpressionUUID->"284c8c78-5793-4f4d-bbb5-7d7c997fe8a8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "3"], ",", 
   RowBox[{"-", 
    FractionBox["2", "3"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.729350693809318*^9, 3.72935098021806*^9, 
  3.729351042520097*^9, 3.729351102739644*^9, 3.7330492044099617`*^9, 
  3.733160786709045*^9, 3.733161264202632*^9, 3.7331615523273697`*^9, 
  3.733161765160884*^9, 3.733511918215664*^9},
 CellLabel->"Out[14]=",
 CellID->659590484,ExpressionUUID->"6d125c40-638c-4bf4-ac4e-46536cd2a27e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"flti", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", "A"}], "]"}]], "Input",
 CellChangeTimes->{{3.7384321521092453`*^9, 3.7384321560673647`*^9}},
 CellLabel->"In[15]:=",
 CellID->870521662,ExpressionUUID->"f89a088c-0415-4e23-b9e1-d7674654f554"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.729350693809318*^9, 3.72935098021806*^9, 
  3.729351042520097*^9, 3.729351102739644*^9, 3.7330492044099617`*^9, 
  3.733160786709045*^9, 3.733161264202632*^9, 3.7331615523273697`*^9, 
  3.733161765160884*^9, 3.7335119182196074`*^9},
 CellLabel->"Out[15]=",
 CellID->426678774,ExpressionUUID->"dd9dd7c5-ddd8-428d-9266-f4a6b5eeee23"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"flti", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "A"}], "]"}]], "Input",
 CellChangeTimes->{{3.7384321521092453`*^9, 3.7384321560673647`*^9}},
 CellLabel->"In[16]:=",
 CellID->51486223,ExpressionUUID->"fcebdfc4-1211-461f-86fd-27f8bc7602fb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.729350693809318*^9, 3.72935098021806*^9, 
  3.729351042520097*^9, 3.729351102739644*^9, 3.7330492044099617`*^9, 
  3.733160786709045*^9, 3.733161264202632*^9, 3.7331615523273697`*^9, 
  3.733161765160884*^9, 3.733511918223501*^9},
 CellLabel->"Out[16]=",
 CellID->742257285,ExpressionUUID->"b063d187-d325-4011-a312-d0268105e3bd"]
}, Open  ]],

Cell[TextData[{
 "We will see that if, in the original formula, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["d", "1"], "=", 
    RowBox[{
     SubscriptBox["d", "2"], "=", "0"}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"798da54a-c895-438e-9a01-5b1508efd22f"],
 ", then the FLT leaves the infinite line alone and simply transforms the \
affine plane. These transformations may be familiar to you from elementary \
transformational geometry."
}], "Text",
 CellChangeTimes->{{3.694013505611804*^9, 3.694013752024591*^9}, {
   3.694013891597328*^9, 3.694014203273232*^9}, {3.694176210649396*^9, 
   3.694176227057863*^9}, {3.694176265354819*^9, 3.694176266523313*^9}, 
   3.722792269916029*^9, {3.7227923281832952`*^9, 3.7227923459904327`*^9}, {
   3.7290137277062597`*^9, 3.729013728786282*^9}, 
   3.729352224980812*^9},ExpressionUUID->"31ee7214-f756-402d-b528-\
1af299405afa"],

Cell[TextData[{
 "Later in this chapter, we will also consider FLTs defined by matrices with \
complex entries. These work the same way, but now the group of \
transformations is known as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"PGL", 
    RowBox[{"(", 
     RowBox[{"2", ",", "\[DoubleStruckCapitalC]"}], ")"}]}], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "c5cf239c-9c87-4289-b703-afc34058f958"],
 ". Unless noted otherwise, you can assume that we are talking about real \
FLTs."
}], "Text",
 CellChangeTimes->{{3.694013808856311*^9, 3.694013881356203*^9}, {
   3.694014210189969*^9, 3.694014285240756*^9}, {3.722792423102641*^9, 
   3.722792439309067*^9}, {3.722792486528199*^9, 3.72279249549579*^9}, 
   3.7290137435062237`*^9, {3.7293522250142937`*^9, 3.729352225047145*^9}, {
   3.737989979612981*^9, 
   3.737989991988958*^9}},ExpressionUUID->"84aa54b7-6611-43b1-acf8-\
b9d9a5b15cf5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 The Action of FLT on Curves", "Subsection",
 CellChangeTimes->{{3.694263487451887*^9, 3.694263517740853*^9}, 
   3.729013752392673*^9, {3.738432263337965*^9, 3.738432263969499*^9}},
 CellID->571049554,ExpressionUUID->"d00281bd-1471-432c-a881-aee2799e4dbe"],

Cell[TextData[{
 "The most important property of FLTs is that they act on curves as well as \
points. Again, we do the special plane invertible case only. One key is that \
the denominator in the formula (6.1) is the same for both coordinates, so \
passing to the projective case, we can use coordinate ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]], "InlineMath",ExpressionUUID->
  "71eb4282-6008-46ac-a6e9-c3890b1cc12f"],
 " for the denominator. Thus, projectively, the FLTs are polynomial \
transformations, not rational transformations. "
}], "Text",
 CellChangeTimes->{{3.694263526082645*^9, 3.694263697145622*^9}, {
   3.694263730186082*^9, 3.694263880637339*^9}, {3.694264388795425*^9, 
   3.694264418660479*^9}, {3.718197722599797*^9, 3.718197754351318*^9}, 
   3.718197797399286*^9, {3.729352225080554*^9, 3.7293522251469793`*^9}, {
   3.737990022964967*^9, 3.73799006397292*^9}},
 CellID->2003433773,ExpressionUUID->"4b5dbc58-7608-4cad-b8c6-8462d3ff0ab0"],

Cell[TextData[{
 "Given an FLT ",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "(", "p", ")"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"8eabe435-268a-4417-8e7f-7be1dc1c8d0a"],
 " and a curve ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", "0"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"4567ba2f-ec23-42e8-a23c-58c2979e68a4"],
 ", we want a new curve ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", "0"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"be62b469-5a5e-4126-8d53-cc12eb1907bb"],
 " with the property that if each point ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "babfcd7d-a879-4ff8-afca-4dcc18a55671"],
 " on ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "75f4c3be-d903-42c6-b065-30efe59fdaed"],
 ", then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", 
     RowBox[{"F", "\[VeryThinSpace]", "(", "p", ")"}], ")"}], "=", "0"}], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "efc0d940-add1-45f4-aaf1-9dae12b6a7fc"],
 "; that is, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"F", "\[VeryThinSpace]", "(", "p", ")"}], " "}], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "b4d4ac8b-f67d-4e5c-939c-69e5e4537359"],
 "is on the curve ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "87156bc0-b368-4b74-8874-5326d1e7adf6"],
 ", and conversely, if ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]], "InlineMath",ExpressionUUID->
  "84ff778e-f163-42ad-8e92-815208c907ad"],
 " is on the curve ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "38ba3055-fa71-473f-b675-4f4bfbc99765"],
 ", then there is a unique point ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "6bd9571b-0695-45b7-b1f5-6f6fe41152e8"],
 " on ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "=", "0", " "}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"51f4cd00-40b5-47a3-8149-68d03dccd8af"],
 "with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"F", "\[VeryThinSpace]", "(", "p", ")"}], "=", "q"}], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "4d65b98f-b357-4129-a8d8-7a38e15da6a2"],
 ", but invertibility of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "\[VeryThinSpace]"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"367fb0d8-ad42-4018-9b69-4921372cc462"],
 " implies that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["F", 
       RowBox[{"\[VeryThinSpace]", 
        RowBox[{"-", "1"}]}]], "(", "q", ")"}], "."}]}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"61b7661a-5e5a-455f-b714-ed8b2db26143"],
 " Hence we conclude that our formula for ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]], "InlineMath",ExpressionUUID->
  "8c1526a7-003b-4bc7-9430-006e3e203f8a"],
 " should be"
}], "Text",
 CellChangeTimes->{{3.694264442914107*^9, 3.694264516621207*^9}, {
   3.694264557014403*^9, 3.69426482526969*^9}, {3.694264867397942*^9, 
   3.694264928489832*^9}, {3.694264961368104*^9, 3.694264981370415*^9}, {
   3.694265076890071*^9, 3.694265105082014*^9}, 3.718197805025116*^9, {
   3.72901773692892*^9, 3.7290177999975767`*^9}, {3.729352225181012*^9, 
   3.729352225214764*^9}, 3.737990072924965*^9, {3.737990119596079*^9, 
   3.737990169684001*^9}, 3.737991035193686*^9, 3.738432366289369*^9, {
   3.738432454682166*^9, 3.7384324547770557`*^9}, {3.7431666549168367`*^9, 
   3.743166660222246*^9}, {3.743166947443562*^9, 3.7431669836637278`*^9}},
 CellID->1062740437,ExpressionUUID->"6130cfa6-0556-4bf9-bdad-d81de1ad322c"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"g", " ", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"f", "(", 
     RowBox[{
      SuperscriptBox["F", 
       RowBox[{"\[VeryThinSpace]", 
        RowBox[{"-", "1"}]}]], "(", 
      RowBox[{"x", ",", "y"}], ")"}], ")"}], "."}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.7290177212310333`*^9, 3.729017728815289*^9}, 
   3.737991024753984*^9, 3.7431669597803793`*^9},
 CellID->1840390777,ExpressionUUID->"12c9e222-cf09-4f99-91d7-90104e15d121"],

Cell[TextData[{
 "Working affinely, we have the problem that since ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["F", 
    RowBox[{"\[VeryThinSpace]", 
     RowBox[{"-", "1"}]}]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "97cc781d-4bf0-49ff-ac5a-24435731ef9e"],
 " is a rational transformation, we will be getting denominators that are no \
longer the same, causing problems numerically since we cannot assume \
simplification, but we can avoid this by working projectively. Assume ",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "\[VeryThinSpace]"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"0b61ac27-af2b-4ed8-90fd-35aec7296062"],
 " is given by matrix ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "454c56b2-20fd-406f-9718-1e168dbd7b83"],
 " and the homogenization of the curve is the homogeneous polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{"h", "(", 
    RowBox[{"x", ",", "y", ",", "z"}], ")"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"73702556-1725-41c7-937a-d4c1868954c4"],
 ". Then the new projective curve is given by"
}], "Text",
 CellChangeTimes->{{3.694265208422755*^9, 3.69426522020875*^9}, {
   3.694265255369753*^9, 3.694265399035867*^9}, {3.694265467589871*^9, 
   3.694265509726831*^9}, 3.694265896271133*^9, {3.694265978937405*^9, 
   3.694266008923257*^9}, {3.694266045137476*^9, 3.694266162976343*^9}, {
   3.729017830189363*^9, 3.729017843261156*^9}, {3.729352225248448*^9, 
   3.7293522253150377`*^9}, 3.737991014131629*^9, {3.73799112537143*^9, 
   3.737991192705666*^9}, {3.7384325047693167`*^9, 3.738432505360878*^9}, 
   3.738432641981554*^9, {3.7431669630875187`*^9, 3.743166992215446*^9}, {
   3.743167041768751*^9, 3.743167042128068*^9}},
 CellID->1920540131,ExpressionUUID->"65395a1f-3ee0-4a7c-b97d-9ee226e23607"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"g", "(", 
    RowBox[{"x", ",", "y", ",", "z"}], ")"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"h", "(", 
     RowBox[{
      SuperscriptBox["A", 
       RowBox[{"\[VeryThinSpace]", 
        RowBox[{"-", "1"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y", ",", "z"}], ")"}]}], ")"}], "."}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.729017853822394*^9, 3.729017861435751*^9}, 
   3.743167003924162*^9},
 CellID->2010825750,ExpressionUUID->"050acaf9-541a-4399-ba1e-39ea7b7f4ebb"],

Cell[TextData[{
 "Or in the Wolfram Language, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y", ",", "z"}]}]}], "}"}], "=", 
   RowBox[{"FLTh", "[", 
    RowBox[{"h", ",", "A", ",", "x", ",", "y", ",", "z"}], "]"}]}]], 
  "InlineCode",ExpressionUUID->"b0c2e2ff-98d6-4698-a330-95bf0ae2d319"],
 " where (For a complete list of global functions, see Appendix 2):"
}], "CodeCaption",
 CellChangeTimes->{{3.694266258842026*^9, 3.694266287513614*^9}, {
  3.71819786347272*^9, 3.718197870856723*^9}, {3.727094131598522*^9, 
  3.727094171240337*^9}, {3.729017874119089*^9, 3.7290178819728603`*^9}, {
  3.7293467564450502`*^9, 3.729346765886397*^9}, {3.7348021288386383`*^9, 
  3.7348021305335493`*^9}, {3.738506854728547*^9, 3.738506864361794*^9}},
 CellID->603777940,ExpressionUUID->"41774e93-c324-45ca-8b3f-f153c5350f3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FLTh", "[", 
    RowBox[{"h_", ",", "A_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], " ", ":=", 
   RowBox[{
    RowBox[{"Expand", " ", "h"}], "/.", 
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], "->", 
      RowBox[{
       RowBox[{"Inverse", "[", "A", "]"}], ".", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}]}]}], "]"}]}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.734802744064764*^9},
 CellLabel->"In[17]:=",
 CellID->105443599,ExpressionUUID->"e51b9c48-76c9-4299-9a01-213419e0dac9"],

Cell[TextData[{
 "Consider the projective circle of radius 2, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "2"], "+", " ", 
     SuperscriptBox["y", "2"], "-", 
     RowBox[{"4", 
      SuperscriptBox["z", 
       RowBox[{"2", " "}]]}]}], "=", "0"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"345832f0-a359-4bdb-b691-87f3d7ad93df"],
 ", and the FLT ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]], "InlineMath",ExpressionUUID->
  "8a71ea1d-e750-4847-8375-cb5dc6b18dd7"],
 ", which translates the origin from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"a031a1e0-6dec-4ef4-926e-5e42f305bedd"],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"2c058a1a-3add-45fb-80bf-0ec6f34393e3"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.729017953189163*^9, 3.7290179547725563`*^9}, {
  3.7330510368250513`*^9, 3.7330510452414827`*^9}, {3.734802116914297*^9, 
  3.7348021207921143`*^9}, {3.734802481331793*^9, 3.734802504857692*^9}, {
  3.737991235433399*^9, 
  3.737991246728732*^9}},ExpressionUUID->"eeb39142-46ba-43ef-b1dc-\
cd936518396b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"h", "=", " ", 
   RowBox[{
    RowBox[{"x", "^", "2"}], "+", 
    RowBox[{"y", "^", "2"}], "-", 
    RowBox[{"4", 
     RowBox[{"z", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"k", "=", 
  RowBox[{"FLTh", "[", 
   RowBox[{"h", ",", "A", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], "Input",
 CellLabel->"In[17]:=",
 CellID->1183392164,ExpressionUUID->"c7d29739-814c-41dd-b139-8ec691ce2d24"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", "2"], "+", 
  SuperscriptBox["y", "2"], "-", 
  RowBox[{"4", " ", "x", " ", "z"}], "-", 
  RowBox[{"6", " ", "y", " ", "z"}], "+", 
  RowBox[{"9", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{3.729350693893283*^9, 3.729350980301703*^9, 
  3.729351042604537*^9, 3.7293511028392897`*^9, 3.73304933868097*^9, 
  3.7330513132571983`*^9, 3.733160786743157*^9, 3.733161264228335*^9, 
  3.7331615523550453`*^9, 3.733161765186689*^9, 3.733511918262141*^9},
 CellLabel->"Out[19]=",
 CellID->385683572,ExpressionUUID->"b02ec302-6dab-401a-97a1-b44759bd08c2"]
}, Open  ]],

Cell[TextData[{
 "Here, ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]], "InlineMath",ExpressionUUID->
  "f8262cc7-b0c5-451a-9562-35d9f1790d67"],
 " is the homogenization of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}], "=", "4"}], ","}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"a80d1956-efc0-4fe2-857d-3f057ad461f7"],
 " but the specialization of ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]], "InlineMath",ExpressionUUID->
  "ffa5fb11-2a25-4d5b-855d-933845f56d99"],
 " at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "1"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "683c7b87-28da-4563-8425-d8bbd863c190"],
 " is just ",
 Cell[BoxData[
  FormBox[Cell[TextData[{
    Cell[BoxData[
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "2"}], ")"}], "2"], TraditionalForm]], "InlineMath",
     ExpressionUUID->"13feeee2-a449-4b5f-9436-587c4a100dd4"],
    " + ",
    Cell[BoxData[
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"y", "-", "3"}], ")"}], "2"], TraditionalForm]], "InlineMath",
     ExpressionUUID->"5f6cce59-9b20-45dc-909b-19ddec101825"],
    " = 4."
   }],ExpressionUUID->"6be78742-47a4-49af-805e-f4d7cff4bd04"], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "feb94d42-0c33-45af-9b04-3226cc80aeff"]
}], "Text",
 CellChangeTimes->{{3.694266968086051*^9, 3.694267203263863*^9}, {
   3.729018022687821*^9, 3.7290180285985737`*^9}, {3.729352225349346*^9, 
   3.729352225418661*^9}, 3.737991257633441*^9},
 CellID->1673578066,ExpressionUUID->"5a1f3add-f02c-4381-97f0-d6914664549d"],

Cell["On the point level, we can use the following:", "CodeCaption",
 CellChangeTimes->{{3.727094263436678*^9, 3.727094271915535*^9}, 
   3.7379913182729692`*^9, 3.737991355504345*^9, {3.737991421576734*^9, 
   3.737991424032124*^9}},
 CellID->2139834071,ExpressionUUID->"60575d6d-e6c3-40a6-96de-126b6037e2ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"flth", "[", 
    RowBox[{"p_", ",", "A_"}], "]"}], ":=", 
   RowBox[{"A", ".", "p"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.727094311869812*^9, 3.727094348397997*^9}},
 CellLabel->"In[20]:=",
 CellID->228034918,ExpressionUUID->"6b7f3893-df1d-40cb-b7d9-9130090604ed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"flth", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "2", ",", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], "}"}], ",", "A"}], "]"}]], "Input",
 CellChangeTimes->{{3.727094373799774*^9, 3.727094378799339*^9}, {
  3.727094422032589*^9, 3.727094442657274*^9}},
 CellLabel->"In[21]:=",
 CellID->1046888275,ExpressionUUID->"7a691b87-7d56-4857-840b-4ad72a4d7475"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", "+", 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]}], ",", 
   RowBox[{"2", "+", 
    RowBox[{"3", " ", 
     SqrtBox["2"]}]}], ",", 
   SqrtBox["2"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.727094443374149*^9, 3.72935069394643*^9, 3.7293509803573093`*^9, 
   3.729351042657733*^9, 3.729351102893879*^9, {3.7330493620446377`*^9, 
   3.7330493857681026`*^9}, 3.7331606131888447`*^9, 3.7331607867726593`*^9, 
   3.733161264249474*^9, 3.733161552377096*^9, 3.733161765209176*^9, 
   3.7335119183174953`*^9},
 CellLabel->"Out[21]=",
 CellID->1078147958,ExpressionUUID->"9f1440e8-a4fd-49cf-9328-ec737e1446f6"]
}, Open  ]],

Cell[TextData[{
 "As suggested by the example above, the affine case is now handled by \
homogenizing ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "\[VeryThinSpace]"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"3856add7-ef6c-49ae-b6b8-8a52b96cbf4e"],
 ", transforming by ",
 Cell[BoxData[
 "FLTh"], "InlineCodeText",ExpressionUUID->
  "07a120aa-e761-4ec9-97db-e4aa65666d62"],
 " and finally specializing at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "1"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "42b238ae-7021-4b67-a7ad-f45c0f99b11f"],
 "."
}], "Text",
 CellChangeTimes->{{3.694266875459324*^9, 3.694266885130844*^9}, {
   3.694267214629845*^9, 3.694267236895518*^9}, {3.694267320511686*^9, 
   3.694267438667559*^9}, {3.694267730841732*^9, 3.694267748904634*^9}, {
   3.718198411514951*^9, 3.71819841537084*^9}, {3.729018076778571*^9, 
   3.729018077934659*^9}, {3.733050169703703*^9, 3.733050170559155*^9}, {
   3.733050320665101*^9, 3.73305040855758*^9}, {3.733050444947715*^9, 
   3.733050454181155*^9}, {3.734100771992999*^9, 3.734100772520968*^9}, {
   3.734100810872579*^9, 3.734100822409939*^9}, 3.734110279602977*^9, 
   3.737991504944633*^9, {3.737991575223792*^9, 3.7379915824740677`*^9}, {
   3.738507112194214*^9, 3.738507118538167*^9}, {3.7385071908427467`*^9, 
   3.73850719283764*^9}},
 CellID->761726760,ExpressionUUID->"3718a420-4f61-43d0-9b64-e78d178a1321"],

Cell[TextData[{
 "We use ",
 Cell[BoxData[
 "homog"], "InlineCode",ExpressionUUID->
  "7399083d-e291-40cb-b4f8-5b786f53d773"],
 " from Chapter 5 or Appendix 2:"
}], "CodeCaption",
 CellChangeTimes->{{3.694266875459324*^9, 3.694266885130844*^9}, {
   3.694267214629845*^9, 3.694267236895518*^9}, {3.694267320511686*^9, 
   3.694267438667559*^9}, {3.694267730841732*^9, 3.694267748904634*^9}, {
   3.718198411514951*^9, 3.71819841537084*^9}, {3.729018076778571*^9, 
   3.729018077934659*^9}, {3.733050169703703*^9, 3.733050170559155*^9}, {
   3.733050320665101*^9, 3.73305040855758*^9}, {3.733050444947715*^9, 
   3.733050454181155*^9}, {3.734100771992999*^9, 3.734100772520968*^9}, {
   3.734100810872579*^9, 3.734100822409939*^9}, 3.734110279602977*^9, 
   3.737991504944633*^9, {3.737991575223792*^9, 3.7379915824740677`*^9}, {
   3.738507112194214*^9, 3.738507118538167*^9}, {3.7385071908427467`*^9, 
   3.738507198658051*^9}},
 CellID->460431146,ExpressionUUID->"11503fb6-91a7-49b4-ba28-66a3d29f19c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FLT", "[", 
    RowBox[{"f_", ",", "A_", ",", "x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fh", ",", "gh", ",", " ", "AI", ",", "B", ",", "d", ",", "z"}],
       "}"}], ",", "\n", 
     RowBox[{
      RowBox[{"fh", "=", 
       RowBox[{"homog", "[", 
        RowBox[{"f", ",", "x", ",", "y", ",", "z"}], "]"}]}], ";", "\n", 
      RowBox[{"AI", "=", 
       RowBox[{"Inverse", "[", "A", "]"}]}], ";", "\n", 
      RowBox[{"B", "=", 
       RowBox[{"AI", ".", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z"}], "}"}]}]}], ";", "\n", 
      RowBox[{"gh", "=", 
       RowBox[{"Expand", "[", 
        RowBox[{"fh", "/.", 
         RowBox[{"Thread", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", "z"}], "}"}], "\[Rule]", "B"}], 
          "]"}]}], "]"}]}], ";", "\n", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{"gh", "/.", 
         RowBox[{"{", 
          RowBox[{"z", "\[Rule]", "1"}], "}"}]}], ",", "1*^-10"}], "]"}]}]}], 
    "\n", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.733050269953987*^9, 3.7330502699657373`*^9}, {
  3.7330503006135597`*^9, 3.733050307599236*^9}, {3.733050463993985*^9, 
  3.733050494749878*^9}},
 CellLabel->"In[22]:=",
 CellID->561263152,ExpressionUUID->"9189e315-828a-46fc-bdb8-201052f746cb"],

Cell[TextData[{
 "Using ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "f99efd58-2779-45db-92bd-a9c71ecbe5a7"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7341017275739803`*^9, 3.7341017278214083`*^9}, 
   3.734110279642646*^9, {3.7379917605518303`*^9, 3.73799176200721*^9}},
 CellID->1913777443,ExpressionUUID->"d41cf21e-52e1-4223-8eb9-cb2ea50a0c9f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"g", "=", 
  RowBox[{"FLT", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "^", "2"}], "+", 
     RowBox[{"y", "^", "2"}], "-", "4"}], ",", " ", "A", ",", "x", ",", "y"}],
    "]"}]}]}], "Input",
 CellLabel->"In[23]:=",
 CellID->1659050685,ExpressionUUID->"0aa0719f-0a5d-41fb-b575-48dc62b217a2"],

Cell[BoxData[
 RowBox[{"9", "-", 
  RowBox[{"4", " ", "x"}], "+", 
  SuperscriptBox["x", "2"], "-", 
  RowBox[{"6", " ", "y"}], "+", 
  SuperscriptBox["y", "2"]}]], "Output",
 CellLabel->"Out[24]=",
 CellID->2113200367,ExpressionUUID->"68868416-ea11-423d-a570-7bcec1f79a86"]
}, Open  ]],

Cell[TextData[{
 "If an FLT takes curve ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "cea52364-214b-4d26-9597-1ad2e1956745"],
 " to curve ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "1713f650-ffd6-4432-b740-f6e066b4975e"],
 ", then we say ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]], "InlineMath",ExpressionUUID->
  "19fb929e-6ace-457e-acb7-93555e728cf5"],
 " and ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]], "InlineMath",ExpressionUUID->
  "8096edae-978f-4f22-b2e3-7a634de3665e"],
 " are ",
 StyleBox["equivalent",
  FontSlant->"Italic"],
 " projective curves. Although they may look different in the affine plane, \
the FLT is a polynomial map in the projective plane and hence continuous. \
Moreover, the fact that the projective FLT is invertible makes it 1-1 and \
onto. In particular, all topological properties are preserved. It is not \
difficult to show the projective graphs, as defined in Chapter 5, are also \
preserved. Thus, from a geometer\[CloseCurlyQuote]s point of view, they are \
the same. We will see a number of examples in the next section. "
}], "Text",
 CellChangeTimes->{{3.694268693408246*^9, 3.694269010304262*^9}, {
  3.694269040793347*^9, 3.694269055370083*^9}, {3.734101594114085*^9, 
  3.734101607417554*^9}, {3.737991778400262*^9, 3.737991799495618*^9}, {
  3.737991896919753*^9, 3.737991924207856*^9}, {3.738507783402083*^9, 
  3.7385077951708593`*^9}},
 CellID->515117492,ExpressionUUID->"0fe568d8-ee79-42be-9a76-f1405ca6b60f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.3 Examples of FLTs", "Subsection",
 CellChangeTimes->{{3.694347151086124*^9, 3.694347193358507*^9}, 
   3.737991946639222*^9},ExpressionUUID->"540de46e-9421-4169-841d-\
19d68e5c5406"],

Cell["\<\
In this section, we will look at various subgroups of the FLT group; that is, \
sets of transformations that are closed under composition and taking \
inverses. Each subgroup defines a different kind of plane geometry. We will \
develop this material further in Chapter 7.\
\>", "Text",
 CellChangeTimes->{{3.694347203061441*^9, 3.694347212719342*^9}, {
   3.694347321625724*^9, 3.694347430379067*^9}, {3.694347540707467*^9, 
   3.694347558756152*^9}, {3.722796047132763*^9, 3.722796050988657*^9}, 
   3.7290182383798943`*^9, 3.7293522254517107`*^9, 
   3.7379919392628927`*^9},ExpressionUUID->"2e208b28-0967-4c35-b0d1-\
56458252c4ca"],

Cell[CellGroupData[{

Cell["The Euclidean Group", "Subsubsection",
 CellChangeTimes->{{3.694347441589382*^9, 3.694347444180328*^9}, {
   3.694347511594385*^9, 3.694347517435156*^9}, {3.694347576635947*^9, 
   3.694347581739989*^9}, 
   3.729348762236054*^9},ExpressionUUID->"2ce76531-6462-42a7-9b5e-\
7df34c6cb304"],

Cell[TextData[{
 "An FLT defined by matrix ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "7c88b5a7-9252-4d16-b5f6-047fee1126b0"],
 " is Euclidean if the last row is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"74835e85-042d-4c1f-96b3-fb295e18b955"],
 " and the determinant is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[PlusMinus]", "1"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"3f296365-6ec3-4f1c-b444-fc7054647867"],
 ". FLTs in the Euclidean group take the affine plane to the affine plane and \
the infinite line into the infinite line."
}], "Text",
 CellChangeTimes->{{3.694347585432774*^9, 3.694347841840761*^9}, {
   3.694347871969232*^9, 3.694347965907753*^9}, {3.694348066840514*^9, 
   3.694348130753826*^9}, {3.694348796047918*^9, 3.694348802367895*^9}, 
   3.694348850008591*^9, {3.722796094377883*^9, 3.7227961100015707`*^9}, 
   3.7227979229708023`*^9, {3.7290181264854307`*^9, 3.729018134254127*^9}, {
   3.729352225485333*^9, 3.729352225519374*^9}, {3.737991982624713*^9, 
   3.737991998967224*^9}},ExpressionUUID->"ef0cd685-a886-4eab-a37f-\
0ec1ea94aeda"],

Cell[TextData[{
 StyleBox["Translations",
  FontSlant->"Italic"],
 ": If we think of the affine plane as a vector space, a translation adds a \
constant vector to each point. A translation is defined by the image of a \
single point. The product of two translations is a translation, as is the \
inverse."
}], "Text",
 CellChangeTimes->{{3.694348003125099*^9, 3.694348063047187*^9}, {
   3.694348150954486*^9, 3.694348244869983*^9}, {3.694348287887298*^9, 
   3.694348318920218*^9}, {3.694348361625625*^9, 3.694348375121527*^9}, {
   3.694348410917231*^9, 3.694348567234176*^9}, {3.694348624771598*^9, 
   3.694348631515609*^9}, {3.694348966339268*^9, 3.694348991690897*^9}, 
   3.718198707389768*^9, 3.718198836596023*^9, {3.722796147533327*^9, 
   3.7227961507245493`*^9}, {3.729018259427876*^9, 3.729018259619197*^9}, {
   3.729018299563122*^9, 3.729018316850874*^9}, {3.7290184837861433`*^9, 
   3.729018489834059*^9}, {3.729018588817751*^9, 3.729018592401512*^9}, {
   3.72901873821909*^9, 3.729018739769108*^9}, {3.729022668279961*^9, 
   3.729022669340724*^9}, {3.729347116019599*^9, 3.7293471185180807`*^9}, {
   3.7293509247222567`*^9, 3.7293509250099697`*^9}, 3.73799201254313*^9, {
   3.742659926020925*^9, 
   3.742659929266088*^9}},ExpressionUUID->"82dbccbe-13e3-4dc8-8867-\
c96705743cdc"],

Cell["A nonidentity translation is not a linear transformation:", \
"CodeCaption",
 CellChangeTimes->{{3.694348003125099*^9, 3.694348063047187*^9}, {
   3.694348150954486*^9, 3.694348244869983*^9}, {3.694348287887298*^9, 
   3.694348318920218*^9}, {3.694348361625625*^9, 3.694348375121527*^9}, {
   3.694348410917231*^9, 3.694348567234176*^9}, {3.694348624771598*^9, 
   3.694348631515609*^9}, {3.694348966339268*^9, 3.694348991690897*^9}, 
   3.718198707389768*^9, 3.718198836596023*^9, {3.722796147533327*^9, 
   3.7227961507245493`*^9}, {3.729018259427876*^9, 3.729018259619197*^9}, {
   3.729018299563122*^9, 3.729018316850874*^9}, {3.7290184837861433`*^9, 
   3.729018489834059*^9}, {3.729018588817751*^9, 3.729018592401512*^9}, {
   3.72901873821909*^9, 3.729018739769108*^9}, {3.729022668279961*^9, 
   3.729022669340724*^9}, {3.729347116019599*^9, 3.72934712574671*^9}, 
   3.737992113238803*^9},
 CellID->1346752915,ExpressionUUID->"491bb34c-0212-4499-ad2f-eaf9e4b98daf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PQTranslation", "[", 
    RowBox[{"p_", ",", "q_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", 
       RowBox[{
        RowBox[{"q", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{"p", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", 
       RowBox[{
        RowBox[{"q", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "-", 
        RowBox[{"p", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.737992303294779*^9},
 CellLabel->"In[25]:=",
 CellID->1032644750,ExpressionUUID->"e2a6d296-06e1-4c20-9c47-30affff26ae4"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"PQTranslation", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"A", " ", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{
  3.7293509671391487`*^9, {3.729350998690531*^9, 3.72935100294515*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"8d2667f6-aa98-4068-8cc2-2414f9ee545a"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "3"},
     {"0", "1", 
      RowBox[{"-", "1"}]},
     {"0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.729351016053482*^9, 3.7293510427101927`*^9}, 
   3.729351102949946*^9, 3.7330516270023823`*^9, 3.733160786834805*^9, 
   3.733161264293086*^9, 3.7331615524242907`*^9, 3.733161765255705*^9, 
   3.733511918411121*^9},
 CellLabel->"Out[27]//MatrixForm=",
 CellID->1474014083,ExpressionUUID->"876315e3-7f41-413d-8298-398125826ede"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Inverse", "[", "A", "]"}], "//", "MatrixForm", " "}]], "Input",
 CellChangeTimes->{{3.7293509671391487`*^9, 3.729351007161234*^9}},
 CellLabel->"In[28]:=",
 CellID->1468367643,ExpressionUUID->"f45e9314-b437-4cf0-a4b6-114719d8a071"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", 
      RowBox[{"-", "3"}]},
     {"0", "1", "1"},
     {"0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.694348649701301*^9, 3.694348657428881*^9}, 
   3.694348910536603*^9, 3.729350694008922*^9, 3.729350980397881*^9, {
   3.729351016100422*^9, 3.729351042730427*^9}, 3.729351102981448*^9, 
   3.7330516390102654`*^9, 3.733160786855373*^9, 3.733161264308094*^9, 
   3.733161552440069*^9, 3.7331617652713346`*^9, 3.733511918455427*^9},
 CellLabel->"Out[28]//MatrixForm=",
 CellID->383341189,ExpressionUUID->"cec76894-453a-44c5-9cc7-41b7c9c99c31"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Rotations",
  FontSlant->"Italic"],
 ": The standard clockwise rotation around the origin in ",
 Cell[BoxData[
  FormBox["\[Theta]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "2ab0af0f-4b23-40e7-ac86-c3cb3b4c2108"],
 " radians is given by the matrix"
}], "Text",
 CellChangeTimes->{{3.694349021499658*^9, 3.694349079837487*^9}, {
  3.694349159774498*^9, 3.694349171477646*^9}, {3.694349527341587*^9, 
  3.694349534644723*^9}, {3.72279619428537*^9, 3.722796226828446*^9}, {
  3.729018539538538*^9, 3.72901854164179*^9}, {3.72901857238691*^9, 
  3.729018596001615*^9}, {3.7290226615368423`*^9, 3.729022662416813*^9}, {
  3.72934690198059*^9, 3.7293469024759293`*^9}, {3.729347059507127*^9, 
  3.729347066475109*^9}, {3.729347393593586*^9, 3.729347393761524*^9}, {
  3.7379922003344707`*^9, 3.73799220833457*^9}, {3.742659939828492*^9, 
  3.74265994260192*^9}},ExpressionUUID->"6afd6599-13f4-4731-aa09-\
f9ef851b74fc"],

Cell[BoxData[
 FormBox[
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"Cos", "[", "\[Theta]", "]"}], 
        RowBox[{"-", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "0"},
       {
        RowBox[{"Sin", "[", "\[Theta]", "]"}], 
        RowBox[{"Cos", "[", "\[Theta]", "]"}], "0"},
       {"0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "."}], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.729022969494974*^9, 3.729022979461746*^9}, 
   3.737992215062501*^9},
 CellID->481702036,ExpressionUUID->"129ff960-813c-43a9-adbb-deccef51720b"],

Cell[TextData[{
 "However, for our purposes, it is more useful to define a rotation by giving \
two intersecting affine lines, considering the rotation around the \
intersection point and taking the first line to the second line. The code \
makes use of the built-in Mathematica function ",
 ButtonBox["RotationMatrix",
  BaseStyle->"Link"],
 "."
}], "Text",
 CellChangeTimes->{{3.694349233178988*^9, 3.694349255639262*^9}, {
   3.694349315817137*^9, 3.694349384074883*^9}, {3.694349547293495*^9, 
   3.694349588935289*^9}, {3.694349825299498*^9, 3.694349826487187*^9}, {
   3.69434985729166*^9, 3.694349857715628*^9}, {3.694349947213929*^9, 
   3.694350070901339*^9}, {3.694350122095916*^9, 3.694350147305912*^9}, {
   3.718199412616572*^9, 3.718199412621884*^9}, {3.722796272226007*^9, 
   3.722796293466147*^9}, {3.722796327402794*^9, 3.722796327698575*^9}, {
   3.729018614056308*^9, 3.729018617994464*^9}, {3.729347049291668*^9, 
   3.729347075275228*^9}, {3.729347388754476*^9, 3.729347388849843*^9}, 
   3.729352225553556*^9, {3.737992447863447*^9, 3.737992478901486*^9}, 
   3.738508238689906*^9},ExpressionUUID->"ef123c5b-1404-411f-9b0f-\
b6d83c01cd4c"],

Cell["\<\
If we restricted ourselves to FLTs with rational matrices, we would not be \
able to construct these FLTs, even from lines defined by integer \
coefficients. This is perhaps the biggest single argument for doing curve \
theory numerically.\
\>", "Text",
 CellChangeTimes->{{3.694349233178988*^9, 3.694349255639262*^9}, {
   3.694349315817137*^9, 3.694349384074883*^9}, {3.694349547293495*^9, 
   3.694349588935289*^9}, {3.694349825299498*^9, 3.694349826487187*^9}, {
   3.69434985729166*^9, 3.694349857715628*^9}, {3.694349947213929*^9, 
   3.694350070901339*^9}, {3.694350122095916*^9, 3.694350147305912*^9}, {
   3.7227963728584747`*^9, 3.7227963824568777`*^9}, {3.722796415274446*^9, 
   3.722796439914681*^9}, 3.722797988054311*^9, {3.729347009468173*^9, 
   3.729347013163589*^9}, 3.72934719233899*^9, {3.72934745565821*^9, 
   3.7293474660172777`*^9}, 3.729352225587174*^9, {3.737992495829824*^9, 
   3.737992514173855*^9}},
 CellID->2048709178,ExpressionUUID->"1d60711a-cbe6-4c00-bc9e-71b29b35e034"],

Cell["\<\
Note that this code returns a matrix with machine numbers (For a complete \
list of global functions, see Appendix 2):\
\>", "CodeCaption",
 CellChangeTimes->{{3.72934719797954*^9, 3.729347228316526*^9}},
 CellID->285700976,ExpressionUUID->"5bb1c063-2b30-4041-9ded-50409debafa7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"klRotation", "[", 
   RowBox[{"k_", ",", "l_", ",", "x_", ",", "y_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "p", ",", "a1", ",", "a2", ",", "b1", ",", "b2", ",", "T", ",", "R", ",",
       " ", "A", ",", "B", ",", "m"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"a1", "=", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"k", ",", "x"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"b1", "=", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"k", ",", "y"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"a2", "=", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"l", ",", "x"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"b2", "=", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"l", ",", "y"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"a1", "*", "b2"}], "-", 
          RowBox[{"a2", "*", "b1"}]}], "]"}], "<", " ", "1.*^-9"}], ",", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<No affine center\>\"", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Return", "[", "Fail", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"p", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], "/.", 
       RowBox[{
        RowBox[{"NSolve", "[", 
         RowBox[{"{", 
          RowBox[{"k", ",", "l"}], "}"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"T", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", 
          RowBox[{"-", 
           RowBox[{"p", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", 
          RowBox[{"-", 
           RowBox[{"p", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"R", "=", 
      RowBox[{"N", "[", 
       RowBox[{"RotationMatrix", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"a1", ",", "b1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"a2", ",", "b2"}], "}"}]}], "}"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"R", "=", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Append", "[", 
         RowBox[{"R", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "0", "}"}], ",", 
          RowBox[{"{", "0", "}"}], ",", 
          RowBox[{"{", "1", "}"}]}], "}"}], ",", "2"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Inverse", "[", "T", "]"}], ".", "R", ".", "T"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694349416109933*^9, 3.694349478478812*^9}, {
  3.69434978321304*^9, 3.694349787836823*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"069e2c96-3e5d-48db-ba54-6049e41a22cf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"R", "=", 
   RowBox[{"klRotation", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "x"}], "+", 
      RowBox[{"3", "y"}], "+", "1"}], ",", 
     RowBox[{"x", "-", "y", "+", "2"}], ",", "x", ",", "y"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.72934726163575*^9, {3.733051721802616*^9, 3.733051722824782*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"7c558668-159b-4f8d-afee-77ec6eb7b9a3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{
  3.72934726163575*^9, 3.729351064890237*^9, {3.733051728718917*^9, 
   3.7330517303368273`*^9}},
 CellLabel->"In[31]:=",
 CellID->1649319220,ExpressionUUID->"e883e754-cae9-4c8b-837a-3a3c09b2e017"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.19611613513818404`"}], "0.9805806756909202`", 
      RowBox[{"-", "2.26291099460801`"}]},
     {
      RowBox[{"-", "0.9805806756909202`"}], 
      RowBox[{"-", "0.19611613513818404`"}], 
      RowBox[{"-", "0.6551432648843778`"}]},
     {"0.`", "0.`", "1.`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7293511030290527`*^9, {3.733051714347642*^9, 3.733051739529737*^9}, 
   3.733160786924981*^9, 3.733161264335433*^9, 3.733161552474321*^9, 
   3.73316176530164*^9, 3.733511918517736*^9},
 CellLabel->"Out[31]//MatrixForm=",
 CellID->364422523,ExpressionUUID->"04cde8bb-c666-45fe-bf10-8c860f41ba63"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Inverse", "[", "R", "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{
  3.72934726163575*^9, 3.729351064890237*^9, {3.733051748678183*^9, 
   3.7330517495456667`*^9}},
 CellLabel->"In[32]:=",
 CellID->1854731525,ExpressionUUID->"1fe95ce0-e050-4a4f-be8a-4e2916969af4"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.19611613513818402`"}], 
      RowBox[{"-", "0.98058067569092`"}], 
      RowBox[{"-", "1.0862141837789054`"}]},
     {"0.9805806756909201`", 
      RowBox[{"-", "0.19611613513818402`"}], "2.090482627050199`"},
     {"0.`", "0.`", "1.`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7293506940661173`*^9, 3.729350980447486*^9, 
  3.729351042787508*^9, 3.729351103061315*^9, 3.733051750586616*^9, 
  3.7331607869473877`*^9, 3.73316126435007*^9, 3.733161552490409*^9, 
  3.733161765318048*^9, 3.733511918539364*^9},
 CellLabel->"Out[32]//MatrixForm=",
 CellID->225982817,ExpressionUUID->"4fcf6be3-d812-4aa4-bdf5-413cb1c11287"]
}, Open  ]],

Cell[TextData[{
 "Again, since the intersection of the two lines is not the origin, this \
rotation matrix is also not a linear transformation of the plane. However, \
note that the upper left ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Times]", "2"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"c4a9541c-29da-4667-869b-267276382682"],
 " submatrix in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", 
    RowBox[{"-", "1"}]], TraditionalForm]], "InlineMath",ExpressionUUID->
  "4fd7715e-92ea-4587-87b5-f2da29b5786b"],
 " is the transpose of that in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", "."}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "7e5e5b1b-c75d-4cf1-ad3a-2e73fce73152"]
}], "Text",
 CellChangeTimes->{{3.7330517883050537`*^9, 3.733051826084691*^9}, {
   3.733051869351618*^9, 3.7330520116040363`*^9}, 3.7341015943654222`*^9, {
   3.7379925498458633`*^9, 3.737992561157086*^9}},
 CellID->726092803,ExpressionUUID->"280e137f-e9a6-4e84-9824-35b9255c7374"],

Cell[TextData[{
 StyleBox["Reflections",
  FontSlant->"Italic"],
 ": The reflection in the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "13950e8a-129b-40a4-a5a6-e028e65253ea"],
 "-axis takes point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"a605c9bb-b192-426c-b136-813efe5a1b75"],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}]}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"a8e0585f-ea8c-42a2-8564-936fab2a7fea"],
 ". This reflection is its own inverse. The best way to reflect about an \
arbitrary line is to use translations and rotations to move an arbitrary line \
to the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "6d07612a-618e-4feb-aa07-33f6141dbc52"],
 "-axis, reflect and then move back. This combined operation is called \
conjugation in group theory."
}], "Text",
 CellChangeTimes->{{3.694350205315368*^9, 3.694350234788757*^9}, {
   3.694350282942762*^9, 3.694350411877522*^9}, {3.69435049955293*^9, 
   3.694350573531116*^9}, {3.694351266850403*^9, 3.694351351165155*^9}, {
   3.722796478240767*^9, 3.7227964917850513`*^9}, {3.7227965404882793`*^9, 
   3.7227965412079353`*^9}, {3.7227965828758993`*^9, 
   3.7227965878924427`*^9}, {3.722796618635661*^9, 3.7227966573955593`*^9}, {
   3.72279668762132*^9, 3.72279672516505*^9}, {3.729018775905477*^9, 
   3.729018830418025*^9}, {3.72901887545963*^9, 3.729018888539007*^9}, {
   3.729019227393816*^9, 3.729019232937957*^9}, {3.729022654249362*^9, 
   3.7290226557164993`*^9}, {3.729023039728104*^9, 3.729023039728322*^9}, {
   3.729346940980816*^9, 3.729346941155931*^9}, {3.729347534066256*^9, 
   3.7293475465245743`*^9}, 3.7293522256222773`*^9, {3.742659953857581*^9, 
   3.742659957642103*^9}},ExpressionUUID->"29711fa9-46e3-4ad9-9286-\
9be2cc6627ff"],

Cell[TextData[{
 "Note that ",
 Cell[BoxData[
 "k"], "InlineCode",ExpressionUUID->"d0e5b4d9-fb42-4bb7-8d98-97c96fbeb0d2"],
 " must be an affine line, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", "x"}], "+", "b"}], " ", "\[Dash]", " ", 
   RowBox[{"c", "=", "0"}]}]], "InlineCode",ExpressionUUID->
  "28b6736c-c1f8-4afc-be23-a8d02c4edc59"],
 ", with either ",
 Cell[BoxData[
 "a"], "InlineCode",ExpressionUUID->"2f4bd272-b653-449d-a965-e3a866c97cb0"],
 " or ",
 Cell[BoxData[
 "b"], "InlineCode",ExpressionUUID->"f9e92179-de0c-4a94-ad2d-88fb4b9a616f"],
 " being something other than zero (For a complete list of global functions, \
see Appendix 2):"
}], "CodeCaption",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQXS++6n1m22vHetvIzyBaWjvuJ4heKVLDmQWkZ20s
FAHRz/9tkAXRDWbRJSD6s8fTOhAdu+X49tV7XjuqyFfuBNF/5vfvB9EZy5eB
6Tj2O0dA9JO+mqMgOiw85CSIzlmhcw5E33r4+SKIFvdYeg1Er/7551PnideO
ZQlnf4Jor615/0F0j70gYxeQVpmVow2i9zHL6YDoY7+OX+8G0hPefgPTC32+
s/cA6Sw/CH0jab6+1snXjsl/l4Dpo3KHKkH0tDP21SB6xQ65jctvAs3dCaET
a6P8F9967Si0wTsYRBsf2uvb9vi14zwoDQBHGq5g
  "],
 CellID->454323746,ExpressionUUID->"21cc2311-ea27-4e51-b8e6-cd35451541e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kReflection", "[", 
   RowBox[{"k_", ",", "x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "T", ",", "RX", ",", "RO"}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"RX", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"a", "=", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"k", ",", "x"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"b", "=", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"k", ",", "y"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"c", "=", 
      RowBox[{"k", "/.", 
       RowBox[{"Thread", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}], "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"a", "\[Equal]", "0"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "=", 
         RowBox[{"PQTranslation", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{
              RowBox[{"-", "c"}], "/", "b"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Return", "[", 
         RowBox[{"T", ".", "RX", ".", 
          RowBox[{"Inverse", "[", "T", "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"RO", "=", 
         RowBox[{"klRotation", "[", 
          RowBox[{"y", ",", "k", ",", "x", ",", "y"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Return", "[", 
         RowBox[{"RO", ".", "RX", ".", 
          RowBox[{"Inverse", "[", "RO", "]"}]}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694350577934209*^9, 3.694350614813238*^9}, {
   3.694350652110984*^9, 3.694350685400382*^9}, {3.694350733625932*^9, 
   3.694350755610837*^9}, {3.694350787259651*^9, 3.694350886887089*^9}, {
   3.694350968890346*^9, 3.694351097094579*^9}, {3.694351163944568*^9, 
   3.69435120480855*^9}, {3.694351387382775*^9, 3.694351410799409*^9}, {
   3.694351625517827*^9, 3.694351632357676*^9}, {3.694351687407303*^9, 
   3.694351853147496*^9}, {3.694351929270196*^9, 3.694351939677756*^9}, {
   3.694352004056121*^9, 3.694352019336122*^9}, 3.694352071153508*^9},
 CellLabel->"In[33]:=",ExpressionUUID->"66c8f35b-e7b1-4c99-a006-6ba317b9008b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "=", 
  RowBox[{"kReflection", "[", 
   RowBox[{
    RowBox[{"x", "-", "y"}], ",", "x", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7290192760391617`*^9, 3.7290192763104973`*^9}, 
   3.729347572681169*^9},
 CellLabel->"In[34]:=",ExpressionUUID->"a4b23317-4fda-4241-91f5-2bc4c042a874"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", "1.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.729350694125536*^9, 3.729350980495303*^9, 
  3.729351042842325*^9, 3.72935110309177*^9, 3.733052097429536*^9, 
  3.7331607869753017`*^9, 3.7331612643744593`*^9, 3.733161552516548*^9, 
  3.7331617653463078`*^9, 3.733511918578906*^9},
 CellLabel->"Out[34]=",
 CellID->1342117423,ExpressionUUID->"0588f782-e22e-4e8a-904f-830e4b634f34"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B", "=", 
  RowBox[{"kReflection", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"3", "x"}], "-", 
     RowBox[{"2", "y"}], "-", "1"}], ",", "x", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7290192760391617`*^9, 3.7290192763104973`*^9}, {
   3.729347572681169*^9, 3.72934757419306*^9}, 3.733052107782279*^9},
 CellLabel->"In[35]:=",
 CellID->1514833937,ExpressionUUID->"b7fb96a7-a58b-497c-93c8-d01ff2e2ef1b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.38461538461538464`"}], ",", "0.9230769230769231`", ",", 
     "0.46153846153846145`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9230769230769232`", ",", "0.3846153846153845`", ",", 
     RowBox[{"-", "0.3076923076923077`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", "1.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.733052109986209*^9, 3.733160786996632*^9, 
  3.733161264389772*^9, 3.733161552532124*^9, 3.733161765363369*^9, 
  3.7335119186223183`*^9},
 CellLabel->"Out[35]=",
 CellID->1946783920,ExpressionUUID->"ce671ae5-eecd-4e3d-bc56-2e9d7d6090da"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"B", "//", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inverse", "[", "B", "]"}], "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.7290192760391617`*^9, 3.7290192763104973`*^9}, {
  3.729347572681169*^9, 3.72934757419306*^9}, {3.7293506090141172`*^9, 
  3.7293506102431507`*^9}, {3.733052146001206*^9, 3.733052162251958*^9}},
 CellLabel->"In[36]:=",
 CellID->554882788,ExpressionUUID->"501cb60d-0001-424f-9e0b-4fc0cd411035"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.38461538461538464`"}], "0.9230769230769231`", 
      "0.46153846153846145`"},
     {"0.9230769230769232`", "0.3846153846153845`", 
      RowBox[{"-", "0.3076923076923077`"}]},
     {"0.`", "0.`", "1.`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.729350694189637*^9, 3.729350980575247*^9, 
  3.729351042928997*^9, 3.7293511031952972`*^9, 3.7330521187429447`*^9, 
  3.733052163149604*^9, 3.733160787017983*^9, 3.733161264404787*^9, 
  3.733161552548335*^9, 3.733161765381325*^9, 3.73351191865617*^9},
 CellLabel->"Out[36]//MatrixForm=",
 CellID->536497748,ExpressionUUID->"d96d91a6-563f-42ae-8f94-803f574d91bf"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.38461538461538447`"}], "0.9230769230769229`", 
      "0.4615384615384614`"},
     {"0.9230769230769231`", "0.3846153846153845`", 
      RowBox[{"-", "0.30769230769230765`"}]},
     {"0.`", "0.`", "1.`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.729350694189637*^9, 3.729350980575247*^9, 
  3.729351042928997*^9, 3.7293511031952972`*^9, 3.7330521187429447`*^9, 
  3.733052163149604*^9, 3.733160787017983*^9, 3.733161264404787*^9, 
  3.733161552548335*^9, 3.733161765381325*^9, 3.733511918662085*^9},
 CellLabel->"Out[37]//MatrixForm=",
 CellID->1781300530,ExpressionUUID->"e33a0c9c-eb53-4882-a9b1-7bbe0689caaf"]
}, Open  ]],

Cell["\<\
Note that even though the line is not through the origin, the reflection FLT \
is its own inverse.\
\>", "Text",
 CellChangeTimes->{{3.733052781956925*^9, 3.7330528146925383`*^9}, {
  3.7379942129157124`*^9, 3.73799421646577*^9}},
 CellID->546514578,ExpressionUUID->"9af1460b-db47-4041-abc5-d2b306f12fd8"],

Cell[TextData[{
 "Generally speaking, any Euclidean transformation is a composition of the \
above three types. A Euclidean transformation is determined uniquely by \
taking the three noncolinear vertices of a triangle to corresponding vertices \
of a congruent triangle. In fact, it is enough to use two or three \
reflections. We will illustrate this in Chapter 7 by showing how to take any \
affine ellipse to an ellipse of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FractionBox[
      SuperscriptBox["x", "2"], 
      SuperscriptBox["a", "2"]], "+", 
     FractionBox[
      SuperscriptBox["y", "2"], 
      SuperscriptBox["b", "2"]], "-", "1"}], "=", "0"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"80ecc880-4ca5-455a-a665-d55815217853"],
 "."
}], "Text",
 CellChangeTimes->{{3.694352850405116*^9, 3.694352924465541*^9}, 
   3.694352978100098*^9, {3.694353009317531*^9, 3.694353067150762*^9}, {
   3.69435368949574*^9, 3.694353741201267*^9}, {3.69435529128332*^9, 
   3.694355404881862*^9}, {3.694360713309096*^9, 3.694360720637726*^9}, {
   3.722796796170095*^9, 3.722796859740657*^9}, 3.722797633493485*^9, {
   3.729018979320004*^9, 3.729018990874254*^9}, {3.729019304017332*^9, 
   3.729019324278537*^9}, 
   3.737994250938567*^9},ExpressionUUID->"d854990e-e6a1-4449-9021-\
0847c50c94f6"],

Cell["\<\
If one includes similarity transformations with matrices of the form\
\>", "Text",
 CellChangeTimes->{{3.694355468808375*^9, 3.694355658472846*^9}, {
   3.722796904244815*^9, 3.722796906148301*^9}, {3.7227969369185266`*^9, 
   3.722796962637987*^9}, {3.7227970250782633`*^9, 3.72279703473461*^9}, 
   3.7290189498316517`*^9, 
   3.737994268002063*^9},ExpressionUUID->"f4f369a4-422a-49cf-a400-\
959e951c4649"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", GridBox[{
      {"r", "0", "0"},
      {"0", "r", "0"},
      {"0", "0", "1"}
     }], ")"}], ","}], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.729018962409307*^9, 3.729018969955257*^9}, {
  3.737994271337679*^9, 3.7379942906576357`*^9}},
 CellID->2043160019,ExpressionUUID->"25d241ee-0765-4251-a188-fc815e50d132"],

Cell[TextData[{
 "when ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", ">", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "3c9a2430-db62-4069-8f95-c53e5e0c4fa5"],
 ", one gets the group of Euclidean similarities. With these, you can \
transform any triangle to a given similar triangle."
}], "Text",
 CellChangeTimes->{{3.694355468808375*^9, 3.694355658472846*^9}, {
   3.722796904244815*^9, 3.722796906148301*^9}, {3.7227969369185266`*^9, 
   3.722796962637987*^9}, {3.7227970250782633`*^9, 3.72279703473461*^9}, 
   3.729018976488587*^9, {3.737994293537655*^9, 3.73799429367352*^9}},
 CellID->995857870,ExpressionUUID->"c4f6a034-610e-4b86-bfe0-45d4dd7316e5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Affine Transformations", "Subsubsection",
 CellChangeTimes->{{3.694360023976019*^9, 3.694360044753091*^9}, 
   3.722882069111639*^9},ExpressionUUID->"dbf14725-3754-41ac-b7e6-\
f008ff9eb8d7"],

Cell["\<\
The word \[OpenCurlyDoubleQuote]affine\[CloseCurlyDoubleQuote] comes from \
\[OpenCurlyDoubleQuote]affine transformations,\[CloseCurlyDoubleQuote] which \
are transformations that take Euclidean lines to Euclidean lines; \
specifically, an FLT defined by the matrix\
\>", "Text",
 CellChangeTimes->{{3.694360053008209*^9, 3.694360462222505*^9}, {
   3.722797291373776*^9, 3.722797301061768*^9}, {3.722797339541841*^9, 
   3.722797371039548*^9}, 3.722798094451454*^9, {3.722798125759412*^9, 
   3.722798128718464*^9}, 3.729019005230592*^9, {3.737994317330214*^9, 
   3.737994339777432*^9}},ExpressionUUID->"ec45f3e7-3ee5-477f-9ab4-\
f0035d73db6d"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"A", "=", 
    FormBox[
     RowBox[{"(", GridBox[{
        {
         SubscriptBox["a", 
          RowBox[{"1", ",", "1"}]], 
         SubscriptBox["a", 
          RowBox[{"1", ",", "2"}]], 
         SubscriptBox["a", "13"]},
        {
         SubscriptBox["a", 
          RowBox[{"2", ",", "1"}]], 
         SubscriptBox["a", 
          RowBox[{"2", ",", "2"}]], 
         SubscriptBox["a", 
          RowBox[{"2", ",", "3"}]]},
        {"0", "0", "1"}
       }], ")"}],
     TraditionalForm]}], ","}], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.729019015919742*^9, 3.72901902652247*^9}, 
   3.7290225083778543`*^9, 3.737994347010028*^9},
 CellID->1085437560,ExpressionUUID->"a0135f41-2f79-410e-b4ec-320f38acda78"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["a", 
       RowBox[{"1", ",", " ", "1"}]], 
      SubscriptBox["a", 
       RowBox[{"2", ",", " ", "2"}]]}], "-", 
     RowBox[{
      SubscriptBox["a", 
       RowBox[{"1", ",", " ", "2"}]], 
      SubscriptBox["a", 
       RowBox[{"2", ",", " ", "1"}]]}]}], "\[NotEqual]", "0"}], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "37c80bf5-83d1-479e-9b31-1c500498379e"],
 ". In particular, the group of affine transformations contains the Euclidean \
and similarity transformations. There are two new types that, with the \
Euclidean transformations, generate the entire group."
}], "Text",
 CellChangeTimes->{{3.694360053008209*^9, 3.694360462222505*^9}, {
   3.722797291373776*^9, 3.722797301061768*^9}, {3.722797339541841*^9, 
   3.722797371039548*^9}, 3.722798094451454*^9, {3.722798125759412*^9, 
   3.722798128718464*^9}, {3.729019033961982*^9, 3.729019068849893*^9}, 
   3.7293522256560917`*^9, {3.737994357794265*^9, 3.737994368193595*^9}},
 CellID->597915239,ExpressionUUID->"cf8c4d08-ff3c-421f-b3ad-5fdd6de48f10"],

Cell[TextData[{
 StyleBox["Shears",
  FontSlant->"Italic"],
 ": The standard shear leaves the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "2d6282ca-1361-4c42-a864-adfaf2ed558e"],
 "-coordinate fixed while shrinking or expanding the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "129bf57e-17b8-424a-b3d2-a0d7bf8c6f96"],
 "-coordinate so that a given line ",
 Cell[BoxData[
  FormBox["l", TraditionalForm]], "InlineMath",ExpressionUUID->
  "249a8648-2202-49e0-a95f-d1a86a14bd93"],
 " intersecting the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "4bda8fda-ecbf-4929-b878-af3a332f0611"],
 "-axis is moved to the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "52925687-fb86-449e-af7f-b5132a82c213"],
 "-axis."
}], "Text",
 CellChangeTimes->{{3.694360476797956*^9, 3.694360518030942*^9}, {
   3.694360570568336*^9, 3.694360646810112*^9}, {3.694360747909087*^9, 
   3.694360780606227*^9}, {3.694360870032387*^9, 3.694360932218653*^9}, 
   3.722797422882577*^9, {3.722797472137377*^9, 3.722797545911121*^9}, {
   3.729019156185357*^9, 3.72901921831092*^9}, {3.729022624648365*^9, 
   3.729022639552005*^9}, {3.7293476564724913`*^9, 3.729347656824707*^9}, {
   3.7293477940161*^9, 3.729347816699054*^9}, {3.733053065569499*^9, 
   3.733053072192322*^9}, {3.733053105690908*^9, 3.7330531319143677`*^9}, {
   3.734101160996501*^9, 3.734101183940361*^9}, {3.742659972983588*^9, 
   3.7426599826337757`*^9}},ExpressionUUID->"16e882bf-f39f-43a7-8c67-\
7458583a842c"],

Cell["\<\
More general shears may be made by conjugating by a Euclidean transformation \
(For a complete list of global functions, see Appendix 2):\
\>", "CodeCaption",
 CellChangeTimes->{{3.694360476797956*^9, 3.694360518030942*^9}, {
   3.694360570568336*^9, 3.694360646810112*^9}, {3.694360747909087*^9, 
   3.694360780606227*^9}, {3.694360870032387*^9, 3.694360932218653*^9}, 
   3.722797422882577*^9, {3.722797472137377*^9, 3.722797545911121*^9}, {
   3.729019156185357*^9, 3.72901921831092*^9}, {3.729022624648365*^9, 
   3.729022639552005*^9}, {3.7293476564724913`*^9, 3.729347656824707*^9}, {
   3.7293477940161*^9, 3.72934782614569*^9}},
 CellID->1559055042,ExpressionUUID->"35e3b9b2-af18-47db-827b-284ede2367a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kShear", "[", 
   RowBox[{"k_", ",", "x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"c", "=", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"k", ",", "x"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"d", "=", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"k", ",", "y"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"e", "=", 
      RowBox[{"k", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "\[Rule]", "0"}], ",", 
         RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"a", "=", 
      RowBox[{
       RowBox[{"-", "e"}], "/", "d"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"b", "=", 
      RowBox[{
       RowBox[{"-", "c"}], "/", "d"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "b"}], ",", "1", ",", 
         RowBox[{"-", "a"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694360962315923*^9, 3.694360994467071*^9}, {
  3.718363512930537*^9, 3.718363513457838*^9}, {3.718363567154637*^9, 
  3.718363572138322*^9}, {3.718363663571499*^9, 3.718363664082837*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"f8941ba9-2d0c-420d-ba60-bab0d3c646d2"],

Cell["Let\[CloseCurlyQuote]s try generating a shear:", "CodeCaption",
 CellChangeTimes->{{3.718362990545179*^9, 3.718363002045374*^9}, {
   3.718363184870756*^9, 3.718363196974747*^9}, {3.722798231174749*^9, 
   3.722798233271257*^9}, 3.729347854147213*^9, {3.737994386121875*^9, 
   3.737994386609353*^9}},
 CellID->481081581,ExpressionUUID->"12911e05-68af-4c69-a792-84e2e0e64b73"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"kShear", "[", 
    RowBox[{
     RowBox[{"x", "+", "y"}], ",", "x", ",", "y"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"A", " ", "//", "MatrixForm"}]}], "Input",
 CellLabel->"In[39]:=",ExpressionUUID->"ebe6db0b-ea2e-45c8-9d7b-7f01f3d997d6"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"1", "1", "0"},
     {"0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.729350694242544*^9, 3.7293509806351*^9, 
  3.729351043005876*^9, 3.7293511032367477`*^9, 3.733053628167191*^9, 
  3.733160787048341*^9, 3.7331612644258842`*^9, 3.733161552572681*^9, 
  3.7331617654063787`*^9, 3.733511918695992*^9},
 CellLabel->"Out[40]//MatrixForm=",
 CellID->248484883,ExpressionUUID->"4acc2384-2a91-4049-9d78-53ba98f4101b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"S", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"S1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"flt", "[", 
     RowBox[{"#", ",", "A"}], "]"}], "&"}], "/@", 
   "S"}]}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListLinePlot", "[", 
      RowBox[{"S", ",", " ", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".5"}], ",", "1.5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".5"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "->", "Thick"}]}], "]"}], ",", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "\"\<A\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"Bottom", ",", "Left"}], "}"}]}], "]"}], ",", 
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", "\"\<B\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"Bottom", ",", "Right"}], "}"}]}], "]"}], ",", 
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], ",", "\"\<C\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"Top", ",", "Right"}], "}"}]}], "]"}], ",", " ", 
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], ",", "\"\<D\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"Top", ",", "Left"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    "]"}], ",", " ", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"flt", "[", 
          RowBox[{"#", ",", "A"}], "]"}], "&"}], "/@", "S"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".5"}], ",", "1.5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".5"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "]"}], ",", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{"flt", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "A"}], "]"}], ",", 
          "\"\<A'\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"Bottom", ",", "Right"}], "}"}]}], "]"}], ",", 
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{"flt", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "0"}], "}"}], ",", "A"}], "]"}], ",", 
          "\"\<B'\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"Bottom", ",", "Left"}], "}"}]}], "]"}], ",", 
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{"flt", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "1"}], "}"}], ",", "A"}], "]"}], ",", 
          "\"\<C'\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"Top", ",", "Left"}], "}"}]}], "]"}], ",", 
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{"flt", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "1"}], "}"}], ",", "A"}], "]"}], ",", 
          "\"\<D'\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"Top", ",", "Right"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    "]"}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.73305341674514*^9, 3.733053508136875*^9}, {
  3.733053581923278*^9, 3.7330536165933027`*^9}, {3.733053658344445*^9, 
  3.733053715669724*^9}, {3.733053819578521*^9, 3.7330538292392883`*^9}, {
  3.7330538821301603`*^9, 3.733053914736699*^9}, {3.7330540354221497`*^9, 
  3.733054122986123*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"72ccd166-b020-4bf2-99f6-a029c51fdf9e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.718366042555056*^9, 3.718366130376639*^9, 3.718366215831154*^9, {
   3.718366308169361*^9, 3.718366331023738*^9}, 3.718366658047564*^9, {
   3.718366786877304*^9, 3.718366813887671*^9}, 3.729350694268166*^9, 
   3.729350980661146*^9, 3.729351043043187*^9, 3.7293511032807903`*^9, 
   3.733053006365109*^9, 3.733053202753282*^9, {3.733053454046706*^9, 
   3.733053472984396*^9}, 3.733053509274611*^9, {3.733053591584332*^9, 
   3.733053633669292*^9}, {3.733053664805994*^9, 3.733053678780509*^9}, 
   3.733053716471622*^9, 3.733053832928388*^9, {3.7330538957567244`*^9, 
   3.733053915659461*^9}, {3.733054038281971*^9, 3.733054066510181*^9}, {
   3.733054102550477*^9, 3.7330541237414007`*^9}, 3.733160787078041*^9, 
   3.733161264440114*^9, 3.733161552588705*^9, 3.73316176542253*^9, 
   3.733511918738592*^9},
 CellLabel->"Out[42]=",
 CellID->1577218813,ExpressionUUID->"4634a422-d965-4aa9-9eb9-204345722cf5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{{}, {{}, {}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.019444444444444445`], Thickness[Large], 
        LineBox[{{0., 0.}, {1., 0.}, {1., 1.}, {0., 1.}, {0., 
         0.}}]}}, {}, {}, {}, {}}, {{}, {{{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.012833333333333334`], AbsoluteThickness[1.6], 
         PointBox[{{0., 0.}, {1., 0.}, {1., 1.}, {0., 1.}}]}, {}}, {
        TagBox[
         {Opacity[0.], PointBox[{{0., 0.}}]},
         Annotation[#, {{Labeled}, Charting`Private`Tag$29030, {1}}]& ], 
        TagBox[
         {Opacity[0.], PointBox[{{1., 0.}}]},
         Annotation[#, {{Labeled}, Charting`Private`Tag$29030, {2}}]& ], 
        TagBox[
         {Opacity[0.], PointBox[{{1., 1.}}]},
         Annotation[#, {{Labeled}, Charting`Private`Tag$29030, {3}}]& ], 
        TagBox[
         {Opacity[0.], PointBox[{{0., 1.}}]},
         Annotation[#, {{Labeled}, Charting`Private`Tag$29030, {
           4}}]& ]}}, {{{}, {}}, {{{}, {}, {}, {}, {}}, {{}, 
         InsetBox["\<\"A\"\>", Offset[{0, -2}, {0., 0.}], 
          ImageScaled[{0.5, 1}]], 
         InsetBox["\<\"B\"\>", Offset[{0, -2}, {1., 0.}], 
          ImageScaled[{0.5, 1}]], 
         InsetBox["\<\"C\"\>", Offset[{0, 2}, {1., 1.}], 
          ImageScaled[{0.5, 0}]], 
         InsetBox["\<\"D\"\>", Offset[{0, 2}, {0., 1.}], 
          ImageScaled[{0.5, 0}]]}}}, {}, {}, {}}},
    AspectRatio->1,
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    ImageSize->{199.703125, Automatic},
    Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotRange->{{-0.5, 1.5}, {-0.5, 2.2}},
    PlotRangeClipping->True,
    PlotRangePadding->{{0, 0}, {0, 0}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{{}, {{}, {}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.019444444444444445`], Thickness[Large], 
        LineBox[{{0., 0.}, {1., 1.}, {1., 2.}, {0., 1.}, {0., 
         0.}}]}}, {}, {}, {}, {}}, {{}, {{{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.012833333333333334`], AbsoluteThickness[1.6], 
         PointBox[{{0., 0.}, {1., 1.}, {1., 2.}, {0., 1.}}]}, {}}, {
        TagBox[
         {Opacity[0.], PointBox[{{0., 0.}}]},
         Annotation[#, {{Labeled}, Charting`Private`Tag$29151, {1}}]& ], 
        TagBox[
         {Opacity[0.], PointBox[{{1., 1.}}]},
         Annotation[#, {{Labeled}, Charting`Private`Tag$29151, {2}}]& ], 
        TagBox[
         {Opacity[0.], PointBox[{{1., 2.}}]},
         Annotation[#, {{Labeled}, Charting`Private`Tag$29151, {3}}]& ], 
        TagBox[
         {Opacity[0.], PointBox[{{0., 1.}}]},
         Annotation[#, {{Labeled}, Charting`Private`Tag$29151, {
           4}}]& ]}}, {{{}, {}}, {{{}, {}, {}, {}, {}}, {{}, 
         InsetBox["\<\"A'\"\>", Offset[{0, -2}, {0., 0.}], 
          ImageScaled[{0.5, 1}]], 
         InsetBox["\<\"B'\"\>", Offset[{0, -2}, {1., 1.}], 
          ImageScaled[{0.5, 1}]], 
         InsetBox["\<\"C'\"\>", Offset[{0, 2}, {1., 2.}], 
          ImageScaled[{0.5, 0}]], 
         InsetBox["\<\"D'\"\>", Offset[{0, 2}, {0., 1.}], 
          ImageScaled[{0.5, 0}]]}}}, {}, {}, {}}},
    AspectRatio->1,
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    ImageSize->{200.328125, Automatic},
    Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotRange->{{-0.5, 1.5}, {-0.5, 2.2}},
    PlotRangeClipping->True,
    PlotRangePadding->{{0, 0}, {0, 0}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.718366042555056*^9, 3.718366130376639*^9, 3.718366215831154*^9, {
   3.718366308169361*^9, 3.718366331023738*^9}, 3.718366658047564*^9, {
   3.718366786877304*^9, 3.718366813887671*^9}, 3.729350694268166*^9, 
   3.729350980661146*^9, 3.729351043043187*^9, 3.7293511032807903`*^9, 
   3.733053006365109*^9, 3.733053202753282*^9, {3.733053454046706*^9, 
   3.733053472984396*^9}, 3.733053509274611*^9, {3.733053591584332*^9, 
   3.733053633669292*^9}, {3.733053664805994*^9, 3.733053678780509*^9}, 
   3.733053716471622*^9, 3.733053832928388*^9, {3.7330538957567244`*^9, 
   3.733053915659461*^9}, {3.733054038281971*^9, 3.733054066510181*^9}, {
   3.733054102550477*^9, 3.7330541237414007`*^9}, 3.733160787078041*^9, 
   3.733161264440114*^9, 3.733161552588705*^9, 3.73316176542253*^9, 
   3.7335119191724157`*^9},
 CellLabel->"Out[43]=",
 CellID->1925935170,ExpressionUUID->"eaecab37-90bf-45be-9a6e-5f43681b788f"]
}, Open  ]],

Cell[TextData[{
 "A shear takes the line ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "y"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "80cc5e09-b4ee-4705-8c55-83e8e4e7ba85"],
 " to the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "bfad4bcc-4375-48b0-9cb6-b2e29b8fee23"],
 "-axis, point ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "8f138ffb-badd-4ebd-8761-0e03d4b5033c"],
 " to point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "'"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "d3f5af56-400a-4856-9784-f8f8fc25880d"],
 ", etc. In both examples, notice what happens to points ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]], "InlineMath",ExpressionUUID->
  "74e9907a-4817-4cc6-bcba-4e7fe3084f06"],
 ", ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]], "InlineMath",ExpressionUUID->
  "9c45a1f3-0b59-4204-84a8-5e321a86fb44"],
 ", and ",
 Cell[BoxData[
  FormBox["D", TraditionalForm]], "InlineMath",ExpressionUUID->
  "4119a685-eb98-4cfe-b166-5f15347fd9ac"],
 "; noting that point ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]], "InlineMath",ExpressionUUID->
  "752c7fe9-72d6-4fdf-8b33-3ead8370113a"],
 " stays fixed at the origin."
}], "Text",
 CellChangeTimes->{{3.718363210784844*^9, 3.718363266791047*^9}, {
   3.718364976618668*^9, 3.718365005155564*^9}, 3.718365660794467*^9, {
   3.71836569437884*^9, 3.718365715107361*^9}, {3.718366438968243*^9, 
   3.718366502604206*^9}, {3.718374553347684*^9, 3.718374614125342*^9}, {
   3.7227982712282867`*^9, 3.722798272645088*^9}, {3.722798328550281*^9, 
   3.722798335757656*^9}, {3.722798420616081*^9, 3.72279842223871*^9}, {
   3.729347887186346*^9, 3.729347907127268*^9}, {3.729352225690749*^9, 
   3.7293522257243643`*^9}, {3.7330541633785143`*^9, 3.7330541852367764`*^9}, 
   3.73305432059409*^9, {3.734802872538529*^9, 3.734802887267446*^9}, {
   3.73799446595397*^9, 3.737994515019226*^9}, {3.738511419934568*^9, 
   3.738511420789748*^9}, {3.7431671893374977`*^9, 3.743167189519414*^9}},
 CellID->1794031519,ExpressionUUID->"e2c813c7-104f-4282-ae20-7aabcbded3d0"],

Cell[TextData[{
 StyleBox["Homothety",
  FontSlant->"Italic"],
 ": Also in the affine group is the homothety given by the matrix"
}], "Text",
 CellChangeTimes->{{3.694434446522776*^9, 3.694434467604805*^9}, {
  3.694434523084882*^9, 3.694434689904025*^9}, {3.722798443691087*^9, 
  3.7227984742315073`*^9}, {3.7290226169757557`*^9, 3.729022619122487*^9}, {
  3.729023114359523*^9, 3.729023128411944*^9}, {3.729347919335182*^9, 
  3.729347933450992*^9}, {3.7379945947791157`*^9, 3.737994615128791*^9}, {
  3.7426599914216127`*^9, 
  3.7426599945937243`*^9}},ExpressionUUID->"d689d368-c5b3-42ee-992e-\
05fbe1bb5c7a"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", GridBox[{
      {"r", "0", "0"},
      {"0", "s", "0"},
      {"0", "0", "1"}
     }], ")"}], ","}], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.694434446522776*^9, 3.694434467604805*^9}, {
  3.694434523084882*^9, 3.694434689904025*^9}, {3.722798443691087*^9, 
  3.7227984742315073`*^9}, {3.7290226169757557`*^9, 3.729022619122487*^9}, {
  3.729023114359523*^9, 3.729023128411944*^9}, {3.729347919335182*^9, 
  3.729347948185185*^9}, {3.737994639137445*^9, 3.737994640224818*^9}},
 CellID->1133957471,ExpressionUUID->"df7bad16-a34f-47ed-a487-2821de743cb7"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]], "InlineMath",ExpressionUUID->
  "3f3c3d91-db84-4b8a-91ac-7474fe122067"],
 " and ",
 Cell[BoxData[
  FormBox["s", TraditionalForm]], "InlineMath",ExpressionUUID->
  "a279b866-f553-451d-9ece-57db9508ba55"],
 " are positive reals."
}], "Text",
 CellChangeTimes->{{3.694434446522776*^9, 3.694434467604805*^9}, {
   3.694434523084882*^9, 3.694434689904025*^9}, {3.722798443691087*^9, 
   3.7227984742315073`*^9}, {3.7290226169757557`*^9, 3.729022619122487*^9}, {
   3.729023114359523*^9, 3.729023128411944*^9}, {3.729347919335182*^9, 
   3.7293479313518972`*^9}, 3.737994643352663*^9},
 CellID->1253612000,ExpressionUUID->"e6d433e1-ead9-44fc-91d4-332083c9cf98"],

Cell[TextData[{
 "Here is my code for ",
 Cell[BoxData[
 "homethety"], "InlineCode",ExpressionUUID->
  "cc48ea95-3d67-4ccb-89f6-390ac35f2e42"],
 " (For a complete list of global functions, see Appendix 2):"
}], "CodeCaption",
 CellChangeTimes->{{3.718543993929395*^9, 3.718543997871877*^9}, 
   3.729023483683226*^9, {3.729347981146089*^9, 3.7293479974074097`*^9}, 
   3.733054347787302*^9, {3.7379946769876213`*^9, 3.7379947087845793`*^9}, {
   3.743167203941059*^9, 3.743167204847528*^9}},
 CellID->494823283,ExpressionUUID->"e8454aca-5ba3-4e3f-baa0-204a15f0773c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"homothety", "[", 
     RowBox[{"r_", ",", " ", "s_"}], "]"}], " ", ":=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "s", ",", " ", "0"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], "}"}]}], ";"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694434710891717*^9, 3.694434713568303*^9}, {
   3.694434764833022*^9, 3.694434803642016*^9}, {3.718543620588741*^9, 
   3.7185436344135*^9}, 3.718543749671711*^9, {3.718543786937023*^9, 
   3.718543790192926*^9}, {3.718543858585565*^9, 3.718543876010485*^9}, 
   3.729352225730114*^9},
 CellLabel->"In[44]:=",ExpressionUUID->"2f23e18f-955a-43e7-9b03-a1624ac573ab"],

Cell["Here is an example building on the one output above:", "CodeCaption",
 CellChangeTimes->{{3.718543993929395*^9, 3.718543997871877*^9}, 
   3.729023483683226*^9, {3.729347981146089*^9, 3.7293479974074097`*^9}, 
   3.729348029722114*^9},
 CellID->898827428,ExpressionUUID->"f8e4264e-36df-4f84-a7a3-632ef71f8222"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"B", "=", " ", 
  RowBox[{"homothety", "[", 
   RowBox[{"2", ",", ".5"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.694434837894398*^9, 3.694434954004162*^9}, 
   3.729350630132319*^9},
 CellLabel->"In[45]:=",ExpressionUUID->"2f718039-cfd5-4e6e-9082-57b2d990786a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0.5`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.729350694812564*^9, 3.7293509811851387`*^9, 
  3.7293510435316763`*^9, 3.7293511037792892`*^9, 3.733054354717883*^9, 
  3.7331607876661873`*^9, 3.733161264739359*^9, 3.733161552891179*^9, 
  3.733161765721664*^9, 3.7335119192135477`*^9},
 CellLabel->"Out[45]=",
 CellID->171390959,ExpressionUUID->"f33273a4-8d3b-44c5-a788-a5350560bbbf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SS", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"flt", "[", 
     RowBox[{"#", ",", "B"}], "]"}], "&"}], "/@", "S"}]}]], "Input",
 CellChangeTimes->{{3.694434837894398*^9, 3.694434954004162*^9}, 
   3.729350630132319*^9},
 CellLabel->"In[47]:=",
 CellID->1314761274,ExpressionUUID->"b41641f0-bdeb-495f-9257-7909ec4b0782"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.694434957837933*^9, {3.718543916848178*^9, 3.718543931862554*^9}, 
   3.7293506948327103`*^9, 3.729350981207067*^9, 3.7293510435760527`*^9, 
   3.72935110380015*^9, 3.733054361390184*^9, 3.733160787685729*^9, 
   3.733161264755117*^9, 3.733161552906294*^9, 3.7331617657374573`*^9, 
   3.733511919256002*^9},
 CellLabel->"Out[47]=",
 CellID->792277286,ExpressionUUID->"00fff2e3-9b44-4df4-a977-f4731390fed8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"S", ",", "SS"}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", "Orange"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694434972379821*^9, 3.694434981892624*^9}, {
  3.694435018813048*^9, 3.694435029940855*^9}, {3.718543939773005*^9, 
  3.718543961894201*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"36ccf43c-8eb9-4557-b853-26e25919028e"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0, 0, 1], PointSize[0.019444444444444445`], AbsoluteThickness[
     1.6], LineBox[{{0., 0.}, {1., 0.}, {1., 1.}, {0., 1.}, {0., 0.}}]}, 
    {RGBColor[1, 0.5, 0], PointSize[0.019444444444444445`], AbsoluteThickness[
     1.6], LineBox[{{0., 0.}, {2., 0.}, {2., 0.5}, {0., 0.5}, {0., 
      0.}}]}}, {}, {}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2.}, {0, 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.694434984687258*^9, 3.694435031369724*^9, 
  3.71854396638149*^9, 3.7293506948807*^9, 3.729350981248001*^9, 
  3.729351043618039*^9, 3.7293511038411007`*^9, 3.733054367502342*^9, 
  3.733160787776519*^9, 3.7331612648383827`*^9, 3.7331615529905567`*^9, 
  3.7331617658222933`*^9, 3.733511919333459*^9},
 CellLabel->"Out[48]=",
 CellID->1405734402,ExpressionUUID->"20868f25-3c7c-4494-ba7f-06f018652664"]
}, Open  ]],

Cell["\<\
Now you can construct any affine transformation using the Euclidean, shear or \
homothety transformations.\
\>", "Text",
 CellChangeTimes->{{3.694435113075096*^9, 3.694435154206643*^9}, {
   3.722799566109199*^9, 3.722799575876583*^9}, 
   3.7385081313143272`*^9},ExpressionUUID->"ba2e84e3-9b90-4c8a-86cd-\
073f31c4bb02"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some Projective Transformations", "Subsubsection",
 CellChangeTimes->{{3.694435181539387*^9, 3.694435223400011*^9}, 
   3.729348774483985*^9},ExpressionUUID->"350cfe20-4828-4e8b-a7c6-\
9fd710627be6"],

Cell[TextData[{
 "As mentioned earlier, the full projective linear group consists of all \
FLTs. There are two that will generally be useful in the next two chapters \
that will be mentioned here. The first is the ",
 Cell[BoxData[
 "ip2z"], "InlineCodeText",ExpressionUUID->
  "fb96882d-2e0f-40ce-ade3-5b436665fcab"],
 StyleBox[" ", "Input"],
 "transform, which takes an infinite point and places it at the origin. The \
second, ",
 Cell[BoxData[
 "iTransform"], "InlineCodeText",ExpressionUUID->
  "2fb2b770-6ad4-42a8-9a11-ee5819dc7552"],
 ", places affine line ",
 Cell[BoxData[
  FormBox["\[ScriptL]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "25fd81a5-94e3-467f-903d-43af22e89921"],
 " at infinity. Both of these place the infinite line at the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "cf080bf0-af2f-4c07-84c6-6add7d59ff51"],
 "-axis."
}], "Text",
 CellChangeTimes->{{3.694435230413413*^9, 3.694435293880962*^9}, {
   3.694435373962456*^9, 3.694435429435759*^9}, {3.694435541181373*^9, 
   3.694435554500794*^9}, {3.694436826272751*^9, 3.694436906362829*^9}, {
   3.694436952035917*^9, 3.694436956803591*^9}, {3.694437267238249*^9, 
   3.694437296864482*^9}, {3.694437396929721*^9, 3.694437402025976*^9}, 
   3.722799569429214*^9, {3.722799622435837*^9, 3.722799644758422*^9}, 
   3.722799726271039*^9, {3.729023147765788*^9, 3.729023197988799*^9}, {
   3.7293522257641277`*^9, 3.729352225867824*^9}, {3.733159747133786*^9, 
   3.7331597485251617`*^9}, {3.734101254320889*^9, 3.734101262023336*^9}, 
   3.737994793201273*^9},ExpressionUUID->"8b0b7285-5bf0-4ca8-91a3-\
f7982e468652"],

Cell[TextData[{
 "To send ",
 Cell[BoxData[
 "ip2z"], "InlineCode",ExpressionUUID->"1635ebf7-1dd0-435f-b255-ded79606ec89"],
 " to origin (For a complete list of global functions, see Appendix 2):"
}], "CodeCaption",
 CellChangeTimes->{{3.718366983771082*^9, 3.718367011864932*^9}, 
   3.722799792804788*^9, {3.729023213532649*^9, 3.7290232264626637`*^9}, {
   3.729348064687148*^9, 3.729348088679152*^9}, {3.7330544097330523`*^9, 
   3.7330544165961037`*^9}, {3.737994838737156*^9, 3.737994838740223*^9}, {
   3.738508356186964*^9, 3.738508356520898*^9}},
 CellID->1291918271,ExpressionUUID->"958c81bf-b992-40b1-8f84-ac98af2c6ea1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ip2z", "[", 
   RowBox[{"ip_", ",", "x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"Module", "[", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "l", ",", "A", ",", "B"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "ip", "]"}], " ", "\[NotEqual]", " ", "3"}], 
       ",", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<not infinite point\>\"", "]"}], ";", 
        RowBox[{"Abort", "[", "]"}]}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"ip", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "]"}], ">", "1.*^-6"}], ",", 
         RowBox[{
          RowBox[{"Print", "[", "\"\<not infinite point\>\"", "]"}], ";", 
          RowBox[{"Abort", "[", "]"}]}], ",", 
         RowBox[{"p", "=", 
          RowBox[{"Chop", "[", 
           RowBox[{"ip", ",", "1.*^-6"}], "]"}]}]}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"B", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1.414213562373095`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "0.`", ",", "1.414213562373095`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", 
          RowBox[{"-", "0.7071067811865475`"}], ",", 
          RowBox[{"-", "0.7071067811865475`"}]}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"p", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}], "<", "1.*^-6"}], ",", 
       RowBox[{"Return", "[", "B", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ral", "=", 
      RowBox[{"line", "[", 
       RowBox[{"p", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", "x", ",", "y"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"B", ".", 
      RowBox[{"klRotation", "[", 
       RowBox[{"l", ",", "x", ",", "x", ",", "y"}], "]"}]}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6959919110420322`*^9, 3.695991911182644*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"414c4957-5023-4b7a-8383-a4646206cf2d"],

Cell[TextData[{
 "Send line ",
 Cell[BoxData[
  FormBox["l", TraditionalForm]], "InlineMath",ExpressionUUID->
  "16066cb1-ac71-4e66-b3ff-9caa0a39c4bf"],
 " to the infinite line; that is, delete it from the affine plane:"
}], "CodeCaption",
 CellChangeTimes->{{3.71836701895641*^9, 3.71836704931587*^9}, {
   3.7227998458439627`*^9, 3.722799850923695*^9}, 3.729023239717787*^9},
 CellID->1707640208,ExpressionUUID->"4ede65f0-3139-4d41-bcea-a44dd2701a10"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rrit1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7812879011987071`"}], ",", 
     RowBox[{"-", "0.3168196688992504`"}], ",", "0.9191639531555853`"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rrit2", "=", "1.4009431979825675`"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"iTransform", "[", 
    RowBox[{"l_", ",", "x_", ",", "y_"}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "ph", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ph", "=", 
       RowBox[{"N", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{"l", ",", "x"}], "]"}], ",", 
          RowBox[{"Coefficient", "[", 
           RowBox[{"l", ",", "y"}], "]"}], ",", " ", 
          RowBox[{"l", "/.", 
           RowBox[{"Thread", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x", ",", "y"}], "}"}], "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}]}], "}"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"ph", "=", 
       RowBox[{"ph", "/", 
        RowBox[{"Norm", "[", "ph", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"rrit1", ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "rrit2"}], "}"}], ",", "ph"}], "}"}]}]}],
     "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.69443662344893*^9, 3.694436648870615*^9}, 
   3.694865516984065*^9, {3.694865939387056*^9, 3.694865944576913*^9}, {
   3.718367103381909*^9, 3.718367150775314*^9}, {3.718367201177202*^9, 
   3.71836720655365*^9}, {3.733054508600699*^9, 3.7330545090362377`*^9}, {
   3.7331598335889797`*^9, 3.733159833902916*^9}, {3.7331599072057543`*^9, 
   3.733159907355073*^9}, {3.7331609121745653`*^9, 3.733160919046123*^9}, {
   3.733162245983567*^9, 3.733162284504036*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"40d8f77f-31a8-4878-a65a-70471452764e"],

Cell[TextData[{
 "Programming note: ",
 Cell[BoxData[
 "iTransform"], "InlineCodeText",ExpressionUUID->
  "e5648ca5-c31d-4c47-ac19-dacbab558ab8"],
 " uses random numbers ",
 Cell[BoxData[
 "rrit1"], "InlineCodeText",ExpressionUUID->
  "b1f293a6-f2d6-4f18-82e3-8139f05c4be3"],
 ", ",
 Cell[BoxData[
 "rrit2"], "InlineCodeText",ExpressionUUID->
  "56adfbae-18f0-49da-8aab-7491777fb5a1"],
 ". On this page, they are set to specific random numbers. In Appendix 2, \
they are set once per initialization. Thus using this function out of this \
specific context may give different answers."
}], "Text",
 CellChangeTimes->{{3.6959918834940166`*^9, 3.695991902932556*^9}, {
  3.6959919337856827`*^9, 3.6959921093170643`*^9}, {3.718367228857471*^9, 
  3.718367330595606*^9}, {3.722799855181551*^9, 3.722799858675758*^9}, {
  3.722799921274527*^9, 3.722799937466155*^9}, {3.729348181558661*^9, 
  3.7293481932780046`*^9}, {3.733159768149188*^9, 3.733159785426187*^9}, {
  3.733162310070834*^9, 3.7331623336227427`*^9}, {3.733162370551517*^9, 
  3.733162456373499*^9}, {3.7341012804309387`*^9, 3.7341012830630703`*^9}, {
  3.737994902376882*^9, 3.737994911176196*^9}, {3.737996860209023*^9, 
  3.737996910183557*^9}},
 FontSlant->"Italic",
 CellID->250108572,ExpressionUUID->"c4035970-3c23-43bc-912d-750abff614a1"],

Cell[TextData[{
 "As examples of these two transformations, consider the hyperbola ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   FractionBox["1", "x"]}]], "InlineCode",ExpressionUUID->
  "aecc732d-cc49-4477-8a00-48a4ea16a9bb"],
 " and the lines ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"l", "=", 
    RowBox[{"x", "-", "y"}]}], ",", " ", 
   RowBox[{"m", "=", 
    RowBox[{"x", "+", "y"}]}]}]], "InlineCode",ExpressionUUID->
  "f8735026-d115-4cb0-a6a2-b5560b290cf9"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.694437437949562*^9, 3.694437489277538*^9}, {
  3.694437559764084*^9, 3.694437570321827*^9}, {3.694437659763708*^9, 
  3.694437696711112*^9}, {3.71854417025319*^9, 3.718544206647785*^9}, {
  3.718544260007332*^9, 3.718544274321066*^9}, {3.72279997967689*^9, 
  3.7227999822532883`*^9}, {3.7293482140779877`*^9, 3.72934823902184*^9}, {
  3.729352225901752*^9, 3.729352225941636*^9}, {3.737994933824319*^9, 
  3.737994935168152*^9}, {3.738510787912458*^9, 3.7385107879160433`*^9}, {
  3.7385112162816553`*^9, 
  3.738511225517737*^9}},ExpressionUUID->"27039f4a-f86f-4d43-9e5f-\
4f4ee1745245"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x", " ", "y"}], " ", "==", "1"}], ",", 
     RowBox[{
      RowBox[{"x", "-", "y"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"x", "+", "y"}], "\[Equal]", "0"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[53]:=",ExpressionUUID->"bef2587f-587c-43ba-bb55-b45b503dade8"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1lwlwVeUVxxOJT0iAJIACKVAbEhBbUDqTKtPI+ZQWsyC0UnFopxUBW0CW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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105}], 
       LineBox[{106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 
        118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 
        132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 
        146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 
        160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 
        174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
        188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 
        202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 
        216, 217, 218, 219, 220}]},
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              TagBox["x", HoldForm], " ", 
              TagBox["y", HoldForm]}], "\[Equal]", "1"}], ",", 
          RowBox[{
            RowBox[{
              TagBox["x", HoldForm], "-", 
              TagBox["y", HoldForm]}], "\[Equal]", "0"}], ",", 
          RowBox[{
            RowBox[{
              TagBox["x", HoldForm], "+", 
              TagBox["y", HoldForm]}], "\[Equal]", "0"}]}], "}"}]],
     Annotation[#, {
      HoldForm[$CellContext`x] HoldForm[$CellContext`y] == 1, 
       HoldForm[$CellContext`x] - HoldForm[$CellContext`y] == 0, 
       HoldForm[$CellContext`x] + HoldForm[$CellContext`y] == 0}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[{221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 
        233, 234, 235, 236, 237, 238, 239}]},
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              TagBox["x", HoldForm], " ", 
              TagBox["y", HoldForm]}], "\[Equal]", "1"}], ",", 
          RowBox[{
            RowBox[{
              TagBox["x", HoldForm], "-", 
              TagBox["y", HoldForm]}], "\[Equal]", "0"}], ",", 
          RowBox[{
            RowBox[{
              TagBox["x", HoldForm], "+", 
              TagBox["y", HoldForm]}], "\[Equal]", "0"}]}], "}"}]],
     Annotation[#, {
      HoldForm[$CellContext`x] HoldForm[$CellContext`y] == 1, 
       HoldForm[$CellContext`x] - HoldForm[$CellContext`y] == 0, 
       HoldForm[$CellContext`x] + HoldForm[$CellContext`y] == 0}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwNzEVWQgEAAMCP3dhdKHZ3J2Indvs8gD5vbnfNYrYTub5N3ISCILjjngce
eeKZF155450PPvnimx9++SMQhUgimRRSSSOdDDLJIpsccskjTD4FFFJEMSWU
UkY5FVRSRTU11FJHPREaaCRKE8200Eob7XTQSRfd9NBLH/0MMMgQw4wwyhjj
TDDJFNPMMMsc88RYIM4iSyyzwiprrLPBJltss0OCXfbY54BDjjjmhFPOOOeC
S674B+xmJC4=
        "]]},
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              TagBox["x", HoldForm], " ", 
              TagBox["y", HoldForm]}], "\[Equal]", "1"}], ",", 
          RowBox[{
            RowBox[{
              TagBox["x", HoldForm], "-", 
              TagBox["y", HoldForm]}], "\[Equal]", "0"}], ",", 
          RowBox[{
            RowBox[{
              TagBox["x", HoldForm], "+", 
              TagBox["y", HoldForm]}], "\[Equal]", "0"}]}], "}"}]],
     Annotation[#, {
      HoldForm[$CellContext`x] HoldForm[$CellContext`y] == 1, 
       HoldForm[$CellContext`x] - HoldForm[$CellContext`y] == 0, 
       HoldForm[$CellContext`x] + HoldForm[$CellContext`y] == 0}, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{124., Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
  PlotRange->{{-5, 5}, {-5, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.694437817266305*^9, 3.729350695499971*^9, 
  3.7293509818232517`*^9, 3.729351044205656*^9, 3.729351104441938*^9, 
  3.733054486104595*^9, 3.7331599332983217`*^9, 3.7331607884554033`*^9, 
  3.7331612649351254`*^9, 3.73316155309486*^9, 3.733161765924576*^9, 
  3.733511919428803*^9},
 CellLabel->"Out[53]=",
 CellID->1710493767,ExpressionUUID->"838f6a50-c0f3-4d64-bad4-f81d7c809075"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "=", 
  RowBox[{"ip2z", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", "x", ",", "y"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.729348261902012*^9},
 CellLabel->"In[54]:=",ExpressionUUID->"f43a1dcf-c276-4a49-bd8b-cc829f11ec2f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.414213562373095`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", "1.414213562373095`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "0.7071067811865475`"}], ",", 
     RowBox[{"-", "0.7071067811865475`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.729350695592813*^9, 3.7293509818516283`*^9, 
  3.729351044221002*^9, 3.729351104473988*^9, 3.7330544898955812`*^9, 
  3.7331599353866987`*^9, 3.7331607884662523`*^9, 3.7331612649486322`*^9, 
  3.733161553110531*^9, 3.733161765938854*^9, 3.73316204989113*^9, 
  3.733511919443164*^9},
 CellLabel->"Out[54]=",
 CellID->2052643227,ExpressionUUID->"a10e0199-735c-4612-8795-d83ca393dadb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B1", "=", 
  RowBox[{"iTransform", "[", 
   RowBox[{
    RowBox[{"x", "-", "y"}], ",", "x", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.729348261902012*^9, 3.7293482633178864`*^9}, 
   3.7293506399161167`*^9, {3.733054528335043*^9, 3.7330545291791697`*^9}},
 CellLabel->"In[55]:=",
 CellID->1733488135,ExpressionUUID->"3aa6f7e8-b442-43e9-a56e-c35187865d4a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7812879011987071`"}], ",", 
     RowBox[{"-", "0.3168196688992504`"}], ",", "0.9191639531555853`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1.4009431979825675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7071067811865475`", ",", 
     RowBox[{"-", "0.7071067811865475`"}], ",", "0.`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.729350695612483*^9, 3.729350981872601*^9, 3.729351044260138*^9, 
   3.7293511044950733`*^9, 3.733054492296618*^9, {3.733054524334511*^9, 
   3.733054530584746*^9}, 3.733055569076194*^9, {3.733055826522477*^9, 
   3.733055852050549*^9}, 3.733159938548229*^9, 3.7331607884728403`*^9, 
   3.733161033905238*^9, 3.733161264963282*^9, 3.733161553126029*^9, 
   3.7331617659542627`*^9, 3.733162052178897*^9, 3.733162086696568*^9, 
   3.733511919489025*^9},
 CellLabel->"Out[55]=",
 CellID->1597410781,ExpressionUUID->"e0e40616-6a2b-48e3-ba5b-1431d3843d6f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B2", "=", 
  RowBox[{"iTransform", "[", 
   RowBox[{
    RowBox[{"x", "+", "y"}], ",", "x", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.729348261902012*^9, 3.7293482633178864`*^9}, 
   3.7293506415721197`*^9, {3.733054519214562*^9, 3.733054519982059*^9}},
 CellLabel->"In[56]:=",
 CellID->1971929743,ExpressionUUID->"b44b6aa8-ad11-48f6-b8f9-fdd5172fb82c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7812879011987071`"}], ",", 
     RowBox[{"-", "0.3168196688992504`"}], ",", "0.9191639531555853`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1.4009431979825675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7071067811865475`", ",", "0.7071067811865475`", ",", "0.`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7293506956468983`*^9, 3.729350981974518*^9, 3.72935104436161*^9, 
   3.7293511045971823`*^9, 3.733054521224957*^9, 3.733055571197513*^9, {
   3.733055828709405*^9, 3.733055854651382*^9}, 3.733159946782866*^9, 
   3.733160788489564*^9, {3.733161013344541*^9, 3.733161038445581*^9}, 
   3.7331612649796257`*^9, 3.733161553143651*^9, 3.733161765974245*^9, 
   3.73316205422031*^9, 3.73316208892015*^9, 3.733511919523056*^9},
 CellLabel->"Out[56]=",
 CellID->1989925120,ExpressionUUID->"fd7b407b-98d4-4bd8-b968-761cb7b3a138"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{
    RowBox[{"x", " ", "y"}], "-", "1"}]}], ";"}]], "Input",
 CellChangeTimes->{3.7293482831098824`*^9},
 CellLabel->"In[57]:=",ExpressionUUID->"349162d0-6950-4b18-8939-da654459c477"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "=", 
  RowBox[{"FLT", "[", 
   RowBox[{"f", ",", 
    RowBox[{"N", "[", "A", "]"}], ",", "x", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.7293482831098824`*^9, 3.729350659964127*^9, {3.733161053468207*^9, 
   3.733161056368287*^9}},
 CellLabel->"In[58]:=",
 CellID->2027725351,ExpressionUUID->"716d23db-f909-4f96-808d-f9708c658fd7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "1.0000000000000002`"}], " ", "x"}], "-", 
  RowBox[{"0.5000000000000001`", " ", "x", " ", "y"}], "-", 
  RowBox[{"0.5000000000000001`", " ", 
   SuperscriptBox["y", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.729350695677973*^9, 3.72935098202248*^9, 3.729351044409213*^9, 
   3.729351104645487*^9, 3.733054550717803*^9, 3.733055857959282*^9, 
   3.7331599540255337`*^9, 3.7331607885118227`*^9, {3.733161016129527*^9, 
   3.733161086597983*^9}, 3.7331612649997807`*^9, 3.733161553191139*^9, 
   3.733161765999888*^9, 3.733162010182106*^9, 3.733162056224744*^9, 
   3.733162091363162*^9, 3.733511919561185*^9},
 CellLabel->"Out[58]=",
 CellID->1908657109,ExpressionUUID->"30b86860-f081-4f47-acfe-6d65e23ec4ed"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h1", "=", 
  RowBox[{"FLT", "[", 
   RowBox[{"f", ",", "B1", ",", "x", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.7293482831098824`*^9, {3.729350659964127*^9, 3.729350661579969*^9}},
 CellLabel->"In[59]:=",
 CellID->1649143435,ExpressionUUID->"8eed3f24-a169-4431-b211-f945bbf44b75"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "0.4105475449967975`"}], "+", 
  RowBox[{"0.544729935250067`", " ", "x"}], "+", 
  RowBox[{"0.8292972572606271`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"0.3573993017044993`", " ", "y"}], "-", 
  RowBox[{"1.0882099237463128`", " ", "x", " ", "y"}], "-", 
  RowBox[{"0.15252805926335045`", " ", 
   SuperscriptBox["y", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.72935069569788*^9, 3.729350982056039*^9, 3.729351044441326*^9, 
   3.729351104678994*^9, 3.733054553784562*^9, 3.733055577879171*^9, {
   3.73305577773691*^9, 3.733055786573943*^9}, {3.733055816782344*^9, 
   3.733055860312622*^9}, 3.733159956858253*^9, 3.73316078854455*^9, {
   3.733161065764473*^9, 3.733161088983117*^9}, 3.7331612650135603`*^9, 
   3.733161553207492*^9, 3.733161766028019*^9, 3.7331620122204723`*^9, 
   3.733162059088731*^9, 3.73316209345002*^9, 3.733511919605351*^9},
 CellLabel->"Out[59]=",
 CellID->1836795724,ExpressionUUID->"130311cb-e735-4148-8814-ea511aac217d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h2", "=", 
  RowBox[{"FLT", "[", 
   RowBox[{"f", ",", "B2", ",", "x", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.7293482831098824`*^9, {3.729350659964127*^9, 3.729350661579969*^9}},
 CellLabel->"In[60]:=",
 CellID->1729763863,ExpressionUUID->"4ad14e96-54d2-4d58-9266-c0a4d686bfee"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2.294780758013289`"}], "-", 
  RowBox[{"7.198596857845491`", " ", "x"}], "-", 
  RowBox[{"4.635408034530393`", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"4.723025711933947`", " ", "y"}], "+", 
  RowBox[{"6.082616311130605`", " ", "x", " ", "y"}], "-", 
  RowBox[{"2.5049307116095973`", " ", 
   SuperscriptBox["y", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.729350695730238*^9, 3.7293509820894527`*^9, 3.729351044462522*^9, 
   3.729351104712349*^9, 3.733054557011084*^9, 3.733055580270029*^9, {
   3.733055779905987*^9, 3.733055788958444*^9}, {3.733055819145289*^9, 
   3.73305586242367*^9}, 3.7331599596842833`*^9, 3.733160788569153*^9, {
   3.733161069111886*^9, 3.7331610915343933`*^9}, 3.733161265028551*^9, 
   3.733161553224794*^9, 3.733161766043964*^9, 3.733162014444261*^9, 
   3.7331620615079412`*^9, 3.733162095587915*^9, 3.733511919639724*^9},
 CellLabel->"Out[60]=",
 CellID->948307643,ExpressionUUID->"9cbb3b9b-ed61-4975-b26d-c3fe0ad81f57"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "\[Equal]", "0"}], ",", 
       RowBox[{"y", "\[Equal]", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Dashed"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"h1", "\[Equal]", "0"}], ",", 
       RowBox[{"y", "\[Equal]", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Dashed"}], "}"}]}], ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"h2", "\[Equal]", "0"}], ",", 
       RowBox[{"y", "\[Equal]", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Dashed"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.733054666860014*^9, 3.733054706121169*^9}, {
  3.733054743710651*^9, 3.73305475515965*^9}, {3.7330547921005774`*^9, 
  3.7330548124080553`*^9}, {3.733055605603463*^9, 3.7330556078165197`*^9}, {
  3.733055726837582*^9, 3.733055752719648*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"6ecaa5b8-3a68-40f0-8dc0-02de87927722"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxtlg04ldkWxzm+i+TUNH1NSaFR0xhTd1Jq78koiZAZhZvbiNFjipibOzOa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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], AbsoluteThickness[1.6], 
         LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
          35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
          52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
          69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
          86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
          102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 
          115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 
          128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 
          141, 142, 143, 144, 145, 146}]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{"-", "1.0000000000000002`"}], " ", 
                  TagBox["x", HoldForm]}], "-", 
                RowBox[{"0.5000000000000001`", " ", 
                  TagBox["x", HoldForm], " ", 
                  TagBox["y", HoldForm]}], "-", 
                RowBox[{"0.5000000000000001`", " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              TagBox["y", HoldForm], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {(-1.0000000000000002`) HoldForm[$CellContext`x] - (
           0.5000000000000001 HoldForm[$CellContext`x]) 
          HoldForm[$CellContext`y] - 0.5000000000000001 
          HoldForm[$CellContext`y]^2 == 0, HoldForm[$CellContext`y] == 0}, 
        "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
         Dashing[{Small, Small}], 
         LineBox[{147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
          159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 
          172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 
          185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 
          198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 
          211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 
          224, 225, 226, 227, 228, 229, 230, 231}]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{"-", "1.0000000000000002`"}], " ", 
                  TagBox["x", HoldForm]}], "-", 
                RowBox[{"0.5000000000000001`", " ", 
                  TagBox["x", HoldForm], " ", 
                  TagBox["y", HoldForm]}], "-", 
                RowBox[{"0.5000000000000001`", " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              TagBox["y", HoldForm], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {(-1.0000000000000002`) HoldForm[$CellContext`x] - (
           0.5000000000000001 HoldForm[$CellContext`x]) 
          HoldForm[$CellContext`y] - 0.5000000000000001 
          HoldForm[$CellContext`y]^2 == 0, HoldForm[$CellContext`y] == 0}, 
        "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->Small,
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-5, 5}, {-5, 5}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxt1Xs8VOkfB/AhUcuvEkpRSaKbS+kXtq1vREWlbVsZtWZjoxJdtC5td1ak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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], AbsoluteThickness[1.6], 
         LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
          35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
          52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
          69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
          86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96}], 
         LineBox[{97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 
          109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 
          122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 
          135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 
          148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 
          161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 
          174, 175}]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"-", "0.4105475449967975`"}], "+", 
                RowBox[{"0.544729935250067`", " ", 
                  TagBox["x", HoldForm]}], "+", 
                RowBox[{"0.8292972572606271`", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"]}], "-", 
                RowBox[{"0.3573993017044993`", " ", 
                  TagBox["y", HoldForm]}], "-", 
                RowBox[{"1.0882099237463128`", " ", 
                  TagBox["x", HoldForm], " ", 
                  TagBox["y", HoldForm]}], "-", 
                RowBox[{"0.15252805926335045`", " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              TagBox["y", HoldForm], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {-0.4105475449967975 + 
          0.544729935250067 HoldForm[$CellContext`x] + 
          0.8292972572606271 HoldForm[$CellContext`x]^2 - 0.3573993017044993 
          HoldForm[$CellContext`y] - (1.0882099237463128` 
           HoldForm[$CellContext`x]) HoldForm[$CellContext`y] - 
          0.15252805926335045` HoldForm[$CellContext`y]^2 == 0, 
         HoldForm[$CellContext`y] == 0}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
         Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwN0Gk2ggEAAMCvdJGu1Hsu4AC6GhEhlSzZ2ij7msoaiRCF+TEXmOhEPDYZ
CoJgnCmmSTDDLEnmmCfFAosskWaZDFlyrJBnlTXW2aDAJltss8MuRUqUqVBl
j31q1DngkCOOOeGUM8654JIrrmlwQ5MWbW65454HHnmiwzMvdHmlxxvv9Png
ky8GfPPDkBG//BGIDBFmjAj/ENBFcA==
          "]]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"-", "0.4105475449967975`"}], "+", 
                RowBox[{"0.544729935250067`", " ", 
                  TagBox["x", HoldForm]}], "+", 
                RowBox[{"0.8292972572606271`", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"]}], "-", 
                RowBox[{"0.3573993017044993`", " ", 
                  TagBox["y", HoldForm]}], "-", 
                RowBox[{"1.0882099237463128`", " ", 
                  TagBox["x", HoldForm], " ", 
                  TagBox["y", HoldForm]}], "-", 
                RowBox[{"0.15252805926335045`", " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              TagBox["y", HoldForm], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {-0.4105475449967975 + 
          0.544729935250067 HoldForm[$CellContext`x] + 
          0.8292972572606271 HoldForm[$CellContext`x]^2 - 0.3573993017044993 
          HoldForm[$CellContext`y] - (1.0882099237463128` 
           HoldForm[$CellContext`x]) HoldForm[$CellContext`y] - 
          0.15252805926335045` HoldForm[$CellContext`y]^2 == 0, 
         HoldForm[$CellContext`y] == 0}, "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->Small,
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-2, 2}, {-2, 2}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxtmHk8lPsXx8eSLKWNm1Jdym2RdFWI4ivlapFKJRVKKZQWirRIpMiVWyRF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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0, 0, 1], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FV4EAQUBeCNUaNjdIwBg7HRICEgDZLKaJAGCZXukO5UaVAE6e6Q7kYa
CVG6EYMG4d/nw3/u83k4N6xlp+iOgQEBAR+ImBuLIGITh7jEIz7BJCAhiUhM
EpKSjOSkICUhpCI1aUhLOtKTgYxkIjOhZCGMrGQjO+HkICcR5CKSKHKTh7zk
Iz8FKEghCsd0oghFKUZxPqQEJSnFR5SmDGUpR3kqUJFKVOZjqlCValSnBjX5
hE+pRTS1qUNd6lGfBjSkEY35jCY0pRnNaUFLWtGaNnxOW9rRng58wZd8RUc6
0ZkudKUb3elBT3rRmz70pR/9GcDXDGQQgxnCUIYxnBGMZBSjGcNYxjGeCUxk
Et/wLd8xmSlMZRrTmcFMZjGb7/mBOfzIXObxE/NZwEIWsZglLGUZy1nBSlax
mjWsZR3r2cBGNrGZLfzMVraxnR3sZBe72cNe9rGfAxzkEIc5wlGOcZwT/MJJ
TnGaM5zlHOe5wK9c5BKXucJvXOV3/uAa17nBTW5xmzvc5R73ecBDHvGYP3nC
X/zNP/zLU57xnBe85BWvecNb/uMdMeMPJBZBxCYOcYlHfIJJQEISkZgkJCUZ
yUlBSkJIRWrSkJZ0pCcDGclEZkLJQhhZyUZ2wslBTiLIRSRR5CYPeclHfgpQ
kEIUDvz/p70HUKmHNw==
          "]]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"-", "2.294780758013289`"}], "-", 
                RowBox[{"7.198596857845491`", " ", 
                  TagBox["x", HoldForm]}], "-", 
                RowBox[{"4.635408034530393`", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"]}], "+", 
                RowBox[{"4.723025711933947`", " ", 
                  TagBox["y", HoldForm]}], "+", 
                RowBox[{"6.082616311130605`", " ", 
                  TagBox["x", HoldForm], " ", 
                  TagBox["y", HoldForm]}], "-", 
                RowBox[{"2.5049307116095973`", " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              TagBox["y", HoldForm], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {-2.294780758013289 - 7.198596857845491 
          HoldForm[$CellContext`x] - 4.635408034530393 
          HoldForm[$CellContext`x]^2 + 
          4.723025711933947 
           HoldForm[$CellContext`y] + (6.082616311130605 
            HoldForm[$CellContext`x]) HoldForm[$CellContext`y] - 
          2.5049307116095973` HoldForm[$CellContext`y]^2 == 0, 
         HoldForm[$CellContext`y] == 0}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
         Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz9k2QgEAQNHbp/QTCFFISippEDKUKVMoQ8kUJb7a7mGvdV5PuN4q3ISC
ICgxJaaZIcIsc8wTZYFFYsRZYpkVEqySZI0UadbJsEGWHHk2KbBFkRJlKmxT
ZYdd9qixzwGHHFGnwTEnnHLGOU0uuOSKayajLW654542HR545IlnuvR4oc8r
b7zzwScDvvhmyIgfxvzyxz9McyI+
          "]]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"-", "2.294780758013289`"}], "-", 
                RowBox[{"7.198596857845491`", " ", 
                  TagBox["x", HoldForm]}], "-", 
                RowBox[{"4.635408034530393`", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"]}], "+", 
                RowBox[{"4.723025711933947`", " ", 
                  TagBox["y", HoldForm]}], "+", 
                RowBox[{"6.082616311130605`", " ", 
                  TagBox["x", HoldForm], " ", 
                  TagBox["y", HoldForm]}], "-", 
                RowBox[{"2.5049307116095973`", " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              TagBox["y", HoldForm], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {-2.294780758013289 - 7.198596857845491 
          HoldForm[$CellContext`x] - 4.635408034530393 
          HoldForm[$CellContext`x]^2 + 
          4.723025711933947 
           HoldForm[$CellContext`y] + (6.082616311130605 
            HoldForm[$CellContext`x]) HoldForm[$CellContext`y] - 
          2.5049307116095973` HoldForm[$CellContext`y]^2 == 0, 
         HoldForm[$CellContext`y] == 0}, "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->Small,
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-2, 2}, {-2, 2}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729351193433771*^9, 3.729351193457686*^9}, 
   3.733054561651327*^9, {3.73305467465877*^9, 3.733054709399184*^9}, 
   3.733054756176057*^9, 3.73305481341199*^9, {3.733055584353405*^9, 
   3.7330556086678534`*^9}, {3.733055730595402*^9, 3.733055791453751*^9}, {
   3.733055837708343*^9, 3.7330558664616613`*^9}, 3.733159964101403*^9, 
   3.733160788789814*^9, {3.733160975925063*^9, 3.733160998407544*^9}, {
   3.7331610729747257`*^9, 3.7331610943816137`*^9}, 3.733161265276774*^9, 
   3.7331615534913387`*^9, 3.733161766301476*^9, {3.733162003510056*^9, 
   3.733162017202352*^9}, 3.733162064093418*^9, 3.733162098666705*^9, 
   3.733511919853177*^9},
 CellLabel->"Out[61]=",
 CellID->1730411514,ExpressionUUID->"e7926b3f-8341-4ba9-b357-bb7fa8ba9e84"]
}, Open  ]],

Cell[TextData[{
 "In these examples, the dashed line is the original infinite line. In the \
first case, ",
 Cell[BoxData[
 "ip2z"], "InlineCodeText",ExpressionUUID->
  "0f9cd057-d817-4f59-9945-3bd2721a6183"],
 " shows the intersection of the hyperbola with the infinite line at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"4d403ef8-48bb-4f32-879f-bb45b45e28bd"],
 ". The infinite line is now at the origin, but the intersection with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"c4192b57-73a6-428c-8730-aab13b0d9e07"],
 " remains infinite under the transformation and the transformed equation is \
actually a parabola. In the second of the two cases, both of the original \
infinite points are shown, but we get a hyperbola (or ellipse, depending on \
whether the removed line intersects the original hyperbola in two or zero \
points). It was Johann Kepler who first noted in 1604 that the parabola, \
hyperbola and ellipse were the same except for the number of infinite points. \
We will say more on conics and rational function curves in Chapter 7. "
}], "Text",
 CellChangeTimes->{{3.694438655377232*^9, 3.694438941282568*^9}, {
   3.694438995564265*^9, 3.694439027412226*^9}, {3.694527709608041*^9, 
   3.694527709767002*^9}, {3.694527814735356*^9, 3.694527824159694*^9}, {
   3.694527915329773*^9, 3.694528050854365*^9}, {3.72280002776707*^9, 
   3.722800030341094*^9}, {3.722800067950081*^9, 3.722800084773703*^9}, {
   3.7228001408099947`*^9, 3.722800166221386*^9}, 3.722800282539701*^9, {
   3.7228003547086678`*^9, 3.722800419209652*^9}, {3.7290233611738157`*^9, 
   3.729023371252652*^9}, {3.729348369589342*^9, 3.729348377341164*^9}, {
   3.729352225972584*^9, 3.729352226146694*^9}, {3.737994974873238*^9, 
   3.737994982808733*^9}, {3.737995030961193*^9, 3.7379950841450243`*^9}, 
   3.738508416951152*^9},ExpressionUUID->"b957dc3d-73e4-44c9-9e83-\
ddabffe5b12e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.4 Applications", "Subsection",
 CellChangeTimes->{{3.69453710552818*^9, 3.694537128234323*^9}, 
   3.729352226181313*^9},ExpressionUUID->"4aaffe78-1fc3-4f5b-a209-\
241b71ed68a7"],

Cell["\<\
I will give three important applications of FLTs here. In the next chapter, I \
will give applications to classical mathematics.\
\>", "Text",
 CellChangeTimes->{{3.694537136515089*^9, 3.694537225012928*^9}, {
   3.694537278511091*^9, 3.694537280535412*^9}, {3.7228004650305653`*^9, 
   3.722800471190694*^9}, 3.729352226214919*^9, 
   3.737995093816313*^9},ExpressionUUID->"6203e6ce-69c8-4393-b142-\
7a9ba185640b"],

Cell[CellGroupData[{

Cell["Projective Singular Points", "Subsubsection",
 CellChangeTimes->{{3.694537229531191*^9, 3.694537274551769*^9}, 
   3.729348734035391*^9},ExpressionUUID->"75106c9c-a408-4d76-8c03-\
a2afb466d36c"],

Cell[TextData[{
 "In Chapter 5, we saw that it was important to find all complex projective \
singular points in order to decide if a curve is nonsingular. To properly \
describe the projective graph of a curve, it is necessary to have at least \
all real projective singular points. The method of Chapter 5 required \
checking for singular points in all three specializations. Using FLTs, we \
will see that it is usually enough to check once. The strategy is to pick a \
random affine line and remove it from the projective plane. We get the image \
of this specialization by using FLT. We then use the procedure below for \
finding all complex affine singular points. This procedure has a fourth \
parameter, ",
 Cell[BoxData[
 "eps"], "InlineCodeText",ExpressionUUID->
  "df32699e-c885-4d2f-a6bb-6a3a137ed0bb"],
 ", which gives a tolerance. If you think the curve has no singular points, \
use a very loose tolerance such as ",
 Cell[BoxData[
  RowBox[{"eps", "=", ".01"}]], "InlineCodeText",ExpressionUUID->
  "83f7e40d-be92-4ac3-9ef7-8f7a6996c8c0"],
 StyleBox[" ", "Input"],
 "to be sure you get all the singular points available. If the result is the \
empty set ",
 Cell[BoxData[
  RowBox[{"{", "\[ThickSpace]", "}"}]], "InlineCodeText",ExpressionUUID->
  "8ea1020c-bea5-4356-9f83-52c7838f19a7"],
 ", you can be fairly confident that the curve is nonsingular. However, you \
may get some false singular points, but by decreasing the tolerance, the \
false ones will be eliminated. Also note that singular points that appear on \
one run of the algorithm but not others are probably false, but be careful \
with infinite points that are only defined up to a constant. "
}], "Text",
 CellChangeTimes->{{3.694537297572931*^9, 3.69453733342385*^9}, {
   3.694537378257437*^9, 3.694537678770455*^9}, {3.694537746764295*^9, 
   3.694537818894257*^9}, {3.694538289754666*^9, 3.69453835599299*^9}, {
   3.694866653851745*^9, 3.694866834938349*^9}, {3.694866871080173*^9, 
   3.694866947305395*^9}, {3.694866984410363*^9, 3.694867139865597*^9}, {
   3.694868120038208*^9, 3.694868142477675*^9}, {3.694872927610407*^9, 
   3.694872955834962*^9}, {3.694873016224552*^9, 3.694873045708204*^9}, {
   3.694873183470602*^9, 3.694873189989619*^9}, {3.694873237621279*^9, 
   3.694873260181678*^9}, {3.722800495953668*^9, 3.72280056631376*^9}, {
   3.722800637494329*^9, 3.7228007354004307`*^9}, {3.722800766662669*^9, 
   3.722800778553154*^9}, {3.7228008326164494`*^9, 3.722800842005397*^9}, 
   3.72280087374962*^9, 3.7228584537645283`*^9, {3.729023388582615*^9, 
   3.729023450944628*^9}, {3.729352226252452*^9, 3.7293522266417503`*^9}, {
   3.737995104347435*^9, 3.737995116777474*^9}, {3.73799515346592*^9, 
   3.737995209569252*^9}, {3.7385084801765337`*^9, 3.738508481423876*^9}, 
   3.738508529134885*^9},ExpressionUUID->"82842fcc-0e0d-4e3a-afe9-\
0052f51548c1"],

Cell["\<\
Note that the last third of this procedure is devoted to displaying the \
points nicely, encouraging infinite singular points to display as infinite \
and real points to display as real.\
\>", "Text",
 CellChangeTimes->{{3.694537297572931*^9, 3.69453733342385*^9}, {
   3.694537378257437*^9, 3.694537678770455*^9}, {3.694537746764295*^9, 
   3.694537818894257*^9}, {3.694538289754666*^9, 3.69453835599299*^9}, {
   3.694866653851745*^9, 3.694866834938349*^9}, {3.694866871080173*^9, 
   3.694866947305395*^9}, {3.694866984410363*^9, 3.694867139865597*^9}, {
   3.694868120038208*^9, 3.694868142477675*^9}, {3.694872927610407*^9, 
   3.694872955834962*^9}, {3.694873016224552*^9, 3.694873045708204*^9}, {
   3.694873183470602*^9, 3.694873189989619*^9}, {3.694873237621279*^9, 
   3.694873260181678*^9}, {3.722800495953668*^9, 3.72280056631376*^9}, {
   3.722800637494329*^9, 3.7228007354004307`*^9}, {3.722800766662669*^9, 
   3.722800778553154*^9}, {3.7228008326164494`*^9, 3.722800842005397*^9}, 
   3.72280087374962*^9, 3.7228584537645283`*^9, {3.729023388582615*^9, 
   3.729023457187429*^9}, 3.72934839716149*^9, {3.737995254208139*^9, 
   3.7379952645519447`*^9}, {3.738508568390541*^9, 3.73850857618999*^9}},
 CellID->533988008,ExpressionUUID->"9d87ac13-e599-43c8-9186-33d59364909d"],

Cell["For a complete list of global functions, see Appendix 2:", "CodeCaption",
 CellChangeTimes->{{3.694537297572931*^9, 3.69453733342385*^9}, {
   3.694537378257437*^9, 3.694537678770455*^9}, {3.694537746764295*^9, 
   3.694537818894257*^9}, {3.694538289754666*^9, 3.69453835599299*^9}, {
   3.694866653851745*^9, 3.694866834938349*^9}, {3.694866871080173*^9, 
   3.694866947305395*^9}, {3.694866984410363*^9, 3.694867139865597*^9}, {
   3.694868120038208*^9, 3.694868142477675*^9}, {3.694872927610407*^9, 
   3.694872955834962*^9}, {3.694873016224552*^9, 3.694873045708204*^9}, {
   3.694873183470602*^9, 3.694873189989619*^9}, {3.694873237621279*^9, 
   3.694873260181678*^9}, {3.722800495953668*^9, 3.72280056631376*^9}, {
   3.722800637494329*^9, 3.7228007354004307`*^9}, {3.722800766662669*^9, 
   3.722800778553154*^9}, {3.7228008326164494`*^9, 3.722800842005397*^9}, 
   3.72280087374962*^9, 3.7228584537645283`*^9, {3.729023388582615*^9, 
   3.729023457187429*^9}, 3.72934839716149*^9, {3.737995254208139*^9, 
   3.7379952645519447`*^9}, {3.738508568390541*^9, 3.7385085724938917`*^9}},
 CellID->1796972018,ExpressionUUID->"f381f1e6-6a56-4c90-95b0-14007181da59"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"complexProjectiveSingularPoints", "[", 
    RowBox[{"h_", ",", "u_", ",", "v_", ",", "eps_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "f", ",", "w", ",", "A", ",", "a", ",", "b", ",", "sol1", ",", "sol2", 
       ",", "solz", ",", "sing", ",", "sing1", ",", "sing2"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"A", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"1", ",", "2"}], "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}]}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"f", "=", 
       RowBox[{"FLT", "[", 
        RowBox[{"h", ",", "A", ",", "u", ",", "v"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "=", 
       RowBox[{"RandomComplex", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "-", "I"}], ",", 
           RowBox[{"1", "+", "I"}]}], "}"}], ",", "2"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sol1", "=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v"}], "}"}], "/.", 
        RowBox[{"NSolve", "[", 
         RowBox[{"{", 
          RowBox[{"f", ",", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"D", "[", 
              RowBox[{"f", ",", "u"}], "]"}]}], "+", 
            RowBox[{"b", " ", 
             RowBox[{"D", "[", 
              RowBox[{"f", ",", "v"}], "]"}]}]}]}], "}"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "=", 
       RowBox[{"RandomComplex", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "-", "I"}], ",", 
           RowBox[{"1", "+", "I"}]}], "}"}], ",", "2"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sol2", "=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v"}], "}"}], "/.", 
        RowBox[{"NSolve", "[", 
         RowBox[{"{", 
          RowBox[{"f", ",", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"D", "[", 
              RowBox[{"f", ",", "u"}], "]"}]}], "+", 
            RowBox[{"b", " ", 
             RowBox[{"D", "[", 
              RowBox[{"f", ",", "v"}], "]"}]}]}]}], "}"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"solz", "=", 
       RowBox[{"Join", "[", 
        RowBox[{"sol1", ",", "sol2"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"sing", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"Select", "[", 
            RowBox[{
             RowBox[{"Tally", "[", 
              RowBox[{"solz", ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"Norm", "[", 
                  RowBox[{"#1", "-", "#2"}], "]"}], "<", "eps"}], "&"}]}], 
              "]"}], ",", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ">", "1"}], "&"}]}], "]"}], 
           ",", "All", ",", "1"}], "]"}], ",", "1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sing1", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"sing", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"sing", "[", 
                RowBox[{"[", 
                 RowBox[{"j", ",", "2"}], "]"}], "]"}], "]"}], ">", "eps"}], 
             ",", 
             RowBox[{"sing", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "0"}], "]"}]}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"Length", "[", "sing", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sing2", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"flti", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Inverse", "[", "A", "]"}]}], "]"}], "&"}], "/@", 
        "sing1"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"sing2", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Which", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "p", "]"}], "\[Equal]", "2"}], ",", "p", 
           ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"p", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], ">", "eps"}], ",", 
           RowBox[{"p", "/", 
            RowBox[{"p", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"p", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "]"}], ">", "eps"}], ",", 
           RowBox[{"p", "/", 
            RowBox[{"p", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], ",", "True", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", 
             RowBox[{"p", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"p", ",", "sing2"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Chop", "[", 
       RowBox[{"sing2", ",", "eps"}], "]"}]}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694792048573609*^9, 3.694792064357045*^9}, {
   3.694792094919752*^9, 3.694792095959068*^9}, {3.694792170001564*^9, 
   3.694792173744549*^9}, {3.694792209161067*^9, 3.694792277002443*^9}, {
   3.69479231917668*^9, 3.694792343908025*^9}, 3.694792442185147*^9, {
   3.69486649176984*^9, 3.694866559932989*^9}, {3.694870429822021*^9, 
   3.694870545990263*^9}, {3.694870582688156*^9, 3.694870695692214*^9}, {
   3.694870901160727*^9, 3.694870905399963*^9}, {3.694871165212325*^9, 
   3.69487117812636*^9}, {3.694871263816445*^9, 3.694871264920814*^9}, 
   3.718545085104959*^9, {3.718546149980517*^9, 3.718546158246486*^9}, 
   3.733055908295711*^9, {3.733057139153462*^9, 3.733057140063492*^9}, {
   3.733057205689992*^9, 3.7330572065039473`*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"0ec05a6f-8863-4a01-a986-fda3240910d2"],

Cell["Here is an example:", "CodeCaption",
 CellChangeTimes->{{3.694867199560844*^9, 3.694867206194897*^9}, 
   3.722881443963665*^9, {3.738508601294552*^9, 
   3.738508604981844*^9}},ExpressionUUID->"a45ba8a5-ee14-49d8-919b-\
5d00473d1794"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fs", "=", 
   RowBox[{
    RowBox[{"-", "1"}], "-", 
    RowBox[{"x", " ", "y"}], "+", 
    RowBox[{
     SuperscriptBox["x", "3"], " ", "y"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.694867209738583*^9, 3.694867225301798*^9}, 
   3.7331616847023582`*^9},
 CellLabel->"In[63]:=",ExpressionUUID->"4d49cf11-1336-49df-8d79-9498642b2284"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sing", "=", 
  RowBox[{"complexProjectiveSingularPoints", "[", 
   RowBox[{"fs", ",", "x", ",", "y", ",", ".1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694867230881628*^9, 3.694867248518291*^9}, {
   3.694867457457383*^9, 3.694867460088902*^9}, {3.718545902445704*^9, 
   3.718545907597149*^9}, {3.718546038217088*^9, 3.718546055721437*^9}, {
   3.733057210902157*^9, 3.733057217775114*^9}, 3.733161691469049*^9},
 CellLabel->"In[64]:=",ExpressionUUID->"e79be2b0-bc96-40c0-815b-686f1c18a2c0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.6626579250627278`", ",", 
     RowBox[{"-", "2.6904652547179415`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.694867251483711*^9, 3.694867464714139*^9, 3.718545812029729*^9, {
   3.718545862252677*^9, 3.718545880131156*^9}, {3.718545911251322*^9, 
   3.718546011136308*^9}, {3.718546043142866*^9, 3.718546062009735*^9}, 
   3.718546271197817*^9, {3.733055956810281*^9, 3.733055979412692*^9}, {
   3.7330560743621817`*^9, 3.7330560975774803`*^9}, {3.7330572130348463`*^9, 
   3.733057230784258*^9}, 3.7331607894466667`*^9, 3.733161265681568*^9, {
   3.733161361542117*^9, 3.733161401681621*^9}, 3.7331615539388933`*^9, {
   3.73316161314675*^9, 3.733161629338066*^9}, 3.7331617229252462`*^9, 
   3.733161766799925*^9},
 CellLabel->"Out[64]=",
 CellID->1329001556,ExpressionUUID->"6f6202fa-3fc4-4d53-9c82-bd803683ea5d"]
}, Open  ]],

Cell["\<\
Here, each time you run this, you will probably get a different answer. You \
will often get two finite real answers that are near turning points that do \
not look singular:\
\>", "CodeCaption",
 CellChangeTimes->{{3.694867312476244*^9, 3.694867328614748*^9}, 
   3.694867483616736*^9, {3.694867530968637*^9, 3.694867569793909*^9}, {
   3.722881468687439*^9, 3.722881470871224*^9}, {3.7330561148916616`*^9, 
   3.7330561725927963`*^9}, 3.734101594408197*^9, 3.73411027970728*^9, {
   3.73799537453729*^9, 
   3.737995405439563*^9}},ExpressionUUID->"dea2ed95-f5a1-4ffd-a10e-\
68c7fea530f7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"fs", "\[Equal]", "0"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694869974317312*^9, 3.694869985170769*^9}, {
  3.694870084854042*^9, 3.694870115734226*^9}, {3.694870153946082*^9, 
  3.694870228902558*^9}, {3.7331616946417837`*^9, 3.7331617140649137`*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"f3d764d0-09d7-4508-a96d-aee6f3f4e42e"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxF2QlcTVsXAPDSXLdUNyQ9KtPDQz0zsbYQIZJnyBSJh2Qen94jkTzzlCmZ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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179}], LineBox[CompressedData["
1:eJwt0FdbDgAAgNGvlFS2srJCJSQRZZQVKUoiRSGJXPHnImSVkTKKykgIkcqW
rJRz0cV53vs3tuJM4emgQCBwlurRnqOG81zgIrVc4jJXuMo16qjnOje4yS0a
uE0jTdzhLve4TzMtPOAhrbTRziMe84SndPCMTp7zgpd08YrXvKGbt7yjh/f0
0kc/H/jIJz7zha984zsD/GCQn/ziN3/4yxD/GGaEgHFBBDOGEEIZSxjjCCeC
SMYzgYlMYjJTmMo0oohmOjOYySxmE8Mc5jKP+SwgloUsYjFxxJPAEhJZyjKW
k8QKkllJCqtYTSprWEsa6axjPRvYSAaZbGIzW9jKNrLYzg6y2UkOuexiN3nk
s4cC9lLIPvZTxAGKKeEghyiljMMc4SjlHKOC41RygpNUcYr/mDNYuA==
        "]], 
       LineBox[CompressedData["
1:eJwVyec2FgAAgOHPpbgll9A/q8+OzD6bhEhkZu89K6PMqJC9Z8RVePx4znnP
ecNfBCNehgUCgRCRIopoYojleQaJI54EEkkimRRekUoar0kng0yyyCaHN4TI
JY98CiikiGJKKOUtZbyjnAoqeU8V1Xygho/UUscn6mmgkSaaaeEzrbTRTged
dNFND7300c8AgwwxzAijjDHOBJNMMc0MX/jKN2aZY54FvvODRZZYZoVV1vjJ
Ohv84jd/2GSLbf6ywy577HPAIUccc8IpZ5xzwSVXXHPDLf+4457/PPDIEwYx
WMs=
        "]], LineBox[CompressedData["
1:eJwVzMVWVQEAQNFLIx0iKOWjQ6REukTpbqQbJvoJfDDdHZvBXuuMTmjj/+S/
sCAIDjgURxxzwilnnHPBJVdcc8Mtd9zzwCNPPPPC6/s4PAjCCCeCSKKIJoZY
PhBHPAkkkkQyKaSSRjofyeATmWTxmS9kk0MueeTzlRAFFFJEMSWUUkY5FVTy
jSq+U00NtdRRzw8a+EkjTTTTQitttNNBJ11084sefvOHXvroZ4BBhhhmhFHG
GGeCSaaYZoZZ5phngb8sssQyK6yyxjobbLLFNjvsssc+bxo+LPI=
        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{
            TagBox["x", HoldForm], " ", 
            TagBox["y", HoldForm]}], "+", 
          RowBox[{
            SuperscriptBox[
             TagBox["x", HoldForm], "3"], " ", 
            TagBox["y", HoldForm]}]}], "\[Equal]", "0"}]],
     Annotation[#, -1 - HoldForm[$CellContext`x] HoldForm[$CellContext`y] + 
       HoldForm[$CellContext`x]^3 HoldForm[$CellContext`y] == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
  PlotRange->{{-5, 5}, {-5, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.733161715894882*^9, 3.7331617252255983`*^9}, 
   3.733161766907566*^9, 3.73351192039476*^9},
 CellLabel->"Out[65]=",
 CellID->277084545,ExpressionUUID->"65e98cea-4b09-4228-a66c-9758bd1e1ed2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sing", "=", 
  RowBox[{"complexProjectiveSingularPoints", "[", 
   RowBox[{"f", ",", "x", ",", "y", ",", ".0001"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694867644931187*^9, 3.694867645299368*^9}, {
  3.733057151378131*^9, 3.7330571520199757`*^9}, {3.733057239994*^9, 
  3.7330572405838127`*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"4bc09036-ebb4-4670-9cc8-043e8e0a7d19"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{{3.733057302596292*^9, 3.733057310984132*^9}, 
   3.733160790078782*^9, 3.733161266581582*^9, 3.7331614101499367`*^9, 
   3.733161554780059*^9, 3.733161729222062*^9, 3.733161766983275*^9, 
   3.733511920447329*^9},
 CellLabel->"Out[66]=",
 CellID->1215401119,ExpressionUUID->"72ac3328-1c59-4438-ac4d-6022de802fd7"]
}, Open  ]],

Cell[TextData[{
 "Our next examples involve perturbing curve ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]], "InlineMath",ExpressionUUID->
  "7ad7d6ee-82e1-4d2b-bb4c-d40f59f0dba3"],
 " slightly. In the affine real case, we saw that a small perturbation of a \
curve with a singular point often made the singular point appear to vanish. \
We now explore the complex projective case."
}], "Text",
 CellChangeTimes->{{3.733056271376614*^9, 3.733056328574418*^9}, {
  3.73305636577285*^9, 3.73305645293895*^9}, {3.733060781393888*^9, 
  3.733060784131691*^9}, {3.7341015944499083`*^9, 3.734101594491497*^9}, {
  3.7379954909914227`*^9, 3.7379955052074423`*^9}, {3.738508678198241*^9, 
  3.738508679573744*^9}},
 CellID->1164661911,ExpressionUUID->"d5bdcbab-7749-4363-8e0a-5db47a3aec63"],

Cell[TextData[{
 "The second run with tighter tolerance indicates that the infinite point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"f0084175-eab2-4c68-8f68-437d07d71741"],
 " is probably the only singular point:"
}], "CodeCaption",
 CellChangeTimes->{{3.694867654025368*^9, 3.69486772921901*^9}, {
  3.722881512721423*^9, 3.7228815130733757`*^9}, {3.733056190178627*^9, 
  3.733056216608974*^9}, {3.738510757722459*^9, 3.738510770395433*^9}},
 CellID->254362753,ExpressionUUID->"cc7bd85a-e4f9-471b-817f-9f37b38167db"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SuperscriptBox["x", "2"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "3"]}], "-", "y", "+", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h", "=", 
   RowBox[{
    RowBox[{"-", "0.9975`"}], "+", 
    SuperscriptBox["x", "2"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"0.9925`", " ", "y"}], "+", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"0.0075`", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"0.0025`", " ", 
     SuperscriptBox["y", "3"]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7330603080280037`*^9, 3.733060358044105*^9}, {
  3.733060452724161*^9, 3.733060485757999*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"3bee4e76-34bb-4e7d-bfdb-52e80e1881f3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"singg", "=", 
  RowBox[{"complexProjectiveSingularPoints", "[", 
   RowBox[{"g", ",", "x", ",", "y", ",", ".01"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"singh", " ", "=", 
  RowBox[{"complexProjectiveSingularPoints", "[", 
   RowBox[{"h", ",", "x", ",", "y", ",", ".01"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.733057121246439*^9, 3.7330571287033043`*^9}, {
  3.7330573259483833`*^9, 3.733057333842059*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"f4e71d9f-5d90-410e-ac76-1ec888df4fd8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0.9999999999999999`", ",", "0"}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7293506960133142`*^9, 3.729350982389426*^9, 3.729351044742578*^9, 
   3.729351105162003*^9, 3.7330562389811783`*^9, 3.7330564602129498`*^9, 
   3.733056520758877*^9, 3.7330571710044813`*^9, {3.733057329874156*^9, 
   3.733057335048769*^9}, 3.7330603628324842`*^9, 3.73306051426754*^9, 
   3.733160790234517*^9, 3.7331612667472553`*^9, 3.733161418694056*^9, 
   3.7331615549240723`*^9, 3.733161767153576*^9, 3.7335119205497313`*^9},
 CellLabel->"Out[69]=",
 CellID->382156769,ExpressionUUID->"09158212-5c62-4e7b-8eaa-867eaf6c6c84"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{
  3.7293506960133142`*^9, 3.729350982389426*^9, 3.729351044742578*^9, 
   3.729351105162003*^9, 3.7330562389811783`*^9, 3.7330564602129498`*^9, 
   3.733056520758877*^9, 3.7330571710044813`*^9, {3.733057329874156*^9, 
   3.733057335048769*^9}, 3.7330603628324842`*^9, 3.73306051426754*^9, 
   3.733160790234517*^9, 3.7331612667472553`*^9, 3.733161418694056*^9, 
   3.7331615549240723`*^9, 3.733161767153576*^9, 3.733511920630587*^9},
 CellLabel->"Out[70]=",
 CellID->1932712053,ExpressionUUID->"750eb5df-1311-45a5-b1dd-b6fe130c6346"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"singg", "=", 
  RowBox[{"complexProjectiveSingularPoints", "[", 
   RowBox[{"g", ",", "x", ",", "y", ",", ".000001"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"singh", " ", "=", 
  RowBox[{"complexProjectiveSingularPoints", "[", 
   RowBox[{"h", ",", "x", ",", "y", ",", ".000001"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.733056562452935*^9, 3.733056587930635*^9}, {
  3.7330566323285007`*^9, 3.733056645836832*^9}, {3.7330566803539953`*^9, 
  3.733056684171715*^9}, {3.733057158187969*^9, 3.7330571632139587`*^9}, {
  3.733057343404015*^9, 3.733057354619454*^9}, {3.733060527164811*^9, 
  3.7330605340737543`*^9}},
 CellLabel->"In[71]:=",ExpressionUUID->"c3e0c2cc-68a0-4564-bd9e-30a04c6dcf54"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.729350696064168*^9, 3.7293509824399357`*^9, 3.729351044792636*^9, 
   3.72935110521192*^9, {3.733056466167828*^9, 3.733056532899702*^9}, {
   3.73305656381151*^9, 3.733056588955097*^9}, {3.733056633887053*^9, 
   3.733056651049499*^9}, 3.733056686632304*^9, 3.7330571641064034`*^9, {
   3.73305734572581*^9, 3.733057355787354*^9}, 3.7330603714724693`*^9, {
   3.733060520601066*^9, 3.733060534967404*^9}, 3.733160790471363*^9, 
   3.733161267021534*^9, 3.7331614231577673`*^9, 3.733161555172246*^9, 
   3.7331617674554653`*^9, 3.733511920711794*^9},
 CellLabel->"Out[71]=",
 CellID->253830249,ExpressionUUID->"5da8ad83-2c18-4066-8af9-f1480f1c55b9"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{
  3.729350696064168*^9, 3.7293509824399357`*^9, 3.729351044792636*^9, 
   3.72935110521192*^9, {3.733056466167828*^9, 3.733056532899702*^9}, {
   3.73305656381151*^9, 3.733056588955097*^9}, {3.733056633887053*^9, 
   3.733056651049499*^9}, 3.733056686632304*^9, 3.7330571641064034`*^9, {
   3.73305734572581*^9, 3.733057355787354*^9}, 3.7330603714724693`*^9, {
   3.733060520601066*^9, 3.733060534967404*^9}, 3.733160790471363*^9, 
   3.733161267021534*^9, 3.7331614231577673`*^9, 3.733161555172246*^9, 
   3.7331617674554653`*^9, 3.7335119207926817`*^9},
 CellLabel->"Out[72]=",
 CellID->1222472001,ExpressionUUID->"ce235c5f-c695-4ace-b368-f86a4a2cc52f"]
}, Open  ]],

Cell[TextData[{
 "Here, ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]], "InlineMath",ExpressionUUID->
  "3d20bdc6-7950-48f1-bc48-56b462894369"],
 " has an infinite singular point, but ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]], "InlineMath",ExpressionUUID->
  "cdd17c8a-7eb0-4d67-9320-789f093c4f13"],
 ", which is ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]], "InlineMath",ExpressionUUID->
  "22e11bb4-fade-4fd9-acc5-a2b824e96cac"],
 " with a small perturbation, has no singular points, real or complex."
}], "Text",
 CellChangeTimes->{{3.733060608541924*^9, 3.7330606092612677`*^9}, {
   3.733060676441986*^9, 3.733060770850266*^9}, 3.737995530631295*^9, {
   3.737995563814661*^9, 3.7379955716712627`*^9}},
 CellID->1716536722,ExpressionUUID->"c080e793-825c-4114-b055-5b1a5cefbefb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Projective Complex Intersection Points", "Subsubsection",
 CellChangeTimes->{{3.694537229531191*^9, 3.694537274551769*^9}, {
   3.694872526461699*^9, 3.69487253066979*^9}, {3.694872603880808*^9, 
   3.694872613985166*^9}, 
   3.729348723709487*^9},ExpressionUUID->"d7007205-086b-4e64-935c-\
3a56d22f5c95"],

Cell["\<\
The same technique works for finding all the complex projective intersection \
points of two curves.\
\>", "Text",
 CellChangeTimes->{{3.694872625594466*^9, 3.694872699254245*^9}, {
  3.694880803455082*^9, 3.694880865897891*^9}, {3.722881638906685*^9, 
  3.722881654738628*^9}, {3.722881687065546*^9, 3.722881704682067*^9}, {
  3.722881766690444*^9, 3.722881772490231*^9}, {3.729023647002775*^9, 
  3.729023650729422*^9}, {3.729348845732004*^9, 
  3.729348854686572*^9}},ExpressionUUID->"4e2009e8-89b8-4375-b7ec-\
fc1978e64532"],

Cell[TextData[{
 "In this case, ",
 ButtonBox["NSolve",
  BaseStyle->"Link"],
 " does the work of making the output look nice so we do not need the \
post-processing (For a complete list of global functions, see Appendix 2):"
}], "CodeCaption",
 CellChangeTimes->{{3.694872625594466*^9, 3.694872699254245*^9}, {
   3.694880803455082*^9, 3.694880865897891*^9}, {3.722881638906685*^9, 
   3.722881654738628*^9}, {3.722881687065546*^9, 3.722881704682067*^9}, {
   3.722881766690444*^9, 3.722881772490231*^9}, {3.729023647002775*^9, 
   3.729023650729422*^9}, {3.729348845732004*^9, 3.7293488667734756`*^9}, 
   3.743167270663822*^9},
 CellID->2123183291,ExpressionUUID->"1b13fbfd-e9f9-46da-89ae-32dff1751fb5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"complexProjectiveIntersectionpoints", "[", 
    RowBox[{"f_", ",", "g_", ",", "x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f1", ",", "g1", ",", "A", ",", "sol", ",", " ", "sol2"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"A", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"1", ",", "2"}], "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"RandomReal", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "3"}], "]"}]}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"f1", "=", 
       RowBox[{"FLT", "[", 
        RowBox[{"f", ",", "A", ",", "x", ",", "y"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"g1", "=", 
       RowBox[{"FLT", "[", 
        RowBox[{"g", ",", "A", ",", "x", ",", "y"}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"sol", "=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], "/.", 
        RowBox[{"NSolve", "[", 
         RowBox[{"{", 
          RowBox[{"f1", ",", "g1"}], "}"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"flti", "[", 
         RowBox[{"#", ",", 
          RowBox[{"Inverse", "[", "A", "]"}]}], "]"}], "&"}], "/@", 
       "sol"}]}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694881063665804*^9, 3.694881069305685*^9}, 
   3.733160003010277*^9, {3.7331602805143833`*^9, 3.7331602810479603`*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"048e87b7-6629-464a-b316-bdf084c9edda"],

Cell["A complicated example comes from Gauss curves:", "CodeCaption",
 CellChangeTimes->{{3.694880909444588*^9, 3.694880945092118*^9}, {
  3.722881715712871*^9, 3.72288171958454*^9}, {3.740753732923449*^9, 
  3.7407537330337143`*^9}},ExpressionUUID->"b78d96a9-b705-44a5-ad41-\
c02dc85aa9c5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{
    RowBox[{"-", "4"}], "-", 
    RowBox[{"20", " ", "x"}], "+", 
    SuperscriptBox["x", "2"], "+", 
    SuperscriptBox["x", "3"], "+", 
    SuperscriptBox["x", "5"], "-", 
    SuperscriptBox["y", "2"], "-", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{"10", " ", 
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"5", " ", "x", " ", 
     SuperscriptBox["y", "4"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{
    RowBox[{"16", " ", "x"}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["x", "3"]}], "+", 
    SuperscriptBox["x", "5"], "+", 
    RowBox[{"24", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{"10", " ", 
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"5", " ", "x", " ", 
     SuperscriptBox["y", "4"]}]}]}], ";"}]}], "Input",
 CellLabel->"In[74]:=",ExpressionUUID->"5d6bb617-a7f2-431e-b4b8-a37aa3a73a11"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "\[Equal]", "0"}], ",", 
     RowBox[{"g", "\[Equal]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[76]:=",ExpressionUUID->"55ce7e7b-6db1-41bf-898c-7ba0e6c25a6b"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJyFfXVYVc/39U06FBsDJGzsALk6A4pSImJ3twIqFhY2igEIiCgGiGCCKFjo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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl1FV4EAQUBeANGDBqxIiN2EZ3N0iIdKdISUuOEKSURkC6Q+luBEFppBuL
TqVUQLoR+Pfx8J/7el7OjWrdrV50YEBAQEYRc2MRmzgEEZd4xCeYBCQkEYlJ
QghJSUZyUhBKSlKRmjSEEU5a0pGeDEQQSVRMDzKRmSxkJRvZyUFOcpGbPOQl
H/kpQEEKUZgiFKUYxSlBSUpRmg8oQ1nKUZ4PqcBHVKQSlalCVapRnRrUpBa1
qUNd6lGfBjSkER/TmE9oQlOa0ZwWfEpLWtGaNrSlHe35jA50pBOd6UJXoulG
d3rQk8/pRW++oA996Ud/BvAlXzGQQQxmCEMZxnBG8DUjGcVovmEMYxnHeCYw
kUlMZgpTmcZ0ZjCTWczmW75jDnOZx3wWsJBFLGYJS1nGclawklWsZg1rWcd6
vmcDG/mBTWzmR35iC1vZxnZ2sJNd7OZn9rCXfeznAAc5xGGOcJRjHOcEJ/mF
X/mN3/mDU5zmDGc5x3kucJFLXOYKV/mTv7jGdW5wk1v8zT/8y23ucJf/uMd9
HvCQRzzmCU95xnNe8JJXvOZ/3vCWmPEHEovYxCGIuMQjPsEkICGJSEwSQkhK
MpKTglBSkorUpCGMcNKSjvRkIIJIogLf/6F3VNCDzQ==
        "]], 
       LineBox[CompressedData["
1:eJwV0FdXDgAAgOGvn9KRpF1khCTZs4iQVfYKZYaylVlZ7TISQlEoIzJDpZTf
09PFc857/QZn56bvCwoEAm2MESGMJZRxhDGecCKIJIpoYogljngmMJEEJjGZ
KUwlkWlMZwZJzCSZWaQwm1TmMJd5zGcBC1nEYpawlGUsJ410VrCSDFaxmkzW
sJZ1ZLGeDWxkE5vJJoctbGUb29nBTnaxmz3sZXRaLvs5wEHyyOcQhznCUY5x
nAJOcJJTFFLEac5wlnOc5wIXuUQxJVzmCle5xnVuUEoZ5dzkFre5w10qqKSK
amqopY56GrjHfR7wkEYe0cRjnvCUZp7xnBe00MpLXtFGO695w1s66OQd7/nA
R7r4xGe6+cJXvvGdH/ykh1/85g+99NHPXwYY5B9DDPOfEfzgWqY=
        "]], 
       LineBox[CompressedData["
1:eJwVzmdbjQEAgOG30xAhZBRFh7KiqIhEKjNZZbRUsrLOIRHV7/GXpChEEkIJ
Ldx9uK/r+fiEW6PVkZggCJ7zQvTykj76ecVrBhjkDW95xxDv+cAwHxnhE6N8
5gtfGeMb3/nBOBP8ZJJf/OYPU0wzwyxz/OXf/GgoCGIIEUsc8SSwgEQWsogk
FrOEpSSzjOWsIIWVrGI1a0gljbWsI50M1rOBTMJsZBNZZLOZLWxlG9vJYQc7
ySWPXewmnwIK2cNeitjHfoo5QAkHOUQphymjnAqOcJRjHOcEJ6nkFFWc5gxn
Ocd5qqnhAhe5xGVqqaOeBhq5QhPNtHCVVq5xnRvc5BZt3OYOd7nHfSJEecBD
2nlEB495QidPeUYX3fTwH+deR2Y=
        "]], LineBox[CompressedData["
1:eJwNwwc6kAEAANDfKDSlRZsjOYID6ATRoCGiIZSVIhkZ2UWaJG2iUNJCRbS0
1Hvf9+KTdiYmhwRBUOGu0CBIMdXd7nGv+0wz3f0e8KCHzPCwmWZ5xGxzPOox
j3vCXE+aZ74FnvK0hRZZbImlnrHMs56z3ArPW+kFq6y2xlovWme9DTZ6ySab
bbHVNtvt8LJX7LTLq3Z7zeve8Ka3vG2Pvd6xz7v2e8/7PvChj3zsEwcc9KlD
DvvM54446pgvfOm4r5zwtW986zvfO+mU037wo5+ccdbPzjnvF7/6ze/+cMGf
/vK3f/zrov8MwoIgxFDDDHeJS40w0iiXudwVrnSVq412jTGudZ3r3eBGY41z
k5vd4la3ud0dxpvgf2CkZ1Y=
        "]], LineBox[CompressedData["
1:eJwNw4c2lgEAANDP8SQdFNEQSktZWZF+khBFVlZSFBmF7NJvRKiMklFGPWD3
nnNP1HaE2iOCIAgbFRkE0cZ40lPGGudp403wjGc953kTvWCSyaZ40Uumetkr
XvWa103zhjdNN8NMs8z2ljnmmme+Bd620CLvWOxdQ5ZY6j3LvG+5D6yw0iof
Wm2Nj3xsrXU+sd4GG22y2ae22Gqb7Xb4zE6f2+ULX9ptj698ba99vrHfAQcd
8q3vHHbEUd875rgTTjrltDN+8KOzfjLsnPMuuOhnl1z2iyuuuuZXv/nddTfc
dMsf/nTbX+646577/vaPBx565LF//ed/0bJBSw==
        "]]},
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"-", "4"}], "-", 
              RowBox[{"20", " ", 
                TagBox["x", HoldForm]}], "+", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], "+", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"], "+", 
              SuperscriptBox[
               TagBox["x", HoldForm], "5"], "-", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"], "-", 
              RowBox[{"3", " ", 
                TagBox["x", HoldForm], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}], "-", 
              RowBox[{"10", " ", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "3"], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}], "+", 
              RowBox[{"5", " ", 
                TagBox["x", HoldForm], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "4"]}]}], "\[Equal]", "0"}], ",", 
          RowBox[{
            RowBox[{
              RowBox[{"16", " ", 
                TagBox["x", HoldForm]}], "-", 
              RowBox[{"8", " ", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "3"]}], "+", 
              SuperscriptBox[
               TagBox["x", HoldForm], "5"], "+", 
              RowBox[{"24", " ", 
                TagBox["x", HoldForm], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}], "-", 
              RowBox[{"10", " ", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "3"], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}], "+", 
              RowBox[{"5", " ", 
                TagBox["x", HoldForm], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "4"]}]}], "\[Equal]", "0"}]}], "}"}]],
     
     Annotation[#, {-4 - 20 HoldForm[$CellContext`x] + 
        HoldForm[$CellContext`x]^2 + HoldForm[$CellContext`x]^3 + 
        HoldForm[$CellContext`x]^5 - 
        HoldForm[$CellContext`y]^2 - (3 HoldForm[$CellContext`x]) 
        HoldForm[$CellContext`y]^2 - (10 HoldForm[$CellContext`x]^3) 
        HoldForm[$CellContext`y]^2 + (5 HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y]^4 == 0, 
       16 HoldForm[$CellContext`x] - 8 HoldForm[$CellContext`x]^3 + 
        HoldForm[$CellContext`x]^5 + (24 HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y]^2 - (10 HoldForm[$CellContext`x]^3) 
        HoldForm[$CellContext`y]^2 + (5 HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y]^4 == 0}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwNwwdXiAEAAMAvZZdsEpJs2UJ2MlpWRvbIXoXKlv2TzIzsPbJnhGwhe4S7
9y42OzczJyQIghL3hgbBPvd7wIMessjDHvGoxyz2uCc86SlPe8aznvO8F7zo
JS97xates8Tr3vCmt7ztHe96z/s+8KGPLPWxTyzzqc98brkvfOkrX/vGt77z
vRV+8KOfrPSzX/zqN7/7w5/+8rd/rPKv/wzCgiDEaoYaZnVrWNNa1raOdQ03
wnpGWt8GNrSRjW1iU5vZ3ChbGG1LW9naGNsYa1vjbGd7O9jRTna2i12Nt5vd
7WFPe9nbPvY1wX72d4CJDnSQgx3iUIc53CRHmOxIRznaMaaYaprpZjjWcY53
ghPNdJKTneJUs5zmdGc401nOdo5zned8s13gQhe52CUudZnLXeFKV5ljrqtd
41rzzLfAda53gxvd5Ga3uNVCt7ndHe50l7vd43/j1mgr
        "]], 
       LineBox[CompressedData["
1:eJwNwwdaiAEAANC/NGgoZKQdkYy4iiN0gNwCFRoqK0o20TCSzJCsrFJkZiTS
UMhI3vu+l5G3YX1+SBAEdW4MC4JNbrbAQovc4la3WWyJpZa53XIrrHSHO93l
bvdY5V73WW2N+631gAc95GGPeNRjHveEdZ70lPU22GiTpz3jWc/Z7HlbvGCr
F73kZa941Wu2ed0b3rTdW3Z42zve9Z737fSBD33kY5/YZbdP7bHXZz63zxe+
9JWvfeNb+33nez/40QE/OehnvzjkV4cdcdQxvznuhN/94U8n/eVv//jXKf85
bRAeBCGGOsMww40w0pnOMspoY4x1tnHGO8e5zjPB+S5woYtMdLFJJptiqmmm
m2GmS1xqlstcbrYrzHGlq1ztGnNd6zr/A7jgZrw=
        "]], LineBox[CompressedData["

1:eJwNw+dWiAEAANDPDw/SK4hQksxIIVtWUdopMxTZhEgUyipCNGRVVpLIqEQp
St7EvefckOTchJwJQRA0OWliEIQ62SmGOdVpTjfcCGcY6UyjnGW0s53jXOc5
3wXGuNBFxrrYOONd4lKXmeByV7jSVa52jWtdZ6Lr3eBGN7nZJJPd4lZTTHWb
aaabYaZZZptjrtvNM98d7nSXu93jXgvc534PWGiRBz1ksYc94lGPedwTnvSU
py3xjGc9Z6nnvWCZFy33kpetsNIrXvWaVVZ73Rve9Ja3rbHWO961znve94H1
PvSRDTbaZLOPbfGJT33mc1/YapvtvvSVr33jWzt8Z6fv7fKD3X70kz1+9otf
/Wavffb73QF/+NNBh/zlsCP+9o+jjvnXcf/5H2mvZFw=
        "]], 
       LineBox[CompressedData["
1:eJwN0+MCkAcAQNEva6uWsWzba9l2y+ayl21j2baWbbu2FpZtu50f577BTdKo
XeW2IYIgSCq3wgTBbe5wl3vc5wEPecRjnvCUZzznBS95xWve8JZ3vOcDH/nE
Z77wlW98JwgbBCEISShCE4awhCM8EYhIJH7gRyIThaj8RDSiE4OYxCI2cYhL
POLzMwlISCISk4SkJCM5KUhJKlKThrSkIz0ZyEgmMpOFrGQjOznISS5yk4e8
5OMX8vMrBShIIQpThKIUozglKEkpSlOGspSjPBWoSCUqU4WqVKM6NajJb9Si
NnWoSz3q04CGNKIxTWhKM5rTgpa0ojW/04a2tKM9HehIJzrTha50ozs9+IOe
9KI3fehLP/ozgIEMYjBDGMowhjOCkYxiNGMYyzjGM4GJTGIyU/iTqUxjOjOY
ySxmM4e5zGM+C1jIIhazhKUsYzkrWMkqVrOGtaxjPRvYyF9sYjNb2Mo2trOD
nexiN3vYyz72c4CDHOIwRzjKMY5zgpOc4jRnOMs5znOBi1zib/7hMv9yhatc
4zr/cYOb3OI2d7jLPe7zgIc84jFPeMoznvOCl7ziNW94yzve84GPfOIzX/jK
N74ThPM/IQnF/zlXpD4=
        "]], LineBox[CompressedData["
1:eJwNxGOAFgYAANAv3mWbV5eNxWUtc9nGlmvZdi3bXLZtm8vm4qqtrffjvZCm
Haq1DxMIBEIVPigQiEBEgggmEpGJQlSiEZ0YxCQWsYlDXOIRnwQkJBGJSUJS
kpGcFKQkhFSkJpQ0pCUd6clARjKRmSxkJRvZyUFOcpGbH8hDXvKRnwIU5EcK
UZgiFKUYxSlBSUpRmjL8RFnKUZ4KVKQSlalCVapRnRr8TE1qUZs61KUe9WlA
QxrRmCY0pRnNaUFLWtGaNrSlHb/wK+3pQEc60ZkudKUb3fmNHvSkF73pQ1/6
0Z8BDGQQgxnCUIYxnBGMZBSjGcNYxjGeCUxkEr8zmSlMZRrTmcFMZjGbOcxl
HvNZwEIWsZglLGUZy1nBSlbxB6tZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe
9rGfAxzkEIc5wlGOcZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFn9ymzvc
5R73ecBDHvGYJzzlGc95wUte8Zo3/MVb3vGeD3zkE3/zmS985R/+5Rv/8T+B
4EAgDGEJR3giEJEggolEZKIQlWhEJwYxiUVs4hCXeMQnAQlJRGKSkJRkJCcF
KQkhFakJJQ1pScd3wZuMgw==
        "]]},
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"-", "4"}], "-", 
              RowBox[{"20", " ", 
                TagBox["x", HoldForm]}], "+", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], "+", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"], "+", 
              SuperscriptBox[
               TagBox["x", HoldForm], "5"], "-", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"], "-", 
              RowBox[{"3", " ", 
                TagBox["x", HoldForm], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}], "-", 
              RowBox[{"10", " ", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "3"], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}], "+", 
              RowBox[{"5", " ", 
                TagBox["x", HoldForm], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "4"]}]}], "\[Equal]", "0"}], ",", 
          RowBox[{
            RowBox[{
              RowBox[{"16", " ", 
                TagBox["x", HoldForm]}], "-", 
              RowBox[{"8", " ", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "3"]}], "+", 
              SuperscriptBox[
               TagBox["x", HoldForm], "5"], "+", 
              RowBox[{"24", " ", 
                TagBox["x", HoldForm], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}], "-", 
              RowBox[{"10", " ", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "3"], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"]}], "+", 
              RowBox[{"5", " ", 
                TagBox["x", HoldForm], " ", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "4"]}]}], "\[Equal]", "0"}]}], "}"}]],
     
     Annotation[#, {-4 - 20 HoldForm[$CellContext`x] + 
        HoldForm[$CellContext`x]^2 + HoldForm[$CellContext`x]^3 + 
        HoldForm[$CellContext`x]^5 - 
        HoldForm[$CellContext`y]^2 - (3 HoldForm[$CellContext`x]) 
        HoldForm[$CellContext`y]^2 - (10 HoldForm[$CellContext`x]^3) 
        HoldForm[$CellContext`y]^2 + (5 HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y]^4 == 0, 
       16 HoldForm[$CellContext`x] - 8 HoldForm[$CellContext`x]^3 + 
        HoldForm[$CellContext`x]^5 + (24 HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y]^2 - (10 HoldForm[$CellContext`x]^3) 
        HoldForm[$CellContext`y]^2 + (5 HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y]^4 == 0}, "Tooltip"]& ]}],
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{178., Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
  PlotRange->{{-4, 4}, {-4, 4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7293506962272463`*^9, 3.729350982625358*^9, 
  3.7293510449800367`*^9, 3.729351105399209*^9, 3.733160012970603*^9, 
  3.733160790782587*^9, 3.733161267361701*^9, 3.733161555510747*^9, 
  3.733161767789122*^9, 3.733511921003565*^9},
 CellLabel->"Out[76]=",
 CellID->1110869958,ExpressionUUID->"7754c3fd-d9ac-425a-afdc-e8bc20d9da6c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"L", "=", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"complexProjectiveIntersectionpoints", "[", 
     RowBox[{"f", ",", "g", ",", "x", ",", "y"}], "]"}], ",", "1.*^-6"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "L", "]"}]}], "Input",
 CellChangeTimes->{{3.733160288788826*^9, 3.733160289546261*^9}},
 CellLabel->"In[77]:=",ExpressionUUID->"a3215c97-bc72-44ed-a588-6caa661e1d7b"],

Cell[BoxData[
 TemplateBox[{
  "NSolve","zerosol",
   "\"Scale of possible solution value \\!\\(\\*RowBox[{\\\"-\\\", \
\\\"1.8716491201227072482595521`1.1722894462799431*^-13\\\"}]\\) for variable \
\\!\\(\\*RowBox[{\\\"y\\\"}]\\) is too small. Must set this value to zero in \
order to avoid generation of spurious solutions. This may cause the loss of \
some solutions.\"",2,766,56,18147825225995434468,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.733162135864901*^9},
 CellLabel->"During evaluation of In[77]:=",
 CellID->280728025,ExpressionUUID->"c52ba8b2-aa6c-440b-acda-a5fd03c5b49d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.9999999999999503`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.9999999999999503`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.021808036665556`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.0267580159303848`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.021808036665556`", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.0267580159303848`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.22594588132839674`"}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.8945212513337828`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.22594588132839674`"}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.8945212513337828`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.999999999999336`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.999999999999336`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.999999999999336`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.999999999999336`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9625288220040195`"}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.9708312355305537`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9625288220040195`"}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.9708312355305537`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.000000000000098`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.000000000000098`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.6626637976645795`"}], ",", 
     RowBox[{"-", "1.1900716085404364`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.6626637976645795`"}], ",", 
     RowBox[{"-", "1.1900716085404364`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.1985863757568307`"}], ",", "0.38944432111981975`", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.1985863757568307`"}], ",", "0.38944432111981975`", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5738868286683807`"}], ",", "0.7898874553756456`", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5738868286683807`"}], ",", "0.7898874553756456`", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.1577587647932805`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.1577587647932805`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.1577587647932805`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.574400676974355`", ",", "2.1669766273650786`", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.574400676974355`", ",", "2.1669766273650786`", ",", "0"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.694881039022203*^9, 3.694881074048248*^9, 3.694881141607811*^9, 
   3.695816460425178*^9, 3.695816734499906*^9, 3.733160026781575*^9, 
   3.73316010563026*^9, {3.733160291797954*^9, 3.733160334822866*^9}, 
   3.73316079087175*^9, 3.733161267454336*^9, 3.733161555617845*^9, 
   3.73316176788997*^9, {3.7331621125318403`*^9, 3.733162135877604*^9}},
 CellLabel->"Out[77]=",
 CellID->1539654935,ExpressionUUID->"6fd6a198-9ece-4b9f-ac92-09a73de3b358"],

Cell[BoxData["25"], "Output",
 CellChangeTimes->{
  3.694881039022203*^9, 3.694881074048248*^9, 3.694881141607811*^9, 
   3.695816460425178*^9, 3.695816734499906*^9, 3.733160026781575*^9, 
   3.73316010563026*^9, {3.733160291797954*^9, 3.733160334822866*^9}, 
   3.73316079087175*^9, 3.733161267454336*^9, 3.733161555617845*^9, 
   3.73316176788997*^9, {3.7331621125318403`*^9, 3.733162135877604*^9}, 
   3.733511921103134*^9},
 CellLabel->"Out[78]=",
 CellID->408047623,ExpressionUUID->"27c5c4be-c94a-4b6c-b3aa-3477024628b3"]
}, Open  ]],

Cell["We may want to do additional post-processing:", "CodeCaption",
 CellChangeTimes->{{3.694881154735167*^9, 3.694881170643652*^9}, {
  3.695817712078522*^9, 
  3.695817715429607*^9}},ExpressionUUID->"b74474a0-bdc6-4348-8443-\
b1dedd3b1ca8"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Li", "=", 
  RowBox[{"Tally", "[", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"L", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "#", "]"}], "\[Equal]", "3"}], "&"}]}], "]"}], 
    ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Norm", "[", 
       RowBox[{"#1", "-", "#2"}], "]"}], "<", ".01"}], "&"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"La", "=", 
  RowBox[{"Tally", "[", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"L", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "#", "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
    ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Norm", "[", 
       RowBox[{"#1", "-", "#2"}], "]"}], "<", ".01"}], "&"}]}], 
   "]"}]}]}], "Input",
 CellLabel->"In[79]:=",ExpressionUUID->"dd92152d-c868-4492-98db-990cd66d553e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"20.705520603276618`", ",", "6.727631464760796`", ",", "0"}], 
      "}"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2.378534071414304`", ",", 
       RowBox[{"-", "0.7728325679577503`"}], ",", "0"}], "}"}], ",", "2"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.9779499806780159`", ",", 
       RowBox[{"-", "1.3460326725740686`"}], ",", "0"}], "}"}], ",", "2"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1.7462664285718015`"}], ",", "0"}], "}"}], ",", "3"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.805628226304174`"}], ",", 
       RowBox[{"-", "2.4852340457748126`"}], ",", "0"}], "}"}], ",", "2"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729351719983287*^9, 3.729351719989154*^9}, 
   3.733160057700781*^9, 3.733160117187724*^9, 3.7331603424392557`*^9, 
   3.733160790894977*^9, 3.733161267471839*^9, 3.7331615556341877`*^9, 
   3.733161767908958*^9},
 CellLabel->"Out[79]=",
 CellID->1775515605,ExpressionUUID->"8d85b271-d091-4576-86c3-cc9fa073dc77"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.9999999999986355`", ",", "0"}], "}"}], ",", "2"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.0218080366682072`", ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.0267580159312113`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",",
      "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.0218080366682072`", ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.0267580159312113`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",",
      "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.22594588132329893`"}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"0.8945212513341578`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",",
      "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.22594588132329893`"}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.8945212513341578`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",",
      "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.9625288219862475`"}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"0.9708312355278877`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",",
      "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.9625288219862475`"}], ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.9708312355278877`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",",
      "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.0000000000567217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",",
      "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.0000000000567217`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",",
      "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2.0000000000035687`"}], ",", "0"}], "}"}], ",", "2"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729351719983287*^9, 3.729351719989154*^9}, 
   3.733160057700781*^9, 3.733160117187724*^9, 3.7331603424392557`*^9, 
   3.733160790894977*^9, 3.733161267471839*^9, 3.7331615556341877`*^9, 
   3.7331617679126577`*^9},
 CellLabel->"Out[80]=",
 CellID->1279883780,ExpressionUUID->"b452ab6f-d7d8-4fae-9923-84f3d4439b05"]
}, Open  ]],

Cell[TextData[{
 "We conclude there are, as B\[EAcute]zout tells us, 25 intersection points \
counted by multiplicity. These include five real infinite points, one ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"72e1c23d-4eb6-441f-afc6-62c6ca48970b"],
 " of multiplicity 3 and four of multiplicity 2. There are two real affine \
intersection points ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[PlusMinus]", "2"}], ",", "0"}], "}"}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"5856c480-d88a-4e64-bf82-fab12689991d"],
 " of multiplicity 2, two complex affine multiple two-intersection points ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"\[PlusMinus]", "2"}], "\[ImaginaryI]"}]}], "}"}], 
   TraditionalForm]], "InlineMath",ExpressionUUID->
  "929ca050-3579-4854-abe5-11e30f504ee4"],
 " and three pairs of complex conjugate affine simple intersection points."
}], "Text",
 CellChangeTimes->{{3.7293489692107143`*^9, 3.729348969914452*^9}, {
   3.729352226678832*^9, 3.729352226713538*^9}, 
   3.737995715182886*^9},ExpressionUUID->"9c06a3e8-0702-4315-875b-\
1eeeb36b6385"],

Cell[TextData[{
 "Note that finding intersection points is more stable than finding singular \
points. ",
 Cell[BoxData[
 "complexProjectiveIntersectionpoints"], "InlineCodeText",ExpressionUUID->
  "4d048983-ad9e-4bf7-bc75-a334b012919a"],
 " does not require a tolerance, and usually, running it once is enough. It \
is better to use this second function to find singular points that come from \
intersections."
}], "Text",
 CellChangeTimes->{{3.718546699402405*^9, 3.718546847171724*^9}, {
   3.718546957454567*^9, 3.71854699168059*^9}, {3.722881945072489*^9, 
   3.722881945648282*^9}, {3.722881977110327*^9, 3.722881997604918*^9}, {
   3.7228820361790733`*^9, 3.7228820428494873`*^9}, {3.722882289279516*^9, 
   3.722882290992076*^9}, {3.729023734867002*^9, 3.729023765223537*^9}, {
   3.729348885683735*^9, 3.729348888530704*^9}, 3.729352226747991*^9, {
   3.737995743846846*^9, 3.737995756582082*^9}, {3.738508849203355*^9, 
   3.738508849203401*^9}},
 CellID->1855421355,ExpressionUUID->"5f4230bf-8c28-4989-b35a-051d129aa7a9"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructions with Curves", "Subsubsection",
 CellChangeTimes->{{3.695817908412067*^9, 3.695817931356276*^9}, {
   3.695818121632901*^9, 3.695818123952978*^9}, {3.7228821302708817`*^9, 
   3.722882130806493*^9}, 
   3.729348743179482*^9},ExpressionUUID->"d871bfde-d8d8-45e8-a70e-\
742570fc9339"],

Cell[TextData[{
 "One way to make interesting new curves from old curves is to add or \
subtract infinite points by removing an affine line ",
 Cell[BoxData[
  FormBox["\[ScriptL]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "5539fb9d-f1be-457b-a9fc-d6db11e8bae5"],
 " using ",
 Cell[BoxData[
 "iTransform"], "InlineCodeText",ExpressionUUID->
  "0b2794bc-fb77-4772-bb05-12938c84ec48"],
 ". The new infinite points correspond to the affine points on ",
 Cell[BoxData[
  FormBox["\[ScriptL]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "1c044cf1-819d-442f-8e83-746042e3ee32"],
 " while infinite points not on ",
 Cell[BoxData[
  FormBox["\[ScriptL]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "94630994-cbd6-4811-918b-0b23fd47fe53"],
 " become affine points."
}], "Text",
 CellChangeTimes->{{3.69581813295781*^9, 3.695818355103227*^9}, 
   3.722882175290593*^9, {3.729023771786706*^9, 3.729023782411797*^9}, {
   3.737996132476405*^9, 3.73799613355132*^9}, {3.743167396080978*^9, 
   3.74316739633685*^9}},ExpressionUUID->"e6893fcd-dba3-49ea-a0ce-\
bf36bc6819ea"],

Cell["\<\
Newton observed that there were cubic curves with four affine components. We \
saw this with Newton hyperbolas. Another way to construct such a curve is to \
start with a common cubic such as\
\>", "Text",
 CellChangeTimes->{{3.695823246105808*^9, 3.69582333961497*^9}, {
   3.69582338185594*^9, 3.695823410360516*^9}, {3.7228822395612993`*^9, 
   3.722882245583473*^9}, {3.729352226781685*^9, 3.729352226815303*^9}, {
   3.73799615250205*^9, 3.73799615296518*^9}, 3.737996360533339*^9, 
   3.7431674124953127`*^9},ExpressionUUID->"436c58a1-aa5f-4199-9263-\
987ff328a3dc"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "=", 
    RowBox[{
     SuperscriptBox["y", "2"], "-", 
     SuperscriptBox["x", "3"], "+", "x"}]}], ";"}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.729349203209943*^9, 3.729349212376786*^9}, {
  3.743869229112661*^9, 3.74386927736493*^9}},
 CellID->361149351,ExpressionUUID->"a139e8a2-4349-4b34-b219-36f0f42d196d"],

Cell[TextData[{
 "and remove a line ",
 Cell[BoxData[
  FormBox["\[ScriptL]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "23680210-e9a4-450d-8d42-af3d8c8359dc"],
 " intersecting the infinite component in two chosen real points. We can see, \
as B\[EAcute]zout determined, it will also intersect in an additional point \
that must also be real and in the infinite (versus the finite) component."
}], "Text",
 CellChangeTimes->{{3.695823428830658*^9, 3.695823454984574*^9}, {
   3.695823489602398*^9, 3.695823559692949*^9}, {3.695823591726759*^9, 
   3.695823641648646*^9}, {3.695823678099191*^9, 3.695823752062255*^9}, 
   3.695823799441484*^9, {3.722882307247086*^9, 3.722882319487205*^9}, {
   3.722882412066105*^9, 3.722882442550318*^9}, {3.729023800690611*^9, 
   3.7290238008898077`*^9}, {3.7293491439302187`*^9, 3.729349150881627*^9}, {
   3.7379964558214693`*^9, 3.737996459508583*^9}, {3.738508914157693*^9, 
   3.738508917829611*^9}, {3.738510714165577*^9, 3.738510715859456*^9}, {
   3.743167431719146*^9, 
   3.743167434942359*^9}},ExpressionUUID->"922d0ff7-b7d1-4d7f-af88-\
e3bcb5a5f58d"],

Cell["Choose some parameters:", "CodeCaption",
 CellChangeTimes->{{3.695823905150359*^9, 3.695823922747435*^9}, {
   3.695824320541898*^9, 3.695824323526254*^9}, 3.718547050769321*^9, 
   3.722882402835907*^9, 3.729349369230287*^9, 
   3.737996422381323*^9},ExpressionUUID->"d426d778-9d34-4c15-8eb5-\
6c60e4971b08"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l", "=", 
  RowBox[{
   RowBox[{"10", "x"}], "-", "y", "-", "20"}]}]], "Input",
 Editable->False,
 CellLabel->"In[81]:=",ExpressionUUID->"bcb09aeb-76bd-47a4-8bbe-e6fcef3dfd9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "20"}], "+", 
  RowBox[{"10", " ", "x"}], "-", "y"}]], "Output",
 CellChangeTimes->{3.729350696363508*^9, 3.729350982773007*^9, 
  3.729351045126314*^9, 3.729351105545192*^9, 3.7293516599241877`*^9, 
  3.733160169410138*^9, 3.733160255234809*^9, 3.733160790914316*^9, 
  3.73316126748074*^9, 3.73316155564888*^9, 3.7331617679272614`*^9, 
  3.7331621488302402`*^9, 3.7335119211721*^9},
 CellLabel->"Out[81]=",
 CellID->1391209594,ExpressionUUID->"80ba1b95-b834-4fb0-b71d-f461e14b733b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"A", "=", 
  RowBox[{"iTransform", "[", 
   RowBox[{"l", ",", "x", ",", "y"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"h", "=", 
  RowBox[{"FLT", "[", 
   RowBox[{"f", ",", "A", ",", "x", ",", "y"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "\[Equal]", "0"}], ",", 
       RowBox[{"l", "==", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"h", "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "8"}], ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "8"}], ",", "8"}], "}"}]}], "]"}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.733160236764845*^9, 3.7331602372019663`*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"45c39dad-835a-4696-b52e-361c55f03db3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7812879011987071`"}], ",", 
     RowBox[{"-", "0.3168196688992504`"}], ",", "0.9191639531555853`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1.4009431979825675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4467670516087703`", ",", 
     RowBox[{"-", "0.04467670516087703`"}], ",", 
     RowBox[{"-", "0.8935341032175406`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729351873206562*^9, 3.729351873212164*^9}, 
   3.733160184005538*^9, {3.7331602383006887`*^9, 3.733160260644271*^9}, 
   3.733160790936907*^9, {3.733161125026042*^9, 3.73316114047473*^9}, 
   3.733161267495685*^9, {3.7331614648615837`*^9, 3.7331614735490503`*^9}, 
   3.7331615556630917`*^9, 3.7331617679441*^9, 3.7331619195856123`*^9, 
   3.733161978143382*^9, 3.73316215144972*^9, 3.733511921204131*^9},
 CellLabel->"Out[82]=",
 CellID->257697822,ExpressionUUID->"b0defad6-908b-49e8-8c00-5aa87c5a3ba5"],

Cell[BoxData[
 RowBox[{"2334.571128726373`", "\[VeryThinSpace]", "+", 
  RowBox[{"6575.52709095994`", " ", "x"}], "+", 
  RowBox[{"5771.270174688617`", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"1708.5005388041536`", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"13.448920829350612`", " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"50.99209142137938`", " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"3130.8243837639175`", " ", "y"}], "+", 
  RowBox[{"9202.617073403377`", " ", "x", " ", "y"}], "+", 
  RowBox[{"7680.042879501856`", " ", 
   SuperscriptBox["x", "2"], " ", "y"}], "+", 
  RowBox[{"2214.6893971024833`", " ", 
   SuperscriptBox["x", "3"], " ", "y"}], "+", 
  RowBox[{"158.7026458748683`", " ", 
   SuperscriptBox["x", "4"], " ", "y"}], "+", 
  RowBox[{"923.9412520607452`", " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{"3710.1642235780896`", " ", "x", " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{"2710.0602421918816`", " ", 
   SuperscriptBox["x", "2"], " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{"500.49649501688936`", " ", 
   SuperscriptBox["x", "3"], " ", 
   SuperscriptBox["y", "2"]}], "-", 
  RowBox[{"268.8099325430901`", " ", 
   SuperscriptBox["y", "3"]}], "+", 
  RowBox[{"344.4164622950726`", " ", "x", " ", 
   SuperscriptBox["y", "3"]}], "+", 
  RowBox[{"238.5192664896606`", " ", 
   SuperscriptBox["x", "2"], " ", 
   SuperscriptBox["y", "3"]}], "-", 
  RowBox[{"162.88162726839312`", " ", 
   SuperscriptBox["y", "4"]}], "-", 
  RowBox[{"29.774252857616702`", " ", "x", " ", 
   SuperscriptBox["y", "4"]}], "-", 
  RowBox[{"23.603058173644747`", " ", 
   SuperscriptBox["y", "5"]}]}]], "Output",
 CellChangeTimes->{{3.729351873206562*^9, 3.729351873212164*^9}, 
   3.733160184005538*^9, {3.7331602383006887`*^9, 3.733160260644271*^9}, 
   3.733160790936907*^9, {3.733161125026042*^9, 3.73316114047473*^9}, 
   3.733161267495685*^9, {3.7331614648615837`*^9, 3.7331614735490503`*^9}, 
   3.7331615556630917`*^9, 3.7331617679441*^9, 3.7331619195856123`*^9, 
   3.733161978143382*^9, 3.73316215144972*^9, 3.73351192121002*^9},
 CellLabel->"Out[83]=",
 CellID->1800262002,ExpressionUUID->"27876cbc-6970-4ba2-bf79-20d1039c4ab9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdWwc41d//v8ueTaUhok17oG/nqIRI0jca2nuh0NAeSilFUom+RZJUhGjI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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJwl1FV4EAQUBeANGDBqxIiN2EZ3N0iIdKdISUuOEKSURkC6Q+luBEFppBuL
TqVUQLoR+Pfx8J/7el7OjWrdrV50YEBAQEYRc2MRmzgEEZd4xCeYBCQkEYlJ
QghJSUZyUhBKSlKRmjSEEU5a0pGeDEQQSVRMDzKRmSxkJRvZyUFOcpGbPOQl
H/kpQEEKUZgiFKUYxSlBSUpRmg8oQ1nKUZ4PqcBHVKQSlalCVapRnRrUpBa1
qUNd6lGfBjSkER/TmE9oQlOa0ZwWfEpLWtGaNrSlHe35jA50pBOd6UJXoulG
d3rQk8/pRW++oA996Ud/BvAlXzGQQQxmCEMZxnBG8DUjGcVovmEMYxnHeCYw
kUlMZgpTmcZ0ZjCTWczmW75jDnOZx3wWsJBFLGYJS1nGclawklWsZg1rWcd6
vmcDG/mBTWzmR35iC1vZxnZ2sJNd7OZn9rCXfeznAAc5xGGOcJRjHOcEJ/mF
X/mN3/mDU5zmDGc5x3kucJFLXOYKV/mTv7jGdW5wk1v8zT/8y23ucJf/uMd9
HvCQRzzmCU95xnNe8JJXvOZ/3vCWmPEHEovYxCGIuMQjPsEkICGJSEwSQkhK
MpKTglBSkorUpCGMcNKSjvRkIIJIogLf/6F3VNCDzQ==
          "]], 
         LineBox[CompressedData["
1:eJwV0FdXDgAAgOGvn9KRpF1khCTZs4iQVfYKZYaylVlZ7TISQlEoIzJDpZTf
09PFc857/QZn56bvCwoEAm2MESGMJZRxhDGecCKIJIpoYogljngmMJEEJjGZ
KUwlkWlMZwZJzCSZWaQwm1TmMJd5zGcBC1nEYpawlGUsJ410VrCSDFaxmkzW
sJZ1ZLGeDWxkE5vJJoctbGUb29nBTnaxmz3sZXRaLvs5wEHyyOcQhznCUY5x
nAJOcJJTFFLEac5wlnOc5wIXuUQxJVzmCle5xnVuUEoZ5dzkFre5w10qqKSK
amqopY56GrjHfR7wkEYe0cRjnvCUZp7xnBe00MpLXtFGO695w1s66OQd7/nA
R7r4xGe6+cJXvvGdH/ykh1/85g+99NHPXwYY5B9DDPOfEfzgWqY=
          "]], 
         LineBox[CompressedData["
1:eJwVzmdbjQEAgOG30xAhZBRFh7KiqIhEKjNZZbRUsrLOIRHV7/GXpChEEkIJ
Ldx9uK/r+fiEW6PVkZggCJ7zQvTykj76ecVrBhjkDW95xxDv+cAwHxnhE6N8
5gtfGeMb3/nBOBP8ZJJf/OYPU0wzwyxz/OXf/GgoCGIIEUsc8SSwgEQWsogk
FrOEpSSzjOWsIIWVrGI1a0gljbWsI50M1rOBTMJsZBNZZLOZLWxlG9vJYQc7
ySWPXewmnwIK2cNeitjHfoo5QAkHOUQphymjnAqOcJRjHOcEJ6nkFFWc5gxn
Ocd5qqnhAhe5xGVqqaOeBhq5QhPNtHCVVq5xnRvc5BZt3OYOd7nHfSJEecBD
2nlEB495QidPeUYX3fTwH+deR2Y=
          "]], LineBox[CompressedData["
1:eJwNwwc6kAEAANDfKDSlRZsjOYID6ATRoCGiIZSVIhkZ2UWaJG2iUNJCRbS0
1Hvf9+KTdiYmhwRBUOGu0CBIMdXd7nGv+0wz3f0e8KCHzPCwmWZ5xGxzPOox
j3vCXE+aZ74FnvK0hRZZbImlnrHMs56z3ArPW+kFq6y2xlovWme9DTZ6ySab
bbHVNtvt8LJX7LTLq3Z7zeve8Ka3vG2Pvd6xz7v2e8/7PvChj3zsEwcc9KlD
DvvM54446pgvfOm4r5zwtW986zvfO+mU037wo5+ccdbPzjnvF7/6ze/+cMGf
/vK3f/zrov8MwoIgxFDDDHeJS40w0iiXudwVrnSVq412jTGudZ3r3eBGY41z
k5vd4la3ud0dxpvgf2CkZ1Y=
          "]], LineBox[CompressedData["
1:eJwNw4c2lgEAANDP8SQdFNEQSktZWZF+khBFVlZSFBmF7NJvRKiMklFGPWD3
nnNP1HaE2iOCIAgbFRkE0cZ40lPGGudp403wjGc953kTvWCSyaZ40Uumetkr
XvWa103zhjdNN8NMs8z2ljnmmme+Bd620CLvWOxdQ5ZY6j3LvG+5D6yw0iof
Wm2Nj3xsrXU+sd4GG22y2ae22Gqb7Xb4zE6f2+ULX9ptj698ba99vrHfAQcd
8q3vHHbEUd875rgTTjrltDN+8KOzfjLsnPMuuOhnl1z2iyuuuuZXv/nddTfc
dMsf/nTbX+646577/vaPBx565LF//ed/0bJBSw==
          "]]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"-", "4"}], "-", 
                RowBox[{"20", " ", 
                  TagBox["x", HoldForm]}], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "2"], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "3"], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "5"], "-", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"], "-", 
                RowBox[{"3", " ", 
                  TagBox["x", HoldForm], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "-", 
                RowBox[{"10", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "3"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "+", 
                RowBox[{"5", " ", 
                  TagBox["x", HoldForm], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "4"]}]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              RowBox[{
                RowBox[{"-", "20"}], "+", 
                RowBox[{"10", " ", 
                  TagBox["x", HoldForm]}], "-", 
                TagBox["y", HoldForm]}], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {-4 - 20 HoldForm[$CellContext`x] + 
          HoldForm[$CellContext`x]^2 + HoldForm[$CellContext`x]^3 + 
          HoldForm[$CellContext`x]^5 - 
          HoldForm[$CellContext`y]^2 - (3 HoldForm[$CellContext`x]) 
          HoldForm[$CellContext`y]^2 - (10 HoldForm[$CellContext`x]^3) 
          HoldForm[$CellContext`y]^2 + (5 HoldForm[$CellContext`x]) 
           HoldForm[$CellContext`y]^4 == 
         0, -20 + 10 HoldForm[$CellContext`x] - HoldForm[$CellContext`y] == 
         0}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJwNw9c6AmAAANC/ITPv4JVcdukBeDqZSVFmslcZIZnZs4xzvu8MDI0MDkdC
CClHYyGkHXPcCSedctqMM2adNWfeOectWHTBRZdcdsVVS65Zdt0NN91y2x13
3XPfAw+tWPXIY088teaZ515Y99KGV15746133tv0wUeffPbFV99898NPv/y2
Zdsff/0zxEOIGDVm3A4Tdtpltz322mfSfv8BgopDcg==
          "]]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"-", "4"}], "-", 
                RowBox[{"20", " ", 
                  TagBox["x", HoldForm]}], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "2"], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "3"], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "5"], "-", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "2"], "-", 
                RowBox[{"3", " ", 
                  TagBox["x", HoldForm], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "-", 
                RowBox[{"10", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "3"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "+", 
                RowBox[{"5", " ", 
                  TagBox["x", HoldForm], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "4"]}]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              RowBox[{
                RowBox[{"-", "20"}], "+", 
                RowBox[{"10", " ", 
                  TagBox["x", HoldForm]}], "-", 
                TagBox["y", HoldForm]}], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {-4 - 20 HoldForm[$CellContext`x] + 
          HoldForm[$CellContext`x]^2 + HoldForm[$CellContext`x]^3 + 
          HoldForm[$CellContext`x]^5 - 
          HoldForm[$CellContext`y]^2 - (3 HoldForm[$CellContext`x]) 
          HoldForm[$CellContext`y]^2 - (10 HoldForm[$CellContext`x]^3) 
          HoldForm[$CellContext`y]^2 + (5 HoldForm[$CellContext`x]) 
           HoldForm[$CellContext`y]^4 == 
         0, -20 + 10 HoldForm[$CellContext`x] - HoldForm[$CellContext`y] == 
         0}, "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-4, 4}, {-4, 4}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxNmgk0Vd/bx+/kmrn3muchU4aKpETOrqiUsSRKA6UIjUKZShPSSEpJiFQU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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
          35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
          52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
          69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
          86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
          102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 
          115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 
          128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 
          141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 
          154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 
          167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 
          180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 
          193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 
          206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 
          219, 220, 221, 222, 223, 224}], LineBox[CompressedData["
1:eJwl02ecDwQYB/D/3eFwHM7mOOfszZmpqJBNtsyMErIJFUrbyijKJsosSrYy
KquBilJx1pm33J15rq9PL76/5+Xz4vk90f2GdxgWFAgEuos48xznucBFLhHP
Za5wlWtc5wYJJJJEMincJJU00rnFbe5wl3vcJ4MHZBKwP4hgQshCVrIRSnZy
kJMwcpGbcPKQl3xEkJ8CFKQQhSlCUYpRnEhKUJIoShFNaWIoQ1nKUZ4KVKQS
lalCVapRnRrUpBax1KYOdalHfRrwCA15lMd4nEY05gme5Cma0JRmPE1zWtCS
VrSmDW1pR3ueoQMd6URnutCVbkH/3/hZetCTXvSmD315jn70ZwADeZ4XGMSL
DGYIQ3mJh+UZzghGMorRjGEs43iZ8UxgIq/wKq8xiclM4XXeYCpv8hZv8w7v
8h7vM43pzGAms/iA2cxhLvP4kI+YzwI+5hMWsojFLGEpy1jOClbyKatYzWd8
zhrWso71bGAjX/Alm9jMV3zNFr5hK9vYzg52sovd7OFbvmMv+9jPAb7nB37k
IIc4zBGO8hM/8wu/cozjnOA3fucPTnKKP/mL0/zNP/zLGc4SxznOc4GLXCKe
y1zhKte4zg0SSCSJZFK4SSpppHOL29zhLve4TwYPyCQQ7P8JJoQsZCUboWQn
BzkJIxe5CScPeclHBPkpQEEKUZgiFKUYxYmkBCWJohTRlCaGMpSlHOWpQEUq
UZkqVKUa1alBTWoRS23qUJd61KcB/wFFRKaH
          "]], LineBox[CompressedData["
1:eJwNxGeADgQAANDPTLIiyh4VKmnIOvvsdcfZzro7bnJn3Z1xnH32btuKiqYt
o7JFVqXsssqm7Pl+vFc6MiksMVMgEAhXUOZAoAY1qUVt6lCXegRTnwY0pBGN
aUJTmtGcFrQkhFBa0Zow2tCWdrSnAx3pRGfC6UJXutGdHkQQSRQ96UU0McQS
RzwJ9KYPiSTRl370ZwADSSaFVAYxmCEMJY1hDCedEYxkFKMZw1jGkcF4JjCR
SUxmClOZxnRmMJNZzOZd3uN9PuBDPuJj5jCXecxnAQtZxGI+4VOWsJTP+Jwv
WMZyvuQrvuYbvuU7VrCSVaxmDWtZx3q+ZwMb2cRmfuBHfmILW9nGdnawk13s
5mf2sJdf2Md+DnCQQ/zKb/zOYf7gT45wlGMc5wQnOcVf/M1pznCWc5znH/7l
Ahe5xGWucJVrXOcG//E/N7nFbe5wl3vc5wEPecRjAlkCgUxkJgtZyUZ2niIH
T5OTZ8hFbvKQl3w8S34K8BwFKcTzvEBhilCUYhSnBCUpRWnK8CIv8TJlKUd5
XuFVXqMCr1ORN3iTt3ibSrxDZapQlWpUJ4ga1KQWtalDXeoRTH0a0JBGNKYJ
TWlGc1rQkhBCaUVrwmhDW9rRng50pBOdCacLXelGd3oQQSRR9KQX0cQQSxzx
JNCbPiSSRF/60Z8BDCSZFFIZxGCGMJQ0hjGcdEYwklGMZgxjGUcG45nARCYx
mSlMZRrTmcFMZjGbJ5COqXg=
          "]], LineBox[CompressedData["
1:eJwN0+ljyAUAgOGfWEqkUpKcKUQ5KyVJrlw5RkrlDKGMLhWVTuWu2MyxMba5
rzk3t2HmmGPua3Mz9zm3ng/P+x+8JTv1Cg3LEQRBTwnPGQQRjCKS0YxhLOOI
IprxTCCGiUwiljjimcwUpjKN6cxgJrOYzRzmksA85rOAhSxiMYkksYSlLGM5
K1jJKlaTzBrWso4U1pPKBjayic2ksYWtbGM76exgJ7vYzR72so/9HOAgh8gg
k8Mc4SjHOM4JTnKK02RxhrOc4zwXuMglLnOFq1zjOtnc4Ca3uM0d7nKP+wS5
giAHD5CTXITwILl5iIfJwyPkJR+Pkp/HeJwnKMCTPEVBnqYQz1CYZylCUYpR
nBKU5DlK8TwvUJoylOVFylGel3iZClSkEpWpQlVe4VVeoxqv8wbVeZMavEVN
3qYW71CbOtSlHvV5lwY0pBGNacJ7NKUZzWlBKC1pxfu05gM+pA0f8TGf0JZ2
tKcDHenEp3SmC135jG50pwef8wU9CaMXvfmSr/iab/iWPnzH9/xAX/rxIz/x
M/35hV/5jd/5gz8ZwF/8zUAGMZghDGUYw/mHf/mPEYwknAhGEcloxjCWcUQR
zXgmEMNEJhFLHPFMZgpTmcZ0ZjCTWcxmDnNJYB7zWcBCFrGYRJJYwlKWsZwV
rGQVq0lmDWtZRwrrSWUDG9nEZtLYwla2sZ10drCTXexmD3vZx34OcJBDZJDJ
YY5wlGMc5wQnOcVpsjjDWc5xngtc5BKXucJVrnGdbG5wk1vc5g53ucd9ghD/
8z+kb9tc
          "]]},
        RowBox[{
          RowBox[{
            RowBox[{"2334.571128726373`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"6575.52709095994`", " ", 
              TagBox["x", HoldForm]}], "+", 
            RowBox[{"5771.270174688617`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"]}], "+", 
            RowBox[{"1708.5005388041536`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"]}], "-", 
            RowBox[{"13.448920829350612`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "4"]}], "-", 
            RowBox[{"50.99209142137938`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "5"]}], "+", 
            RowBox[{"3130.8243837639175`", " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"9202.617073403377`", " ", 
              TagBox["x", HoldForm], " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"7680.042879501856`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"2214.6893971024833`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"], " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"158.7026458748683`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "4"], " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"923.9412520607452`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "+", 
            RowBox[{"3710.1642235780896`", " ", 
              TagBox["x", HoldForm], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "+", 
            RowBox[{"2710.0602421918816`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "+", 
            RowBox[{"500.49649501688936`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "-", 
            RowBox[{"268.8099325430901`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "3"]}], "+", 
            RowBox[{"344.4164622950726`", " ", 
              TagBox["x", HoldForm], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "3"]}], "+", 
            RowBox[{"238.5192664896606`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "3"]}], "-", 
            RowBox[{"162.88162726839312`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "4"]}], "-", 
            RowBox[{"29.774252857616702`", " ", 
              TagBox["x", HoldForm], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "4"]}], "-", 
            RowBox[{"23.603058173644747`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "5"]}]}], "\[Equal]", "0"}]],
       Annotation[#, 
        2334.571128726373 + 6575.52709095994 HoldForm[$CellContext`x] + 
         5771.270174688617 HoldForm[$CellContext`x]^2 + 
         1708.5005388041536` HoldForm[$CellContext`x]^3 - 13.448920829350612` 
         HoldForm[$CellContext`x]^4 - 50.99209142137938 
         HoldForm[$CellContext`x]^5 + 
         3130.8243837639175` 
          HoldForm[$CellContext`y] + (9202.617073403377 
           HoldForm[$CellContext`x]) 
          HoldForm[$CellContext`y] + (7680.042879501856 
           HoldForm[$CellContext`x]^2) 
          HoldForm[$CellContext`y] + (2214.6893971024833` 
           HoldForm[$CellContext`x]^3) 
          HoldForm[$CellContext`y] + (158.7026458748683 
           HoldForm[$CellContext`x]^4) HoldForm[$CellContext`y] + 
         923.9412520607452 
          HoldForm[$CellContext`y]^2 + (3710.1642235780896` 
           HoldForm[$CellContext`x]) 
          HoldForm[$CellContext`y]^2 + (2710.0602421918816` 
           HoldForm[$CellContext`x]^2) 
          HoldForm[$CellContext`y]^2 + (500.49649501688936` 
           HoldForm[$CellContext`x]^3) HoldForm[$CellContext`y]^2 - 
         268.8099325430901 
         HoldForm[$CellContext`y]^3 + (344.4164622950726 
           HoldForm[$CellContext`x]) 
          HoldForm[$CellContext`y]^3 + (238.5192664896606 
           HoldForm[$CellContext`x]^2) HoldForm[$CellContext`y]^3 - 
         162.88162726839312` 
         HoldForm[$CellContext`y]^4 - (29.774252857616702` 
          HoldForm[$CellContext`x]) HoldForm[$CellContext`y]^4 - 
         23.603058173644747` HoldForm[$CellContext`y]^5 == 0, "Tooltip"]& ]}],
    
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-8, 8}, {-8, 8}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729351873206562*^9, 3.729351873212164*^9}, 
   3.733160184005538*^9, {3.7331602383006887`*^9, 3.733160260644271*^9}, 
   3.733160790936907*^9, {3.733161125026042*^9, 3.73316114047473*^9}, 
   3.733161267495685*^9, {3.7331614648615837`*^9, 3.7331614735490503`*^9}, 
   3.7331615556630917`*^9, 3.7331617679441*^9, 3.7331619195856123`*^9, 
   3.733161978143382*^9, 3.73316215144972*^9, 3.7335119214684763`*^9},
 CellLabel->"Out[84]=",
 CellID->1106365031,ExpressionUUID->"9643437e-dabe-4e31-a550-9af04d96176c"]
}, Open  ]],

Cell[TextData[{
 "Programming note: Since ",
 Cell[BoxData[
 "iTransform"], "InlineCodeText",ExpressionUUID->
  "3174407a-8ec9-426e-8d90-6ad17514aa64"],
 " is partially random, the curve will come out differently when you run this \
example. The curve will still have four affine components, but you may have \
to adjust the scale in order to be able to see them."
}], "Text",
 CellChangeTimes->{{3.695824487179553*^9, 3.695824546668077*^9}, {
   3.695824646959287*^9, 3.695824648527344*^9}, {3.695912835029043*^9, 
   3.695912844636434*^9}, {3.695912980777586*^9, 3.695912996386356*^9}, {
   3.722882595210088*^9, 3.722882836101388*^9}, {3.7290238539546137`*^9, 
   3.7290238551469393`*^9}, {3.72934901898814*^9, 3.7293490219942207`*^9}, {
   3.7293498186327133`*^9, 3.729349820806601*^9}, {3.733160192327651*^9, 
   3.733160197374752*^9}, 3.7379964907814207`*^9, {3.737996814022193*^9, 
   3.7379968265813437`*^9}, {3.737996963806191*^9, 3.737996991155429*^9}, {
   3.743167448552507*^9, 3.743167451046386*^9}},
 FontSlant->"Italic",ExpressionUUID->"586d2125-d093-43ea-ad43-8f65e6454391"],

Cell["\<\
Projective real curves of even degree can often be represented by affine \
curves with no infinite points. We will see in Chapter 9 that this is not \
true of odd degree curves. This is easy to check if you can find a line that \
does not intersect the curve in a real projective point.\
\>", "Text",
 CellChangeTimes->{{3.695913097135669*^9, 3.695913135293886*^9}, {
  3.695913198399131*^9, 3.695913361850961*^9}, {3.695914234104968*^9, 
  3.695914242136887*^9}, {3.722882849355754*^9, 3.7228828665157833`*^9}, {
  3.722882917850998*^9, 3.722882934437396*^9}, {3.729349939624813*^9, 
  3.729349940709902*^9}, {3.7293522268492393`*^9, 
  3.729352226884446*^9}},ExpressionUUID->"22622bc6-83c3-4131-b232-\
11c2e0f6b72f"],

Cell["We illustrate this with Gauss curves. Let:", "CodeCaption",
 CellChangeTimes->{{3.6959133683127*^9, 3.695913399451072*^9}, {
  3.729349943390243*^9, 3.729349946285915*^9}, {3.737998604194025*^9, 
  3.737998605079751*^9}, {3.7407537384895277`*^9, 
  3.7407537386255198`*^9}},ExpressionUUID->"2c052bb8-0532-43c4-af36-\
0086c5ee2fe0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "=", " ", 
  RowBox[{"gaussCurve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "^", "6"}], "-", 
     RowBox[{"6", "z"}], "+", "6"}], ",", "x", ",", "y", ",", "z"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.733160220953257*^9, 3.733160221645431*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"44d54922-aa02-46e7-95cc-0738bf2714b0"],

Cell[BoxData[
 RowBox[{"6", "-", 
  RowBox[{"6", " ", "x"}], "+", 
  SuperscriptBox["x", "6"], "-", 
  RowBox[{"15", " ", 
   SuperscriptBox["x", "4"], " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{"15", " ", 
   SuperscriptBox["x", "2"], " ", 
   SuperscriptBox["y", "4"]}], "-", 
  SuperscriptBox["y", "6"]}]], "Output",
 CellChangeTimes->{{3.7293519755500603`*^9, 3.729351975555752*^9}, {
   3.733160216187859*^9, 3.7331602226301622`*^9}, 3.733160386541327*^9, 
   3.733160791259293*^9, 3.7331611529517307`*^9, 3.7331612677862253`*^9, 
   3.733161490895155*^9, 3.73316155595747*^9, 3.7331617682500753`*^9, 
   3.733161945847055*^9, 3.733162157531897*^9, 3.73351192153573*^9},
 CellLabel->"Out[85]=",
 CellID->1763660291,ExpressionUUID->"d42b36b3-1754-45e0-88e7-65f76d77fd21"]
}, Open  ]],

Cell[TextData[{
 "We see below that this curve does not meet the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "1d3e8c45-c7cf-46a6-b177-7dd03490baa1"],
 "-axis in an affine or infinite point:"
}], "CodeCaption",ExpressionUUID->"2636d03a-42c8-45c1-ab24-7616080b96c5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B", "=", 
  RowBox[{"iTransform", "[", 
   RowBox[{"y", ",", "x", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7331602259055977`*^9, 3.733160226469192*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"62f95d44-1c86-40b1-9b2e-d4fb37d8d003"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7812879011987071`"}], ",", 
     RowBox[{"-", "0.3168196688992504`"}], ",", "0.9191639531555853`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1.4009431979825675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729351993005978*^9, 3.729351993011506*^9}, 
   3.7331602272532177`*^9, 3.733160389412527*^9, 3.7331607912781754`*^9, {
   3.733161155131391*^9, 3.733161165536272*^9}, 3.7331612677992697`*^9, {
   3.73316148293058*^9, 3.7331614939411087`*^9}, 3.733161555974123*^9, 
   3.733161768267885*^9, 3.733161899852991*^9, 3.7331619481174726`*^9, 
   3.73316215965517*^9, 3.7335119215717707`*^9},
 CellLabel->"Out[86]=",
 CellID->121731296,ExpressionUUID->"3f0bc17f-2399-41ea-96c3-3d38ba2396d7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g1", "=", 
   RowBox[{"FLT", "[", 
    RowBox[{"g", ",", "B", ",", "x", ",", "y"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "\[Equal]", "0"}], ",", 
       RowBox[{"y", "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "]"}], ",", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"g1", "\[Equal]", "0"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]}], "}"}]}], "Input",
 CellLabel->"In[87]:=",ExpressionUUID->"bfc96941-e4fe-4230-82d6-1bfda42136e3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxtnAlYjc/7/9v35bTLEqmshQhZZ5DKUshSyC5SipK1lC1LklIIIUuixZJ2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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
          35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
          52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
          69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
          86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
          102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 
          115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 
          128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 
          141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 
          154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 
          167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 
          180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 
          193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 
          206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 
          219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 
          232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 
          245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255}], 
         LineBox[CompressedData["
1:eJwl01V0EAQABdAFNWCwwejB2NhgbMQA6QbpHiqIgjiQEGmQ7kaU7lRCEQxC
TEIsQhoDCaVbuvNy+Ljv/513XnRK9+RugQEBASWfBYEEEUwqUpOGtKQjhPRk
ICOhZCIzYYSThaxEkI3s5CAnuchNHiLJSz6iyE80MRQgljgKUoh4CpNAIkUo
SjGKk0SJwOddSvECpSlDWcpRngpUpBKVqUJVqlGdGtTkRWpRmzrUpR71aUBD
GtGYJjSlGck05yVe5hVa0JJXacVrvE5r2vAGbXmTFNrRnrfoQEc60Zm36cI7
dOXZgN3pQU960Zs+9OVd+tGfAQxkEIMZwlCGMZwRjGQUoxnDWMYxnglM5D0m
8T4fMJkpTGUa05nBTGYxmznMZR7zWcBCFrGYJXzIRyxlGctZwcd8wko+ZRWr
+YzP+YIvWcNa1rGer9jA13zDt3zH9/zARjaxmS38yFZ+4md+4Vd+Yxvb2cFO
fmcXu9nDXvaxnwMc5A/+5C/+5hD/cJgjHOUY//IfxznBSU5xmjOc5RznucBF
LnGZ/7nCVa5xnRvc5Ba3ucNd7nGfBzzkEY95QkCQ/xNEMKlITRrSko4Q0pOB
jISSicyEEU4WshJBNrKTg5zkIjd5iCQv+YgiP9HEUIBY4ihIIeIpTAKJFKEo
xShOEiV4Crfhh5Q=
          "]], LineBox[CompressedData["
1:eJwNxFVgFQQAAMAHo6RDSkK6u3uwwQK2AaOkpaVDuhSkG5RQGhSURhoFRbpD
OqRDSmmUvI+77K27x3aLEwgEcqhE3ECgJKUoTRnKUo7yVKAilahMFYKpSjVC
CKU6NQgjnAgiqUktoogmhtrUoS6x1KM+DWhIIz6hMU1oSjOa04KWfEorWtOG
trSjPR34jI50ojNd6Eo3utODnvTic3rTh770oz8DGMggBjOEoXzBlwxjOF8x
gpGMYjRjGMs4xjOBiUxiMlOYyjS+5humM4OZzOJbvmM2c5jLPOazgIUsYjHf
8wNLWMqP/MQylrOClaxiNWtYy8+sYz0b2MgmNrOFrfzCr2xjO7/xOzv4g53s
Yjd72Ms+9nOAgxziMEc4yjGOc4I/OckpTnOGs5zjPBe4yCX+4jJXuMo1rnOD
m9ziNnf4m7vc4z4PeMg//MsjHvOEpzzjOS94yX/8zyte84a3vCMQFAjEIS5B
xCM+CUhIIj4gMUlISjKSk4KUpCI1afiQtKQjPRnIyEdkIjNZyMrHZCM7OchJ
LnKTh7zkIz8FKEghClOEohSjOCUoSSlKU4aylKM8FahIJSpThWCqUo0QQqlO
DcIIJ4JIalKLKKKJoTZ1qEss9XgP7WqMxA==
          "]], LineBox[CompressedData["
1:eJwN0mOjFgYAQOH3dm+2jZu9bC4s28u1bLu2altetm1j1RaWW7Zt23g+POcX
nNCmHat1CAoEAkFSIzgQqEktalOHutTjZ+rTgIY0ojFNaEozmvMLLWhJK1rT
hra0oz0d6EgnOtOFrnSjOz3oSS9604e+9KM/AxjIIH7lNwYzhKH8zh/8yTCG
M4KRjGI0Y/iLsYxjPBOYyCQmM4WpTGM6M5jJLGYzh7nMYz4LWMgiFrOEpSxj
OStYySpWs4a1rGM9G9jIJjazhb/Zyja28w//soOd7GI3/7GHvexjPwc4yCEO
8z9HOMoxjnOCk5ziNGc4yznOc4GLXOIyV7jKNa5zg5vc4jZ3uMs97vOAhzzi
MU94yjOe84KXvOI1b3jLO97zgY984jNf+Mo3AiG+JQzBhBCWcIQnAhGJRGSi
EJVoRCcGMYlFbOIQl3jEJwEJSURikpCUZCQnBaGkJBWpSUNa0pGeDGQkE5nJ
QlZ+IBvZyUFOcpGbPOQlH/kpQEEKUZgiFKUYxfmREpSkFKX5iTKUpRzlqUBF
KlGZKlSlGtWpwXfTpoTi
          "]], LineBox[CompressedData["
1:eJwNxGeADgQAANDvcJQyitKQVXZGIamsrLLJGXfmccftbd4uGWXL3rMysilk
lNHOzKpQRiEqyub9eK9seELH+KBAIFBdIfkCgc50oSvdCCWM7vSgJ73oTR/C
6Us/IoikPwOIIpoYYokjngQSSSKZFFJJYyCDGMwQhjKMdDLIJItscsjlbd5h
OO8ygpGMYjTv8T5jGMs4xjOBiUxiMh8whalMYzozmMksZjOHucxjPgtYyCIW
s4SlfMhHfMwylrOClXzCKlazhrWsYz0b2MgmPuUzNrOFrXzONrazg518wZfs
Yjd72MtXfM03fMt3fM8P/Mg+9nOAgxziMD9xhKMc4zgn+Jlf+JWTnOI0v/E7
ZzjLOc7zB39ygYtc4i8uc4W/+Yd/uco1/uN/rnODm9ziNne4yz0CwYFAEHnI
Sz6CyU8BHuBBCvIQD1OIwhShKI/wKMUozmM8Tgme4Eme4mlK8gylKE0ZylKO
Z3mO8lSgIpWoTBWq8jzVqE4NavICL1KL2tThJeryMvV4hVd5jfo0oCGNaMzr
NKEpzWhOC97gTVrSita0oS3taE8HOvIWnQihM13oSjdCCaM7PehJL3rTh3D6
0o8IIunPAKKIJoZY4ogngUSSSCaFVNIYyCAGM4ShDCOdDDLJIpsccrkPNC6Z
7w==
          "]], LineBox[CompressedData["
1:eJwNxFVgFQQAAMA3UkBKWjqkle7urgHSopQ0KN3NglwS0p3SKaCISipItxIG
3Z33cZe9Q5/g3kGBQCCtxsUPBMYzgYmEEEoY4UxiMlOYyjSmE0EkUUQTQywz
mMksZvMdc5jLPOazgIUsYjFLWMoylrOClaxiNWtYy/esYz0b2MgmNrOFrWxj
OzvYyQ/sYjd7+JGf2MvP7OMXfuU39nOAgxziMEf4nT84yjH+5DgnOMkpTnOG
s5zjPBe4yCUu8xd/c4WrXOM6//Av//E/N7jJLW5zh7vc4z4PeMgjHvOEpzzj
OS94ySte84a3vCOQIBAIIg5xiUd8EpCQD0hEYpLwIUlJRnJSkJKPSEVq0pCW
dKQnAx+TkUxkJgtZyUZ2cpCTXHxCbvKQl3zkpwAF+ZTPKERhilCUYhSnBCUp
RWnKUJZylKcCFalEZapQlWpUpwY1qUVt6lCXetSnAQ1pRGOaEExTmtGcz2lB
S1rRmja0pR1f0J4v+YoOdKQTnenC13SlG93pQU960Zs+9OUbvqUf/RnAQAYx
mCEMZRjDGcFIRjGaMYxlHOOZwERCCCWMcCYxmSlMZRrTiSCSKKKJIZYZzOQ9
BxCTew==
          "]]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"6", "-", 
                RowBox[{"6", " ", 
                  TagBox["x", HoldForm]}], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "6"], "-", 
                RowBox[{"15", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "4"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "+", 
                RowBox[{"15", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "4"]}], "-", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "6"]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              TagBox["y", HoldForm], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {
        6 - 6 HoldForm[$CellContext`x] + 
          HoldForm[$CellContext`x]^6 - (15 HoldForm[$CellContext`x]^4) 
          HoldForm[$CellContext`y]^2 + (15 HoldForm[$CellContext`x]^2) 
           HoldForm[$CellContext`y]^4 - HoldForm[$CellContext`y]^6 == 0, 
         HoldForm[$CellContext`y] == 0}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJwNw2kyAmAAANDPH/dwpWZcwAHqPLKUbNlVyk4SWSuiyJp9yR28N/P6BmKR
aE8Iod/B3hDiDjnsiKMmTDpmynEnnHTKadPOOOuc8y646JLLZsyac8W8BVdd
c90NN91y2x13LbpnyX3LHnhoxSOPPfHUM8+tWrPuhZc2vPLapi1vvLXtnfc+
+OiTz3Z88dU33/3w0y+//fHXrn/+A3+DRMY=
          "]]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"6", "-", 
                RowBox[{"6", " ", 
                  TagBox["x", HoldForm]}], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "6"], "-", 
                RowBox[{"15", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "4"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "+", 
                RowBox[{"15", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "4"]}], "-", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "6"]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              TagBox["y", HoldForm], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {
        6 - 6 HoldForm[$CellContext`x] + 
          HoldForm[$CellContext`x]^6 - (15 HoldForm[$CellContext`x]^4) 
          HoldForm[$CellContext`y]^2 + (15 HoldForm[$CellContext`x]^2) 
           HoldForm[$CellContext`y]^4 - HoldForm[$CellContext`y]^6 == 0, 
         HoldForm[$CellContext`y] == 0}, "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-6, 6}, {-6, 6}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdeQc41e/7/zkH2Xu2FEmiUhRl9Dxlj4ZKmmYTlYSPliRElFFRKbvIahgh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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJwl1GeYCAQcBvA7t8/t6YZxd9ye3ODOnTs3lDK6pkrlSqVyl1TS0qaJhiZl
tCdpkLYmotBWhNBWadH43dOH3/v//j7P+8/q6GrvDAwICBghum8PgggmhFDC
CCeCSHoSRTQxxBJHPAkkkkQyKaTSizTSySCT3vShL/3IIpsc+jOAXPLIp4BC
iiimhFLKKKeCgQyikiqqqWEwQ6iljqHU08AwGmliOM200EpbdzccxMGM5BAO
ZRSjGcNYDqOdwzmCIzmKozmGcRzLcRzPeE7gRE5iAh2czClM5FRO43QmcQZn
chaT6aSLs5nCOUzlXM7jfKZxAdO5kIu4mEu4lBlcxuVcwZVcxdVcw0xmcS3X
cT03cCM3MZs5zOVmbuFWbmMet3MHd3IXd3MP81nAvdzHQhaxmCXczwM8yEM8
zCM8ymM8zhM8yVMsZRlPs5xneJbneJ4VrOQFVvEiL/Eyr/Aqr/E6q3mDN3mL
t3mHd1nDWtbxHuvZwPt8wEY2sZkP+YiP+YRP+YzP2cIXfMlWtvEV29nBTr5m
F7vZwzd8y3d8zw/8yE/s5Wd+4Vf28Ru/8wd/8hf7OcDf/MO/dI8/kB4EEUwI
oYQRTgSR9CSKaGKIJY54EkgkiWRSSKUXaaSTQSa96UNf+pFFNjn0ZwC55JFP
AYUUUUwJpZRRTgUDGUQlVVRTw2CGUEsdQ6mngWE00sRwmmmhlbbA/3/jf1iw
i8A=
          "]], LineBox[CompressedData["
1:eJwVzlVgFQQAQNE3SlKkWxjS3Y2kdI5eM7qR7m6kpJRSWgEllC6lFFCU7pbu
VNrDx7nfNzimW0jXoEAgkE1qUJNa1KYOdalHfRrQkBAa0ZgmNKUZzWlBKGGE
E0EkUUTTkhha0Zo2tKUd7elARzrRmS68H+xGdz6nBz3pRW/60Jd+9GcAAxnE
YIYwlGEMZwQjGcVoxjCWcYxnAhP5gklMZgpTmcaXTGcGM5nFbL7ia+Ywl3nM
ZwHf8C0LWcRilrCUZSznO75nBStZxQ/8yGrWsJZ1/MTPrGcDG9nEZrawlW1s
Zwc7+YVf2cVu9rCXffzG7+znAAf5gz85xF/8zWGOcJRjHOcEJznFac5wlnOc
5wIXucRlrnCVf7jGdW5wk1vc5g53ucd9HvCQRzzmCU95xnP+5T9e8JJXvOYN
b3lHIFYgEEQsYhOHuMTjA+KTgIQkIjFJ+JCkfEQykpOClKQiNWlISzrSk4GM
ZOJjMpOFYLLyCdnITg5ykovc5CEv+chPAQpSiMIUoSjFKE4JSlKK0pShLOUo
z6dUoCKVqEwVqvIZ1ahODWpSi9rUoS71qE8DGhJCIxrThKY0ozktCCWMcCKI
JIpoWhJDK1rThra0oz0d6Egn/gfVZI9/
          "]], LineBox[CompressedData["
1:eJwNw+c2kAEAANCPN/FKHsFvI1tJtmRkJSF7C9k7hZBZyF4lRMQruPecGxYR
Ex4dEgRBjpGhQRBltDE+MdY4400w0SSTTfGpz0z1uWm+MN0MM80y2xxzzfOl
+b6ywEKLLPa1JZZaZrkVvrHSt1b5zmprrPW9ddbbYKNNNttiq22222GnXXb7
wR577fOj/Q446JDDjjjqmONOOOmU035yxs9+cdY55/3qgosu+c1lV1x1zXU3
/O4PN91y25/uuOue+x546JHHnnjqmb/87bl/vPDSK/967Y3/vPXO/9774CMA
Kly2
          "]]},
        RowBox[{
          RowBox[{
            RowBox[{"1.0654181100763895`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"10.534151752504581`", " ", 
              TagBox["x", HoldForm]}], "+", 
            RowBox[{"0.9930713463050133`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"]}], "-", 
            RowBox[{"48.221075182012136`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"]}], "-", 
            RowBox[{"33.63764368839561`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "4"]}], "+", 
            RowBox[{"8.357892716135318`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "5"]}], "+", 
            RowBox[{"4.396766539765745`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "6"]}], "-", 
            RowBox[{"6.911495470991559`", " ", 
              TagBox["y", HoldForm]}], "-", 
            RowBox[{"1.3031154806986147`", " ", 
              TagBox["x", HoldForm], " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"94.91407107769653`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"88.2791239273342`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"], " ", 
              TagBox["y", HoldForm]}], "-", 
            RowBox[{"27.418219811039066`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "4"], " ", 
              TagBox["y", HoldForm]}], "-", 
            RowBox[{"17.308407591170198`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "5"], " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"0.42748941512476873`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "-", 
            RowBox[{"62.27346897968333`", " ", 
              TagBox["x", HoldForm], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "-", 
            RowBox[{"86.88038385176202`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "+", 
            RowBox[{"35.97838848326677`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "+", 
            RowBox[{"28.390273722800334`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "4"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "+", 
            RowBox[{"13.619283543283649`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "3"]}], "+", 
            RowBox[{"38.00169161645718`", " ", 
              TagBox["x", HoldForm], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "3"]}], "-", 
            RowBox[{"23.60555219802593`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "3"]}], "-", 
            RowBox[{"24.83594982180285`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "3"]}], "-", 
            RowBox[{"6.2332621949060805`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "4"]}], "+", 
            RowBox[{"7.743844542021189`", " ", 
              TagBox["x", HoldForm], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "4"]}], "+", 
            RowBox[{"12.221218096916443`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "4"]}], "-", 
            RowBox[{"0.5652846931803331`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "5"]}], "-", 
            RowBox[{"1.7842474715801033`", " ", 
              TagBox["x", HoldForm], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "5"]}], "+", 
            RowBox[{"0.21066882634208323`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "6"]}]}], "\[Equal]", "0"}]],
       Annotation[#, 
        1.0654181100763895` + 10.534151752504581` HoldForm[$CellContext`x] + 
         0.9930713463050133 HoldForm[$CellContext`x]^2 - 48.221075182012136` 
         HoldForm[$CellContext`x]^3 - 33.63764368839561 
         HoldForm[$CellContext`x]^4 + 
         8.357892716135318 HoldForm[$CellContext`x]^5 + 
         4.396766539765745 HoldForm[$CellContext`x]^6 - 6.911495470991559 
         HoldForm[$CellContext`y] - (1.3031154806986147` 
          HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y] + (94.91407107769653 
           HoldForm[$CellContext`x]^2) 
          HoldForm[$CellContext`y] + (88.2791239273342 
           HoldForm[$CellContext`x]^3) HoldForm[$CellContext`y] - (
          27.418219811039066` HoldForm[$CellContext`x]^4) 
         HoldForm[$CellContext`y] - (17.308407591170198` 
          HoldForm[$CellContext`x]^5) HoldForm[$CellContext`y] + 
         0.42748941512476873` HoldForm[$CellContext`y]^2 - (62.27346897968333 
          HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y]^2 - (86.88038385176202 
          HoldForm[$CellContext`x]^2) 
         HoldForm[$CellContext`y]^2 + (35.97838848326677 
           HoldForm[$CellContext`x]^3) 
          HoldForm[$CellContext`y]^2 + (28.390273722800334` 
           HoldForm[$CellContext`x]^4) HoldForm[$CellContext`y]^2 + 
         13.619283543283649` 
          HoldForm[$CellContext`y]^3 + (38.00169161645718 
           HoldForm[$CellContext`x]) HoldForm[$CellContext`y]^3 - (
          23.60555219802593 HoldForm[$CellContext`x]^2) 
         HoldForm[$CellContext`y]^3 - (24.83594982180285 
          HoldForm[$CellContext`x]^3) HoldForm[$CellContext`y]^3 - 
         6.2332621949060805` 
         HoldForm[$CellContext`y]^4 + (7.743844542021189 
           HoldForm[$CellContext`x]) 
          HoldForm[$CellContext`y]^4 + (12.221218096916443` 
           HoldForm[$CellContext`x]^2) HoldForm[$CellContext`y]^4 - 
         0.5652846931803331 
         HoldForm[$CellContext`y]^5 - (1.7842474715801033` 
          HoldForm[$CellContext`x]) HoldForm[$CellContext`y]^5 + 
         0.21066882634208323` HoldForm[$CellContext`y]^6 == 0, "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-6, 6}, {-10, 10}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729352009238451*^9, 3.729352009257865*^9}, 
   3.7331603921187067`*^9, 3.733160791533451*^9, {3.733161147759193*^9, 
   3.733161168436981*^9}, 3.733161268075931*^9, {3.733161485357985*^9, 
   3.7331614966548853`*^9}, 3.733161556294078*^9, 3.733161768589912*^9, {
   3.7331619023724003`*^9, 3.733161950839259*^9}, 3.7331621626528482`*^9, 
   3.7335119219840937`*^9},
 CellLabel->"Out[88]=",
 CellID->1533459928,ExpressionUUID->"6f2ff96f-2837-4f5f-8bc2-b9d95e8d1473"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", "=", 
  RowBox[{"gaussCurve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", "^", "2"}], "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", "^", "2"}], "-", "4"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", "^", "2"}], "-", "9"}], ")"}]}], ",", "x", ",", "y", ",", 
    "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.733160403237949*^9, 3.733160403749401*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"48ce7425-4f7c-4c96-ae0d-edbdaedc9214"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "36"}], "+", 
  RowBox[{"49", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"14", " ", 
   SuperscriptBox["x", "4"]}], "+", 
  SuperscriptBox["x", "6"], "-", 
  RowBox[{"49", " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{"84", " ", 
   SuperscriptBox["x", "2"], " ", 
   SuperscriptBox["y", "2"]}], "-", 
  RowBox[{"15", " ", 
   SuperscriptBox["x", "4"], " ", 
   SuperscriptBox["y", "2"]}], "-", 
  RowBox[{"14", " ", 
   SuperscriptBox["y", "4"]}], "+", 
  RowBox[{"15", " ", 
   SuperscriptBox["x", "2"], " ", 
   SuperscriptBox["y", "4"]}], "-", 
  SuperscriptBox["y", "6"]}]], "Output",
 CellChangeTimes->{{3.7293520272298737`*^9, 3.7293520272355013`*^9}, {
   3.733160398295115*^9, 3.733160404580103*^9}, 3.7331607915593233`*^9, 
   3.733161172551518*^9, 3.733161268100617*^9, 3.733161556317349*^9, 
   3.7331617686270237`*^9, 3.733162171352334*^9, 3.7335119220100183`*^9},
 CellLabel->"Out[89]=",
 CellID->909762249,ExpressionUUID->"0ad6be11-aab3-4b2b-89f2-3bbbb586b0c1"]
}, Open  ]],

Cell[TextData[{
 "This curve does not meet the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "3d0d9a81-4f24-40e2-a942-c399c7bf6253"],
 "-axis: "
}], "CodeCaption",
 CellChangeTimes->{{3.695914349833748*^9, 3.695914371879344*^9}, {
   3.695914534783522*^9, 3.695914558992763*^9}, {3.695914592593505*^9, 
   3.695914595129735*^9}, {3.722883012574627*^9, 3.722883013630587*^9}, 
   3.729352226919374*^9, {3.7385106488187037`*^9, 
   3.73851069176795*^9}},ExpressionUUID->"1e4099f9-07a9-4c20-bdcc-\
5c5515757a48"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "=", 
  RowBox[{"iTransform", "[", 
   RowBox[{"x", ",", "x", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.733160411909684*^9, 3.733160412903081*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"8a8123ca-3250-4357-9124-7686a5807e33"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7812879011987071`"}], ",", 
     RowBox[{"-", "0.3168196688992504`"}], ",", "0.9191639531555853`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1.4009431979825675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.729352040853757*^9, 3.72935204085935*^9}, {
   3.733160407366007*^9, 3.733160415748947*^9}, 3.7331607915759907`*^9, 
   3.733161193196619*^9, 3.733161268116116*^9, 3.733161556345457*^9, 
   3.733161768643115*^9, 3.73316217367596*^9, 3.733511922057218*^9},
 CellLabel->"Out[90]=",
 CellID->290552303,ExpressionUUID->"3e13c645-1317-40be-8292-283395ed5baf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"h1", "=", 
   RowBox[{"FLT", "[", 
    RowBox[{"h", ",", "A", ",", "x", ",", "y"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"h", "\[Equal]", "0"}], ",", 
       RowBox[{"x", "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "]"}], ",", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"h1", "\[Equal]", "0"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]}], "}"}]}], "Input",
 CellLabel->"In[91]:=",ExpressionUUID->"0493bd8b-0ebb-487c-b34b-3123395a1fcb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxtnAVYlUvX9zfdXXZgYIKd6IzdAXZ3Yh3j2B3HLiwssLvbo84CC7sVExVF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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJwl1GOjEAYABdD3amlZy+bism1ry3xh8WXbtm1uy9bici27Ldt2p/pw7v0F
9yYJal05ODAgICCE+NaE5AdCEZowhCUcPxKeCEQkEpGJQlSiEZ0YxOQnYhGb
OMQlHvFJQEISkZgkJCUZyUlBSlKRmp9JQ1rSkZ4MZOQXMpGZLGQlG9nJQU5y
kZs85CUf+SlAQQpRmCIUpRjFKUFJSlGaMpSlHOWpQEUqUZkq/MpvVKUa1alB
TWpRmzrUpR71aUAQDWlEY5rwO01pRnNa0JJWBNOaNrSlHe3pQEc60ZkudKUb
3elBT3rRmz70pR/9GcBABjGYIQxlGMMZwUhGMZoxjGUc45nARCYxmSlMZRrT
mcFMZjGbOcxlHvNZwEIWsZglLGUZf/Anf7GcFaxkFatZw1rWsZ4NbGQTm9nC
Vraxnb/ZwU52sZs97OUf9rGfAxzkEIc5wlGO8S/HOcFJTnGaM5zlHOe5wEUu
cZkr/Mf/XOUa17nBTW5xmzvc5R73ecBDHvGYJzzlGc95wUte8Zo3vOUd7/nA
Rz7xma/jDwz8/gNfAKrSgT0=
          "]], LineBox[CompressedData["
1:eJwl0fefDwQAxvHvcbg7Z527s8fZblt39t7jcEpGZiKJUymFsndR9myakcqW
vUNmCCmFIg1ERtPbyw/vzx/wPDE9M9IHBAUCgbaSmWCykJVshBBKGNkJJwc5
yUVu8hBBXiKJIpp85KcABSlEYYpQlGIUJ4YSlKQUpSlDWcpRnljiiCeBRJJI
pgIVqURlqpBCKlWpRnVqUJNa1KYOdalHfRrQkEY0pglNaUZzWtCSVqTRmjZB
j7ZLpx2P8TjteYIOdKQTnXmSLnSlG93pQU+eohdP05s+PENfnqUfz9Gfh6dl
MJDneYEXGcRLvMxgXuFVhjCUYbzG6wxnBCMZxWjGMJZxjGcCE5nEZN7gTaYw
lbd4m2lMZwYzmcVs5jCXecxnAQt5h3d5j/f5gA9ZxGKWsJRlLOcjVrCSj1nF
J3zKZ6xmDWtZx3o2sJFNfM5mtrCVbWxnBzvZxW72sJd97OcLDnCQQ3zJYY5w
lGMc5wRfcZJTnOZrznCWc3zDeb7lOy7wPT9wkUtc5kd+4gpX+Zlr/MKv/Mbv
XOcGN/mDW9zmT+5wl3vc5y/+5h/+5T/+J5ApEAgiE5kJJgtZyUYIoYSRnXBy
kJNc5CYPEeQlkiiiyUd+ClCQQhSmCEUpRnFiKEFJSlGaMpSlHOWJJY54Ekgk
iWQqUJFKVKYKKaRSlWpUpwY1qUVt6lCXetSnAQ1pRGOa0JRmNKcFLWlFGq1p
Q1vSaccDeX2Qxg==
          "]], LineBox[CompressedData["
1:eJwNxFVgFQQAAMAHo6RLukYoIdKNEtKIwuiNHAtyo1MEA1S6Q1KkS7qR7u7u
7lBCAeU+7oLDY0Ni4gQCgaxqEDcQaEgjGtOEpoQSRjOa04KWtKI14bQhgkii
iKYt7WhPBzrSiRhi6UwXutKN7vSgJ73oTR/60o9v6M+3DGAg3/E9P/AjgxjM
T/zMLwxhKMMYzghGMorRjGEs4xjPBCYyicn8yhSmMo3pzGAmvzGL35nNHOYy
j/ksYCGLWMwSlvIHy1jOClayitWsYS3rWM8GNrKJzfzJFrayje3sYCe72M0e
9rKP/RzgIIc4zBGOcozjnOAkpzjNGc5yjvNc4CKXuMwVrnKN69zgJre4zR3u
co/7POAhj3jME57yjOf8xd+84CWveM0//Msb3vKO//ifQFAgEIe4BBGP+CQg
IYn4gMQkISnJSE4KUpKK1KQhLR+SjvRkICOZyEwWspKN7OQgmJzkIjd5+IiP
yUs+8lOATyjIpxSiMEUoSjGKU4KSlKI0ZShLOcrzGZ9TgYpUojJfUIWqVKM6
NahJLWrzJXX4iq+pSz1CqE8DGtKIxjShKaGE0YzmtKAlrWhNOG2IIJIoomlL
O9rTgY50IoZYOvMeaKyPFw==
          "]], LineBox[CompressedData["
1:eJwNxGeADgQAANAPZ6+ipIxcZTVRSoqyK6MotIeMZFx3x3Fnu2mfc5xz9rxl
c3fWGXc0bbJHO0IRKZTej/eCe4R0GVgkEAh0VWixQCCMcAYxmAiGMJRIohjG
cEYwklGMZgxjiSaGWOKIJ4FxjGcCE5nEZKaQyFSSmEYy05lBCjNJZRZpzGYO
c5nHfBawkEUsZglLWUY6GWSSRTbLWcFKVrGaNaxlHevJIZc8NrCRTWxmC/ls
ZRvb2UEBhexkF5/zBV/yFV/zDbvZw172sZ8DHOQQh/mWIxzlGMc5wUlOcZoz
nOU7vucHfuQnfuYXfuUc5/mNC1zkEr/zB5e5wp9c5Rp/cZ2/+Ycb3OQW//If
twkEBQJFKEoxgihOCUpSitKUoSzlKE8FKnIHd1KJytzF3VThHqpyL/dRjerU
oCb3U4tgHuBBHqI2dahLPerzMI/wKI/xOE/QgIY04kmeojFP8wxNeJamPMfz
NKM5L/AiLWhJK1rThra04yVe5hXa04GOdOJVXqMzXXidN+hKN7rzJm/xNu/w
Lu/xPh/wIR/Rg4/pSS9604dP6Mun9KM/AxhICJ8RShjhDGIwEQxhKJFEMYzh
jGAkoxjNGMYSTQyxxBFPAuMYzwQmMonJTCGRqSQxjWSmM4MUZpLKLNKYzRzm
Mo/5LGAhi1jMEpayjHQyyCSLbJazgpWsYjVrWMs61pNDLnlsYCOb2MwW8tnK
NrazgwIK2cn/nhe5xg==
          "]], LineBox[CompressedData["
1:eJwNw4dWjgEAANDvT0VIJCOhgSJEIoWGVZkNKg2hYVfv5UFQKSUzRJmlQRKi
uPecm9zYXtEWCoLgjnfDg+Ce9+2w0y4f2G2PD+21z0f2+9gnPvWZz33hgC99
5WsHfeNbhxz2ne/94Ec/+dkRR/3imONOOOlXvznld6f94Yw//eVvZ/3jX+ec
959BRBCEDHOB4UYY6UIXGeVil7jUaJcZ43JXGOtK41zlate41njXmeB6N7jR
RJNMNsVNbnaLqaa51W2mu90d7jTDXe420z1mudd9ZrvfHHM94EEPmWe+BRZ6
2CMe9ZjHLbLYEk940lOe9oxnLbXMcis853krrbLaC9ZYa531XrTBS172io02
2WyLV73mdW9401vettU22/0PFERRDw==
          "]], LineBox[CompressedData["
1:eJwNw/dazQEAANDfLfcKqWSV/7ySR/AAJMqIEoUkpayisiuXZIfISCSECKWM
sktWIRnnfN+ZO3/hvAWhIAiipoWDYJHpLnaJGWa61GUud4VZrnSV2ea42lzX
uNY8813nejdY4EYL3WSRmy22xC2WWuZWt7ndHe603Ap3udtKq6x2j3vd534P
eNBD1lhrnYeNesSj1nvMBo97wpOe8rRnPGuj5zzvBZu86CWbvewVr3rNFq/b
6g1v2uYt273tHe/a4T3v+8BOH/rILh/7xKd22+Mze+3zuS986Sv7HfC1b3zr
O9/7wY8OOuQnh/3sF7/6ze+OOOoPf/rLMX877h//+s8gEgQhY4x1gmEjTjTO
SU52ivFONcFEk5xmstOd4UxnOdsUU53jf2+jbmg=
          "]]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"-", "36"}], "+", 
                RowBox[{"49", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"]}], "-", 
                RowBox[{"14", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "4"]}], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "6"], "-", 
                RowBox[{"49", " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "+", 
                RowBox[{"84", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "-", 
                RowBox[{"15", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "4"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "-", 
                RowBox[{"14", " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "4"]}], "+", 
                RowBox[{"15", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "4"]}], "-", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "6"]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              TagBox["x", HoldForm], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {-36 + 49 HoldForm[$CellContext`x]^2 - 14 
          HoldForm[$CellContext`x]^4 + HoldForm[$CellContext`x]^6 - 49 
          HoldForm[$CellContext`y]^2 + (84 HoldForm[$CellContext`x]^2) 
           HoldForm[$CellContext`y]^2 - (15 HoldForm[$CellContext`x]^4) 
          HoldForm[$CellContext`y]^2 - 14 
          HoldForm[$CellContext`y]^4 + (15 HoldForm[$CellContext`x]^2) 
           HoldForm[$CellContext`y]^4 - HoldForm[$CellContext`y]^6 == 0, 
         HoldForm[$CellContext`x] == 0}, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJwNw9k2AlAAAMDrxU+IhJQ1KVEp+xIRpYSyZEtS//9m5pyJ9cb10UQIoenU
ZAgRp50x6qwx55x3wbiLJky65LIrrrrmuik3TLtpxqxb5tx2x7wFi+5asuye
+x546JHHnnjqmedWvPDSqldeW/PGW+s2vLNpy3vbPvjokx27Pvviq2/2fPfD
T7/8tu+PA38d+ufIsf9iFxrw
          "]]},
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"-", "36"}], "+", 
                RowBox[{"49", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"]}], "-", 
                RowBox[{"14", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "4"]}], "+", 
                SuperscriptBox[
                 TagBox["x", HoldForm], "6"], "-", 
                RowBox[{"49", " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "+", 
                RowBox[{"84", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "-", 
                RowBox[{"15", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "4"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], "-", 
                RowBox[{"14", " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "4"]}], "+", 
                RowBox[{"15", " ", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"], " ", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "4"]}], "-", 
                SuperscriptBox[
                 TagBox["y", HoldForm], "6"]}], "\[Equal]", "0"}], ",", 
            RowBox[{
              TagBox["x", HoldForm], "\[Equal]", "0"}]}], "}"}]],
       Annotation[#, {-36 + 49 HoldForm[$CellContext`x]^2 - 14 
          HoldForm[$CellContext`x]^4 + HoldForm[$CellContext`x]^6 - 49 
          HoldForm[$CellContext`y]^2 + (84 HoldForm[$CellContext`x]^2) 
           HoldForm[$CellContext`y]^2 - (15 HoldForm[$CellContext`x]^4) 
          HoldForm[$CellContext`y]^2 - 14 
          HoldForm[$CellContext`y]^4 + (15 HoldForm[$CellContext`x]^2) 
           HoldForm[$CellContext`y]^4 - HoldForm[$CellContext`y]^6 == 0, 
         HoldForm[$CellContext`x] == 0}, "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-6, 6}, {-6, 6}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxlWnk4lG/UZlSWRBKihRJatFmSxINEQihSoZKSFkSKKIk2pUgoipKtLJFQ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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJwl1cMWGAgQBMDYtm3btm3btm3btm3btm1bi2zl7aF6vqB7EjZqX6ldwAAB
AvwSf24gAhOEoAQjOCEISShCE4awhCM8EYhIJCIThahEIzoxiEksYhOHuMQj
PglISCISk4SkJCM5KUhJKlKThrSkIz0ZyEgmMpOFrGQjOznISS5yk4e85CM/
BShIIQpThKIUozglKEkpSlOGspSjPBWoSCUqU4WqVKM6NahJLWpTh7rUoz4N
aEgjGtOEpjSjOS1oSSta04a2tKM9HehIJzrTha50ozs96EkvetOHvvSjPwMY
yCAGM4ShDGM4IxjJKEYzhrGMYzwTmMgkJjOFqUxjOjOYySxmM4e5zGM+C1jI
IhazhKUsYzkrWMkqVrOGtaxjPRvYyCY2s4WtbGM7O9jJLnazh73sYz8HOMgh
DnOEoxzjOCc4ySlOc4aznOM8F7jIJS5zhatc4zo3uMktbnOHu9zjPg94yCMe
84SnPOM5L3jJK17zhre84z0f+MgnPvOFr3zjOz/4yS/+4m/+4V9+86f8AQlE
YIIQlGAEJwQhCUVowhCWcIQnAhGJRGSiEJVoRCcGMYlFbOIQl3jEJwEJSURi
kpCUZCQnBSlJRWrSkJZ0pCcDGclEZrKQlWxkJwc5yUVu8pCXfOSnAAUpRGGK
UJRiFKcEJSlFacpQlnKUpwIVqURlqlCValSnBjWpRW3qUJd61KcBDWlEY5rQ
lGY0pwUtaUVr2tCWP+Pdng50pBOd6UJXutGdHvSkF73pQ1/60Z8BDGQQgxnC
UIYxnBGMZBSjGcNYxjGeCUxkEpOZwlSmMZ0ZzGQWs5nDXOYxnwUsZBGLWcJS
lrGcFaxkFatZw1rWsZ4NbGQTm9nCVraxnR3sZBe72cNe9rGfAxzkEIc5wlGO
cZwTnOQUpznDWc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nCU57x
nBe85BWvecNb3vGeD3zkE5/5wle+8Z0f/Az4/5//D/yb/bk=
          "]], 
         LineBox[CompressedData["
1:eJwVyVdXiAEAgOGv7JFkj0hUVvYsM1lFISN7ZI/KJtl7ZmTvvffKXiHElZ+T
9bh4znnPeaOzcjNyQoIg+EmZ+MVv/vD3/wgNghBCKUd5KlCRSlSmClWpRnXC
qEE4NYmgFrWpQ13qUZ8GNKQRjYmkCU2JohnRNKcFMcQSR0ta0Zo2tCWedrSn
Ax3pRGe60JVudKcHPUkgkV70pg996Ud/khhAMgMZxGCGMJQUUhnGcNJIZwQj
GUUGoxnDWMaRyXgmMJFJTGYKU5nGdGaQxUxmMZs5zGUe81nAQhaRTQ65LGYJ
S1nGclawklWsJo815LOWdaxnAxvZxGa2sJVtbGcHO9nFbvawl30UsJ8DHOQQ
hRzmCEc5xnFOcJJTnOYMZznHeS5wkUtc5gpXucZ1bnCTW9zmDne5x30e8JBH
POYJTyniGc95wUte8Zo3vOUd7/lAMR/5xGdK+MJXvlHKd37wDynQW5Q=
          "]], 
         LineBox[CompressedData["
1:eJwNw1VWFVAAAMD7HlISktLdIhLSDQILYAksAL7ZJGUgIN3S3TFzzpRNTI1P
RkII085EQ5h1znkX/Okvf/vHRf+65LIr/nPVNdfdcNMtt91x1z33PfDQ/x55
7ImnnnnuhZdeee2Nt95574OPPvnsi6++GWJCiBg1xg/GGme8CSb60SSTTTHV
T6aZboaZZpntZ3PMNc98Cyy0yGJLLLXMciustMpqa6y1zi/W+9UGv9lok822
+N1W22y3w0677LbHXvvsd8BBhxz2hyOOOuY7JbQ6IA==
          "]]},
        RowBox[{
          RowBox[{
            RowBox[{"239.61491864022324`", "\[VeryThinSpace]"}], "+", 
            RowBox[{"879.4387119495389`", " ", 
              TagBox["x", HoldForm]}], "-", 
            RowBox[{"223.34396946917786`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"]}], "-", 
            RowBox[{"4778.917049180995`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"]}], "-", 
            RowBox[{"7565.181386925961`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "4"]}], "-", 
            RowBox[{"4635.424745079152`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "5"]}], "-", 
            RowBox[{"988.8426400321733`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "6"]}], "-", 
            RowBox[{"577.0029535798872`", " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"293.0735895450716`", " ", 
              TagBox["x", HoldForm], " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"9406.394833966327`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"19854.172645856113`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"], " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"15206.59559708713`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "4"], " ", 
              TagBox["y", HoldForm]}], "+", 
            RowBox[{"3892.69962423739`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "5"], " ", 
              TagBox["y", HoldForm]}], "-", 
            RowBox[{"106.80423541429673`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "-", 
            RowBox[{"6855.908168363035`", " ", 
              TagBox["x", HoldForm], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "-", 
            RowBox[{"21706.251994753693`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "-", 
            RowBox[{"22166.839646279786`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "-", 
            RowBox[{"7093.044578147778`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "4"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "2"]}], "+", 
            RowBox[{"1798.7266375143308`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "3"]}], "+", 
            RowBox[{"11389.77148023392`", " ", 
              TagBox["x", HoldForm], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "3"]}], "+", 
            RowBox[{"17447.178679520875`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "3"]}], "+", 
            RowBox[{"7443.768446412725`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "3"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "3"]}], "-", 
            RowBox[{"2399.199126403391`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "4"]}], "-", 
            RowBox[{"7350.324090128391`", " ", 
              TagBox["x", HoldForm], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "4"]}], "-", 
            RowBox[{"4703.979211025159`", " ", 
              SuperscriptBox[
               TagBox["x", HoldForm], "2"], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "4"]}], "+", 
            RowBox[{"1318.426846009805`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "5"]}], "+", 
            RowBox[{"1687.5044960852224`", " ", 
              TagBox["x", HoldForm], " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "5"]}], "-", 
            RowBox[{"269.3943118998183`", " ", 
              SuperscriptBox[
               TagBox["y", HoldForm], "6"]}]}], "\[Equal]", "0"}]],
       Annotation[#, 
        239.61491864022324` + 879.4387119495389 HoldForm[$CellContext`x] - 
         223.34396946917786` HoldForm[$CellContext`x]^2 - 4778.917049180995 
         HoldForm[$CellContext`x]^3 - 7565.181386925961 
         HoldForm[$CellContext`x]^4 - 4635.424745079152 
         HoldForm[$CellContext`x]^5 - 988.8426400321733 
         HoldForm[$CellContext`x]^6 - 577.0029535798872 
         HoldForm[$CellContext`y] + (293.0735895450716 
           HoldForm[$CellContext`x]) 
          HoldForm[$CellContext`y] + (9406.394833966327 
           HoldForm[$CellContext`x]^2) 
          HoldForm[$CellContext`y] + (19854.172645856113` 
           HoldForm[$CellContext`x]^3) 
          HoldForm[$CellContext`y] + (15206.59559708713 
           HoldForm[$CellContext`x]^4) 
          HoldForm[$CellContext`y] + (3892.69962423739 
           HoldForm[$CellContext`x]^5) HoldForm[$CellContext`y] - 
         106.80423541429673` 
         HoldForm[$CellContext`y]^2 - (6855.908168363035 
          HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y]^2 - (21706.251994753693` 
          HoldForm[$CellContext`x]^2) 
         HoldForm[$CellContext`y]^2 - (22166.839646279786` 
          HoldForm[$CellContext`x]^3) 
         HoldForm[$CellContext`y]^2 - (7093.044578147778 
          HoldForm[$CellContext`x]^4) HoldForm[$CellContext`y]^2 + 
         1798.7266375143308` 
          HoldForm[$CellContext`y]^3 + (11389.77148023392 
           HoldForm[$CellContext`x]) 
          HoldForm[$CellContext`y]^3 + (17447.178679520875` 
           HoldForm[$CellContext`x]^2) 
          HoldForm[$CellContext`y]^3 + (7443.768446412725 
           HoldForm[$CellContext`x]^3) HoldForm[$CellContext`y]^3 - 
         2399.199126403391 
         HoldForm[$CellContext`y]^4 - (7350.324090128391 
          HoldForm[$CellContext`x]) 
         HoldForm[$CellContext`y]^4 - (4703.979211025159 
          HoldForm[$CellContext`x]^2) HoldForm[$CellContext`y]^4 + 
         1318.426846009805 
          HoldForm[$CellContext`y]^5 + (1687.5044960852224` 
           HoldForm[$CellContext`x]) HoldForm[$CellContext`y]^5 - 
         269.3943118998183 HoldForm[$CellContext`y]^6 == 0, "Tooltip"]& ]}],
    AspectRatio->1,
    AxesLabel->{None, None},
    AxesOrigin->{0., 0.},
    DisplayFunction->Identity,
    Frame->True,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"DefaultBoundaryStyle" -> Automatic, "GridLinesInFront" -> True},
    
    PlotRange->{{-4, 4}, {-3, 3}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7293520538380136`*^9, 3.729352053857297*^9}, 
   3.7331604190004673`*^9, 3.733160791901289*^9, 3.7331611966967793`*^9, 
   3.7331612684027243`*^9, 3.733161556662572*^9, 3.733161768970933*^9, {
   3.733162167617744*^9, 3.733162176163513*^9}, 3.733511922341792*^9},
 CellLabel->"Out[92]=",
 CellID->2082226890,ExpressionUUID->"b09df7f0-b8a4-4718-8704-ccea89b93672"]
}, Open  ]],

Cell["\<\
In Chapter 9, we call the innermost oval a depth 2 oval since it is contained \
in the interior of a curve component, which itself is contained in the \
interior of a curve component.\
\>", "Text",
 CellChangeTimes->{{3.737998621528496*^9, 3.737998636127816*^9}, {
  3.7431674760629063`*^9, 
  3.743167476390263*^9}},ExpressionUUID->"c8887c8f-3629-4b20-8537-\
bf6944048017"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.5 Summary of Fractional Linear Transformations", "Subsection",
 CellChangeTimes->{{3.72708961496471*^9, 3.727089629349016*^9}, {
  3.727089669430244*^9, 3.727089703014363*^9}, {3.727089886051697*^9, 
  3.727089893362864*^9}},
 CellID->370162837,ExpressionUUID->"cb6f8af2-4c42-43a1-bffa-b20035055a4a"],

Cell["\<\
The single idea of transforming curves has several different facets. We can \
give the transformation as a function or use a matrix representation. Since \
we can represent a curve as an equation, bivariate polynomial or a point set, \
we can transform either. Further, we can decide if we want to transform just \
affine points or if we want to include infinite points. In the latter case, \
we can still work primarily in the affine plane or move to the projective \
plane. \
\>", "Text",
 CellChangeTimes->{{3.727089706728869*^9, 3.727089874644279*^9}, {
   3.727089914357401*^9, 3.727090029577613*^9}, {3.7293522269539423`*^9, 
   3.729352227023259*^9}, {3.737998696233678*^9, 3.737998704632419*^9}, {
   3.737998745816868*^9, 3.737998760511595*^9}, 3.737999153815483*^9, 
   3.7431674880551*^9},
 CellID->1873836568,ExpressionUUID->"2eedc596-cf91-4745-bb80-e31ed2e1727a"],

Cell["\<\
As a function on the affine plane, a fractional linear transformation is \
given as \
\>", "Text",
 CellChangeTimes->{{3.727090092793991*^9, 3.727090130882406*^9}, 
   3.737999168112846*^9},
 CellID->1667332537,ExpressionUUID->"3f9151b5-cd8e-4cb8-add8-83abea381e7d"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"F", "(", 
    RowBox[{"x", ",", "y"}], ")"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         SubscriptBox["a", 
          RowBox[{"1", ",", "1"}]], "x"}], "+", 
        RowBox[{
         SubscriptBox["a", 
          RowBox[{"1", ",", "2"}]], "y"}], "+", " ", 
        SubscriptBox["a", 
         RowBox[{"1", ",", "3"}]]}], 
       RowBox[{
        RowBox[{
         SubscriptBox["d", "1"], "x"}], "+", 
        RowBox[{
         SubscriptBox["d", "2"], "y"}], "+", 
        SubscriptBox["d", "3"]}]], ",", 
      FractionBox[
       RowBox[{
        RowBox[{
         SubscriptBox["a", 
          RowBox[{"2", ",", "1"}]], "x"}], "+", 
        RowBox[{
         SubscriptBox["a", 
          RowBox[{"2", ",", "2"}]], "y"}], "+", " ", 
        SubscriptBox["a", 
         RowBox[{"2", ",", "3"}]]}], 
       RowBox[{
        RowBox[{
         SubscriptBox["d", "1"], "x"}], "+", 
        RowBox[{
         SubscriptBox["d", "2"], "y"}], "+", 
        SubscriptBox["d", "3"]}]]}], ")"}], "."}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.729024028242256*^9, 3.729024034935664*^9}, {
   3.729352227028493*^9, 3.729352244333194*^9}, 3.734110279831918*^9, {
   3.737999177135229*^9, 3.7379991786866493`*^9}},
 CellID->931799694,ExpressionUUID->"5e5be858-1d53-4299-8276-ffeebc2f0dc0"],

Cell["\<\
The domain is the plane subset where the denominator is not zero, which is \
either the plane or the plane with a single line removed. This may be \
represented in matrix form:\
\>", "Text",
 CellChangeTimes->{{3.727090150019837*^9, 3.727090237486109*^9}, {
   3.727090272981689*^9, 3.727090273614021*^9}, 3.7293522270761967`*^9},
 CellID->1883940441,ExpressionUUID->"0771f5ab-5f85-4e22-8996-48da14a8da39"],

Cell[BoxData[
 FormBox[
  RowBox[{"A", "=", 
   RowBox[{"(", GridBox[{
      {
       SubscriptBox["a", 
        RowBox[{"1", ",", "1"}]], 
       SubscriptBox["a", 
        RowBox[{"1", ",", "2"}]], 
       SubscriptBox["a", 
        RowBox[{"1", ",", "3"}]]},
      {
       SubscriptBox["a", 
        RowBox[{"2", ",", "1"}]], 
       SubscriptBox["a", 
        RowBox[{"2", ",", "2"}]], 
       SubscriptBox["a", 
        RowBox[{"2", ",", "3"}]]},
      {
       SubscriptBox["d", "1"], 
       SubscriptBox["d", "2"], 
       SubscriptBox["d", "3"]}
     }], ")"}]}], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.729024048130384*^9, 3.729024055343705*^9}, 
   3.7293521025564137`*^9},
 CellID->1591798916,ExpressionUUID->"8719d27a-337a-49bc-b67e-f375585df52e"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"F", ":", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], " ", "\[RightTeeArrow]", " ", 
     RowBox[{"A", "(", "\[NoBreak]", GridBox[{
        {"x"},
        {"y"},
        {"1"}
       }], "\[NoBreak]", ")"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"u", ",", "v", ",", "w"}], "}"}], " ", "\[RightTeeArrow]", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["u", "w"], ",", " ", 
      FractionBox["v", "w"]}], "}"}]}]}], TraditionalForm]], "DisplayFormula",\

 CellChangeTimes->{{3.729024067001976*^9, 3.729024073130773*^9}, {
  3.729352096805235*^9, 3.7293520988524323`*^9}},
 CellID->1704854264,ExpressionUUID->"804ea643-3d1a-4620-8db9-e2b152fd854c"],

Cell[TextData[{
 "This is consistent with transformations in the Wolfram Language. See the \
documentation pages for the Wolfram Language functions ",
 ButtonBox["TransformationMatrix",
  BaseStyle->"Link"],
 " and ",
 Cell[BoxData[
 "Transformation"], "InlineCodeText",ExpressionUUID->
  "994f420a-684f-41dd-8ba8-64caa6f55c2c"],
 " for more information."
}], "Text",
 CellChangeTimes->{{3.727090341545835*^9, 3.727090361577037*^9}, {
   3.727090483228668*^9, 3.727090529942054*^9}, {3.727090659969052*^9, 
   3.727090661938033*^9}, {3.729024108003427*^9, 3.729024140157559*^9}, 
   3.729352227112364*^9, {3.737999204239566*^9, 3.73799922721552*^9}, {
   3.738509090698835*^9, 3.73850910720131*^9}, 3.738509148245412*^9, {
   3.7385092135963297`*^9, 3.7385092195614243`*^9}, {3.738509283020804*^9, 
   3.738509283107955*^9}, {3.743167554321692*^9, 3.7431675708188972`*^9}, {
   3.74316762088295*^9, 3.743167634483938*^9}},
 CellID->521770912,ExpressionUUID->"e4c2b153-1a10-4700-832c-de13382b3167"],

Cell[TextData[{
 "Our matrices agree, in the affine case, with ",
 ButtonBox["TransformationMatrix",
  BaseStyle->"Link"],
 ", and one can generally represent the transformation that works on points \
using either ",
 Cell[BoxData[
 "flt"], "InlineCodeText",ExpressionUUID->
  "8492586f-70bb-4296-9c67-3acddb823de0"],
 " or the ",
 Cell[BoxData[
 "Transformation"], "InlineCodeText",ExpressionUUID->
  "3006cca9-70a5-4d1a-97c3-bb7598b8f843"],
 " function."
}], "Text",
 CellChangeTimes->{{3.72709063288058*^9, 3.727090637944881*^9}, {
   3.72709067178567*^9, 3.727090749860237*^9}, {3.727090894496205*^9, 
   3.727090951884074*^9}, {3.729024149579833*^9, 3.729024180503963*^9}, 
   3.729352227148369*^9, {3.737999488494953*^9, 3.7379995215419703`*^9}, 
   3.737999582774012*^9},
 CellID->443541071,ExpressionUUID->"5f3bbf55-c2c7-4e05-9cfe-b55434be465b"],

Cell[TextData[{
 "For example, consider a random ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", "\[Times]", "3"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"47010bf3-eb25-4eb0-a6d3-25f960936fcd"],
 " matrix and a random real point:"
}], "CodeCaption",
 CellChangeTimes->{{3.727090912130134*^9, 3.727090913763898*^9}, {
   3.727090974169949*^9, 3.727091011714937*^9}, {3.727091077412873*^9, 
   3.727091103419801*^9}, 3.729024189144702*^9, 3.729352227184763*^9, {
   3.7379995537984457`*^9, 3.737999573846366*^9}, {3.738509300324597*^9, 
   3.738509300563863*^9}},
 CellID->695906440,ExpressionUUID->"79a74f9e-ee00-4692-8e3d-8391c58e1905"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "8"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p", "=", 
   RowBox[{"{", 
    RowBox[{"3.4552977152086983`", ",", 
     RowBox[{"-", "3.719873903204607`"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"flt", "[", 
  RowBox[{"p", ",", "A"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TransformationFunction", "[", "A", "]"}], "[", "p", 
  "]"}]}], "Input",
 CellChangeTimes->{{3.727091014036834*^9, 3.727091065940707*^9}, {
  3.727091108622174*^9, 3.727091129630393*^9}},
 CellLabel->"In[93]:=",
 CellID->676175092,ExpressionUUID->"0fa58a9b-6213-46fb-9918-ac9075e7146e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.0199925581618194`"}], ",", "2.617712345631218`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.727091130427585*^9, 3.729350696627749*^9, 
  3.729350983071517*^9, 3.729351045393174*^9, 3.729351105895746*^9, 
  3.729351660323657*^9, 3.729351941663281*^9, 3.733160469256399*^9, 
  3.733160791924604*^9, 3.73316120266893*^9, 3.733161268426749*^9, 
  3.733161523096655*^9, 3.733161556686348*^9, 3.7331617689988537`*^9, 
  3.733511922368561*^9},
 CellLabel->"Out[95]=",
 CellID->593828718,ExpressionUUID->"ec40fa19-0290-451c-8721-60ae4485bbe4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.0199925581618194`"}], ",", "2.617712345631218`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.727091130427585*^9, 3.729350696627749*^9, 
  3.729350983071517*^9, 3.729351045393174*^9, 3.729351105895746*^9, 
  3.729351660323657*^9, 3.729351941663281*^9, 3.733160469256399*^9, 
  3.733160791924604*^9, 3.73316120266893*^9, 3.733161268426749*^9, 
  3.733161523096655*^9, 3.733161556686348*^9, 3.7331617689988537`*^9, 
  3.733511922374456*^9},
 CellLabel->"Out[96]=",
 CellID->1122755817,ExpressionUUID->"25d831cc-9e10-4c4e-8465-3410c45d21c7"]
}, Open  ]],

Cell[TextData[{
 "The difference is that ",
 Cell[BoxData[
 "flt"], "InlineCode",ExpressionUUID->
  "1d16ab72-9d9c-4032-aa88-d6a5fc5c00a4"],
 " can detect when a point is not in the domain whereas ",
 ButtonBox["TransformationFunction",
  BaseStyle->"Link"],
 " returns an error message:"
}], "CodeCaption",
 CellChangeTimes->{{3.727091358734476*^9, 3.727091394125083*^9}, {
  3.727091455486936*^9, 3.727091463369736*^9}, {3.727091701309598*^9, 
  3.727091726782476*^9}, {3.729024222797296*^9, 3.729024228768416*^9}, {
  3.738000149854854*^9, 3.73800015082084*^9}},
 CellID->1146204020,ExpressionUUID->"93a1d094-183f-449f-87dc-80d8deb5da12"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"q", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], " ", ",", 
     RowBox[{"1", "/", "3"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"flt", "[", 
  RowBox[{"q", ",", "A"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TransformationFunction", "[", "A", "]"}], "[", "q", 
  "]"}]}], "Input",
 CellChangeTimes->{{3.727091402325142*^9, 3.727091437846313*^9}},
 CellLabel->"In[97]:=",
 CellID->1407173674,ExpressionUUID->"39b7bf62-7f93-4669-9eaf-4b1d095b9462"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.727091439247336*^9, 3.729350696663457*^9, 
  3.729350983123309*^9, 3.729351045443425*^9, 3.7293511059780397`*^9, 
  3.729351660373097*^9, 3.7293519417142563`*^9, 3.733160476683132*^9, 
  3.7331607919440193`*^9, 3.7331612050819683`*^9, 3.7331612684441643`*^9, 
  3.733161556712452*^9, 3.733161769024041*^9, 3.733511922407654*^9},
 CellLabel->"Out[98]=",
 CellID->218210130,ExpressionUUID->"93df5352-02c6-448a-8bb4-97c41012bfb2"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \\\"0\\\"]\\) \
encountered.\"",2,704,55,18147825225995434468,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.733160476710721*^9, 3.7331607919453297`*^9, 
  3.733161205083523*^9, 3.7331612684466047`*^9, 3.733161556715638*^9, 
  3.733161769027689*^9},
 CellLabel->"During evaluation of In[98]:=",
 CellID->1150404615,ExpressionUUID->"de9db2e8-754a-4615-811d-9eea20cd3862"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"ComplexInfinity", ",", "ComplexInfinity"}], "}"}]], "Output",
 CellChangeTimes->{3.727091439247336*^9, 3.729350696663457*^9, 
  3.729350983123309*^9, 3.729351045443425*^9, 3.7293511059780397`*^9, 
  3.729351660373097*^9, 3.7293519417142563`*^9, 3.733160476683132*^9, 
  3.7331607919440193`*^9, 3.7331612050819683`*^9, 3.7331612684441643`*^9, 
  3.733161556712452*^9, 3.733161769024041*^9, 3.733511922457592*^9},
 CellLabel->"Out[99]=",
 CellID->1703069481,ExpressionUUID->"85118f59-a760-49c5-8bba-3093aa603600"]
}, Open  ]],

Cell[TextData[{
 "An important feature of this code is that we can transform it on the \
equation level. For this, in the affine case, we use ",
 Cell[BoxData[
 "FLT"], "InlineCode",ExpressionUUID->
  "74d6431f-fa67-4280-9836-e2952fbc9a5f"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.727091494073633*^9, 3.727091522680627*^9}, {
   3.727091571418072*^9, 3.727091612811362*^9}, {3.729024253233157*^9, 
   3.729024259832347*^9}, 3.729352227220903*^9, {3.738000266004836*^9, 
   3.738000266564253*^9}, {3.738509477631151*^9, 3.738509487091236*^9}},
 CellID->592142992,ExpressionUUID->"398f2ab0-e1fb-487a-9dc4-6e6439450ee3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FLT", "[", 
  RowBox[{
   RowBox[{"y", "-", 
    RowBox[{"x", "^", "2"}]}], ",", "A", ",", "x", ",", "y"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FLT", "[", 
  RowBox[{
   RowBox[{"y", "-", 
    RowBox[{"x", "^", "2"}]}], ",", 
   RowBox[{"N", "[", "A", "]"}], ",", "x", ",", "y"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7270919389555*^9, 3.727091956756229*^9}, {
  3.72709201624643*^9, 3.72709203112632*^9}},
 CellLabel->"In[100]:=",
 CellID->1633559794,ExpressionUUID->"db5211c1-db82-4707-a613-dc218a47ae34"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["38", "961"]}], "+", 
  FractionBox[
   RowBox[{"577", " ", "x"}], "6727"], "-", 
  FractionBox[
   RowBox[{"312", " ", 
    SuperscriptBox["x", "2"]}], "6727"], "-", 
  FractionBox[
   RowBox[{"146", " ", "y"}], "6727"], "+", 
  FractionBox[
   RowBox[{"3", " ", "x", " ", "y"}], "6727"], "-", 
  FractionBox[
   RowBox[{"67", " ", 
    SuperscriptBox["y", "2"]}], "6727"]}]], "Output",
 CellChangeTimes->{{3.729352142129704*^9, 3.729352142136644*^9}, 
   3.7331604915564528`*^9, 3.73316079196891*^9, 3.733161209100793*^9, 
   3.733161268467527*^9, {3.733161505066215*^9, 3.733161525832464*^9}, 
   3.733161556741787*^9, 3.7331617690543213`*^9, 3.733511922489307*^9},
 CellLabel->"Out[100]=",
 CellID->1826719951,ExpressionUUID->"257c187e-42dd-4507-882c-c6e424deaccb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "0.03954214360041622`"}], "+", 
  RowBox[{"0.08577374758436151`", " ", "x"}], "-", 
  RowBox[{"0.04638025865913484`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"0.021703582577672062`", " ", "y"}], "+", 
  RowBox[{"0.0004459640255685994`", " ", "x", " ", "y"}], "-", 
  RowBox[{"0.009959863237698827`", " ", 
   SuperscriptBox["y", "2"]}]}]], "Output",
 CellChangeTimes->{{3.729352142129704*^9, 3.729352142136644*^9}, 
   3.7331604915564528`*^9, 3.73316079196891*^9, 3.733161209100793*^9, 
   3.733161268467527*^9, {3.733161505066215*^9, 3.733161525832464*^9}, 
   3.733161556741787*^9, 3.7331617690543213`*^9, 3.733511922494945*^9},
 CellLabel->"Out[101]=",
 CellID->1255998945,ExpressionUUID->"eae6ca4a-47d5-4b4d-a006-8466dd9360e1"]
}, Open  ]],

Cell[TextData[{
 "If we want to include infinite points as exceptions, we can use ",
 Cell[BoxData[
 "flti"], "InlineCode",ExpressionUUID->"a7e8f805-7755-4fb9-80ac-3ed45851fd90"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.72709179737078*^9, 3.727091822488676*^9}, {
   3.729024279128772*^9, 3.729024289407463*^9}, {3.7380002770042048`*^9, 
   3.738000277900222*^9}, 3.7380004190366697`*^9},
 CellID->2081800546,ExpressionUUID->"e396858e-bf3f-43d0-9658-8653523b7f72"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"q1", "=", 
  RowBox[{"flti", "[", 
   RowBox[{"q", ",", "A"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"flti", "[", 
  RowBox[{"q1", ",", 
   RowBox[{"Inverse", "[", "A", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.727091846571552*^9, 3.727091851697373*^9}, {
  3.727091887947608*^9, 3.727091910565406*^9}},
 CellLabel->"In[102]:=",
 CellID->1873086096,ExpressionUUID->"dca9eba5-80f5-4e61-a930-5b22ece1fb6e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["41", "3"], ",", "1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.727091852454525*^9, 3.727091911360419*^9, 
  3.729350696764082*^9, 3.7293509832235613`*^9, 3.729351045542952*^9, 
  3.729351106078869*^9, 3.729351660491329*^9, 3.72935194183189*^9, 
  3.7331605028200893`*^9, 3.733160791988123*^9, 3.733161211993227*^9, 
  3.733161268477281*^9, 3.7331615567597933`*^9, 3.733161769082419*^9, 
  3.733511922528247*^9},
 CellLabel->"Out[102]=",
 CellID->1957502252,ExpressionUUID->"a4a6ff78-c101-4084-8e21-9e921cae43a1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "3"}], ",", 
   FractionBox["1", "3"]}], "}"}]], "Output",
 CellChangeTimes->{3.727091852454525*^9, 3.727091911360419*^9, 
  3.729350696764082*^9, 3.7293509832235613`*^9, 3.729351045542952*^9, 
  3.729351106078869*^9, 3.729351660491329*^9, 3.72935194183189*^9, 
  3.7331605028200893`*^9, 3.733160791988123*^9, 3.733161211993227*^9, 
  3.733161268477281*^9, 3.7331615567597933`*^9, 3.733161769082419*^9, 
  3.7335119225338984`*^9},
 CellLabel->"Out[103]=",
 CellID->290877324,ExpressionUUID->"0e5f6bd0-18ee-4e49-b06b-ca609df4a0ef"]
}, Open  ]],

Cell[TextData[{
 "If we want to work completely projectively, we can use ",
 Cell[BoxData[
 "flth"], "InlineCode",ExpressionUUID->"bc7a519a-cfca-4f97-b574-e77ac90b5234"],
 " on the point level and ",
 Cell[BoxData[
 "FLTh"], "InlineCode",ExpressionUUID->"e5985302-952b-4d3e-b70a-510b864ee2d8"],
 " on the homogeneous polynomial level:"
}], "CodeCaption",
 CellChangeTimes->{{3.727092067400908*^9, 3.727092085601924*^9}, {
   3.727092154049477*^9, 3.727092212379421*^9}, 3.72709234511094*^9, {
   3.727092433427373*^9, 3.727092452778085*^9}, {3.727092866448202*^9, 
   3.727092869141234*^9}, {3.729024294833406*^9, 3.729024319039382*^9}, 
   3.729352227256325*^9, {3.73800033230089*^9, 3.738000332852251*^9}, 
   3.7380004249886293`*^9},
 CellID->659348443,ExpressionUUID->"096e1ac5-9c38-4b59-a6f2-3a583151f412"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"flth", "[", 
  RowBox[{
   RowBox[{"Append", "[", 
    RowBox[{"p", ",", "1"}], "]"}], ",", "A"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"flth", "[", 
  RowBox[{
   RowBox[{"Append", "[", 
    RowBox[{"q", ",", "1"}], "]"}], ",", "A"}], "]"}]}], "Input",
 CellChangeTimes->{{3.727092216716979*^9, 3.727092252876465*^9}, {
  3.727092353584618*^9, 3.727092354007121*^9}, {3.727092777970746*^9, 
  3.727092806019361*^9}},
 CellLabel->"In[104]:=",
 CellID->1862985365,ExpressionUUID->"183e5b1d-a60e-4971-8e6f-afd30ead576a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "7.35034323682661`"}], ",", "18.863945704018942`", ",", 
   "7.206271436012276`"}], "}"}]], "Output",
 CellChangeTimes->{{3.727092238127624*^9, 3.727092253829333*^9}, {
   3.727092794638077*^9, 3.727092806715805*^9}, 3.729350696813703*^9, 
   3.729350983272972*^9, 3.729351045593007*^9, 3.72935110612934*^9, 
   3.7293516605417633`*^9, 3.729351941880692*^9, 3.7331605076121264`*^9, 
   3.733160566522551*^9, 3.733160792007482*^9, 3.7331612147253304`*^9, 
   3.733161268502474*^9, 3.73316155678363*^9, 3.7331617691080923`*^9, 
   3.733511922573676*^9},
 CellLabel->"Out[104]=",
 CellID->1102403896,ExpressionUUID->"535a6393-8c00-4a9d-a0bc-a4c0eaf2c548"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["41", "3"], ",", "1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.727092238127624*^9, 3.727092253829333*^9}, {
   3.727092794638077*^9, 3.727092806715805*^9}, 3.729350696813703*^9, 
   3.729350983272972*^9, 3.729351045593007*^9, 3.72935110612934*^9, 
   3.7293516605417633`*^9, 3.729351941880692*^9, 3.7331605076121264`*^9, 
   3.733160566522551*^9, 3.733160792007482*^9, 3.7331612147253304`*^9, 
   3.733161268502474*^9, 3.73316155678363*^9, 3.7331617691080923`*^9, 
   3.733511922579653*^9},
 CellLabel->"Out[105]=",
 CellID->1760857403,ExpressionUUID->"5ab78211-43b5-40da-804e-bcbbc717df16"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FLTh", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"y", " ", "z"}], "-", 
    RowBox[{"x", "^", "2"}]}], ",", "A", ",", "x", ",", "y", ",", "z"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.727092477917357*^9, 3.727092482386577*^9}, {
  3.727092817403754*^9, 3.727092844988462*^9}},
 CellLabel->"In[106]:=",
 CellID->992558205,ExpressionUUID->"ecf33abc-4df3-4aeb-9197-aa2fef87751c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"312", " ", 
     SuperscriptBox["x", "2"]}], "6727"]}], "+", 
  FractionBox[
   RowBox[{"3", " ", "x", " ", "y"}], "6727"], "-", 
  FractionBox[
   RowBox[{"67", " ", 
    SuperscriptBox["y", "2"]}], "6727"], "+", 
  FractionBox[
   RowBox[{"577", " ", "x", " ", "z"}], "6727"], "-", 
  FractionBox[
   RowBox[{"146", " ", "y", " ", "z"}], "6727"], "-", 
  FractionBox[
   RowBox[{"38", " ", 
    SuperscriptBox["z", "2"]}], "961"]}]], "Output",
 CellChangeTimes->{{3.729352190733103*^9, 3.729352190739028*^9}, 
   3.733160792026206*^9, {3.733161217241743*^9, 3.733161219929791*^9}, 
   3.733161268518943*^9, 3.733161556803351*^9, 3.733161769131913*^9, 
   3.733511922623398*^9},
 CellLabel->"Out[106]=",
 CellID->258232914,ExpressionUUID->"258dcd69-a89f-45d8-952e-a5125fd8a519"]
}, Open  ]],

Cell[TextData[{
 "Finally, in Chapter 7, we will be discussing how to transform an affine \
point in the symbolic form using ",
 Cell[BoxData[
 "flts"], "InlineCode",ExpressionUUID->"b36f3381-cac3-4561-810f-1e7eb987492b"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.727092871816329*^9, 3.727092946815252*^9}, {
   3.727093069754608*^9, 3.727093071530672*^9}, {3.729024328009728*^9, 
   3.729024329000663*^9}, 3.734797950201296*^9, {3.738000485308456*^9, 
   3.7380004858118277`*^9}, 3.738510453027754*^9},
 CellID->1448035008,ExpressionUUID->"9eb8c3e2-bf50-415a-b2fa-cc5d06962434"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"flts", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "t", "]"}], ",", 
     RowBox[{"Sin", "[", "t", "]"}]}], "}"}], ",", "A"}], "]"}]], "Input",
 CellChangeTimes->{{3.727093015828446*^9, 3.72709305390934*^9}},
 CellLabel->"In[107]:=",
 CellID->1725818244,ExpressionUUID->"100ffdfd-1e86-4528-b28e-341caee603fc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"7", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "t", "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}]}], 
    RowBox[{"8", "+", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", "t", "]"}]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", "t", "]"}]}], "-", 
     RowBox[{"6", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}]}], 
    RowBox[{"8", "+", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", "t", "]"}]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.729352201325107*^9, 3.729352201330819*^9}, 
   3.733160792043256*^9, 3.733161222844886*^9, 3.733161268534666*^9, 
   3.7331615568227663`*^9, 3.733161769149704*^9, 3.733511922657179*^9},
 CellLabel->"Out[107]=",
 CellID->56135011,ExpressionUUID->"d38dcdfc-d784-481c-8f93-3e2aa3422920"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 CellChangeTimes->{3.650270852705229*^9, 3.65115870052378*^9},
 CellID->1551895974,ExpressionUUID->"57782f3f-c8b4-4a38-824c-85781ed9da9e"],

Cell[TextData[{
 ButtonBox["For more information on linear fractional transformation, check \
out Wolfram MathWorld ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/LinearFractionalTransformation.html"], 
    None},
  ButtonNote->
   "http://mathworld.wolfram.com/LinearFractionalTransformation.html"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/sV04LrrN",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/sV04LrrN"], None},
  ButtonNote->"https://wolfr.am/sV04LrrN"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.6511948809300756`*^9, 3.6511948892178*^9}, {
   3.651194932463626*^9, 3.651194932467025*^9}, 3.655013463296049*^9, 
   3.6640102579191008`*^9, 3.697472133741184*^9, {3.711471316260997*^9, 
   3.711471335354191*^9}, 3.7114713965872097`*^9, {3.711471945695513*^9, 
   3.711471955670023*^9}, {3.711472051039448*^9, 3.711472157518298*^9}, {
   3.711472271718939*^9, 3.71147227206221*^9}, {3.7114723180866737`*^9, 
   3.7114723488541813`*^9}, 3.711472411105101*^9, 3.711472533055881*^9, 
   3.7117216626591787`*^9, {3.711721781287022*^9, 3.71172179996705*^9}, {
   3.7118030196398163`*^9, 3.711803019643268*^9}},
 CellID->813111196,ExpressionUUID->"d6c8db54-7fbc-4a43-a460-8a1b4b692d63"],

Cell[TextData[{
 ButtonBox["To see other samples from the symmetry group, try looking at the \
page about the Klein bottle ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/KleinBottle.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/KleinBottle.html"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/sV01dMoQ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/sV01dMoQ"], None},
  ButtonNote->"https://wolfr.am/sV01dMoQl"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellID->1070349993,ExpressionUUID->"bb6e9760-b184-4cd2-8157-36b33533b739"],

Cell[TextData[{
 ButtonBox["To see an excellent 3D version of a Klein bottle, try I. C. \
Antonio\[CloseCurlyQuote]s Demonstration ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/ColoredKleinBottle/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/ColoredKleinBottle/"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/vmYgN0jE",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/vmYgN0jE"], None},
  ButtonNote->"https://wolfr.am/vmYgN0jE"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.6511948809300756`*^9, 3.6511948892178*^9}, {
   3.651194932463626*^9, 3.651194932467025*^9}, 3.655013463296049*^9, 
   3.6640102579191008`*^9, 3.697472133741184*^9, {3.711471316260997*^9, 
   3.711471335354191*^9}, 3.7114713965872097`*^9, {3.711471945695513*^9, 
   3.711471955670023*^9}, {3.711472051039448*^9, 3.711472157518298*^9}, {
   3.711472271718939*^9, 3.71147227206221*^9}, {3.7114723180866737`*^9, 
   3.7114723488541813`*^9}, 3.711472411105101*^9, 3.711472533055881*^9, 
   3.7117216626591787`*^9, {3.711721781287022*^9, 3.71172179996705*^9}, {
   3.7118030196398163`*^9, 3.711803019643268*^9}},
 CellTags->"LastCellOfAPage",
 CellID->36166222,ExpressionUUID->"36bdd266-4111-4521-8b84-be90efd7fceb"]
}, Open  ]]
}, Open  ]]
},
Saveable->False,
WindowToolbars->{},
BlinkingCellInsertionPoint->False,
CellInsertionPointCell->None,
WindowSize->{830, 800},
WindowMargins->Automatic,
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"Fractional Linear Transformations",
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{"\[ThinSpace]", "\[ThinSpace]", 
          StyleBox[
          "A Numerical Approach to Real Algebraic Curves with \
\[LineSeparator]the Wolfram Language", LineSpacing -> {1, 1}, FontFamily -> 
           "Source Sans Pro", FontSize -> 24, FontColor -> GrayLevel[1]], 
          "\[ThinSpace]"}, "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {65, 75}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"05-Dayton-ClassicalInterlude.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"05-Dayton-ClassicalInterlude.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                  Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"A Classical Interlude\"", TooltipDelay -> 
              0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "A Classical Interlude", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"07-Dayton-AsymptotesConicsCubics.nb", ""},
                     FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"07-Dayton-AsymptotesConicsCubics.nb", ""},
                     FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                  "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Asymptotes, Conics, and Cubics\"", 
              TooltipDelay -> 0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "Asymptotes, Conics, and Cubics", "Tooltip"]& ]}, 
           "RowWithSeparators"], Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> RGBColor[0.2, 0.1, 0.1], 
             ImageSize -> {35, 30}, Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Introduction" :> 
          NotebookLocate[{"00a-Dayton-Introduction.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Chapter Overview and Usage Note" :> 
          NotebookLocate[{"00b-Dayton-ChapterOverview_UsageNote.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace] \
1\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Introduction to \
Numerical Plane Curves" :> 
          NotebookLocate[{"01-Dayton-PlaneCurves.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]2\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Classical vs. Numerical Perspective" :> 
          NotebookLocate[{"02-Dayton-Perspective.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]3\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Special Points and Lines" :> 
          NotebookLocate[{"03-Dayton-SpecialPointsLines.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]4\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Gauss Decomposition" :> 
          NotebookLocate[{"04-Dayton-GaussDecomposition.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]5\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]A Classical Interlude" :> 
          NotebookLocate[{"05-Dayton-ClassicalInterlude.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]6\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Fractional Linear Transformations" :> 
          NotebookLocate[{"06-Dayton-FractionalLinearTransformations.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]7\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Asymptotes, Conics, and Cubics" :> 
          NotebookLocate[{"07-Dayton-AsymptotesConicsCubics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]8\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Global Plots" :> 
          NotebookLocate[{"08-Dayton-GlobalPlots.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]9\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Harnack's Theorem and Newton Hyperbolas" :> 
          NotebookLocate[{
            "09-Dayton-HarnacksTheorem-NewtonHyperbolas.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]10\[ThickSpace]\[ThickSpace]|\[ThickSpace]\
\[ThickSpace]Final Examples" :> 
          NotebookLocate[{"10-Dayton-FinalExample.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "Appendix 1: Topics in Numerical Linear Algebra" :> 
          NotebookLocate[{"Appendix-1-Topics-NumericalLinearAlgebra.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Appendix 2: Global Functions" :> 
          NotebookLocate[{"Appendix-2-GlobalFunctions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "References" :> 
          NotebookLocate[{"References.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> RGBColor[0.2, 0.1, 0.1], 
   CellMargins -> {{0, 0}, {0, -1}}, CellFrameMargins -> {{27, 0}, {1, 7}}, 
   Background -> RGBColor[0.2, 0.1, 0.1], CellTags -> "DockedCellLogoCell"], 
  Cell["BARRY H. DAYTON", "Text", FontFamily -> "Source Sans Pro", FontWeight -> 
   "Light", FontSize -> 15, CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> 
   False, CellMargins -> {{0, 0}, {-1, -1}}, 
   CellFrameMargins -> {{27, 0}, {2, 4}}, CellFrameColor -> 
   RGBColor[0.8, 0.2, 0.2], FontTracking -> "Extended", FontColor -> 
   GrayLevel[1], Background -> RGBColor[0.8, 0.2, 0.2], CellTags -> 
   "DockedCellLogoCell"]},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page", CounterFunction :> FrontEnd`RomanNumeral], 
       "PageNumber"], 
      StyleBox[
       RowBox[{
        "    ", "A", " ", "Numerical", " ", "Approach", " ", "to", " ", 
         "Real", " ", "Algebraic", " ", "Curves", "with", "the", "Wolfram", 
         "Language"}], "Header"]}], "Header", 
    CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], None, None}, {
  None, None, 
   Cell[
    TextData[{
      StyleBox[
       RowBox[{" ", " ", "    "}], "Header"], 
      StyleBox[
       CounterBox["Page", CounterFunction :> FrontEnd`RomanNumeral], 
       "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 17}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageHeader"->True},
ShowCellBracket->Automatic,
ShowAutoSpellCheck->False,
ShowPredictiveInterface->False,
ShowSyntaxStyles->False,
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> "Verdana",
        FontSize -> 7, FontSlant -> "Plain", FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Verdana", FontSize -> 7, 
       FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "WPL Specific", "Section", 
       CellChangeTimes -> {{3.6556608433734913`*^9, 3.6556608489412746`*^9}}], 
      Cell[
       StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
       If[CurrentValue[
           EvaluationCell[], "FontFamily"] === "Source Sans Pro", Inherited, 
         If[CurrentValue[
            EvaluationCell[], "FontFamily"] === "WolframCodeSans", Inherited, 
          Inherited 0.9]], FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["CodeLink"], 
       ButtonBoxOptions -> {
        Appearance -> None, ButtonFunction :> (FEPrivate`FrontEndExecute[
           FrontEndToken["OpenHelpLink", {
             Part[#, 1], Null}]]& ), ButtonSource -> ButtonContents, 
         Evaluator -> None, Method -> "Preemptive"}], 
      Cell[
       StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
       Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxDividers -> {
          "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}]}, Closed]], 
   
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth -> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, 
       AutoStyleOptions -> {
        "FormattingErrorTooltips" -> False, "HighlightComments" -> False, 
         "HighlightEmphasizedSyntaxErrors" -> False, 
         "HighlightExcessArguments" -> False, "HighlightFormattingErrors" -> 
         False, "HighlightGlobalToLocalScopeConflicts" -> False, 
         "HighlightGraphicsCompatibilityProblems" -> False, 
         "HighlightLocalScopeConflicts" -> False, "HighlightMissingArguments" -> 
         False, "HighlightNoKernelPresent" -> False, 
         "HighlightOrderOfEvaluationConflicts" -> False, "HighlightStrings" -> 
         True, "HighlightSymbolContexts" -> False, "HighlightSymbolShadowing" -> 
         False, "HighlightSyntaxErrors" -> False, "HighlightUndefinedSymbols" -> 
         False, "HighlightUnknownOptions" -> False, 
         "HighlightUnwantedAssignments" -> False}, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey -> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey -> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 44}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       StyleData["AnswerKeyNumberedSection"], 
       CellMargins -> {{64, Inherited}, {8, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       18, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["AnswerKeySectionNumber"], CellBaseline -> Baseline, 
       FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["IndexLinkGuide"], 
       CellMargins -> {{64, Inherited}, {48, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["Index"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["IndexSubentry"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["FunctionName"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro Semibold", FontWeight -> "Bold"], 
      Cell[
       StyleData["IndexColumn"], 
       CellMargins -> {{66, 0}, {Inherited, Inherited}}, TabSpacings -> {2.}, 
       MenuSortingValue -> 10000, FontFamily -> "Source Sans Pro", 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
         GridBoxItemSize -> {"Columns" -> {{25}}}, 
         GridBoxSpacings -> {"Columns" -> {{2}}}}], 
      Cell[
       StyleData["IndexSubsection"], 
       CellMargins -> {{64, Inherited}, {9, 28}}, 
       CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
       10000, FontFamily -> "Source Sans Pro", FontSize -> 24], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {12, 32}},
           FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {6, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 67}, CounterIncrements -> 
          "Exercise", MenuSortingValue -> 10020, MenuCommandKey -> "2", 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth -> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, PageBreakBelow -> False, 
          CounterIncrements -> "Question", MenuSortingValue -> 10030, 
          MenuCommandKey -> "3", FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth -> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, LineSpacing -> {1.125, 1., 2.}, 
          MenuSortingValue -> 10032, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 14}}, FontFamily -> 
          "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Italic", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1.3, 1., 2.}, 
          MenuSortingValue -> 10010, MenuCommandKey -> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], 
          CellMargins -> {{99, Inherited}, {2, 12}}, StripStyleOnPaste -> 
          True, DefaultFormatType -> DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", PageBreakWithin -> False, GroupPageBreakWithin -> 
          False, GeneratedCell -> True, CellAutoOverwrite -> True, 
          ShowCellLabel -> False, DefaultFormatType -> 
          DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221], $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, ShowCellLabel -> False, 
          SpanMaxSize -> 1, FontSize -> 
          14, $CellContext`GeneratedCellStyles -> {
           "Output" -> "ExerciseOutput"}], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Closed]], 
      Cell[
       StyleData["ExerciseSummaryCell"], PageWidth -> 700, CellFrame -> 0, 
       CellMargins -> {{64, Inherited}, {8, 10}}, 
       CellGroupingRules -> {"SectionGrouping", 64}, PageBreakBelow -> False, 
       ShowCellLabel -> False, CellFrameMargins -> 0, ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1], 
       GridBoxOptions -> {GridBoxBackground -> {"Columns" -> {{
              RGBColor[0.990997, 0.539528, 0.155779], 
              RGBColor[0.989487, 0.434699, 0.0320439]}}, "Rows" -> {{None}}}, 
         GridBoxItemSize -> {"Columns" -> {
             Scaled[0.7], 
             Scaled[0.3]}, "Rows" -> {{Automatic}}}}], 
      Cell[
       StyleData["ExerciseSummaryHeading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1]], 
      Cell[
       StyleData["ExerciseSummarySubheading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 15, FontColor -> 
       RGBColor[1., 0.9294117647058824, 0.7215686274509804]], 
      Cell[
       StyleData["ExercisePreviewButtonText"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> "Plain", 
       FontColor -> RGBColor[0.6, 0.6, 0.6]], 
      Cell[
       StyleData["ExercisePreviewButtonTextHighlight"], ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> 
       "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            RGBColor[0.8, 0.043, 0.008]], CellMargins -> {{81, 10}, {4, 8}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            GrayLevel[0.2]], 
          CellMargins -> {{80, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 10}, {4, 1}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, Inherited}, {Inherited, 0.5 Inherited}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 10}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 15], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, CellFrameLabelMargins -> 4, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Echo"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Echo", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]]},
      Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth -> DirectedInfinity[1], 
       TextAlignment -> Left, LineSpacing -> {0.6, 1}, 
       AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth -> DirectedInfinity[1], 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       StyleData[
       "IndexNavigationLink", StyleDefinitions -> StyleData["Hyperlink"]], 
       MenuSortingValue -> None, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Crosslink"], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 1, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 1, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.95 Inherited], 
      Cell[
       StyleData["NoLabel"], ShowCellLabel -> 
       False, $CellContext`GeneratedCellStyles -> {
        "Output" -> "ExerciseOutput"}], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, 2018)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "LastCellOfAPage"->{
  Cell[488470, 10704, 1374, 26, 70, "MoreExplore",ExpressionUUID->"36bdd266-4111-4521-8b84-be90efd7fceb",
   CellTags->"LastCellOfAPage",
   CellID->36166222]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"LastCellOfAPage", 570695, 12402}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[627, 23, 647, 12, 93, "Section",ExpressionUUID->"1a49bb50-e93f-4036-aba6-a592a90f4888",
 Evaluatable->False,
 CounterAssignments->{{"Section", 5}, {"Subsection", 5}, {"Subsubsection", 5}, {"Exercise", 5}},
 CellID->282314649],
Cell[1277, 37, 1008, 16, 140, "Text",ExpressionUUID->"75b022a7-1647-41fd-98f8-248e7e4c752c"],
Cell[2288, 55, 579, 9, 115, "Text",ExpressionUUID->"f9bd700d-3538-471f-9bfa-54510f8c5074",
 CellID->1515262201]
}, Open  ]],
Cell[CellGroupData[{
Cell[2904, 69, 245, 4, 67, "Subsection",ExpressionUUID->"23a03a9d-d196-4632-b31d-5c105e07e79a"],
Cell[3152, 75, 251, 5, 40, "Text",ExpressionUUID->"3290f411-4637-43aa-a4e5-03b6b9d2b608"],
Cell[3406, 82, 1427, 44, 54, "DisplayFormula",ExpressionUUID->"d0064d62-0fd1-4094-8b0a-280bd54d3053",
 CellID->1246962250],
Cell[4836, 128, 671, 18, 69, "Text",ExpressionUUID->"f83e6f31-4a1e-4e3c-8b02-8ff1826c9506"],
Cell[5510, 148, 1985, 51, 95, "Text",ExpressionUUID->"c0d7c309-d299-4393-a5c0-13d5d4c8fc42"],
Cell[7498, 201, 270, 6, 40, "Text",ExpressionUUID->"2a40287d-647b-483c-8e38-4aeb3a98098d"],
Cell[7771, 209, 821, 26, 78, "DisplayFormula",ExpressionUUID->"21f304bc-196c-4777-a3c8-ff4ced032068",
 CellID->1343904174],
Cell[8595, 237, 423, 8, 70, "Text",ExpressionUUID->"165c182e-7bcc-4a62-b3b5-c70114689601"],
Cell[9021, 247, 664, 20, 70, "DisplayFormula",ExpressionUUID->"1f8bfd1d-44de-4c4f-a0fa-aea541ca1f71",
 CellID->949111220],
Cell[9688, 269, 280, 4, 70, "CodeCaption",ExpressionUUID->"48b6a8fb-a776-4bec-83c5-745677359f11"],
Cell[9971, 275, 1087, 31, 70, "Input",ExpressionUUID->"d368798d-20a4-43a8-8973-40076763c521",
 InitializationCell->True],
Cell[11061, 308, 212, 4, 70, "CodeCaption",ExpressionUUID->"7fdfc377-0f59-451c-9222-a69a9fb252e4"],
Cell[CellGroupData[{
Cell[11298, 316, 570, 16, 70, "Input",ExpressionUUID->"bec87b3a-5fde-423b-85b6-5e97c29a07ba"],
Cell[11871, 334, 1096, 27, 70, "Output",ExpressionUUID->"29fe9f61-e145-45e8-a21d-6b0e13ba82aa",
 CellID->949579936]
}, Open  ]],
Cell[CellGroupData[{
Cell[13004, 366, 327, 8, 70, "Input",ExpressionUUID->"a35c94e0-1509-4dd4-bcb1-8788a9b2a0db"],
Cell[13334, 376, 504, 9, 70, "Output",ExpressionUUID->"5385a228-40ca-4dea-aaaf-99d0f1f1e39a",
 CellID->1639003495]
}, Open  ]],
Cell[CellGroupData[{
Cell[13875, 390, 247, 5, 70, "Input",ExpressionUUID->"446b9662-a294-4ce0-9744-1251cd5af4f1"],
Cell[14125, 397, 531, 10, 70, "Output",ExpressionUUID->"b227dc82-83a7-4b2a-99c7-26aef01eebdd",
 CellID->959000396]
}, Open  ]],
Cell[CellGroupData[{
Cell[14693, 412, 256, 5, 70, "Input",ExpressionUUID->"1e2e71bb-41a3-4dcf-8da0-c6f619eed2be"],
Cell[14952, 419, 504, 9, 70, "Output",ExpressionUUID->"b1a12590-81e2-4e32-aa51-892aec57dcf6",
 CellID->1054884837]
}, Open  ]],
Cell[15471, 431, 917, 20, 70, "CodeCaption",ExpressionUUID->"36d0441b-7af7-4785-a604-439399bfe716"],
Cell[CellGroupData[{
Cell[16413, 455, 315, 9, 70, "Input",ExpressionUUID->"c1b4050f-acbc-45ac-9c78-ea0ccd58b606"],
Cell[16731, 466, 671, 17, 70, "Output",ExpressionUUID->"df7d87b3-36cc-48ba-8b80-5f4cdffa9c52",
 CellID->1971949474]
}, Open  ]],
Cell[CellGroupData[{
Cell[17439, 488, 268, 6, 70, "Input",ExpressionUUID->"2ce6cef2-6efd-4b29-a41e-981ff2e4c16b"],
Cell[17710, 496, 494, 10, 70, "Output",ExpressionUUID->"16f7f314-14d7-4d33-b244-ef9e7bce1d32",
 CellID->439685367],
Cell[18207, 508, 496, 10, 70, "Output",ExpressionUUID->"9e74deee-43bf-4b9b-9f9f-518d66fd265e",
 CellID->300733842]
}, Open  ]],
Cell[18718, 521, 690, 16, 70, "Text",ExpressionUUID->"6ffa1a02-60f8-45b4-99e4-93eb3bd579ea"],
Cell[CellGroupData[{
Cell[19433, 541, 839, 20, 70, "ItemNumbered",ExpressionUUID->"b2eaf707-f8a9-4b39-a471-df4dc8e68c33"],
Cell[20275, 563, 985, 25, 70, "ItemNumbered",ExpressionUUID->"67b0cefe-8894-4daf-a8a8-738a0cb39642",
 CellID->1115444364],
Cell[21263, 590, 601, 15, 70, "ItemNumbered",ExpressionUUID->"35ae3bd4-1e94-454d-9ce0-1f65b4b6284d",
 CellID->1233155251]
}, Open  ]],
Cell[21879, 608, 423, 8, 70, "Text",ExpressionUUID->"b89220d7-64c1-4f9d-b894-7dc3848ce158"],
Cell[22305, 618, 768, 15, 70, "Text",ExpressionUUID->"94329d10-2b7a-4aa4-a39b-2c0b94d85ee6"],
Cell[23076, 635, 785, 17, 70, "DisplayFormula",ExpressionUUID->"bcdb7bcc-7acc-4976-91c1-16c15ac3174d",
 CellID->90577311],
Cell[23864, 654, 1200, 20, 70, "Text",ExpressionUUID->"6d30d49e-2126-43d9-b6a2-671f22e4c9e9",
 CellID->1373146773],
Cell[25067, 676, 1137, 20, 70, "CodeCaption",ExpressionUUID->"929a291a-f8ee-4557-9940-631108bfb776",
 CellID->327709986],
Cell[CellGroupData[{
Cell[26229, 700, 258, 6, 70, "Input",ExpressionUUID->"c5510a3d-ff57-47cb-af58-0e482cacd740"],
Cell[26490, 708, 710, 17, 70, "Output",ExpressionUUID->"de761180-d8ff-45e5-b781-a3435f956cfe",
 CellID->1404661103],
Cell[27203, 727, 450, 8, 70, "Output",ExpressionUUID->"0a318bf2-897c-4292-82dd-3162480e3a7f",
 CellID->851426650]
}, Open  ]],
Cell[27668, 738, 1810, 49, 70, "Text",ExpressionUUID->"704dfdd2-3e01-453d-8f4a-41504e17ac7a"],
Cell[29481, 789, 762, 14, 70, "Text",ExpressionUUID->"6150d19b-c751-409c-8272-c54822680720"],
Cell[30246, 805, 859, 19, 70, "DisplayFormula",ExpressionUUID->"01aba291-4d1a-4687-b771-0a5791ddfa93",
 CellID->120951910],
Cell[31108, 826, 902, 15, 70, "Text",ExpressionUUID->"c7d31506-6a0a-4c31-97b2-59c9d0fbbe81",
 CellID->1221659312],
Cell[32013, 843, 392, 7, 70, "CodeCaption",ExpressionUUID->"166ca8e1-836e-4d50-9b52-47439555eb56",
 CellID->977497591],
Cell[32408, 852, 1484, 38, 70, "Input",ExpressionUUID->"df8509f9-dc1e-45a6-833b-8441c1777df0",
 InitializationCell->True],
Cell[33895, 892, 1307, 23, 70, "Text",ExpressionUUID->"12c097da-1142-42f9-86c5-86e75fcfbbd4",
 CellID->1026267757],
Cell[35205, 917, 407, 8, 70, "CodeCaption",ExpressionUUID->"ae4de914-a302-4bf6-bf82-a99c6ce4da41",
 CellID->1116831534],
Cell[CellGroupData[{
Cell[35637, 929, 252, 6, 70, "Input",ExpressionUUID->"cd30c726-f95a-4c05-b2a8-0931556c81e0"],
Cell[35892, 937, 491, 11, 70, "Output",ExpressionUUID->"40f3074c-290c-4b84-85f9-fb63bc0e9077",
 CellID->1244166589]
}, Open  ]],
Cell[CellGroupData[{
Cell[36420, 953, 308, 7, 70, "Input",ExpressionUUID->"284c8c78-5793-4f4d-bbb5-7d7c997fe8a8",
 CellID->183917385],
Cell[36731, 962, 488, 11, 70, "Output",ExpressionUUID->"6d125c40-638c-4bf4-ac4e-46536cd2a27e",
 CellID->659590484]
}, Open  ]],
Cell[CellGroupData[{
Cell[37256, 978, 319, 8, 70, "Input",ExpressionUUID->"f89a088c-0415-4e23-b9e1-d7674654f554",
 CellID->870521662],
Cell[37578, 988, 436, 8, 70, "Output",ExpressionUUID->"dd9dd7c5-ddd8-428d-9266-f4a6b5eeee23",
 CellID->426678774]
}, Open  ]],
Cell[CellGroupData[{
Cell[38051, 1001, 328, 8, 70, "Input",ExpressionUUID->"fcebdfc4-1211-461f-86fd-27f8bc7602fb",
 CellID->51486223],
Cell[38382, 1011, 434, 8, 70, "Output",ExpressionUUID->"b063d187-d325-4011-a312-d0268105e3bd",
 CellID->742257285]
}, Open  ]],
Cell[38831, 1022, 902, 19, 70, "Text",ExpressionUUID->"31ee7214-f756-402d-b528-1af299405afa"],
Cell[39736, 1043, 903, 20, 70, "Text",ExpressionUUID->"84aa54b7-6611-43b1-acf8-b9d9a5b15cf5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40676, 1068, 266, 3, 70, "Subsection",ExpressionUUID->"d00281bd-1471-432c-a881-aee2799e4dbe",
 CellID->571049554],
Cell[40945, 1073, 969, 16, 70, "Text",ExpressionUUID->"4b5dbc58-7608-4cad-b8c6-8462d3ff0ab0",
 CellID->2003433773],
Cell[41917, 1091, 3829, 104, 70, "Text",ExpressionUUID->"6130cfa6-0556-4bf9-bdad-d81de1ad322c",
 CellID->1062740437],
Cell[45749, 1197, 566, 16, 70, "DisplayFormula",ExpressionUUID->"12c9e222-cf09-4f99-91d7-90104e15d121",
 CellID->1840390777],
Cell[46318, 1215, 1819, 36, 70, "Text",ExpressionUUID->"65395a1f-3ee0-4a7c-b97d-9ee226e23607",
 CellID->1920540131],
Cell[48140, 1253, 562, 16, 70, "DisplayFormula",ExpressionUUID->"050acaf9-541a-4399-ba1e-39ea7b7f4ebb",
 CellID->2010825750],
Cell[48705, 1271, 872, 18, 70, "CodeCaption",ExpressionUUID->"41774e93-c324-45ca-8b3f-f153c5350f3a",
 CellID->603777940],
Cell[49580, 1291, 651, 19, 70, "Input",ExpressionUUID->"e51b9c48-76c9-4299-9a01-213419e0dac9",
 InitializationCell->True,
 CellID->105443599],
Cell[50234, 1312, 1279, 35, 70, "CodeCaption",ExpressionUUID->"eeb39142-46ba-43ef-b1dc-cd936518396b"],
Cell[CellGroupData[{
Cell[51538, 1351, 758, 23, 70, "Input",ExpressionUUID->"c7d29739-814c-41dd-b139-8ec691ce2d24",
 CellID->1183392164],
Cell[52299, 1376, 617, 13, 70, "Output",ExpressionUUID->"b02ec302-6dab-401a-97a1-b44759bd08c2",
 CellID->385683572]
}, Open  ]],
Cell[52931, 1392, 1682, 47, 70, "Text",ExpressionUUID->"5a1f3add-f02c-4381-97f0-d6914664549d",
 CellID->1673578066],
Cell[54616, 1441, 310, 4, 70, "CodeCaption",ExpressionUUID->"60575d6d-e6c3-40a6-96de-126b6037e2ad",
 CellID->2139834071],
Cell[54929, 1447, 343, 9, 70, "Input",ExpressionUUID->"6b7f3893-df1d-40cb-b7d9-9130090604ed",
 InitializationCell->True,
 CellID->228034918],
Cell[CellGroupData[{
Cell[55297, 1460, 388, 9, 70, "Input",ExpressionUUID->"7a691b87-7d56-4857-840b-4ad72a4d7475",
 CellID->1046888275],
Cell[55688, 1471, 662, 17, 70, "Output",ExpressionUUID->"9f1440e8-a4fd-49cf-9328-ec737e1446f6",
 CellID->1078147958]
}, Open  ]],
Cell[56365, 1491, 1406, 29, 70, "Text",ExpressionUUID->"3718a420-4f61-43d0-9b64-e78d178a1321",
 CellID->761726760],
Cell[57774, 1522, 1004, 18, 70, "CodeCaption",ExpressionUUID->"11503fb6-91a7-49b4-ba28-66a3d29f19c4",
 CellID->460431146],
Cell[58781, 1542, 1411, 38, 70, "Input",ExpressionUUID->"9189e315-828a-46fc-bdb8-201052f746cb",
 CellID->561263152],
Cell[60195, 1582, 391, 9, 70, "CodeCaption",ExpressionUUID->"d41cf21e-52e1-4223-8eb9-cb2ea50a0c9f",
 CellID->1913777443],
Cell[CellGroupData[{
Cell[60611, 1595, 640, 20, 70, "Input",ExpressionUUID->"0aa0719f-0a5d-41fb-b575-48dc62b217a2",
 CellID->1659050685],
Cell[61254, 1617, 274, 7, 70, "Output",ExpressionUUID->"68868416-ea11-423d-a570-7bcec1f79a86",
 CellID->2113200367]
}, Open  ]],
Cell[61543, 1627, 1603, 35, 70, "Text",ExpressionUUID->"0fe568d8-ee79-42be-9a76-f1405ca6b60f",
 CellID->515117492]
}, Open  ]],
Cell[CellGroupData[{
Cell[63183, 1667, 191, 3, 70, "Subsection",ExpressionUUID->"540de46e-9421-4169-841d-19d68e5c5406"],
Cell[63377, 1672, 645, 11, 70, "Text",ExpressionUUID->"2e208b28-0967-4c35-b0d1-56458252c4ca"],
Cell[CellGroupData[{
Cell[64047, 1687, 293, 5, 70, "Subsubsection",ExpressionUUID->"2ce76531-6462-42a7-9b5e-7df34c6cb304"],
Cell[64343, 1694, 1221, 26, 70, "Text",ExpressionUUID->"ef0cd685-a886-4eab-a37f-0ec1ea94aeda"],
Cell[65567, 1722, 1302, 22, 70, "Text",ExpressionUUID->"82dbccbe-13e3-4dc8-8867-c96705743cdc"],
Cell[66872, 1746, 980, 14, 70, "CodeCaption",ExpressionUUID->"491bb34c-0212-4499-ad2f-eaf9e4b98daf",
 CellID->1346752915],
Cell[67855, 1762, 838, 25, 70, "Input",ExpressionUUID->"e2a6d296-06e1-4c20-9c47-30affff26ae4",
 CellID->1032644750],
Cell[CellGroupData[{
Cell[68718, 1791, 477, 12, 70, "Input",ExpressionUUID->"8d2667f6-aa98-4068-8cc2-2414f9ee545a"],
Cell[69198, 1805, 989, 25, 70, "Output",ExpressionUUID->"876315e3-7f41-413d-8298-398125826ede",
 CellID->1474014083]
}, Open  ]],
Cell[CellGroupData[{
Cell[70224, 1835, 266, 5, 70, "Input",ExpressionUUID->"f45e9314-b437-4cf0-a4b6-114719d8a071",
 CellID->1468367643],
Cell[70493, 1842, 1102, 26, 70, "Output",ExpressionUUID->"cec76894-453a-44c5-9cc7-41b7c9c99c31",
 CellID->383341189]
}, Open  ]],
Cell[71610, 1871, 951, 18, 70, "Text",ExpressionUUID->"6afd6599-13f4-4731-aa09-f9ef851b74fc"],
Cell[72564, 1891, 1071, 28, 70, "DisplayFormula",ExpressionUUID->"129ff960-813c-43a9-adbb-deccef51720b",
 CellID->481702036],
Cell[73638, 1921, 1162, 20, 70, "Text",ExpressionUUID->"ef123c5b-1404-411f-9b0f-b6d83c01cd4c"],
Cell[74803, 1943, 1016, 16, 70, "Text",ExpressionUUID->"1d60711a-cbe6-4c00-bc9e-71b29b35e034",
 CellID->2048709178],
Cell[75822, 1961, 289, 5, 70, "CodeCaption",ExpressionUUID->"5bb1c063-2b30-4041-9ded-50409debafa7",
 CellID->285700976],
Cell[76114, 1968, 3259, 89, 70, "Input",ExpressionUUID->"069e2c96-3e5d-48db-ba54-6049e41a22cf",
 InitializationCell->True],
Cell[79376, 2059, 438, 12, 70, "Input",ExpressionUUID->"7c558668-159b-4f8d-afee-77ec6eb7b9a3"],
Cell[CellGroupData[{
Cell[79839, 2075, 277, 6, 70, "Input",ExpressionUUID->"e883e754-cae9-4c8b-837a-3a3c09b2e017",
 CellID->1649319220],
Cell[80119, 2083, 1162, 29, 70, "Output",ExpressionUUID->"04cde8bb-c666-45fe-bf10-8c860f41ba63",
 CellID->364422523]
}, Open  ]],
Cell[CellGroupData[{
Cell[81318, 2117, 311, 7, 70, "Input",ExpressionUUID->"1fe95ce0-e050-4a4f-be8a-4e2916969af4",
 CellID->1854731525],
Cell[81632, 2126, 1181, 28, 70, "Output",ExpressionUUID->"4fcf6be3-d812-4aa4-bdf5-413cb1c11287",
 CellID->225982817]
}, Open  ]],
Cell[82828, 2157, 991, 23, 70, "Text",ExpressionUUID->"280e137f-e9a6-4e84-9824-35b9255c7374",
 CellID->726092803],
Cell[83822, 2182, 1955, 42, 70, "Text",ExpressionUUID->"29711fa9-46e3-4ad9-9286-9be2cc6627ff"],
Cell[85780, 2226, 1149, 28, 70, "CodeCaption",ExpressionUUID->"21cc2311-ea27-4e51-b8e6-cd35451541e8",
 CellID->454323746],
Cell[86932, 2256, 2921, 73, 70, "Input",ExpressionUUID->"66c8f35b-e7b1-4c99-a006-6ba317b9008b",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[89878, 2333, 321, 7, 70, "Input",ExpressionUUID->"a4b23317-4fda-4241-91f5-2bc4c042a874"],
Cell[90202, 2342, 632, 14, 70, "Output",ExpressionUUID->"0588f782-e22e-4e8a-904f-830e4b634f34",
 CellID->1342117423]
}, Open  ]],
Cell[CellGroupData[{
Cell[90871, 2361, 439, 10, 70, "Input",ExpressionUUID->"b7fb96a7-a58b-497c-93c8-d01ff2e2ef1b",
 CellID->1514833937],
Cell[91313, 2373, 684, 16, 70, "Output",ExpressionUUID->"ce671ae5-eecd-4e3d-bc56-2e9d7d6090da",
 CellID->1946783920]
}, Open  ]],
Cell[CellGroupData[{
Cell[92034, 2394, 471, 8, 70, "Input",ExpressionUUID->"501cb60d-0001-424f-9e0b-4fc0cd411035",
 CellID->554882788],
Cell[92508, 2404, 1169, 27, 70, "Output",ExpressionUUID->"d96d91a6-563f-42ae-8f94-803f574d91bf",
 CellID->536497748],
Cell[93680, 2433, 1171, 27, 70, "Output",ExpressionUUID->"e33a0c9c-eb53-4882-a9b1-7bbe0689caaf",
 CellID->1781300530]
}, Open  ]],
Cell[94866, 2463, 315, 6, 70, "Text",ExpressionUUID->"9af1460b-db47-4041-abc5-d2b306f12fd8",
 CellID->546514578],
Cell[95184, 2471, 1333, 28, 70, "Text",ExpressionUUID->"d854990e-e6a1-4449-9021-0847c50c94f6"],
Cell[96520, 2501, 418, 8, 70, "Text",ExpressionUUID->"f4f369a4-422a-49cf-a400-959e951c4649"],
Cell[96941, 2511, 381, 10, 70, "DisplayFormula",ExpressionUUID->"25d241ee-0765-4251-a188-fc815e50d132",
 CellID->2043160019],
Cell[97325, 2523, 669, 13, 70, "Text",ExpressionUUID->"c4f6a034-610e-4b86-bfe0-45d4dd7316e5",
 CellID->995857870]
}, Open  ]],
Cell[CellGroupData[{
Cell[98031, 2541, 196, 3, 70, "Subsubsection",ExpressionUUID->"dbf14725-3754-41ac-b7e6-f008ff9eb8d7"],
Cell[98230, 2546, 656, 11, 70, "Text",ExpressionUUID->"ec45f3e7-3ee5-477f-9ab4-f0035d73db6d"],
Cell[98889, 2559, 779, 24, 70, "DisplayFormula",ExpressionUUID->"a0135f41-2f79-410e-b4ec-320f38acda78",
 CellID->1085437560],
Cell[99671, 2585, 1142, 27, 70, "Text",ExpressionUUID->"cf8c4d08-ff3c-421f-b3ad-5fdd6de48f10",
 CellID->597915239],
Cell[100816, 2614, 1608, 35, 70, "Text",ExpressionUUID->"16e882bf-f39f-43a7-8c67-7458583a842c"],
Cell[102427, 2651, 722, 11, 70, "CodeCaption",ExpressionUUID->"35e3b9b2-af18-47db-827b-284ede2367a6",
 CellID->1559055042],
Cell[103152, 2664, 1656, 44, 70, "Input",ExpressionUUID->"f8941ba9-2d0c-420d-ba60-bab0d3c646d2",
 InitializationCell->True],
Cell[104811, 2710, 382, 5, 70, "CodeCaption",ExpressionUUID->"12911e05-68af-4c69-a792-84e2e0e64b73",
 CellID->481081581],
Cell[CellGroupData[{
Cell[105218, 2719, 311, 8, 70, "Input",ExpressionUUID->"ebe6db0b-ea2e-45c8-9d7b-7f01f3d997d6"],
Cell[105532, 2729, 981, 24, 70, "Output",ExpressionUUID->"4acc2384-2a91-4049-9d78-53ba98f4101b",
 CellID->248484883]
}, Open  ]],
Cell[CellGroupData[{
Cell[106550, 2758, 4565, 130, 70, "Input",ExpressionUUID->"72ccd166-b020-4bf2-99f6-a029c51fdf9e"],
Cell[111118, 2890, 1284, 27, 70, "Output",ExpressionUUID->"4634a422-d965-4aa9-9eb9-204345722cf5",
 CellID->1577218813],
Cell[112405, 2919, 5645, 127, 70, "Output",ExpressionUUID->"eaecab37-90bf-45be-9a6e-5f43681b788f",
 CellID->1925935170]
}, Open  ]],
Cell[118065, 3049, 2130, 48, 70, "Text",ExpressionUUID->"e2c813c7-104f-4282-ae20-7aabcbded3d0",
 CellID->1794031519],
Cell[120198, 3099, 614, 12, 70, "Text",ExpressionUUID->"d689d368-c5b3-42ee-992e-05fbe1bb5c7a"],
Cell[120815, 3113, 622, 13, 70, "DisplayFormula",ExpressionUUID->"df7bad16-a34f-47ed-a487-2821de743cb7",
 CellID->1133957471],
Cell[121440, 3128, 732, 16, 70, "Text",ExpressionUUID->"e6d433e1-ead9-44fc-91d4-332083c9cf98",
 CellID->1253612000],
Cell[122175, 3146, 566, 11, 70, "CodeCaption",ExpressionUUID->"e8454aca-5ba3-4e3f-baa0-204a15f0773c",
 CellID->494823283],
Cell[122744, 3159, 881, 21, 70, "Input",ExpressionUUID->"2f23e18f-955a-43e7-9b03-a1624ac573ab",
 InitializationCell->True],
Cell[123628, 3182, 316, 4, 70, "CodeCaption",ExpressionUUID->"f8e4264e-36df-4f84-a7a3-632ef71f8222",
 CellID->898827428],
Cell[CellGroupData[{
Cell[123969, 3190, 700, 20, 70, "Input",ExpressionUUID->"2f718039-cfd5-4e6e-9082-57b2d990786a"],
Cell[124672, 3212, 621, 14, 70, "Output",ExpressionUUID->"f33273a4-8d3b-44c5-a788-a5350560bbbf",
 CellID->171390959]
}, Open  ]],
Cell[CellGroupData[{
Cell[125330, 3231, 343, 9, 70, "Input",ExpressionUUID->"b41641f0-bdeb-495f-9257-7909ec4b0782",
 CellID->1314761274],
Cell[125676, 3242, 801, 20, 70, "Output",ExpressionUUID->"00fff2e3-9b44-4df4-a977-f4731390fed8",
 CellID->792277286]
}, Open  ]],
Cell[CellGroupData[{
Cell[126514, 3267, 577, 13, 70, "Input",ExpressionUUID->"36ccf43c-8eb9-4557-b853-26e25919028e"],
Cell[127094, 3282, 1710, 42, 70, "Output",ExpressionUUID->"20868f25-3c7c-4494-ba7f-06f018652664",
 CellID->1405734402]
}, Open  ]],
Cell[128819, 3327, 331, 7, 70, "Text",ExpressionUUID->"ba2e84e3-9b90-4c8a-86cd-073f31c4bb02"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129187, 3339, 205, 3, 70, "Subsubsection",ExpressionUUID->"350cfe20-4828-4e8b-a7c6-9fd710627be6"],
Cell[129395, 3344, 1640, 33, 70, "Text",ExpressionUUID->"8b0b7285-5bf0-4ca8-91a3-f7982e468652"],
Cell[131038, 3379, 631, 11, 70, "CodeCaption",ExpressionUUID->"958c81bf-b992-40b1-8f84-ac98af2c6ea1",
 CellID->1291918271],
Cell[131672, 3392, 2313, 62, 70, "Input",ExpressionUUID->"414c4957-5023-4b7a-8383-a4646206cf2d",
 InitializationCell->True],
Cell[133988, 3456, 453, 9, 70, "CodeCaption",ExpressionUUID->"4ede65f0-3139-4d41-bcea-a44dd2701a10",
 CellID->1707640208],
Cell[134444, 3467, 2048, 50, 70, "Input",ExpressionUUID->"40d8f77f-31a8-4878-a65a-70471452764e",
 InitializationCell->True],
Cell[136495, 3519, 1303, 27, 70, "Text",ExpressionUUID->"c4035970-3c23-43bc-912d-750abff614a1",
 CellID->250108572],
Cell[137801, 3548, 1098, 25, 70, "CodeCaption",ExpressionUUID->"27039f4a-f86f-4d43-9e5f-4f4ee1745245"],
Cell[CellGroupData[{
Cell[138924, 3577, 579, 17, 70, "Input",ExpressionUUID->"bef2587f-587c-43ba-bb55-b45b503dade8"],
Cell[139506, 3596, 8392, 174, 70, "Output",ExpressionUUID->"838f6a50-c0f3-4d64-bad4-f81d7c809075",
 CellID->1710493767]
}, Open  ]],
Cell[CellGroupData[{
Cell[147935, 3775, 300, 8, 70, "Input",ExpressionUUID->"f43a1dcf-c276-4a49-bd8b-cc829f11ec2f"],
Cell[148238, 3785, 787, 17, 70, "Output",ExpressionUUID->"a10e0199-735c-4612-8795-d83ca393dadb",
 CellID->2052643227]
}, Open  ]],
Cell[CellGroupData[{
Cell[149062, 3807, 390, 8, 70, "Input",ExpressionUUID->"3aa6f7e8-b442-43e9-a56e-c35187865d4a",
 CellID->1733488135],
Cell[149455, 3817, 1016, 23, 70, "Output",ExpressionUUID->"e0e40616-6a2b-48e3-ba5b-1431d3843d6f",
 CellID->1597410781]
}, Open  ]],
Cell[CellGroupData[{
Cell[150508, 3845, 388, 8, 70, "Input",ExpressionUUID->"b44b6aa8-ad11-48f6-b8f9-fdd5172fb82c",
 CellID->1971929743],
Cell[150899, 3855, 968, 21, 70, "Output",ExpressionUUID->"fd7b407b-98d4-4bd8-b968-761cb7b3a138",
 CellID->1989925120]
}, Open  ]],
Cell[151882, 3879, 239, 6, 70, "Input",ExpressionUUID->"349162d0-6950-4b18-8939-da654459c477"],
Cell[CellGroupData[{
Cell[152146, 3889, 372, 9, 70, "Input",ExpressionUUID->"716d23db-f909-4f96-808d-f9708c658fd7",
 CellID->2027725351],
Cell[152521, 3900, 761, 15, 70, "Output",ExpressionUUID->"30b86860-f081-4f47-acfe-6d65e23ec4ed",
 CellID->1908657109]
}, Open  ]],
Cell[CellGroupData[{
Cell[153319, 3920, 318, 7, 70, "Input",ExpressionUUID->"8eed3f24-a169-4431-b211-f945bbf44b75",
 CellID->1649143435],
Cell[153640, 3929, 1006, 19, 70, "Output",ExpressionUUID->"130311cb-e735-4148-8814-ea511aac217d",
 CellID->1836795724]
}, Open  ]],
Cell[CellGroupData[{
Cell[154683, 3953, 318, 7, 70, "Input",ExpressionUUID->"4ad14e96-54d2-4d58-9266-c0a4d686bfee",
 CellID->1729763863],
Cell[155004, 3962, 1007, 19, 70, "Output",ExpressionUUID->"9cbb3b9b-ed61-4975-b26d-c3fe0ad81f57",
 CellID->948307643]
}, Open  ]],
Cell[CellGroupData[{
Cell[156048, 3986, 2091, 56, 70, "Input",ExpressionUUID->"6ecaa5b8-3a68-40f0-8dc0-02de87927722"],
Cell[158142, 4044, 26486, 510, 70, "Output",ExpressionUUID->"e7926b3f-8341-4ba9-b357-bb7fa8ba9e84",
 CellID->1730411514]
}, Open  ]],
Cell[184643, 4557, 2076, 37, 70, "Text",ExpressionUUID->"b957dc3d-73e4-44c9-9e83-ddabffe5b12e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[186768, 4600, 186, 3, 70, "Subsection",ExpressionUUID->"4aaffe78-1fc3-4f5b-a209-241b71ed68a7"],
Cell[186957, 4605, 425, 8, 70, "Text",ExpressionUUID->"6203e6ce-69c8-4393-b142-7a9ba185640b"],
Cell[CellGroupData[{
Cell[187407, 4617, 200, 3, 70, "Subsubsection",ExpressionUUID->"75106c9c-a408-4d76-8c03-a2afb466d36c"],
Cell[187610, 4622, 2862, 47, 70, "Text",ExpressionUUID->"82842fcc-0e0d-4e3a-afe9-0052f51548c1"],
Cell[190475, 4671, 1299, 19, 70, "Text",ExpressionUUID->"9d87ac13-e599-43c8-9186-33d59364909d",
 CellID->533988008],
Cell[191777, 4692, 1172, 15, 70, "CodeCaption",ExpressionUUID->"f381f1e6-6a56-4c90-95b0-14007181da59",
 CellID->1796972018],
Cell[192952, 4709, 6909, 185, 70, "Input",ExpressionUUID->"0ec05a6f-8863-4a01-a986-fda3240910d2",
 InitializationCell->True],
Cell[199864, 4896, 241, 4, 70, "CodeCaption",ExpressionUUID->"a45ba8a5-ee14-49d8-919b-5d00473d1794"],
Cell[200108, 4902, 372, 10, 70, "Input",ExpressionUUID->"4d49cf11-1336-49df-8d79-9498642b2284"],
Cell[CellGroupData[{
Cell[200505, 4916, 519, 8, 70, "Input",ExpressionUUID->"e79be2b0-bc96-40c0-815b-686f1c18a2c0"],
Cell[201027, 4926, 972, 19, 70, "Output",ExpressionUUID->"6f6202fa-3fc4-4d53-9c82-bd803683ea5d",
 CellID->1329001556]
}, Open  ]],
Cell[202014, 4948, 600, 11, 70, "CodeCaption",ExpressionUUID->"dea2ed95-f5a1-4ffd-a10e-68c7fea530f7"],
Cell[CellGroupData[{
Cell[202639, 4963, 582, 13, 70, "Input",ExpressionUUID->"f3d764d0-09d7-4508-a96d-aee6f3f4e42e"],
Cell[203224, 4978, 11817, 211, 70, "Output",ExpressionUUID->"65e98cea-4b09-4228-a66c-9758bd1e1ed2",
 CellID->277084545]
}, Open  ]],
Cell[CellGroupData[{
Cell[215078, 5194, 402, 7, 70, "Input",ExpressionUUID->"4bc09036-ebb4-4670-9cc8-043e8e0a7d19"],
Cell[215483, 5203, 379, 7, 70, "Output",ExpressionUUID->"72ac3328-1c59-4438-ac4d-6022de802fd7",
 CellID->1215401119]
}, Open  ]],
Cell[215877, 5213, 786, 14, 70, "Text",ExpressionUUID->"d5bdcbab-7749-4363-8e0a-5db47a3aec63",
 CellID->1164661911],
Cell[216666, 5229, 619, 12, 70, "CodeCaption",ExpressionUUID->"cc7bd85a-e4f9-471b-817f-9f37b38167db",
 CellID->254362753],
Cell[217288, 5243, 914, 26, 70, "Input",ExpressionUUID->"3bee4e76-34bb-4e7d-bfdb-52e80e1881f3"],
Cell[CellGroupData[{
Cell[218227, 5273, 524, 10, 70, "Input",ExpressionUUID->"f4e71d9f-5d90-410e-ac76-1ec888df4fd8"],
Cell[218754, 5285, 683, 13, 70, "Output",ExpressionUUID->"09158212-5c62-4e7b-8eaa-867eaf6c6c84",
 CellID->382156769],
Cell[219440, 5300, 599, 10, 70, "Output",ExpressionUUID->"750eb5df-1311-45a5-b1dd-b6fe130c6346",
 CellID->1932712053]
}, Open  ]],
Cell[CellGroupData[{
Cell[220076, 5315, 729, 13, 70, "Input",ExpressionUUID->"c3e0c2cc-68a0-4564-bd9e-30a04c6dcf54"],
Cell[220808, 5330, 782, 14, 70, "Output",ExpressionUUID->"5da8ad83-2c18-4066-8af9-f1480f1c55b9",
 CellID->253830249],
Cell[221593, 5346, 721, 12, 70, "Output",ExpressionUUID->"ce235c5f-c695-4ace-b368-f86a4a2cc52f",
 CellID->1222472001]
}, Open  ]],
Cell[222329, 5361, 802, 18, 70, "Text",ExpressionUUID->"c080e793-825c-4114-b055-5b1a5cefbefb",
 CellID->1716536722]
}, Open  ]],
Cell[CellGroupData[{
Cell[223168, 5384, 311, 5, 70, "Subsubsection",ExpressionUUID->"d7007205-086b-4e64-935c-3a56d22f5c95"],
Cell[223482, 5391, 538, 10, 70, "Text",ExpressionUUID->"4e2009e8-89b8-4375-b7ec-fc1978e64532"],
Cell[224023, 5403, 706, 13, 70, "CodeCaption",ExpressionUUID->"1b13fbfd-e9f9-46da-89ae-32dff1751fb5",
 CellID->2123183291],
Cell[224732, 5418, 2024, 55, 70, "Input",ExpressionUUID->"048e87b7-6629-464a-b316-bdf084c9edda",
 InitializationCell->True],
Cell[226759, 5475, 291, 4, 70, "CodeCaption",ExpressionUUID->"b78d96a9-b705-44a5-ad41-c02dc85aa9c5"],
Cell[227053, 5481, 1057, 31, 70, "Input",ExpressionUUID->"5d6bb617-a7f2-431e-b4b8-a37aa3a73a11"],
Cell[CellGroupData[{
Cell[228135, 5516, 451, 13, 70, "Input",ExpressionUUID->"55ce7e7b-6db1-41bf-898c-7ba0e6c25a6b"],
Cell[228589, 5531, 38710, 700, 70, "Output",ExpressionUUID->"7754c3fd-d9ac-425a-afdc-e8bc20d9da6c",
 CellID->1110869958]
}, Open  ]],
Cell[CellGroupData[{
Cell[267336, 6236, 430, 9, 70, "Input",ExpressionUUID->"a3215c97-bc72-44ed-a588-6caa661e1d7b"],
Cell[267769, 6247, 618, 11, 70, "Message",ExpressionUUID->"c52ba8b2-aa6c-440b-acda-a5fd03c5b49d",
 CellID->280728025],
Cell[268390, 6260, 4004, 100, 70, "Output",ExpressionUUID->"6fd6a198-9ece-4b9f-ac92-09a73de3b358",
 CellID->1539654935],
Cell[272397, 6362, 526, 9, 70, "Output",ExpressionUUID->"27c5c4be-c94a-4b6c-b3aa-3477024628b3",
 CellID->408047623]
}, Open  ]],
Cell[272938, 6374, 243, 4, 70, "CodeCaption",ExpressionUUID->"b74474a0-bdc6-4348-8443-b1dedd3b1ca8"],
Cell[CellGroupData[{
Cell[273206, 6382, 852, 29, 70, "Input",ExpressionUUID->"dd92152d-c868-4492-98db-990cd66d553e"],
Cell[274061, 6413, 1300, 38, 70, "Output",ExpressionUUID->"8d85b271-d091-4576-86c3-cc9fa073dc77",
 CellID->1775515605],
Cell[275364, 6453, 2701, 79, 70, "Output",ExpressionUUID->"b452ab6f-d7d8-4fae-9923-84f3d4439b05",
 CellID->1279883780]
}, Open  ]],
Cell[278080, 6535, 1257, 30, 70, "Text",ExpressionUUID->"9c06a3e8-0702-4315-875b-1eeeb36b6385"],
Cell[279340, 6567, 1032, 18, 70, "Text",ExpressionUUID->"5f4230bf-8c28-4989-b35a-051d129aa7a9",
 CellID->1855421355]
}, Open  ]],
Cell[CellGroupData[{
Cell[280409, 6590, 301, 5, 70, "Subsubsection",ExpressionUUID->"d871bfde-d8d8-45e8-a70e-742570fc9339"],
Cell[280713, 6597, 1086, 24, 70, "Text",ExpressionUUID->"e6893fcd-dba3-49ea-a0ce-bf36bc6819ea"],
Cell[281802, 6623, 582, 10, 70, "Text",ExpressionUUID->"436c58a1-aa5f-4199-9263-987ff328a3dc"],
Cell[282387, 6635, 387, 10, 70, "DisplayFormula",ExpressionUUID->"a139e8a2-4349-4b34-b219-36f0f42d196d",
 CellID->361149351],
Cell[282777, 6647, 1107, 19, 70, "Text",ExpressionUUID->"922d0ff7-b7d1-4d7f-af88-e3bcb5a5f58d"],
Cell[283887, 6668, 315, 5, 70, "CodeCaption",ExpressionUUID->"d426d778-9d34-4c15-8eb5-6c60e4971b08"],
Cell[CellGroupData[{
Cell[284227, 6677, 200, 5, 70, "Input",ExpressionUUID->"bcb09aeb-76bd-47a4-8bbe-e6fcef3dfd9d"],
Cell[284430, 6684, 523, 10, 70, "Output",ExpressionUUID->"80ba1b95-b834-4fb0-b71d-f461e14b733b",
 CellID->1391209594]
}, Open  ]],
Cell[CellGroupData[{
Cell[284990, 6699, 1122, 32, 70, "Input",ExpressionUUID->"45c39dad-835a-4696-b52e-361c55f03db3"],
Cell[286115, 6733, 1003, 21, 70, "Output",ExpressionUUID->"b0defad6-908b-49e8-8c00-5aa87c5a3ba5",
 CellID->257697822],
Cell[287121, 6756, 2213, 49, 70, "Output",ExpressionUUID->"27876cbc-6970-4ba2-bf79-20d1039c4ab9",
 CellID->1800262002],
Cell[289337, 6807, 54585, 978, 70, "Output",ExpressionUUID->"9643437e-dabe-4e31-a550-9af04d96176c",
 CellID->1106365031]
}, Open  ]],
Cell[343937, 7788, 1090, 18, 70, "Text",ExpressionUUID->"586d2125-d093-43ea-ad43-8f65e6454391"],
Cell[345030, 7808, 728, 12, 70, "Text",ExpressionUUID->"22622bc6-83c3-4131-b232-11c2e0f6b72f"],
Cell[345761, 7822, 337, 5, 70, "CodeCaption",ExpressionUUID->"2c052bb8-0532-43c4-af36-0086c5ee2fe0"],
Cell[CellGroupData[{
Cell[346123, 7831, 366, 9, 70, "Input",ExpressionUUID->"44d54922-aa02-46e7-95cc-0738bf2714b0"],
Cell[346492, 7842, 785, 17, 70, "Output",ExpressionUUID->"d42b36b3-1754-45e0-88e7-65f76d77fd21",
 CellID->1763660291]
}, Open  ]],
Cell[347292, 7862, 304, 6, 70, "CodeCaption",ExpressionUUID->"2636d03a-42c8-45c1-ab24-7616080b96c5"],
Cell[CellGroupData[{
Cell[347621, 7872, 267, 5, 70, "Input",ExpressionUUID->"62f95d44-1c86-40b1-9b2e-d4fb37d8d003"],
Cell[347891, 7879, 892, 19, 70, "Output",ExpressionUUID->"3f0bc17f-2399-41ea-96c3-3d38ba2396d7",
 CellID->121731296]
}, Open  ]],
Cell[CellGroupData[{
Cell[348820, 7903, 957, 29, 70, "Input",ExpressionUUID->"bfc96941-e4fe-4230-82d6-1bfda42136e3"],
Cell[349780, 7934, 55925, 999, 70, "Output",ExpressionUUID->"6f2ff96f-2837-4f5f-8bc2-b9d95e8d1473",
 CellID->1533459928]
}, Open  ]],
Cell[CellGroupData[{
Cell[405742, 8938, 548, 16, 70, "Input",ExpressionUUID->"48ce7425-4f7c-4c96-ae0d-edbdaedc9214"],
Cell[406293, 8956, 1032, 27, 70, "Output",ExpressionUUID->"0ad6be11-aab3-4b2b-89f2-3bbbb586b0c1",
 CellID->909762249]
}, Open  ]],
Cell[407340, 8986, 547, 12, 70, "CodeCaption",ExpressionUUID->"1e4099f9-07a9-4c20-bdcc-5c5515757a48"],
Cell[CellGroupData[{
Cell[407912, 9002, 265, 5, 70, "Input",ExpressionUUID->"8a8123ca-3250-4357-9124-7686a5807e33"],
Cell[408180, 9009, 762, 17, 70, "Output",ExpressionUUID->"3e13c645-1317-40be-8292-283395ed5baf",
 CellID->290552303]
}, Open  ]],
Cell[CellGroupData[{
Cell[408979, 9031, 955, 29, 70, "Input",ExpressionUUID->"0493bd8b-0ebb-487c-b34b-3123395a1fcb"],
Cell[409937, 9062, 52474, 959, 70, "Output",ExpressionUUID->"b09df7f0-b8a4-4718-8704-ccea89b93672",
 CellID->2082226890]
}, Open  ]],
Cell[462426, 10024, 384, 8, 70, "Text",ExpressionUUID->"c8887c8f-3629-4b20-8537-bf6944048017"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[462859, 10038, 308, 4, 70, "Subsection",ExpressionUUID->"cb6f8af2-4c42-43a1-bffa-b20035055a4a",
 CellID->370162837],
Cell[463170, 10044, 886, 14, 70, "Text",ExpressionUUID->"2eedc596-cf91-4745-bb80-e31ed2e1727a",
 CellID->1873836568],
Cell[464059, 10060, 276, 6, 70, "Text",ExpressionUUID->"3f9151b5-cd8e-4cb8-add8-83abea381e7d",
 CellID->1667332537],
Cell[464338, 10068, 1421, 44, 70, "DisplayFormula",ExpressionUUID->"5e5be858-1d53-4299-8276-ffeebc2f0dc0",
 CellID->931799694],
Cell[465762, 10114, 416, 7, 70, "Text",ExpressionUUID->"0771f5ab-5f85-4e22-8996-48da14a8da39",
 CellID->1883940441],
Cell[466181, 10123, 780, 25, 70, "DisplayFormula",ExpressionUUID->"8719d27a-337a-49bc-b67e-f375585df52e",
 CellID->1591798916],
Cell[466964, 10150, 754, 22, 70, "DisplayFormula",ExpressionUUID->"804ea643-3d1a-4620-8db9-e2b152fd854c",
 CellID->1704854264],
Cell[467721, 10174, 997, 19, 70, "Text",ExpressionUUID->"e4c2b153-1a10-4700-832c-de13382b3167",
 CellID->521770912],
Cell[468721, 10195, 853, 20, 70, "Text",ExpressionUUID->"5f3bbf55-c2c7-4e05-9cfe-b55434be465b",
 CellID->443541071],
Cell[469577, 10217, 646, 13, 70, "CodeCaption",ExpressionUUID->"79a74f9e-ee00-4692-8e3d-8391c58e1905",
 CellID->695906440],
Cell[CellGroupData[{
Cell[470248, 10234, 966, 29, 70, "Input",ExpressionUUID->"0fa58a9b-6213-46fb-9918-ac9075e7146e",
 CellID->676175092],
Cell[471217, 10265, 595, 12, 70, "Output",ExpressionUUID->"ec40fa19-0290-451c-8721-60ae4485bbe4",
 CellID->593828718],
Cell[471815, 10279, 596, 12, 70, "Output",ExpressionUUID->"25d831cc-9e10-4c4e-8465-3410c45d21c7",
 CellID->1122755817]
}, Open  ]],
Cell[472426, 10294, 641, 14, 70, "CodeCaption",ExpressionUUID->"93a1d094-183f-449f-87dc-80d8deb5da12",
 CellID->1146204020],
Cell[CellGroupData[{
Cell[473092, 10312, 523, 14, 70, "Input",ExpressionUUID->"39b7bf62-7f93-4669-9eaf-4b1d095b9462",
 CellID->1407173674],
Cell[473618, 10328, 494, 8, 70, "Output",ExpressionUUID->"93df5352-02c6-448a-8bb4-97c41012bfb2",
 CellID->218210130],
Cell[474115, 10338, 500, 10, 70, "Message",ExpressionUUID->"de9db2e8-754a-4615-811d-9eea20cd3862",
 CellID->1150404615],
Cell[474618, 10350, 551, 9, 70, "Output",ExpressionUUID->"85118f59-a760-49c5-8bba-3093aa603600",
 CellID->1703069481]
}, Open  ]],
Cell[475184, 10362, 624, 12, 70, "CodeCaption",ExpressionUUID->"398f2ab0-e1fb-487a-9dc4-6e6439450ee3",
 CellID->592142992],
Cell[CellGroupData[{
Cell[475833, 10378, 543, 14, 70, "Input",ExpressionUUID->"db5211c1-db82-4707-a613-dc218a47ae34",
 CellID->1633559794],
Cell[476379, 10394, 824, 21, 70, "Output",ExpressionUUID->"257c187e-42dd-4507-882c-c6e424deaccb",
 CellID->1826719951],
Cell[477206, 10417, 783, 15, 70, "Output",ExpressionUUID->"eae6ca4a-47d5-4b4d-a006-8466dd9360e1",
 CellID->1255998945]
}, Open  ]],
Cell[478004, 10435, 470, 9, 70, "CodeCaption",ExpressionUUID->"e396858e-bf3f-43d0-9658-8653523b7f72",
 CellID->2081800546],
Cell[CellGroupData[{
Cell[478499, 10448, 440, 10, 70, "Input",ExpressionUUID->"dca9eba5-80f5-4e61-a930-5b22ece1fb6e",
 CellID->1873086096],
Cell[478942, 10460, 577, 11, 70, "Output",ExpressionUUID->"a4a6ff78-c101-4084-8e21-9e921cae43a1",
 CellID->1957502252],
Cell[479522, 10473, 586, 12, 70, "Output",ExpressionUUID->"0e5f6bd0-18ee-4e49-b06b-ca609df4a0ef",
 CellID->290877324]
}, Open  ]],
Cell[480123, 10488, 811, 15, 70, "CodeCaption",ExpressionUUID->"096e1ac5-9c38-4b59-a6f2-3a583151f412",
 CellID->659348443],
Cell[CellGroupData[{
Cell[480959, 10507, 549, 14, 70, "Input",ExpressionUUID->"183e5b1d-a60e-4971-8e6f-afd30ead576a",
 CellID->1862985365],
Cell[481511, 10523, 708, 13, 70, "Output",ExpressionUUID->"535a6393-8c00-4a9d-a0bc-a4c0eaf2c548",
 CellID->1102403896],
Cell[482222, 10538, 657, 12, 70, "Output",ExpressionUUID->"5ab78211-43b5-40da-804e-bcbbc717df16",
 CellID->1760857403]
}, Open  ]],
Cell[CellGroupData[{
Cell[482916, 10555, 402, 10, 70, "Input",ExpressionUUID->"ecf33abc-4df3-4aeb-9197-aa2fef87751c",
 CellID->992558205],
Cell[483321, 10567, 848, 23, 70, "Output",ExpressionUUID->"258dcd69-a89f-45d8-952e-a5125fd8a519",
 CellID->258232914]
}, Open  ]],
Cell[484184, 10593, 584, 11, 70, "CodeCaption",ExpressionUUID->"9eb8c3e2-bf50-415a-b2fa-cc5d06962434",
 CellID->1448035008],
Cell[CellGroupData[{
Cell[484793, 10608, 361, 9, 70, "Input",ExpressionUUID->"100ffdfd-1e86-4528-b28e-341caee603fc",
 CellID->1725818244],
Cell[485157, 10619, 1029, 29, 70, "Output",ExpressionUUID->"d38dcdfc-d784-481c-8f93-3e2aa3422920",
 CellID->56135011]
}, Open  ]],
Cell[CellGroupData[{
Cell[486223, 10653, 184, 2, 70, "MoreExploreSection",ExpressionUUID->"57782f3f-c8b4-4a38-824c-85781ed9da9e",
 CellID->1551895974],
Cell[486410, 10657, 1361, 27, 70, "MoreExplore",ExpressionUUID->"d6c8db54-7fbc-4a43-a460-8a1b4b692d63",
 CellID->813111196],
Cell[487774, 10686, 693, 16, 70, "MoreExplore",ExpressionUUID->"bb6e9760-b184-4cd2-8157-36b33533b739",
 CellID->1070349993],
Cell[488470, 10704, 1374, 26, 70, "MoreExplore",ExpressionUUID->"36bdd266-4111-4521-8b84-be90efd7fceb",
 CellTags->"LastCellOfAPage",
 CellID->36166222]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

